""" Cisco_IOS_XR_ipv6_ospfv3_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv6\-ospfv3 package operational data.

This module contains definitions
for the following management objects\:
  ospfv3\: OSPFv3 operational information 

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class ImStateEnum(Enum):
    """
    ImStateEnum

    Im state enum

    .. data:: im_state_not_ready = 0

    	im state not ready

    .. data:: im_state_admin_down = 1

    	im state admin down

    .. data:: im_state_down = 2

    	im state down

    .. data:: im_state_up = 3

    	im state up

    .. data:: im_state_shutdown = 4

    	im state shutdown

    .. data:: im_state_err_disable = 5

    	im state err disable

    .. data:: im_state_down_immediate = 6

    	im state down immediate

    .. data:: im_state_down_immediate_admin = 7

    	im state down immediate admin

    .. data:: im_state_down_graceful = 8

    	im state down graceful

    .. data:: im_state_begin_shutdown = 9

    	im state begin shutdown

    .. data:: im_state_end_shutdown = 10

    	im state end shutdown

    .. data:: im_state_begin_error_disable = 11

    	im state begin error disable

    .. data:: im_state_end_error_disable = 12

    	im state end error disable

    .. data:: im_state_begin_down_graceful = 13

    	im state begin down graceful

    .. data:: im_state_reset = 14

    	im state reset

    .. data:: im_state_operational = 15

    	im state operational

    .. data:: im_state_not_operational = 16

    	im state not operational

    .. data:: im_state_unknown = 17

    	im state unknown

    .. data:: im_state_last = 18

    	im state last

    """

    im_state_not_ready = Enum.YLeaf(0, "im-state-not-ready")

    im_state_admin_down = Enum.YLeaf(1, "im-state-admin-down")

    im_state_down = Enum.YLeaf(2, "im-state-down")

    im_state_up = Enum.YLeaf(3, "im-state-up")

    im_state_shutdown = Enum.YLeaf(4, "im-state-shutdown")

    im_state_err_disable = Enum.YLeaf(5, "im-state-err-disable")

    im_state_down_immediate = Enum.YLeaf(6, "im-state-down-immediate")

    im_state_down_immediate_admin = Enum.YLeaf(7, "im-state-down-immediate-admin")

    im_state_down_graceful = Enum.YLeaf(8, "im-state-down-graceful")

    im_state_begin_shutdown = Enum.YLeaf(9, "im-state-begin-shutdown")

    im_state_end_shutdown = Enum.YLeaf(10, "im-state-end-shutdown")

    im_state_begin_error_disable = Enum.YLeaf(11, "im-state-begin-error-disable")

    im_state_end_error_disable = Enum.YLeaf(12, "im-state-end-error-disable")

    im_state_begin_down_graceful = Enum.YLeaf(13, "im-state-begin-down-graceful")

    im_state_reset = Enum.YLeaf(14, "im-state-reset")

    im_state_operational = Enum.YLeaf(15, "im-state-operational")

    im_state_not_operational = Enum.YLeaf(16, "im-state-not-operational")

    im_state_unknown = Enum.YLeaf(17, "im-state-unknown")

    im_state_last = Enum.YLeaf(18, "im-state-last")


class IpfrrTbrkr(Enum):
    """
    IpfrrTbrkr

    FRR Tiebreakers

    .. data:: downstream = 0

    	Downsteram

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: backup_metric = 2

    	Backup metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondary path

    .. data:: srlg_disjoint = 6

    	SRLG disjoint

    .. data:: tunnel = 7

    	Tunnel

    """

    downstream = Enum.YLeaf(0, "downstream")

    line_card_disjoint = Enum.YLeaf(1, "line-card-disjoint")

    backup_metric = Enum.YLeaf(2, "backup-metric")

    node_protect = Enum.YLeaf(3, "node-protect")

    primary_path = Enum.YLeaf(4, "primary-path")

    secondary_path = Enum.YLeaf(5, "secondary-path")

    srlg_disjoint = Enum.YLeaf(6, "srlg-disjoint")

    tunnel = Enum.YLeaf(7, "tunnel")


class OspfLsaSyncState(Enum):
    """
    OspfLsaSyncState

    LSA synchronization states

    .. data:: none = 0

    	State not set

    .. data:: out_of_sync = 1

    	LSA out of sync with active

    .. data:: in_sync = 2

    	LSA in sync with active

    .. data:: nsr_ack_pending = 3

    	NSR ack pending for LSA sync

    """

    none = Enum.YLeaf(0, "none")

    out_of_sync = Enum.YLeaf(1, "out-of-sync")

    in_sync = Enum.YLeaf(2, "in-sync")

    nsr_ack_pending = Enum.YLeaf(3, "nsr-ack-pending")


class OspfNsrSchedPri(Enum):
    """
    OspfNsrSchedPri

    Ospf nsr sched pri

    .. data:: ospf_nsr_stats_sched_pri_hi = 0

    	ospf nsr stats sched pri hi

    .. data:: ospf_nsr_stats_sched_pri_med = 1

    	ospf nsr stats sched pri med

    .. data:: ospf_nsr_stats_sched_pri_low = 2

    	ospf nsr stats sched pri low

    .. data:: ospf_nsr_stats_sched_pri_max = 3

    	ospf nsr stats sched pri max

    """

    ospf_nsr_stats_sched_pri_hi = Enum.YLeaf(0, "ospf-nsr-stats-sched-pri-hi")

    ospf_nsr_stats_sched_pri_med = Enum.YLeaf(1, "ospf-nsr-stats-sched-pri-med")

    ospf_nsr_stats_sched_pri_low = Enum.YLeaf(2, "ospf-nsr-stats-sched-pri-low")

    ospf_nsr_stats_sched_pri_max = Enum.YLeaf(3, "ospf-nsr-stats-sched-pri-max")


class Ospfv3AreaRangeStatus(Enum):
    """
    Ospfv3AreaRangeStatus

    Ospfv3 area range status

    .. data:: advertise = 1

    	Advertise this range

    .. data:: do_not_advertise = 2

    	Do not advertise this range

    """

    advertise = Enum.YLeaf(1, "advertise")

    do_not_advertise = Enum.YLeaf(2, "do-not-advertise")


class Ospfv3BorderRoute(Enum):
    """
    Ospfv3BorderRoute

    OSPFv3 border route destination types

    .. data:: abr = 1

    	Area border router

    .. data:: asbr = 2

    	Area system boundary router

    .. data:: abr_asbr = 3

    	Area border router and area system boundary

    	router

    """

    abr = Enum.YLeaf(1, "abr")

    asbr = Enum.YLeaf(2, "asbr")

    abr_asbr = Enum.YLeaf(3, "abr-asbr")


class Ospfv3DefaultMetric(Enum):
    """
    Ospfv3DefaultMetric

    OSPFv3 default metric types 

    .. data:: type_none = 0

    	OSPFv3 default metric type None 

    .. data:: type1 = 1

    	OSPFv3 default metric type 1 

    .. data:: type2 = 2

    	OSPFv3 default metric type 2 

    """

    type_none = Enum.YLeaf(0, "type-none")

    type1 = Enum.YLeaf(1, "type1")

    type2 = Enum.YLeaf(2, "type2")


class Ospfv3GracefulRestartReason(Enum):
    """
    Ospfv3GracefulRestartReason

    Reason for router restart

    .. data:: grace_reason_unknown = 0

    	Grace reason unknown

    .. data:: grace_reason_software_restart = 1

    	Grace reason software restart

    .. data:: grace_reason_software_upgrade = 2

    	Software reload/upgrade, RFC 3623

    .. data:: grace_reason_switchover = 3

    	Switch to redundant control processor

    """

    grace_reason_unknown = Enum.YLeaf(0, "grace-reason-unknown")

    grace_reason_software_restart = Enum.YLeaf(1, "grace-reason-software-restart")

    grace_reason_software_upgrade = Enum.YLeaf(2, "grace-reason-software-upgrade")

    grace_reason_switchover = Enum.YLeaf(3, "grace-reason-switchover")


class Ospfv3GracefulShutdownState(Enum):
    """
    Ospfv3GracefulShutdownState

    Graceful Shutdown state

    .. data:: init = 0

    	Init

    .. data:: normal = 1

    	Normal

    .. data:: flushing = 2

    	Flushing

    .. data:: empty_hellos = 3

    	Empty Hellos

    .. data:: quiet = 4

    	Quiet

    """

    init = Enum.YLeaf(0, "init")

    normal = Enum.YLeaf(1, "normal")

    flushing = Enum.YLeaf(2, "flushing")

    empty_hellos = Enum.YLeaf(3, "empty-hellos")

    quiet = Enum.YLeaf(4, "quiet")


class Ospfv3Interface(Enum):
    """
    Ospfv3Interface

    OSPFv3 neighbor interface types

    .. data:: none = 0

    	None

    .. data:: broadcast = 1

    	Broadcast

    .. data:: non_broadcast = 2

    	Non broadcast

    .. data:: point_to_point = 3

    	Point To Point

    .. data:: point_to_multipoint = 4

    	Point To Multipoint

    .. data:: point_to_multipoint_non_broadcast = 5

    	Point-To-Multipoint Non broadcast

    .. data:: virtual_link = 6

    	Virtual link

    .. data:: loopback_interface = 7

    	Loopback

    .. data:: mpls_traffic_engineering = 8

    	MPLS traffic engineering

    .. data:: sham_link = 9

    	Sham link

    """

    none = Enum.YLeaf(0, "none")

    broadcast = Enum.YLeaf(1, "broadcast")

    non_broadcast = Enum.YLeaf(2, "non-broadcast")

    point_to_point = Enum.YLeaf(3, "point-to-point")

    point_to_multipoint = Enum.YLeaf(4, "point-to-multipoint")

    point_to_multipoint_non_broadcast = Enum.YLeaf(5, "point-to-multipoint-non-broadcast")

    virtual_link = Enum.YLeaf(6, "virtual-link")

    loopback_interface = Enum.YLeaf(7, "loopback-interface")

    mpls_traffic_engineering = Enum.YLeaf(8, "mpls-traffic-engineering")

    sham_link = Enum.YLeaf(9, "sham-link")


class Ospfv3InterfaceState(Enum):
    """
    Ospfv3InterfaceState

    OSPFv3 interface states

    .. data:: down = 0

    	Down

    .. data:: loopback = 1

    	Loopback

    .. data:: waiting = 2

    	Waiting

    .. data:: point_to_multipoint = 3

    	Point To Multipoint

    .. data:: point_to_point = 4

    	Point To Point

    .. data:: designated_router = 5

    	Designated router

    .. data:: backup_designated_router = 6

    	Backup designated router

    .. data:: other_designated_router = 7

    	Other designated router

    """

    down = Enum.YLeaf(0, "down")

    loopback = Enum.YLeaf(1, "loopback")

    waiting = Enum.YLeaf(2, "waiting")

    point_to_multipoint = Enum.YLeaf(3, "point-to-multipoint")

    point_to_point = Enum.YLeaf(4, "point-to-point")

    designated_router = Enum.YLeaf(5, "designated-router")

    backup_designated_router = Enum.YLeaf(6, "backup-designated-router")

    other_designated_router = Enum.YLeaf(7, "other-designated-router")


class Ospfv3Link(Enum):
    """
    Ospfv3Link

    OSPFV3 Link type

    .. data:: link_router = 1

    	Router link

    .. data:: link_trans_net = 2

    	Transit network link

    .. data:: link_virtual_link = 4

    	Virutal link

    """

    link_router = Enum.YLeaf(1, "link-router")

    link_trans_net = Enum.YLeaf(2, "link-trans-net")

    link_virtual_link = Enum.YLeaf(4, "link-virtual-link")


class Ospfv3Lsa(Enum):
    """
    Ospfv3Lsa

    Ospfv3 lsa

    .. data:: link_lsa = 8

    	Link LSA

    .. data:: grace_lsa = 11

    	Grace LSA

    .. data:: router = 8193

    	Router LSA

    .. data:: network = 8194

    	Network LSA

    .. data:: inter_area_prefix = 8195

    	Inter-Area Prefix LSA

    .. data:: inter_area_router = 8196

    	Inter-Area Router LSA

    .. data:: nssa_external = 8199

    	NSSA External LSA

    .. data:: intra_area_prefix = 8201

    	Intra-Area Prefix LSA

    .. data:: external = 16389

    	External LSA

    .. data:: opaque_link = 32768

    	Opaque LSALink Scope

    .. data:: opaque_area = 40960

    	Opaque LSA Area Scope

    .. data:: opaque_as = 49152

    	Opaque LSA AS Scope

    .. data:: unknown = 57344

    	Unknown Reserved Scope LSAs

    """

    link_lsa = Enum.YLeaf(8, "link-lsa")

    grace_lsa = Enum.YLeaf(11, "grace-lsa")

    router = Enum.YLeaf(8193, "router")

    network = Enum.YLeaf(8194, "network")

    inter_area_prefix = Enum.YLeaf(8195, "inter-area-prefix")

    inter_area_router = Enum.YLeaf(8196, "inter-area-router")

    nssa_external = Enum.YLeaf(8199, "nssa-external")

    intra_area_prefix = Enum.YLeaf(8201, "intra-area-prefix")

    external = Enum.YLeaf(16389, "external")

    opaque_link = Enum.YLeaf(32768, "opaque-link")

    opaque_area = Enum.YLeaf(40960, "opaque-area")

    opaque_as = Enum.YLeaf(49152, "opaque-as")

    unknown = Enum.YLeaf(57344, "unknown")


class Ospfv3Lsa1(Enum):
    """
    Ospfv3Lsa1

    OSPFv3 LSA types

    .. data:: link = 8

    	Link LSA

    .. data:: grace = 11

    	Grace LSA

    .. data:: router = 8193

    	Router LSA

    .. data:: network = 8194

    	Network LSA

    .. data:: inter_area_prefix = 8195

    	Inter area prefix LSA

    .. data:: inter_area_router = 8196

    	Inter area router LSA

    .. data:: mospf = 8198

    	MOSPF LSA

    .. data:: type7_external = 8199

    	Type-7 External LSA

    .. data:: lsa_prefix = 8201

    	Prefix LSA

    .. data:: as_external = 16389

    	AS external LSA

    .. data:: unknown_link = 32768

    	Unknown link LSA

    .. data:: unknown_area = 40960

    	Unknown area LSA

    .. data:: unknown_as = 49152

    	Unknown AS LSA

    .. data:: unknown_type = 57344

    	Unknown type LSA

    """

    link = Enum.YLeaf(8, "link")

    grace = Enum.YLeaf(11, "grace")

    router = Enum.YLeaf(8193, "router")

    network = Enum.YLeaf(8194, "network")

    inter_area_prefix = Enum.YLeaf(8195, "inter-area-prefix")

    inter_area_router = Enum.YLeaf(8196, "inter-area-router")

    mospf = Enum.YLeaf(8198, "mospf")

    type7_external = Enum.YLeaf(8199, "type7-external")

    lsa_prefix = Enum.YLeaf(8201, "lsa-prefix")

    as_external = Enum.YLeaf(16389, "as-external")

    unknown_link = Enum.YLeaf(32768, "unknown-link")

    unknown_area = Enum.YLeaf(40960, "unknown-area")

    unknown_as = Enum.YLeaf(49152, "unknown-as")

    unknown_type = Enum.YLeaf(57344, "unknown-type")


class Ospfv3LsaInfoTypes(Enum):
    """
    Ospfv3LsaInfoTypes

    OSPFv3 LSA format types

    .. data:: mgmt_lsa_lsasum_type = 0

    	Summary information of LSAs

    .. data:: mgmt_lsa_link_type = 8

    	Link LSA

    .. data:: mgmt_lsa_gr_type = 11

    	Grace LSA

    .. data:: mgmt_lsa_rtr_type = 8193

    	Router LSA

    .. data:: mgmt_lsa_net_type = 8194

    	Network LSA

    .. data:: mgmt_lsa_iapfx_type = 8195

    	Inter Area Prefix Summary LSA

    .. data:: mgmt_lsa_iartr_type = 8196

    	Inter Area Router Summay LSA

    .. data:: mgmt_lsa_nssaext_type = 8199

    	NSSA external LSA

    .. data:: mgmt_lsa_prefix_type = 8201

    	Intra Area Prefix LSA

    .. data:: mgmt_lsa_ext_type = 16389

    	Type 5 External LSA

    .. data:: mgmt_lsa_unk_link_type = 32768

    	Opaque Link scope LSA

    .. data:: mgmt_lsa_unk_area_type = 40960

    	Opaque Area scope LSA

    .. data:: mgmt_lsa_unk_as_type = 49152

    	Opaque AS scope LSA

    .. data:: mgmt_lsa_unk_type = 57344

    	Opaque Reserved scope LSA

    """

    mgmt_lsa_lsasum_type = Enum.YLeaf(0, "mgmt-lsa-lsasum-type")

    mgmt_lsa_link_type = Enum.YLeaf(8, "mgmt-lsa-link-type")

    mgmt_lsa_gr_type = Enum.YLeaf(11, "mgmt-lsa-gr-type")

    mgmt_lsa_rtr_type = Enum.YLeaf(8193, "mgmt-lsa-rtr-type")

    mgmt_lsa_net_type = Enum.YLeaf(8194, "mgmt-lsa-net-type")

    mgmt_lsa_iapfx_type = Enum.YLeaf(8195, "mgmt-lsa-iapfx-type")

    mgmt_lsa_iartr_type = Enum.YLeaf(8196, "mgmt-lsa-iartr-type")

    mgmt_lsa_nssaext_type = Enum.YLeaf(8199, "mgmt-lsa-nssaext-type")

    mgmt_lsa_prefix_type = Enum.YLeaf(8201, "mgmt-lsa-prefix-type")

    mgmt_lsa_ext_type = Enum.YLeaf(16389, "mgmt-lsa-ext-type")

    mgmt_lsa_unk_link_type = Enum.YLeaf(32768, "mgmt-lsa-unk-link-type")

    mgmt_lsa_unk_area_type = Enum.YLeaf(40960, "mgmt-lsa-unk-area-type")

    mgmt_lsa_unk_as_type = Enum.YLeaf(49152, "mgmt-lsa-unk-as-type")

    mgmt_lsa_unk_type = Enum.YLeaf(57344, "mgmt-lsa-unk-type")


class Ospfv3NeighborState(Enum):
    """
    Ospfv3NeighborState

    OSPFv3 neighbor states

    .. data:: neigbhor_down = 0

    	Down

    .. data:: attempt = 1

    	Attempting

    .. data:: init = 2

    	Initializing

    .. data:: two_way = 3

    	2 Way

    .. data:: exstart = 4

    	Exstart

    .. data:: exchange = 5

    	Exchange

    .. data:: loading = 6

    	Loading

    .. data:: full = 7

    	Full

    .. data:: sc_virtual = 8

    	SCVirtual

    """

    neigbhor_down = Enum.YLeaf(0, "neigbhor-down")

    attempt = Enum.YLeaf(1, "attempt")

    init = Enum.YLeaf(2, "init")

    two_way = Enum.YLeaf(3, "two-way")

    exstart = Enum.YLeaf(4, "exstart")

    exchange = Enum.YLeaf(5, "exchange")

    loading = Enum.YLeaf(6, "loading")

    full = Enum.YLeaf(7, "full")

    sc_virtual = Enum.YLeaf(8, "sc-virtual")


class PrefixPriority(Enum):
    """
    PrefixPriority

    Prefix priority

    .. data:: critical = 0

    	Critical priority

    .. data:: high = 1

    	High priority

    .. data:: medium = 2

    	Medium priority

    .. data:: low = 3

    	Low priority

    """

    critical = Enum.YLeaf(0, "critical")

    high = Enum.YLeaf(1, "high")

    medium = Enum.YLeaf(2, "medium")

    low = Enum.YLeaf(3, "low")


class StubRouterAbrOffReason(Enum):
    """
    StubRouterAbrOffReason

    Reason to exiting stub router mode

    .. data:: init_delay = 2

    	Initial delay when stub router mode is

    	activated

    .. data:: no_neighbor = 3

    	No neighbor present

    .. data:: no_full_neighbor = 4

    	No neighbor in FULL state present

    .. data:: new_neighbor = 5

    	A new neighbor discovered less than 60 seconds

    	ago

    .. data:: full_neighbor = 6

    	A neighbor transitioned to FULL state less than

    	60 seconds ago

    """

    init_delay = Enum.YLeaf(2, "init-delay")

    no_neighbor = Enum.YLeaf(3, "no-neighbor")

    no_full_neighbor = Enum.YLeaf(4, "no-full-neighbor")

    new_neighbor = Enum.YLeaf(5, "new-neighbor")

    full_neighbor = Enum.YLeaf(6, "full-neighbor")


class StubRouterExitReason(Enum):
    """
    StubRouterExitReason

    Reason to exiting stub router mode

    .. data:: none = 0

    	No reason

    .. data:: bgp = 1

    	BGP has converged

    .. data:: timer = 2

    	Stub Router timer has expired

    .. data:: configuration = 3

    	Configuration has changed

    .. data:: cleared = 4

    	Process has been cleared

    .. data:: override = 5

    	Preempted by always

    """

    none = Enum.YLeaf(0, "none")

    bgp = Enum.YLeaf(1, "bgp")

    timer = Enum.YLeaf(2, "timer")

    configuration = Enum.YLeaf(3, "configuration")

    cleared = Enum.YLeaf(4, "cleared")

    override = Enum.YLeaf(5, "override")


class StubRouterMode(Enum):
    """
    StubRouterMode

    Stub Router mode

    .. data:: rbit = 0

    	Stub Router mode r-bit

    .. data:: v6bit = 1

    	Stub Router mode v6-bit

    .. data:: max_metric = 2

    	Stub Router mode max-metric

    .. data:: none = 3

    	Stub Router not configured

    """

    rbit = Enum.YLeaf(0, "rbit")

    v6bit = Enum.YLeaf(1, "v6bit")

    max_metric = Enum.YLeaf(2, "max-metric")

    none = Enum.YLeaf(3, "none")


class StubRouterTrigger(Enum):
    """
    StubRouterTrigger

    Trigger for entering stub router mode

    .. data:: on_proc_migration = 0

    	Process migration

    .. data:: on_proc_restart = 1

    	Process restart

    .. data:: on_switchover = 2

    	RP switchover

    .. data:: on_startup = 3

    	Router startup

    .. data:: always = 4

    	Always on

    .. data:: none = 5

    	No trigger

    """

    on_proc_migration = Enum.YLeaf(0, "on-proc-migration")

    on_proc_restart = Enum.YLeaf(1, "on-proc-restart")

    on_switchover = Enum.YLeaf(2, "on-switchover")

    on_startup = Enum.YLeaf(3, "on-startup")

    always = Enum.YLeaf(4, "always")

    none = Enum.YLeaf(5, "none")



class Ospfv3(Entity):
    """
    OSPFv3 operational information 
    
    .. attribute:: processes
    
    	OSPFv3 Process Table
    	**type**\:   :py:class:`Processes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes>`
    
    

    """

    _prefix = 'ipv6-ospfv3-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Ospfv3, self).__init__()
        self._top_entity = None

        self.yang_name = "ospfv3"
        self.yang_parent_name = "Cisco-IOS-XR-ipv6-ospfv3-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"processes" : ("processes", Ospfv3.Processes)}
        self._child_list_classes = {}

        self.processes = Ospfv3.Processes()
        self.processes.parent = self
        self._children_name_map["processes"] = "processes"
        self._children_yang_names.add("processes")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3"


    class Processes(Entity):
        """
        OSPFv3 Process Table
        
        .. attribute:: process
        
        	OSPFv3 Operational data for a particular OSPFv3 process 
        	**type**\: list of    :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process>`
        
        

        """

        _prefix = 'ipv6-ospfv3-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Ospfv3.Processes, self).__init__()

            self.yang_name = "processes"
            self.yang_parent_name = "ospfv3"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"process" : ("process", Ospfv3.Processes.Process)}

            self.process = YList(self)
            self._segment_path = lambda: "processes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Ospfv3.Processes, [], name, value)


        class Process(Entity):
            """
            OSPFv3 Operational data for a particular OSPFv3
            process 
            
            .. attribute:: process_name  <key>
            
            	Particular OSPFv3 process
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: default_vrf
            
            	Operational data for the default VRF (instance) in the OSPFv3 process
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf>`
            
            .. attribute:: statistics
            
            	Container for Statistics
            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics>`
            
            .. attribute:: vrfs
            
            	Table for each VRF
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs>`
            
            

            """

            _prefix = 'ipv6-ospfv3-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ospfv3.Processes.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "processes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"default-vrf" : ("default_vrf", Ospfv3.Processes.Process.DefaultVrf), "statistics" : ("statistics", Ospfv3.Processes.Process.Statistics), "vrfs" : ("vrfs", Ospfv3.Processes.Process.Vrfs)}
                self._child_list_classes = {}

                self.process_name = YLeaf(YType.str, "process-name")

                self.default_vrf = Ospfv3.Processes.Process.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._children_yang_names.add("default-vrf")

                self.statistics = Ospfv3.Processes.Process.Statistics()
                self.statistics.parent = self
                self._children_name_map["statistics"] = "statistics"
                self._children_yang_names.add("statistics")

                self.vrfs = Ospfv3.Processes.Process.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
                self._children_yang_names.add("vrfs")
                self._segment_path = lambda: "process" + "[process-name='" + self.process_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3/processes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Ospfv3.Processes.Process, ['process_name'], name, value)


            class DefaultVrf(Entity):
                """
                Operational data for the default VRF
                (instance) in the OSPFv3 process
                
                .. attribute:: area_informations
                
                	OSPFv3 area information table
                	**type**\:   :py:class:`AreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations>`
                
                .. attribute:: areas
                
                	OSPFv3 area table
                	**type**\:   :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas>`
                
                .. attribute:: bad_checksums
                
                	Bad Checksum Packets information table
                	**type**\:   :py:class:`BadChecksums <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums>`
                
                .. attribute:: border_routers
                
                	OSPFv3 border router information table
                	**type**\:   :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters>`
                
                .. attribute:: connected_routes
                
                	OSPFv3 connected route information table
                	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes>`
                
                .. attribute:: database_summary_table
                
                	Database summary table
                	**type**\:   :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable>`
                
                .. attribute:: database_table
                
                	OSPF Link State Database
                	**type**\:   :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable>`
                
                .. attribute:: external_routes
                
                	OSPFv3 external route information table
                	**type**\:   :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes>`
                
                .. attribute:: fast_reroutes
                
                	OSPFv3 fast reroute topology information table
                	**type**\:   :py:class:`FastReroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes>`
                
                .. attribute:: flood_list_process_table
                
                	OSPFv3 flood list information table for all areas
                	**type**\:   :py:class:`FloodListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable>`
                
                .. attribute:: interface_brief_process_table
                
                	OSPFv3 interface brief information table for all areas
                	**type**\:   :py:class:`InterfaceBriefProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable>`
                
                .. attribute:: interface_process_table
                
                	OSPFv3 interface information table for all areas
                	**type**\:   :py:class:`InterfaceProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable>`
                
                .. attribute:: internal_routes
                
                	OSPFv3 internal route information table
                	**type**\:   :py:class:`InternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes>`
                
                .. attribute:: neighbor_detail_process_table
                
                	OSPFv3 neighbor information table for all areas
                	**type**\:   :py:class:`NeighborDetailProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable>`
                
                .. attribute:: neighbor_process_table
                
                	OSPFv3 neighbor information table for all areas
                	**type**\:   :py:class:`NeighborProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable>`
                
                .. attribute:: protocol_areas
                
                	Protocol area table 
                	**type**\:   :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas>`
                
                .. attribute:: redistributions
                
                	Redistribution information table
                	**type**\:   :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Redistributions>`
                
                .. attribute:: request_list_process_table
                
                	OSPFv3 request list information for all areas
                	**type**\:   :py:class:`RequestListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable>`
                
                .. attribute:: retransmission_list_process_table
                
                	OSPFv3 retransmission list information table for all areas
                	**type**\:   :py:class:`RetransmissionListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable>`
                
                .. attribute:: route_summary
                
                	Summarize OSPFv3 local RIB tables
                	**type**\:   :py:class:`RouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RouteSummary>`
                
                .. attribute:: sham_link_table
                
                	Sham link information
                	**type**\:   :py:class:`ShamLinkTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable>`
                
                .. attribute:: summary
                
                	OSPFv3 summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary>`
                
                .. attribute:: summary_prefixes
                
                	Summary prefix information table
                	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes>`
                
                .. attribute:: virtual_link
                
                	Virtual link information
                	**type**\:   :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink>`
                
                .. attribute:: vrf_statistics
                
                	Container for Statistics
                	**type**\:   :py:class:`VrfStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ospfv3.Processes.Process.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"area-informations" : ("area_informations", Ospfv3.Processes.Process.DefaultVrf.AreaInformations), "areas" : ("areas", Ospfv3.Processes.Process.DefaultVrf.Areas), "bad-checksums" : ("bad_checksums", Ospfv3.Processes.Process.DefaultVrf.BadChecksums), "border-routers" : ("border_routers", Ospfv3.Processes.Process.DefaultVrf.BorderRouters), "connected-routes" : ("connected_routes", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes), "database-summary-table" : ("database_summary_table", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable), "database-table" : ("database_table", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable), "external-routes" : ("external_routes", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes), "fast-reroutes" : ("fast_reroutes", Ospfv3.Processes.Process.DefaultVrf.FastReroutes), "flood-list-process-table" : ("flood_list_process_table", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable), "interface-brief-process-table" : ("interface_brief_process_table", Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable), "interface-process-table" : ("interface_process_table", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable), "internal-routes" : ("internal_routes", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes), "neighbor-detail-process-table" : ("neighbor_detail_process_table", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable), "neighbor-process-table" : ("neighbor_process_table", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable), "protocol-areas" : ("protocol_areas", Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas), "redistributions" : ("redistributions", Ospfv3.Processes.Process.DefaultVrf.Redistributions), "request-list-process-table" : ("request_list_process_table", Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable), "retransmission-list-process-table" : ("retransmission_list_process_table", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable), "route-summary" : ("route_summary", Ospfv3.Processes.Process.DefaultVrf.RouteSummary), "sham-link-table" : ("sham_link_table", Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable), "summary" : ("summary", Ospfv3.Processes.Process.DefaultVrf.Summary), "summary-prefixes" : ("summary_prefixes", Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes), "virtual-link" : ("virtual_link", Ospfv3.Processes.Process.DefaultVrf.VirtualLink), "vrf-statistics" : ("vrf_statistics", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics)}
                    self._child_list_classes = {}

                    self.area_informations = Ospfv3.Processes.Process.DefaultVrf.AreaInformations()
                    self.area_informations.parent = self
                    self._children_name_map["area_informations"] = "area-informations"
                    self._children_yang_names.add("area-informations")

                    self.areas = Ospfv3.Processes.Process.DefaultVrf.Areas()
                    self.areas.parent = self
                    self._children_name_map["areas"] = "areas"
                    self._children_yang_names.add("areas")

                    self.bad_checksums = Ospfv3.Processes.Process.DefaultVrf.BadChecksums()
                    self.bad_checksums.parent = self
                    self._children_name_map["bad_checksums"] = "bad-checksums"
                    self._children_yang_names.add("bad-checksums")

                    self.border_routers = Ospfv3.Processes.Process.DefaultVrf.BorderRouters()
                    self.border_routers.parent = self
                    self._children_name_map["border_routers"] = "border-routers"
                    self._children_yang_names.add("border-routers")

                    self.connected_routes = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes()
                    self.connected_routes.parent = self
                    self._children_name_map["connected_routes"] = "connected-routes"
                    self._children_yang_names.add("connected-routes")

                    self.database_summary_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable()
                    self.database_summary_table.parent = self
                    self._children_name_map["database_summary_table"] = "database-summary-table"
                    self._children_yang_names.add("database-summary-table")

                    self.database_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable()
                    self.database_table.parent = self
                    self._children_name_map["database_table"] = "database-table"
                    self._children_yang_names.add("database-table")

                    self.external_routes = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes()
                    self.external_routes.parent = self
                    self._children_name_map["external_routes"] = "external-routes"
                    self._children_yang_names.add("external-routes")

                    self.fast_reroutes = Ospfv3.Processes.Process.DefaultVrf.FastReroutes()
                    self.fast_reroutes.parent = self
                    self._children_name_map["fast_reroutes"] = "fast-reroutes"
                    self._children_yang_names.add("fast-reroutes")

                    self.flood_list_process_table = Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable()
                    self.flood_list_process_table.parent = self
                    self._children_name_map["flood_list_process_table"] = "flood-list-process-table"
                    self._children_yang_names.add("flood-list-process-table")

                    self.interface_brief_process_table = Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable()
                    self.interface_brief_process_table.parent = self
                    self._children_name_map["interface_brief_process_table"] = "interface-brief-process-table"
                    self._children_yang_names.add("interface-brief-process-table")

                    self.interface_process_table = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable()
                    self.interface_process_table.parent = self
                    self._children_name_map["interface_process_table"] = "interface-process-table"
                    self._children_yang_names.add("interface-process-table")

                    self.internal_routes = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes()
                    self.internal_routes.parent = self
                    self._children_name_map["internal_routes"] = "internal-routes"
                    self._children_yang_names.add("internal-routes")

                    self.neighbor_detail_process_table = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable()
                    self.neighbor_detail_process_table.parent = self
                    self._children_name_map["neighbor_detail_process_table"] = "neighbor-detail-process-table"
                    self._children_yang_names.add("neighbor-detail-process-table")

                    self.neighbor_process_table = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable()
                    self.neighbor_process_table.parent = self
                    self._children_name_map["neighbor_process_table"] = "neighbor-process-table"
                    self._children_yang_names.add("neighbor-process-table")

                    self.protocol_areas = Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas()
                    self.protocol_areas.parent = self
                    self._children_name_map["protocol_areas"] = "protocol-areas"
                    self._children_yang_names.add("protocol-areas")

                    self.redistributions = Ospfv3.Processes.Process.DefaultVrf.Redistributions()
                    self.redistributions.parent = self
                    self._children_name_map["redistributions"] = "redistributions"
                    self._children_yang_names.add("redistributions")

                    self.request_list_process_table = Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable()
                    self.request_list_process_table.parent = self
                    self._children_name_map["request_list_process_table"] = "request-list-process-table"
                    self._children_yang_names.add("request-list-process-table")

                    self.retransmission_list_process_table = Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable()
                    self.retransmission_list_process_table.parent = self
                    self._children_name_map["retransmission_list_process_table"] = "retransmission-list-process-table"
                    self._children_yang_names.add("retransmission-list-process-table")

                    self.route_summary = Ospfv3.Processes.Process.DefaultVrf.RouteSummary()
                    self.route_summary.parent = self
                    self._children_name_map["route_summary"] = "route-summary"
                    self._children_yang_names.add("route-summary")

                    self.sham_link_table = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable()
                    self.sham_link_table.parent = self
                    self._children_name_map["sham_link_table"] = "sham-link-table"
                    self._children_yang_names.add("sham-link-table")

                    self.summary = Ospfv3.Processes.Process.DefaultVrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.summary_prefixes = Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes()
                    self.summary_prefixes.parent = self
                    self._children_name_map["summary_prefixes"] = "summary-prefixes"
                    self._children_yang_names.add("summary-prefixes")

                    self.virtual_link = Ospfv3.Processes.Process.DefaultVrf.VirtualLink()
                    self.virtual_link.parent = self
                    self._children_name_map["virtual_link"] = "virtual-link"
                    self._children_yang_names.add("virtual-link")

                    self.vrf_statistics = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics()
                    self.vrf_statistics.parent = self
                    self._children_name_map["vrf_statistics"] = "vrf-statistics"
                    self._children_yang_names.add("vrf-statistics")
                    self._segment_path = lambda: "default-vrf"


                class AreaInformations(Entity):
                    """
                    OSPFv3 area information table
                    
                    .. attribute:: area_information
                    
                    	OSPFv3 area information
                    	**type**\: list of    :py:class:`AreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.AreaInformations, self).__init__()

                        self.yang_name = "area-informations"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"area-information" : ("area_information", Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation)}

                        self.area_information = YList(self)
                        self._segment_path = lambda: "area-informations"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.AreaInformations, [], name, value)


                    class AreaInformation(Entity):
                        """
                        OSPFv3 area information
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: area_dc_bitless_ls_as
                        
                        	Number of LSA with demand circuit bit not set
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_interfaces
                        
                        	Number of interfaces in the area
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: area_lfa_interface_count
                        
                        	Number of LFA enabled interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_lfa_revision
                        
                        	Area LFA revision
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_opaque_lsa_checksum
                        
                        	Sum of opaque LSA checksums
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_opaque_lsas
                        
                        	Number of opaque LSAs in the area
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_per_prefix_lfa_interface_count
                        
                        	Number of Per Prefix LFA enabled interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_range
                        
                        	List of ranges to summarize
                        	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange>`
                        
                        .. attribute:: do_not_age_ls_as
                        
                        	Number of do not age LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flood_list_length
                        
                        	Number of LSAs which need to be flooded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: indication_ls_as
                        
                        	Number of indication LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_area_nssa
                        
                        	If true, area is a NSSA
                        	**type**\:  bool
                        
                        .. attribute:: is_area_stubbed
                        
                        	If true, stub area
                        	**type**\:  bool
                        
                        .. attribute:: is_area_total_stubbed
                        
                        	If true, totally stubby area
                        	**type**\:  bool
                        
                        .. attribute:: is_backbone_area_active
                        
                        	If true, Backbone area is active
                        	**type**\:  bool
                        
                        .. attribute:: is_nssa_default
                        
                        	If true, generate NSSA default route
                        	**type**\:  bool
                        
                        .. attribute:: is_nssa_translated
                        
                        	If true, perform 7/5 translation
                        	**type**\:  bool
                        
                        .. attribute:: is_rrr_enabled
                        
                        	If true, RRR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: nssa_no_redistribution
                        
                        	If true, No redistribution into this NSSA area
                        	**type**\:  bool
                        
                        .. attribute:: sp_fs
                        
                        	Number of SPF calculations run
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: stub_default_cost
                        
                        	Default cost for Stub or NSSA area
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation, self).__init__()

                            self.yang_name = "area-information"
                            self.yang_parent_name = "area-informations"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"area-range" : ("area_range", Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange)}

                            self.area_id = YLeaf(YType.int32, "area-id")

                            self.area_dc_bitless_ls_as = YLeaf(YType.uint32, "area-dc-bitless-ls-as")

                            self.area_interfaces = YLeaf(YType.uint16, "area-interfaces")

                            self.area_lfa_interface_count = YLeaf(YType.uint32, "area-lfa-interface-count")

                            self.area_lfa_revision = YLeaf(YType.uint32, "area-lfa-revision")

                            self.area_opaque_lsa_checksum = YLeaf(YType.uint32, "area-opaque-lsa-checksum")

                            self.area_opaque_lsas = YLeaf(YType.uint32, "area-opaque-lsas")

                            self.area_per_prefix_lfa_interface_count = YLeaf(YType.uint32, "area-per-prefix-lfa-interface-count")

                            self.do_not_age_ls_as = YLeaf(YType.uint32, "do-not-age-ls-as")

                            self.flood_list_length = YLeaf(YType.uint32, "flood-list-length")

                            self.indication_ls_as = YLeaf(YType.uint32, "indication-ls-as")

                            self.is_area_nssa = YLeaf(YType.boolean, "is-area-nssa")

                            self.is_area_stubbed = YLeaf(YType.boolean, "is-area-stubbed")

                            self.is_area_total_stubbed = YLeaf(YType.boolean, "is-area-total-stubbed")

                            self.is_backbone_area_active = YLeaf(YType.boolean, "is-backbone-area-active")

                            self.is_nssa_default = YLeaf(YType.boolean, "is-nssa-default")

                            self.is_nssa_translated = YLeaf(YType.boolean, "is-nssa-translated")

                            self.is_rrr_enabled = YLeaf(YType.boolean, "is-rrr-enabled")

                            self.nssa_no_redistribution = YLeaf(YType.boolean, "nssa-no-redistribution")

                            self.sp_fs = YLeaf(YType.uint32, "sp-fs")

                            self.stub_default_cost = YLeaf(YType.uint16, "stub-default-cost")

                            self.area_range = YList(self)
                            self._segment_path = lambda: "area-information" + "[area-id='" + self.area_id.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation, ['area_id', 'area_dc_bitless_ls_as', 'area_interfaces', 'area_lfa_interface_count', 'area_lfa_revision', 'area_opaque_lsa_checksum', 'area_opaque_lsas', 'area_per_prefix_lfa_interface_count', 'do_not_age_ls_as', 'flood_list_length', 'indication_ls_as', 'is_area_nssa', 'is_area_stubbed', 'is_area_total_stubbed', 'is_backbone_area_active', 'is_nssa_default', 'is_nssa_translated', 'is_rrr_enabled', 'nssa_no_redistribution', 'sp_fs', 'stub_default_cost'], name, value)


                        class AreaRange(Entity):
                            """
                            List of ranges to summarize
                            
                            .. attribute:: is_cost_configured
                            
                            	If true, cost is configured 
                            	**type**\:  bool
                            
                            .. attribute:: net_cost
                            
                            	Net cost 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_prefix
                            
                            	IP prefix for summarization
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: range_prefix_length
                            
                            	IP prefix length for summarization
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status
                            
                            	Area range status 
                            	**type**\:   :py:class:`Ospfv3AreaRangeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3AreaRangeStatus>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange, self).__init__()

                                self.yang_name = "area-range"
                                self.yang_parent_name = "area-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.is_cost_configured = YLeaf(YType.boolean, "is-cost-configured")

                                self.net_cost = YLeaf(YType.uint32, "net-cost")

                                self.range_prefix = YLeaf(YType.str, "range-prefix")

                                self.range_prefix_length = YLeaf(YType.uint32, "range-prefix-length")

                                self.status = YLeaf(YType.enumeration, "status")
                                self._segment_path = lambda: "area-range"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange, ['is_cost_configured', 'net_cost', 'range_prefix', 'range_prefix_length', 'status'], name, value)


                class Areas(Entity):
                    """
                    OSPFv3 area table
                    
                    .. attribute:: area
                    
                    	Per\-area information
                    	**type**\: list of    :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.Areas, self).__init__()

                        self.yang_name = "areas"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"area" : ("area", Ospfv3.Processes.Process.DefaultVrf.Areas.Area)}

                        self.area = YList(self)
                        self._segment_path = lambda: "areas"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas, [], name, value)


                    class Area(Entity):
                        """
                        Per\-area information
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: database_summary_table
                        
                        	Database summary table
                        	**type**\:   :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable>`
                        
                        .. attribute:: database_table
                        
                        	OSPF Link State Database
                        	**type**\:   :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable>`
                        
                        .. attribute:: flood_list_table
                        
                        	OSPFv3 flood list information table for an area
                        	**type**\:   :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable>`
                        
                        .. attribute:: interface_brief_table
                        
                        	OSPFv3 interface brief information table for an area
                        	**type**\:   :py:class:`InterfaceBriefTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable>`
                        
                        .. attribute:: interface_table
                        
                        	OSPFv3 interface information table for an area
                        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable>`
                        
                        .. attribute:: neighbor_detail_table
                        
                        	OSPFv3 area neighbor information table
                        	**type**\:   :py:class:`NeighborDetailTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable>`
                        
                        .. attribute:: neighbor_table
                        
                        	OSPFv3 neighbor information table
                        	**type**\:   :py:class:`NeighborTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable>`
                        
                        .. attribute:: request_list_table
                        
                        	OSPFv3 request list information in an area
                        	**type**\:   :py:class:`RequestListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable>`
                        
                        .. attribute:: retransmission_list_table
                        
                        	OSPFv3 retransmission list information table in an area
                        	**type**\:   :py:class:`RetransmissionListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area, self).__init__()

                            self.yang_name = "area"
                            self.yang_parent_name = "areas"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"database-summary-table" : ("database_summary_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable), "database-table" : ("database_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable), "flood-list-table" : ("flood_list_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable), "interface-brief-table" : ("interface_brief_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable), "interface-table" : ("interface_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable), "neighbor-detail-table" : ("neighbor_detail_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable), "neighbor-table" : ("neighbor_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable), "request-list-table" : ("request_list_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable), "retransmission-list-table" : ("retransmission_list_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable)}
                            self._child_list_classes = {}

                            self.area_id = YLeaf(YType.int32, "area-id")

                            self.database_summary_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable()
                            self.database_summary_table.parent = self
                            self._children_name_map["database_summary_table"] = "database-summary-table"
                            self._children_yang_names.add("database-summary-table")

                            self.database_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable()
                            self.database_table.parent = self
                            self._children_name_map["database_table"] = "database-table"
                            self._children_yang_names.add("database-table")

                            self.flood_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable()
                            self.flood_list_table.parent = self
                            self._children_name_map["flood_list_table"] = "flood-list-table"
                            self._children_yang_names.add("flood-list-table")

                            self.interface_brief_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable()
                            self.interface_brief_table.parent = self
                            self._children_name_map["interface_brief_table"] = "interface-brief-table"
                            self._children_yang_names.add("interface-brief-table")

                            self.interface_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable()
                            self.interface_table.parent = self
                            self._children_name_map["interface_table"] = "interface-table"
                            self._children_yang_names.add("interface-table")

                            self.neighbor_detail_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable()
                            self.neighbor_detail_table.parent = self
                            self._children_name_map["neighbor_detail_table"] = "neighbor-detail-table"
                            self._children_yang_names.add("neighbor-detail-table")

                            self.neighbor_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable()
                            self.neighbor_table.parent = self
                            self._children_name_map["neighbor_table"] = "neighbor-table"
                            self._children_yang_names.add("neighbor-table")

                            self.request_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable()
                            self.request_list_table.parent = self
                            self._children_name_map["request_list_table"] = "request-list-table"
                            self._children_yang_names.add("request-list-table")

                            self.retransmission_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable()
                            self.retransmission_list_table.parent = self
                            self._children_name_map["retransmission_list_table"] = "retransmission-list-table"
                            self._children_yang_names.add("retransmission-list-table")
                            self._segment_path = lambda: "area" + "[area-id='" + self.area_id.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area, ['area_id'], name, value)


                        class DatabaseSummaryTable(Entity):
                            """
                            Database summary table
                            
                            .. attribute:: database_summary
                            
                            	Database Summary information
                            	**type**\:   :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable, self).__init__()

                                self.yang_name = "database-summary-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"database-summary" : ("database_summary", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary)}
                                self._child_list_classes = {}

                                self.database_summary = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary()
                                self.database_summary.parent = self
                                self._children_name_map["database_summary"] = "database-summary"
                                self._children_yang_names.add("database-summary")
                                self._segment_path = lambda: "database-summary-table"


                            class DatabaseSummary(Entity):
                                """
                                Database Summary information
                                
                                .. attribute:: area_database
                                
                                	OSPFv3 Area Database list 
                                	**type**\: list of    :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                                
                                .. attribute:: database_counters
                                
                                	OSPFv3 database counters 
                                	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                                
                                .. attribute:: database_router_id
                                
                                	Database router ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_opaque_database_capable
                                
                                	If true, opaque database is capable 
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary, self).__init__()

                                    self.yang_name = "database-summary"
                                    self.yang_parent_name = "database-summary-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"database-counters" : ("database_counters", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters)}
                                    self._child_list_classes = {"area-database" : ("area_database", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase)}

                                    self.database_router_id = YLeaf(YType.str, "database-router-id")

                                    self.is_opaque_database_capable = YLeaf(YType.boolean, "is-opaque-database-capable")

                                    self.database_counters = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                    self.database_counters.parent = self
                                    self._children_name_map["database_counters"] = "database-counters"
                                    self._children_yang_names.add("database-counters")

                                    self.area_database = YList(self)
                                    self._segment_path = lambda: "database-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary, ['database_router_id', 'is_opaque_database_capable'], name, value)


                                class AreaDatabase(Entity):
                                    """
                                    OSPFv3 Area Database list 
                                    
                                    .. attribute:: area_database_summary
                                    
                                    	Area database summary 
                                    	**type**\:   :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, self).__init__()

                                        self.yang_name = "area-database"
                                        self.yang_parent_name = "database-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"area-database-summary" : ("area_database_summary", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary)}
                                        self._child_list_classes = {}

                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                        self.area_database_summary = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                        self.area_database_summary.parent = self
                                        self._children_name_map["area_database_summary"] = "area-database-summary"
                                        self._children_yang_names.add("area-database-summary")
                                        self._segment_path = lambda: "area-database"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, ['lsa_area_id'], name, value)


                                    class AreaDatabaseSummary(Entity):
                                        """
                                        Area database summary 
                                        
                                        .. attribute:: deleted_lsa
                                        
                                        	deleted lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa
                                        
                                        	lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_checksum
                                        
                                        	lsa checksum
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_age_lsa
                                        
                                        	max age lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, self).__init__()

                                            self.yang_name = "area-database-summary"
                                            self.yang_parent_name = "area-database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.deleted_lsa = YLeafList(YType.uint32, "deleted-lsa")

                                            self.lsa = YLeafList(YType.uint32, "lsa")

                                            self.lsa_checksum = YLeafList(YType.uint32, "lsa-checksum")

                                            self.max_age_lsa = YLeafList(YType.uint32, "max-age-lsa")
                                            self._segment_path = lambda: "area-database-summary"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, ['deleted_lsa', 'lsa', 'lsa_checksum', 'max_age_lsa'], name, value)


                                class DatabaseCounters(Entity):
                                    """
                                    OSPFv3 database counters 
                                    
                                    .. attribute:: deleted_lsa
                                    
                                    	deleted lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa
                                    
                                    	lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_checksum
                                    
                                    	lsa checksum
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_age_lsa
                                    
                                    	max age lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, self).__init__()

                                        self.yang_name = "database-counters"
                                        self.yang_parent_name = "database-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.deleted_lsa = YLeafList(YType.uint32, "deleted-lsa")

                                        self.lsa = YLeafList(YType.uint32, "lsa")

                                        self.lsa_checksum = YLeafList(YType.uint32, "lsa-checksum")

                                        self.max_age_lsa = YLeafList(YType.uint32, "max-age-lsa")
                                        self._segment_path = lambda: "database-counters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, ['deleted_lsa', 'lsa', 'lsa_checksum', 'max_age_lsa'], name, value)


                        class DatabaseTable(Entity):
                            """
                            OSPF Link State Database
                            
                            .. attribute:: lsa_internal_table
                            
                            	Database LSA information
                            	**type**\:   :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable>`
                            
                            .. attribute:: lsa_table
                            
                            	Database LSA information
                            	**type**\:   :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable, self).__init__()

                                self.yang_name = "database-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"lsa-internal-table" : ("lsa_internal_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable), "lsa-table" : ("lsa_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable)}
                                self._child_list_classes = {}

                                self.lsa_internal_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable()
                                self.lsa_internal_table.parent = self
                                self._children_name_map["lsa_internal_table"] = "lsa-internal-table"
                                self._children_yang_names.add("lsa-internal-table")

                                self.lsa_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable()
                                self.lsa_table.parent = self
                                self._children_name_map["lsa_table"] = "lsa-table"
                                self._children_yang_names.add("lsa-table")
                                self._segment_path = lambda: "database-table"


                            class LsaInternalTable(Entity):
                                """
                                Database LSA information
                                
                                .. attribute:: lsa
                                
                                	Database LSA information
                                	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable, self).__init__()

                                    self.yang_name = "lsa-internal-table"
                                    self.yang_parent_name = "database-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"lsa" : ("lsa", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa)}

                                    self.lsa = YList(self)
                                    self._segment_path = lambda: "lsa-internal-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable, [], name, value)


                                class Lsa(Entity):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: interface_name
                                    
                                    	InterfaceName
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                    
                                    .. attribute:: lsa_info
                                    
                                    	Summary of all LSAs or LSA specific information 
                                    	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "lsa-internal-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-info" : ("lsa_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo)}
                                        self._child_list_classes = {}

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.area_id = YLeaf(YType.int32, "area-id")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.ls_id = YLeaf(YType.int32, "ls-id")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                        self.lsa_info.parent = self
                                        self._children_name_map["lsa_info"] = "lsa-info"
                                        self._children_yang_names.add("lsa-info")
                                        self._segment_path = lambda: "lsa"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                    class LsaInfo(Entity):
                                        """
                                        Summary of all LSAs or LSA specific information 
                                        
                                        .. attribute:: external_lsa_type
                                        
                                        	External LSA
                                        	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                        
                                        .. attribute:: grace_lsa
                                        
                                        	Grace LSA
                                        	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                        
                                        .. attribute:: inter_area_prefix_lsa_type
                                        
                                        	Inter Area Prefix LSA
                                        	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                        
                                        .. attribute:: inter_area_router_lsa_type
                                        
                                        	Inter Area Router LSA
                                        	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                        
                                        .. attribute:: intra_area_prefix_lsa_type
                                        
                                        	Intra Area Prefix LSA
                                        	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                        
                                        .. attribute:: link_lsa_type
                                        
                                        	Link LSA
                                        	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                        
                                        .. attribute:: lsa_info_type
                                        
                                        	LSAInfoType
                                        	**type**\:   :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                        
                                        .. attribute:: lsa_summary_info
                                        
                                        	Summary information of LSAs
                                        	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                        
                                        .. attribute:: network_lsa_type
                                        
                                        	Network LSA
                                        	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                        
                                        .. attribute:: nssalsa_type
                                        
                                        	NSSA External LSA
                                        	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                        
                                        .. attribute:: router_lsa_type
                                        
                                        	Router LSA
                                        	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                        
                                        .. attribute:: unknown_area_lsa_type
                                        
                                        	Unknown\-Area scope LSA
                                        	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                        
                                        .. attribute:: unknown_aslsa_type
                                        
                                        	Unknown\-AS scope LSA
                                        	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                        
                                        .. attribute:: unknown_link_lsa_type
                                        
                                        	Unknown Link Scope LSA
                                        	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                        
                                        .. attribute:: unknown_lsa_type
                                        
                                        	Unknown LSA
                                        	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, self).__init__()

                                            self.yang_name = "lsa-info"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType), "grace-lsa" : ("grace_lsa", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa), "inter-area-prefix-lsa-type" : ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType), "inter-area-router-lsa-type" : ("inter_area_router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType), "intra-area-prefix-lsa-type" : ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType), "link-lsa-type" : ("link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType), "lsa-summary-info" : ("lsa_summary_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo), "network-lsa-type" : ("network_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType), "nssalsa-type" : ("nssalsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType), "router-lsa-type" : ("router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType), "unknown-area-lsa-type" : ("unknown_area_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType), "unknown-aslsa-type" : ("unknown_aslsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType), "unknown-link-lsa-type" : ("unknown_link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType), "unknown-lsa-type" : ("unknown_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType)}
                                            self._child_list_classes = {}

                                            self.lsa_info_type = YLeaf(YType.enumeration, "lsa-info-type")

                                            self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                            self._children_yang_names.add("external-lsa-type")

                                            self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                            self.grace_lsa.parent = self
                                            self._children_name_map["grace_lsa"] = "grace-lsa"
                                            self._children_yang_names.add("grace-lsa")

                                            self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                            self.inter_area_prefix_lsa_type.parent = self
                                            self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"
                                            self._children_yang_names.add("inter-area-prefix-lsa-type")

                                            self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                            self.inter_area_router_lsa_type.parent = self
                                            self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"
                                            self._children_yang_names.add("inter-area-router-lsa-type")

                                            self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                            self.intra_area_prefix_lsa_type.parent = self
                                            self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"
                                            self._children_yang_names.add("intra-area-prefix-lsa-type")

                                            self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                            self.link_lsa_type.parent = self
                                            self._children_name_map["link_lsa_type"] = "link-lsa-type"
                                            self._children_yang_names.add("link-lsa-type")

                                            self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                            self.lsa_summary_info.parent = self
                                            self._children_name_map["lsa_summary_info"] = "lsa-summary-info"
                                            self._children_yang_names.add("lsa-summary-info")

                                            self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                            self._children_yang_names.add("network-lsa-type")

                                            self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                            self.nssalsa_type.parent = self
                                            self._children_name_map["nssalsa_type"] = "nssalsa-type"
                                            self._children_yang_names.add("nssalsa-type")

                                            self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                            self._children_yang_names.add("router-lsa-type")

                                            self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                            self.unknown_area_lsa_type.parent = self
                                            self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"
                                            self._children_yang_names.add("unknown-area-lsa-type")

                                            self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                            self.unknown_aslsa_type.parent = self
                                            self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"
                                            self._children_yang_names.add("unknown-aslsa-type")

                                            self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                            self.unknown_link_lsa_type.parent = self
                                            self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"
                                            self._children_yang_names.add("unknown-link-lsa-type")

                                            self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                            self.unknown_lsa_type.parent = self
                                            self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                            self._children_yang_names.add("unknown-lsa-type")
                                            self._segment_path = lambda: "lsa-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, ['lsa_info_type'], name, value)


                                        class ExternalLsaType(Entity):
                                            """
                                            External LSA
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                                self.yang_name = "external-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                                self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.priority = YLeaf(YType.enumeration, "priority")

                                                self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "external-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class GraceLsa(Entity):
                                            """
                                            Grace LSA
                                            
                                            .. attribute:: grace_period
                                            
                                            	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_reason
                                            
                                            	Reason for router restart
                                            	**type**\:   :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                                self.yang_name = "grace-lsa"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.grace_period = YLeaf(YType.uint32, "grace-period")

                                                self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "grace-lsa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, ['grace_period', 'grace_reason'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "grace-lsa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "grace-lsa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class InterAreaPrefixLsaType(Entity):
                                            """
                                            Inter Area Prefix LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: prefix
                                            
                                            	LSA address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                                self.yang_name = "inter-area-prefix-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.priority = YLeaf(YType.enumeration, "priority")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "inter-area-prefix-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, ['prefix', 'prefix_length', 'priority'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class InterAreaRouterLsaType(Entity):
                                            """
                                            Inter Area Router LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                                self.yang_name = "inter-area-router-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "inter-area-router-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, ['lsa_router_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "inter-area-router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "inter-area-router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class IntraAreaPrefixLsaType(Entity):
                                            """
                                            Intra Area Prefix LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                            
                                            .. attribute:: reference_advertised_router
                                            
                                            	Reference advertised router 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                                self.yang_name = "intra-area-prefix-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)}
                                                self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix)}

                                                self.reference_advertised_router = YLeaf(YType.str, "reference-advertised-router")

                                                self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                                self.reference_type = YLeaf(YType.enumeration, "reference-type")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")

                                                self.prefix = YList(self)
                                                self._segment_path = lambda: "intra-area-prefix-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, ['reference_advertised_router', 'reference_lsa_id', 'reference_type'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class Prefix(Entity):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                    self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                    self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.priority = YLeaf(YType.enumeration, "priority")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                        class LinkLsaType(Entity):
                                            """
                                            Link LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface handle
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_link_local
                                            
                                            	LSA link local 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                            
                                            .. attribute:: router_priority
                                            
                                            	Router priority 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                                self.yang_name = "link-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)}
                                                self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix)}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.lsa_link_local = YLeaf(YType.str, "lsa-link-local")

                                                self.router_priority = YLeaf(YType.uint8, "router-priority")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")

                                                self.prefix = YList(self)
                                                self._segment_path = lambda: "link-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'lsa_link_local', 'router_priority', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class Prefix(Entity):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                    self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                    self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.priority = YLeaf(YType.enumeration, "priority")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                        class LsaSummaryInfo(Entity):
                                            """
                                            Summary information of LSAs
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: links
                                            
                                            	Number of links
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 address Prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                                self.yang_name = "lsa-summary-info"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.links = YLeaf(YType.uint16, "links")

                                                self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                                self.reference_type = YLeaf(YType.uint16, "reference-type")

                                                self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "lsa-summary-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, ['interface_name', 'is_sham_link', 'is_virtual_link', 'links', 'lsa_router_id', 'prefix', 'prefix_length', 'reference_lsa_id', 'reference_type', 'router_la_bits', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "lsa-summary-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "lsa-summary-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class NetworkLsaType(Entity):
                                            """
                                            Network LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                            
                                            .. attribute:: neighbor_router
                                            
                                            	Neighbor router list
                                            	**type**\:  list of str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                                self.yang_name = "network-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.neighbor_router = YLeafList(YType.str, "neighbor-router")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "network-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, ['neighbor_router'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class NssalsaType(Entity):
                                            """
                                            NSSA External LSA
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                                self.yang_name = "nssalsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                                self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.priority = YLeaf(YType.enumeration, "priority")

                                                self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "nssalsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "nssalsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "nssalsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class RouterLsaType(Entity):
                                            """
                                            Router LSA
                                            
                                            .. attribute:: link
                                            
                                            	List of links in this LSA
                                            	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rpf_path
                                            
                                            	Router LSA Reverse\-Path Forwarding information 
                                            	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                                self.yang_name = "router-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader), "rpf-path" : ("rpf_path", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath)}
                                                self._child_list_classes = {"link" : ("link", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link)}

                                                self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")

                                                self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                self.rpf_path.parent = self
                                                self._children_name_map["rpf_path"] = "rpf-path"
                                                self._children_yang_names.add("rpf-path")

                                                self.link = YList(self)
                                                self._segment_path = lambda: "router-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, ['router_la_bits'], name, value)


                                            class Link(Entity):
                                                """
                                                List of links in this LSA
                                                
                                                .. attribute:: link_interface_id
                                                
                                                	LSA link interface ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_metric
                                                
                                                	LSA link metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_neighbor_interface_id
                                                
                                                	LSA link neighbor interface ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_neighbor_router_id
                                                
                                                	LSA link neigbhor router id 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:   :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                    self.yang_name = "link"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.link_interface_id = YLeaf(YType.uint32, "link-interface-id")

                                                    self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                    self.link_neighbor_interface_id = YLeaf(YType.uint32, "link-neighbor-interface-id")

                                                    self.link_neighbor_router_id = YLeaf(YType.uint32, "link-neighbor-router-id")

                                                    self.link_type = YLeaf(YType.enumeration, "link-type")
                                                    self._segment_path = lambda: "link"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, ['link_interface_id', 'link_metric', 'link_neighbor_interface_id', 'link_neighbor_router_id', 'link_type'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class RpfPath(Entity):
                                                """
                                                Router LSA Reverse\-Path Forwarding information 
                                                
                                                .. attribute:: interface_name
                                                
                                                	RPF multicast IDB 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: rpf_multicast_next_hop
                                                
                                                	RPF multicast next hop 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                    self.yang_name = "rpf-path"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.rpf_multicast_next_hop = YLeaf(YType.uint32, "rpf-multicast-next-hop")
                                                    self._segment_path = lambda: "rpf-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, ['interface_name', 'rpf_multicast_next_hop'], name, value)


                                        class UnknownAreaLsaType(Entity):
                                            """
                                            Unknown\-Area scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                                self.yang_name = "unknown-area-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "unknown-area-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-area-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-area-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class UnknownAslsaType(Entity):
                                            """
                                            Unknown\-AS scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                                self.yang_name = "unknown-aslsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "unknown-aslsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-aslsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-aslsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class UnknownLinkLsaType(Entity):
                                            """
                                            Unknown Link Scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                                self.yang_name = "unknown-link-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "unknown-link-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class UnknownLsaType(Entity):
                                            """
                                            Unknown LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                                self.yang_name = "unknown-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "unknown-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                            class LsaTable(Entity):
                                """
                                Database LSA information
                                
                                .. attribute:: lsa
                                
                                	Database LSA information
                                	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable, self).__init__()

                                    self.yang_name = "lsa-table"
                                    self.yang_parent_name = "database-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"lsa" : ("lsa", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa)}

                                    self.lsa = YList(self)
                                    self._segment_path = lambda: "lsa-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable, [], name, value)


                                class Lsa(Entity):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: interface_name
                                    
                                    	InterfaceName
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                    
                                    .. attribute:: lsa_info
                                    
                                    	Summary of all LSAs or LSA specific information 
                                    	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "lsa-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-info" : ("lsa_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo)}
                                        self._child_list_classes = {}

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.area_id = YLeaf(YType.int32, "area-id")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.ls_id = YLeaf(YType.int32, "ls-id")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                        self.lsa_info.parent = self
                                        self._children_name_map["lsa_info"] = "lsa-info"
                                        self._children_yang_names.add("lsa-info")
                                        self._segment_path = lambda: "lsa"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                    class LsaInfo(Entity):
                                        """
                                        Summary of all LSAs or LSA specific information 
                                        
                                        .. attribute:: external_lsa_type
                                        
                                        	External LSA
                                        	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                        
                                        .. attribute:: grace_lsa
                                        
                                        	Grace LSA
                                        	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                        
                                        .. attribute:: inter_area_prefix_lsa_type
                                        
                                        	Inter Area Prefix LSA
                                        	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                        
                                        .. attribute:: inter_area_router_lsa_type
                                        
                                        	Inter Area Router LSA
                                        	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                        
                                        .. attribute:: intra_area_prefix_lsa_type
                                        
                                        	Intra Area Prefix LSA
                                        	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                        
                                        .. attribute:: link_lsa_type
                                        
                                        	Link LSA
                                        	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                        
                                        .. attribute:: lsa_info_type
                                        
                                        	LSAInfoType
                                        	**type**\:   :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                        
                                        .. attribute:: lsa_summary_info
                                        
                                        	Summary information of LSAs
                                        	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                        
                                        .. attribute:: network_lsa_type
                                        
                                        	Network LSA
                                        	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                        
                                        .. attribute:: nssalsa_type
                                        
                                        	NSSA External LSA
                                        	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                        
                                        .. attribute:: router_lsa_type
                                        
                                        	Router LSA
                                        	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                        
                                        .. attribute:: unknown_area_lsa_type
                                        
                                        	Unknown\-Area scope LSA
                                        	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                        
                                        .. attribute:: unknown_aslsa_type
                                        
                                        	Unknown\-AS scope LSA
                                        	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                        
                                        .. attribute:: unknown_link_lsa_type
                                        
                                        	Unknown Link Scope LSA
                                        	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                        
                                        .. attribute:: unknown_lsa_type
                                        
                                        	Unknown LSA
                                        	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo, self).__init__()

                                            self.yang_name = "lsa-info"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType), "grace-lsa" : ("grace_lsa", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa), "inter-area-prefix-lsa-type" : ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType), "inter-area-router-lsa-type" : ("inter_area_router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType), "intra-area-prefix-lsa-type" : ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType), "link-lsa-type" : ("link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType), "lsa-summary-info" : ("lsa_summary_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo), "network-lsa-type" : ("network_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType), "nssalsa-type" : ("nssalsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType), "router-lsa-type" : ("router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType), "unknown-area-lsa-type" : ("unknown_area_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType), "unknown-aslsa-type" : ("unknown_aslsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType), "unknown-link-lsa-type" : ("unknown_link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType), "unknown-lsa-type" : ("unknown_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType)}
                                            self._child_list_classes = {}

                                            self.lsa_info_type = YLeaf(YType.enumeration, "lsa-info-type")

                                            self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                            self._children_yang_names.add("external-lsa-type")

                                            self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                            self.grace_lsa.parent = self
                                            self._children_name_map["grace_lsa"] = "grace-lsa"
                                            self._children_yang_names.add("grace-lsa")

                                            self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                            self.inter_area_prefix_lsa_type.parent = self
                                            self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"
                                            self._children_yang_names.add("inter-area-prefix-lsa-type")

                                            self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                            self.inter_area_router_lsa_type.parent = self
                                            self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"
                                            self._children_yang_names.add("inter-area-router-lsa-type")

                                            self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                            self.intra_area_prefix_lsa_type.parent = self
                                            self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"
                                            self._children_yang_names.add("intra-area-prefix-lsa-type")

                                            self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                            self.link_lsa_type.parent = self
                                            self._children_name_map["link_lsa_type"] = "link-lsa-type"
                                            self._children_yang_names.add("link-lsa-type")

                                            self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                            self.lsa_summary_info.parent = self
                                            self._children_name_map["lsa_summary_info"] = "lsa-summary-info"
                                            self._children_yang_names.add("lsa-summary-info")

                                            self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                            self._children_yang_names.add("network-lsa-type")

                                            self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                            self.nssalsa_type.parent = self
                                            self._children_name_map["nssalsa_type"] = "nssalsa-type"
                                            self._children_yang_names.add("nssalsa-type")

                                            self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                            self._children_yang_names.add("router-lsa-type")

                                            self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                            self.unknown_area_lsa_type.parent = self
                                            self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"
                                            self._children_yang_names.add("unknown-area-lsa-type")

                                            self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                            self.unknown_aslsa_type.parent = self
                                            self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"
                                            self._children_yang_names.add("unknown-aslsa-type")

                                            self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                            self.unknown_link_lsa_type.parent = self
                                            self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"
                                            self._children_yang_names.add("unknown-link-lsa-type")

                                            self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                            self.unknown_lsa_type.parent = self
                                            self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                            self._children_yang_names.add("unknown-lsa-type")
                                            self._segment_path = lambda: "lsa-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo, ['lsa_info_type'], name, value)


                                        class ExternalLsaType(Entity):
                                            """
                                            External LSA
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                                self.yang_name = "external-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                                self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.priority = YLeaf(YType.enumeration, "priority")

                                                self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "external-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class GraceLsa(Entity):
                                            """
                                            Grace LSA
                                            
                                            .. attribute:: grace_period
                                            
                                            	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_reason
                                            
                                            	Reason for router restart
                                            	**type**\:   :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                                self.yang_name = "grace-lsa"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.grace_period = YLeaf(YType.uint32, "grace-period")

                                                self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "grace-lsa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, ['grace_period', 'grace_reason'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "grace-lsa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "grace-lsa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class InterAreaPrefixLsaType(Entity):
                                            """
                                            Inter Area Prefix LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: prefix
                                            
                                            	LSA address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                                self.yang_name = "inter-area-prefix-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.priority = YLeaf(YType.enumeration, "priority")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "inter-area-prefix-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, ['prefix', 'prefix_length', 'priority'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class InterAreaRouterLsaType(Entity):
                                            """
                                            Inter Area Router LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                                self.yang_name = "inter-area-router-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "inter-area-router-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, ['lsa_router_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "inter-area-router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "inter-area-router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class IntraAreaPrefixLsaType(Entity):
                                            """
                                            Intra Area Prefix LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                            
                                            .. attribute:: reference_advertised_router
                                            
                                            	Reference advertised router 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                                self.yang_name = "intra-area-prefix-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)}
                                                self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix)}

                                                self.reference_advertised_router = YLeaf(YType.str, "reference-advertised-router")

                                                self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                                self.reference_type = YLeaf(YType.enumeration, "reference-type")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")

                                                self.prefix = YList(self)
                                                self._segment_path = lambda: "intra-area-prefix-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, ['reference_advertised_router', 'reference_lsa_id', 'reference_type'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class Prefix(Entity):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                    self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                    self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.priority = YLeaf(YType.enumeration, "priority")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                        class LinkLsaType(Entity):
                                            """
                                            Link LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface handle
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_link_local
                                            
                                            	LSA link local 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                            
                                            .. attribute:: router_priority
                                            
                                            	Router priority 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                                self.yang_name = "link-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)}
                                                self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix)}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.lsa_link_local = YLeaf(YType.str, "lsa-link-local")

                                                self.router_priority = YLeaf(YType.uint8, "router-priority")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")

                                                self.prefix = YList(self)
                                                self._segment_path = lambda: "link-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'lsa_link_local', 'router_priority', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class Prefix(Entity):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                    self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                    self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.priority = YLeaf(YType.enumeration, "priority")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                        class LsaSummaryInfo(Entity):
                                            """
                                            Summary information of LSAs
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: links
                                            
                                            	Number of links
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 address Prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                                self.yang_name = "lsa-summary-info"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.links = YLeaf(YType.uint16, "links")

                                                self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                                self.reference_type = YLeaf(YType.uint16, "reference-type")

                                                self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "lsa-summary-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, ['interface_name', 'is_sham_link', 'is_virtual_link', 'links', 'lsa_router_id', 'prefix', 'prefix_length', 'reference_lsa_id', 'reference_type', 'router_la_bits', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "lsa-summary-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "lsa-summary-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class NetworkLsaType(Entity):
                                            """
                                            Network LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                            
                                            .. attribute:: neighbor_router
                                            
                                            	Neighbor router list
                                            	**type**\:  list of str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                                self.yang_name = "network-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.neighbor_router = YLeafList(YType.str, "neighbor-router")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "network-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, ['neighbor_router'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class NssalsaType(Entity):
                                            """
                                            NSSA External LSA
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                                self.yang_name = "nssalsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                                self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.priority = YLeaf(YType.enumeration, "priority")

                                                self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "nssalsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "nssalsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "nssalsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class RouterLsaType(Entity):
                                            """
                                            Router LSA
                                            
                                            .. attribute:: link
                                            
                                            	List of links in this LSA
                                            	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rpf_path
                                            
                                            	Router LSA Reverse\-Path Forwarding information 
                                            	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                                self.yang_name = "router-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader), "rpf-path" : ("rpf_path", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath)}
                                                self._child_list_classes = {"link" : ("link", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link)}

                                                self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")

                                                self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                self.rpf_path.parent = self
                                                self._children_name_map["rpf_path"] = "rpf-path"
                                                self._children_yang_names.add("rpf-path")

                                                self.link = YList(self)
                                                self._segment_path = lambda: "router-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, ['router_la_bits'], name, value)


                                            class Link(Entity):
                                                """
                                                List of links in this LSA
                                                
                                                .. attribute:: link_interface_id
                                                
                                                	LSA link interface ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_metric
                                                
                                                	LSA link metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_neighbor_interface_id
                                                
                                                	LSA link neighbor interface ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_neighbor_router_id
                                                
                                                	LSA link neigbhor router id 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:   :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                    self.yang_name = "link"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.link_interface_id = YLeaf(YType.uint32, "link-interface-id")

                                                    self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                    self.link_neighbor_interface_id = YLeaf(YType.uint32, "link-neighbor-interface-id")

                                                    self.link_neighbor_router_id = YLeaf(YType.uint32, "link-neighbor-router-id")

                                                    self.link_type = YLeaf(YType.enumeration, "link-type")
                                                    self._segment_path = lambda: "link"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, ['link_interface_id', 'link_metric', 'link_neighbor_interface_id', 'link_neighbor_router_id', 'link_type'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class RpfPath(Entity):
                                                """
                                                Router LSA Reverse\-Path Forwarding information 
                                                
                                                .. attribute:: interface_name
                                                
                                                	RPF multicast IDB 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: rpf_multicast_next_hop
                                                
                                                	RPF multicast next hop 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                    self.yang_name = "rpf-path"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.rpf_multicast_next_hop = YLeaf(YType.uint32, "rpf-multicast-next-hop")
                                                    self._segment_path = lambda: "rpf-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, ['interface_name', 'rpf_multicast_next_hop'], name, value)


                                        class UnknownAreaLsaType(Entity):
                                            """
                                            Unknown\-Area scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                                self.yang_name = "unknown-area-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "unknown-area-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-area-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-area-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class UnknownAslsaType(Entity):
                                            """
                                            Unknown\-AS scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                                self.yang_name = "unknown-aslsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "unknown-aslsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-aslsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-aslsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class UnknownLinkLsaType(Entity):
                                            """
                                            Unknown Link Scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                                self.yang_name = "unknown-link-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "unknown-link-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class UnknownLsaType(Entity):
                                            """
                                            Unknown LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                                self.yang_name = "unknown-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._children_yang_names.add("lsa-detail")

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"
                                                self._children_yang_names.add("lsa-header")
                                                self._segment_path = lambda: "unknown-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                    self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                    self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                    self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                    self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                    self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                    self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                    self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                    self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                    self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                    self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                    self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                    self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                    self._segment_path = lambda: "lsa-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                                    self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                    self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                    self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                    self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                    self._segment_path = lambda: "lsa-header"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                        class FloodListTable(Entity):
                            """
                            OSPFv3 flood list information table for an
                            area
                            
                            .. attribute:: flood
                            
                            	OSPFv3 flood list information
                            	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable, self).__init__()

                                self.yang_name = "flood-list-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"flood" : ("flood", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood)}

                                self.flood = YList(self)
                                self._segment_path = lambda: "flood-list-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable, [], name, value)


                            class Flood(Entity):
                                """
                                OSPFv3 flood list information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: area_flood
                                
                                	Area scope floodlist
                                	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood>`
                                
                                .. attribute:: as_flood
                                
                                	AS scope floodlist
                                	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood>`
                                
                                .. attribute:: link_flood
                                
                                	Link floodlist
                                	**type**\: list of    :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood>`
                                
                                .. attribute:: ls_transmission_timer
                                
                                	Time until next LS transmission (ms) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: queue_length
                                
                                	Number of LSAs currently being flooded 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood, self).__init__()

                                    self.yang_name = "flood"
                                    self.yang_parent_name = "flood-list-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"area-flood" : ("area_flood", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood), "as-flood" : ("as_flood", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood), "link-flood" : ("link_flood", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.ls_transmission_timer = YLeaf(YType.uint32, "ls-transmission-timer")

                                    self.queue_length = YLeaf(YType.uint32, "queue-length")

                                    self.area_flood = YList(self)
                                    self.as_flood = YList(self)
                                    self.link_flood = YList(self)
                                    self._segment_path = lambda: "flood" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood, ['interface_name', 'ls_transmission_timer', 'queue_length'], name, value)


                                class AreaFlood(Entity):
                                    """
                                    Area scope floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood, self).__init__()

                                        self.yang_name = "area-flood"
                                        self.yang_parent_name = "flood"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                        self._segment_path = lambda: "area-flood"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                                class AsFlood(Entity):
                                    """
                                    AS scope floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood, self).__init__()

                                        self.yang_name = "as-flood"
                                        self.yang_parent_name = "flood"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                        self._segment_path = lambda: "as-flood"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                                class LinkFlood(Entity):
                                    """
                                    Link floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood, self).__init__()

                                        self.yang_name = "link-flood"
                                        self.yang_parent_name = "flood"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                        self._segment_path = lambda: "link-flood"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class InterfaceBriefTable(Entity):
                            """
                            OSPFv3 interface brief information table for
                            an area
                            
                            .. attribute:: interface_brief
                            
                            	Interface brief information
                            	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable, self).__init__()

                                self.yang_name = "interface-brief-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface-brief" : ("interface_brief", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief)}

                                self.interface_brief = YList(self)
                                self._segment_path = lambda: "interface-brief-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable, [], name, value)


                            class InterfaceBrief(Entity):
                                """
                                Interface brief information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_address
                                
                                	Interface IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_adjacent_neighbors
                                
                                	Total number of adjacent neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_neighbors
                                
                                	Total number of neighbors 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief, self).__init__()

                                    self.yang_name = "interface-brief"
                                    self.yang_parent_name = "interface-brief-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_adjacent_neighbors = YLeaf(YType.uint16, "interface-adjacent-neighbors")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_neighbors = YLeaf(YType.uint16, "interface-neighbors")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                    self._segment_path = lambda: "interface-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief, ['interface_name', 'interface_address', 'interface_adjacent_neighbors', 'interface_link_cost', 'interface_neighbors', 'network_type', 'ospf_interface_state'], name, value)


                        class InterfaceTable(Entity):
                            """
                            OSPFv3 interface information table for an area
                            
                            .. attribute:: interface
                            
                            	OSPFv3 interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable, self).__init__()

                                self.yang_name = "interface-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface" : ("interface", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface)}

                                self.interface = YList(self)
                                self._segment_path = lambda: "interface-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable, [], name, value)


                            class Interface(Entity):
                                """
                                OSPFv3 interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: active_interface
                                
                                	Active interface details 
                                	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface>`
                                
                                .. attribute:: adjacent_neighbor
                                
                                	Number of adjacent neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_designated_router_address
                                
                                	Backup designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_designated_router_id
                                
                                	Backup designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: configured_ldp_sync
                                
                                	If true, configured as LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: dead_interval
                                
                                	Configured dead interval (s) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: designated_router_address
                                
                                	Designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: designated_router_id
                                
                                	Designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: hello_interval
                                
                                	Configured hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_address
                                
                                	Interface IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_authentication_spi
                                
                                	Interface authentication spi 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_authentication_transmit
                                
                                	Interface authentication transmit 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_bfd
                                
                                	BFD information 
                                	**type**\:   :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd>`
                                
                                .. attribute:: interface_dc_bitless_ls_as
                                
                                	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_encrypted_authentication_transmitted
                                
                                	Interface encrypted authentication transmitted 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_encryption_spi
                                
                                	Interface encryption spi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_encryption_transmitted
                                
                                	Interface encryption transmitted 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ldp_sync
                                
                                	If true, interface LDP sync is achieved
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_neighbor
                                
                                	Information for neighbors on the interface
                                	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor>`
                                
                                .. attribute:: interface_number
                                
                                	Interface number 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_priority
                                
                                	Interface priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_references
                                
                                	Interface reference count 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_retransmission_interval
                                
                                	Configured retransmit interval (s) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_router_id
                                
                                	Interface router ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_state
                                
                                	Interface state
                                	**type**\:   :py:class:`ImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnum>`
                                
                                .. attribute:: is_demand_circuit_configured
                                
                                	If true, configured as demand circuit 
                                	**type**\:  bool
                                
                                .. attribute:: is_designated_router
                                
                                	If true, designated router
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_demand_circuit
                                
                                	If true, interface running as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_encryption_enabled
                                
                                	If true, interface encryption is enabled 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_flood_reduction
                                
                                	If true, interface flood reduction is active 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_ip_security_active
                                
                                	If true, interface IP security is active 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_ip_security_required
                                
                                	If true, interface IP security is required 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_line_up
                                
                                	If true, line protocol is up 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_lsa_filtered
                                
                                	Filter is configured for out going LSAs 
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_suppress
                                
                                	If true prefix suppression is enabled
                                	**type**\:  bool
                                
                                .. attribute:: network_lsa_flush_timer
                                
                                	The amount of time in seconds before flush timer for old network LSA expires 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                
                                .. attribute:: next_hello_time
                                
                                	Time until next Hello (s) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface state
                                	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                                
                                .. attribute:: transmission_delay
                                
                                	Interface transmission delay (sec)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: wait_interval
                                
                                	Configured wait interval (s) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interface-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"active-interface" : ("active_interface", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface), "interface-bfd" : ("interface_bfd", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd)}
                                    self._child_list_classes = {"interface-neighbor" : ("interface_neighbor", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.adjacent_neighbor = YLeaf(YType.uint32, "adjacent-neighbor")

                                    self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                    self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                    self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                    self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                    self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                    self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_authentication_spi = YLeaf(YType.uint32, "interface-authentication-spi")

                                    self.interface_authentication_transmit = YLeaf(YType.uint32, "interface-authentication-transmit")

                                    self.interface_dc_bitless_ls_as = YLeaf(YType.uint32, "interface-dc-bitless-ls-as")

                                    self.interface_encrypted_authentication_transmitted = YLeaf(YType.uint32, "interface-encrypted-authentication-transmitted")

                                    self.interface_encryption_spi = YLeaf(YType.uint32, "interface-encryption-spi")

                                    self.interface_encryption_transmitted = YLeaf(YType.uint32, "interface-encryption-transmitted")

                                    self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_number = YLeaf(YType.uint32, "interface-number")

                                    self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                    self.interface_references = YLeaf(YType.uint32, "interface-references")

                                    self.interface_retransmission_interval = YLeaf(YType.uint32, "interface-retransmission-interval")

                                    self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                    self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                    self.is_demand_circuit_configured = YLeaf(YType.boolean, "is-demand-circuit-configured")

                                    self.is_designated_router = YLeaf(YType.boolean, "is-designated-router")

                                    self.is_interface_demand_circuit = YLeaf(YType.boolean, "is-interface-demand-circuit")

                                    self.is_interface_encryption_enabled = YLeaf(YType.boolean, "is-interface-encryption-enabled")

                                    self.is_interface_flood_reduction = YLeaf(YType.boolean, "is-interface-flood-reduction")

                                    self.is_interface_ip_security_active = YLeaf(YType.boolean, "is-interface-ip-security-active")

                                    self.is_interface_ip_security_required = YLeaf(YType.boolean, "is-interface-ip-security-required")

                                    self.is_interface_line_up = YLeaf(YType.boolean, "is-interface-line-up")

                                    self.is_interface_lsa_filtered = YLeaf(YType.boolean, "is-interface-lsa-filtered")

                                    self.is_prefix_suppress = YLeaf(YType.boolean, "is-prefix-suppress")

                                    self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                    self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                    self.active_interface = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface()
                                    self.active_interface.parent = self
                                    self._children_name_map["active_interface"] = "active-interface"
                                    self._children_yang_names.add("active-interface")

                                    self.interface_bfd = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd()
                                    self.interface_bfd.parent = self
                                    self._children_name_map["interface_bfd"] = "interface-bfd"
                                    self._children_yang_names.add("interface-bfd")

                                    self.interface_neighbor = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface, ['interface_name', 'adjacent_neighbor', 'backup_designated_router_address', 'backup_designated_router_id', 'configured_ldp_sync', 'dead_interval', 'designated_router_address', 'designated_router_id', 'hello_interval', 'interface_address', 'interface_authentication_spi', 'interface_authentication_transmit', 'interface_dc_bitless_ls_as', 'interface_encrypted_authentication_transmitted', 'interface_encryption_spi', 'interface_encryption_transmitted', 'interface_ldp_sync', 'interface_link_cost', 'interface_number', 'interface_priority', 'interface_references', 'interface_retransmission_interval', 'interface_router_id', 'interface_state', 'is_demand_circuit_configured', 'is_designated_router', 'is_interface_demand_circuit', 'is_interface_encryption_enabled', 'is_interface_flood_reduction', 'is_interface_ip_security_active', 'is_interface_ip_security_required', 'is_interface_line_up', 'is_interface_lsa_filtered', 'is_prefix_suppress', 'network_lsa_flush_timer', 'network_type', 'next_hello_time', 'ospf_interface_state', 'transmission_delay', 'wait_interval'], name, value)


                                class ActiveInterface(Entity):
                                    """
                                    Active interface details 
                                    
                                    .. attribute:: flood_queue_length
                                    
                                    	Flood queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flood_scan_length
                                    
                                    	Last flood scan length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_flood_index
                                    
                                    	Area scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood
                                    
                                    	Next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood_index
                                    
                                    	Index of next LSA to flood (Area scope) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_flood_index
                                    
                                    	AS scope LSAs flood index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood
                                    
                                    	Next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood_index
                                    
                                    	Index of next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_flood_pacing_timer
                                    
                                    	Time until next flood pacing timer (ms) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_flood_index
                                    
                                    	Interface flood link index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_next_flood
                                    
                                    	Interface link next flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_next_index
                                    
                                    	Interface link next information index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbors
                                    
                                    	Total number of neighbors 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: last_flood_time
                                    
                                    	Last flood scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_length
                                    
                                    	Maximum flood length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_time
                                    
                                    	Maximum flood time (ms) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: suppressed_hellos
                                    
                                    	Number of neighbors for which hellos are suppressed 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: wait_time
                                    
                                    	Wait time for DR/BDR selection (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface, self).__init__()

                                        self.yang_name = "active-interface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.flood_queue_length = YLeaf(YType.uint32, "flood-queue-length")

                                        self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                        self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                        self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                        self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                        self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                        self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                        self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                        self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                        self.interface_link_flood_index = YLeaf(YType.uint32, "interface-link-flood-index")

                                        self.interface_link_next_flood = YLeaf(YType.uint32, "interface-link-next-flood")

                                        self.interface_link_next_index = YLeaf(YType.uint32, "interface-link-next-index")

                                        self.interface_neighbors = YLeaf(YType.uint16, "interface-neighbors")

                                        self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                        self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                        self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                        self.suppressed_hellos = YLeaf(YType.uint16, "suppressed-hellos")

                                        self.wait_time = YLeaf(YType.uint32, "wait-time")
                                        self._segment_path = lambda: "active-interface"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface, ['flood_queue_length', 'flood_scan_length', 'interface_area_flood_index', 'interface_area_next_flood', 'interface_area_next_flood_index', 'interface_as_flood_index', 'interface_as_next_flood', 'interface_as_next_flood_index', 'interface_flood_pacing_timer', 'interface_link_flood_index', 'interface_link_next_flood', 'interface_link_next_index', 'interface_neighbors', 'last_flood_time', 'maximum_flood_length', 'maximum_flood_time', 'suppressed_hellos', 'wait_time'], name, value)


                                class InterfaceBfd(Entity):
                                    """
                                    BFD information 
                                    
                                    .. attribute:: bfd_detection_multiplier
                                    
                                    	BFD detection multiplier 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_interval
                                    
                                    	BFD interval (ms) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD Enable Mode on the interface \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd, self).__init__()

                                        self.yang_name = "interface-bfd"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_detection_multiplier = YLeaf(YType.uint32, "bfd-detection-multiplier")

                                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")
                                        self._segment_path = lambda: "interface-bfd"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd, ['bfd_detection_multiplier', 'bfd_interval', 'bfd_intf_enable_mode'], name, value)


                                class InterfaceNeighbor(Entity):
                                    """
                                    Information for neighbors on the interface
                                    
                                    .. attribute:: interface_neighbor_cost
                                    
                                    	Cost of link to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_id
                                    
                                    	Neighbor router ID 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_hello_suppressed
                                    
                                    	If true, hello is suppressed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_bdr
                                    
                                    	If true, backup designated router is found 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_dr
                                    
                                    	If true, designated router is found 
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor, self).__init__()

                                        self.yang_name = "interface-neighbor"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                        self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                        self.is_hello_suppressed = YLeaf(YType.boolean, "is-hello-suppressed")

                                        self.is_neighbor_bdr = YLeaf(YType.boolean, "is-neighbor-bdr")

                                        self.is_neighbor_dr = YLeaf(YType.boolean, "is-neighbor-dr")
                                        self._segment_path = lambda: "interface-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor, ['interface_neighbor_cost', 'interface_neighbor_id', 'is_hello_suppressed', 'is_neighbor_bdr', 'is_neighbor_dr'], name, value)


                        class NeighborDetailTable(Entity):
                            """
                            OSPFv3 area neighbor information table
                            
                            .. attribute:: neighbor_detail
                            
                            	OSPFv3 neighbor detail information
                            	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable, self).__init__()

                                self.yang_name = "neighbor-detail-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail)}

                                self.neighbor_detail = YList(self)
                                self._segment_path = lambda: "neighbor-detail-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable, [], name, value)


                            class NeighborDetail(Entity):
                                """
                                OSPFv3 neighbor detail information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_neighbor_sham_link
                                
                                	If true, neighbor is on a sham link 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_virtual_link
                                
                                	If true, neighbor is on a virtual link 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_info
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_designated_router
                                
                                	Designated router 
                                	**type**\:  str
                                
                                	**length:** 0..9
                                
                                .. attribute:: neighbor_detail
                                
                                	Detailed OSPFv3 neighbor information 
                                	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail>`
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_interface_id
                                
                                	Neighbor interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_sham_link_id
                                
                                	Neighbor sham link id 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_virtual_link_id
                                
                                	Neighbor virtual link id 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor-detail-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-bfd-info" : ("neighbor_bfd_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo), "neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_neighbor_sham_link = YLeaf(YType.boolean, "is-neighbor-sham-link")

                                    self.is_neighbor_virtual_link = YLeaf(YType.boolean, "is-neighbor-virtual-link")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                    self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                    self.neighbor_designated_router = YLeaf(YType.str, "neighbor-designated-router")

                                    self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                    self.neighbor_interface_id = YLeaf(YType.uint32, "neighbor-interface-id")

                                    self.neighbor_sham_link_id = YLeaf(YType.uint32, "neighbor-sham-link-id")

                                    self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                    self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                    self.neighbor_virtual_link_id = YLeaf(YType.uint32, "neighbor-virtual-link-id")

                                    self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo()
                                    self.neighbor_bfd_info.parent = self
                                    self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                    self._children_yang_names.add("neighbor-bfd-info")

                                    self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail()
                                    self.neighbor_detail.parent = self
                                    self._children_name_map["neighbor_detail"] = "neighbor-detail"
                                    self._children_yang_names.add("neighbor-detail")
                                    self._segment_path = lambda: "neighbor-detail"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail, ['interface_name', 'is_neighbor_sham_link', 'is_neighbor_virtual_link', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_designated_router', 'neighbor_dr_priority', 'neighbor_interface_id', 'neighbor_sham_link_id', 'neighbor_state', 'neighbor_up_time', 'neighbor_virtual_link_id'], name, value)


                                class NeighborBfdInfo(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo, self).__init__()

                                        self.yang_name = "neighbor-bfd-info"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                        self._segment_path = lambda: "neighbor-bfd-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                                class NeighborDetail(Entity):
                                    """
                                    Detailed OSPFv3 neighbor information 
                                    
                                    .. attribute:: interface_type
                                    
                                    	Interface type
                                    	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                    
                                    .. attribute:: is_neighbor_filtered
                                    
                                    	If true, filter outgoing LSAs 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_backup_designated_router_address
                                    
                                    	Address of backup designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_cost
                                    
                                    	Cost of path to this neighbor 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_designated_router_address
                                    
                                    	Address of designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_ignore_timer
                                    
                                    	Remaining time when ignore timer is running 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_option
                                    
                                    	 This is bitmask of neighbor's option field received 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission
                                    
                                    	Retransmission information with this neighbor
                                    	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission>`
                                    
                                    .. attribute:: next_poll_interval
                                    
                                    	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: pending_events
                                    
                                    	Number of pending events 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: poll_interval
                                    
                                    	Poll interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_changes
                                    
                                    	Number of state changes 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail, self).__init__()

                                        self.yang_name = "neighbor-detail"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-retransmission" : ("neighbor_retransmission", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission)}
                                        self._child_list_classes = {}

                                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                        self.is_neighbor_filtered = YLeaf(YType.boolean, "is-neighbor-filtered")

                                        self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                        self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                        self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                        self.neighbor_ignore_timer = YLeaf(YType.uint32, "neighbor-ignore-timer")

                                        self.neighbor_option = YLeaf(YType.uint32, "neighbor-option")

                                        self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                        self.pending_events = YLeaf(YType.uint16, "pending-events")

                                        self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                        self.state_changes = YLeaf(YType.uint16, "state-changes")

                                        self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission()
                                        self.neighbor_retransmission.parent = self
                                        self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                        self._children_yang_names.add("neighbor-retransmission")
                                        self._segment_path = lambda: "neighbor-detail"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail, ['interface_type', 'is_neighbor_filtered', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_ignore_timer', 'neighbor_option', 'next_poll_interval', 'pending_events', 'poll_interval', 'state_changes'], name, value)


                                    class NeighborRetransmission(Entity):
                                        """
                                        Retransmission information with this neighbor
                                        
                                        .. attribute:: area_first_flood
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flood_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: database_descriptor_retransmissions
                                        
                                        	Number of database descriptor retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood
                                        
                                        	Link first flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood_index
                                        
                                        	Link first flood information index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_flood_index
                                        
                                        	Link flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood
                                        
                                        	Link next flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood_index
                                        
                                        	Link next flood information index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmissions
                                        
                                        	Number of neighbor retransmissions 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission, self).__init__()

                                            self.yang_name = "neighbor-retransmission"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                            self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                            self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                            self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                            self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                            self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                            self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                            self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                            self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                            self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                            self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                            self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                            self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                            self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                            self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                            self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                            self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                            self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                            self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                            self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                            self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                            self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                            self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                            self._segment_path = lambda: "neighbor-retransmission"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                        class NeighborTable(Entity):
                            """
                            OSPFv3 neighbor information table
                            
                            .. attribute:: neighbor
                            
                            	OSPFv3 neighbor detail information
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable, self).__init__()

                                self.yang_name = "neighbor-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor" : ("neighbor", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor)}

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "neighbor-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable, [], name, value)


                            class Neighbor(Entity):
                                """
                                OSPFv3 neighbor detail information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_neighbor_sham_link
                                
                                	If true, neighbor is on a sham link 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_virtual_link
                                
                                	If true, neighbor is on a virtual link 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_info
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_designated_router
                                
                                	Designated router 
                                	**type**\:  str
                                
                                	**length:** 0..9
                                
                                .. attribute:: neighbor_detail
                                
                                	Detailed OSPFv3 neighbor information 
                                	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail>`
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_interface_id
                                
                                	Neighbor interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_sham_link_id
                                
                                	Neighbor sham link id 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_virtual_link_id
                                
                                	Neighbor virtual link id 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbor-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-bfd-info" : ("neighbor_bfd_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo), "neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_neighbor_sham_link = YLeaf(YType.boolean, "is-neighbor-sham-link")

                                    self.is_neighbor_virtual_link = YLeaf(YType.boolean, "is-neighbor-virtual-link")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                    self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                    self.neighbor_designated_router = YLeaf(YType.str, "neighbor-designated-router")

                                    self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                    self.neighbor_interface_id = YLeaf(YType.uint32, "neighbor-interface-id")

                                    self.neighbor_sham_link_id = YLeaf(YType.uint32, "neighbor-sham-link-id")

                                    self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                    self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                    self.neighbor_virtual_link_id = YLeaf(YType.uint32, "neighbor-virtual-link-id")

                                    self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo()
                                    self.neighbor_bfd_info.parent = self
                                    self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                    self._children_yang_names.add("neighbor-bfd-info")

                                    self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail()
                                    self.neighbor_detail.parent = self
                                    self._children_name_map["neighbor_detail"] = "neighbor-detail"
                                    self._children_yang_names.add("neighbor-detail")
                                    self._segment_path = lambda: "neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor, ['interface_name', 'is_neighbor_sham_link', 'is_neighbor_virtual_link', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_designated_router', 'neighbor_dr_priority', 'neighbor_interface_id', 'neighbor_sham_link_id', 'neighbor_state', 'neighbor_up_time', 'neighbor_virtual_link_id'], name, value)


                                class NeighborBfdInfo(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo, self).__init__()

                                        self.yang_name = "neighbor-bfd-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                        self._segment_path = lambda: "neighbor-bfd-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                                class NeighborDetail(Entity):
                                    """
                                    Detailed OSPFv3 neighbor information 
                                    
                                    .. attribute:: interface_type
                                    
                                    	Interface type
                                    	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                    
                                    .. attribute:: is_neighbor_filtered
                                    
                                    	If true, filter outgoing LSAs 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_backup_designated_router_address
                                    
                                    	Address of backup designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_cost
                                    
                                    	Cost of path to this neighbor 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_designated_router_address
                                    
                                    	Address of designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_ignore_timer
                                    
                                    	Remaining time when ignore timer is running 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_option
                                    
                                    	 This is bitmask of neighbor's option field received 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission
                                    
                                    	Retransmission information with this neighbor
                                    	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                    
                                    .. attribute:: next_poll_interval
                                    
                                    	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: pending_events
                                    
                                    	Number of pending events 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: poll_interval
                                    
                                    	Poll interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_changes
                                    
                                    	Number of state changes 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail, self).__init__()

                                        self.yang_name = "neighbor-detail"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-retransmission" : ("neighbor_retransmission", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission)}
                                        self._child_list_classes = {}

                                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                        self.is_neighbor_filtered = YLeaf(YType.boolean, "is-neighbor-filtered")

                                        self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                        self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                        self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                        self.neighbor_ignore_timer = YLeaf(YType.uint32, "neighbor-ignore-timer")

                                        self.neighbor_option = YLeaf(YType.uint32, "neighbor-option")

                                        self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                        self.pending_events = YLeaf(YType.uint16, "pending-events")

                                        self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                        self.state_changes = YLeaf(YType.uint16, "state-changes")

                                        self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                        self.neighbor_retransmission.parent = self
                                        self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                        self._children_yang_names.add("neighbor-retransmission")
                                        self._segment_path = lambda: "neighbor-detail"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail, ['interface_type', 'is_neighbor_filtered', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_ignore_timer', 'neighbor_option', 'next_poll_interval', 'pending_events', 'poll_interval', 'state_changes'], name, value)


                                    class NeighborRetransmission(Entity):
                                        """
                                        Retransmission information with this neighbor
                                        
                                        .. attribute:: area_first_flood
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flood_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: database_descriptor_retransmissions
                                        
                                        	Number of database descriptor retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood
                                        
                                        	Link first flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood_index
                                        
                                        	Link first flood information index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_flood_index
                                        
                                        	Link flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood
                                        
                                        	Link next flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood_index
                                        
                                        	Link next flood information index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmissions
                                        
                                        	Number of neighbor retransmissions 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission, self).__init__()

                                            self.yang_name = "neighbor-retransmission"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                            self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                            self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                            self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                            self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                            self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                            self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                            self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                            self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                            self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                            self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                            self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                            self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                            self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                            self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                            self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                            self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                            self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                            self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                            self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                            self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                            self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                            self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                            self._segment_path = lambda: "neighbor-retransmission"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                        class RequestListTable(Entity):
                            """
                            OSPFv3 request list information in an area
                            
                            .. attribute:: request
                            
                            	OSPFv3 request list information
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable, self).__init__()

                                self.yang_name = "request-list-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"request" : ("request", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request)}

                                self.request = YList(self)
                                self._segment_path = lambda: "request-list-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable, [], name, value)


                            class Request(Entity):
                                """
                                OSPFv3 request list information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_request_sham_link
                                
                                	If true, sham link is requested 
                                	**type**\:  bool
                                
                                .. attribute:: is_request_virtual_link
                                
                                	If true, virtual link is requested 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request
                                
                                	List of request list entries
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request>`
                                
                                .. attribute:: request_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request_sham_link_id
                                
                                	Request sham link ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: request_virtual_link_id
                                
                                	Request virtual link ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "request-list-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"request" : ("request", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_request_sham_link = YLeaf(YType.boolean, "is-request-sham-link")

                                    self.is_request_virtual_link = YLeaf(YType.boolean, "is-request-virtual-link")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                    self.request_sham_link_id = YLeaf(YType.uint32, "request-sham-link-id")

                                    self.request_virtual_link_id = YLeaf(YType.uint32, "request-virtual-link-id")

                                    self.request = YList(self)
                                    self._segment_path = lambda: "request"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request, ['interface_name', 'is_request_sham_link', 'is_request_virtual_link', 'neighbor_address', 'request_neighbor_address', 'request_sham_link_id', 'request_virtual_link_id'], name, value)


                                class Request(Entity):
                                    """
                                    List of request list entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                        self._segment_path = lambda: "request"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class RetransmissionListTable(Entity):
                            """
                            OSPFv3 retransmission list information table
                            in an area
                            
                            .. attribute:: retransmission
                            
                            	OSPFv3 retransmission list information
                            	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable, self).__init__()

                                self.yang_name = "retransmission-list-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"retransmission" : ("retransmission", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission)}

                                self.retransmission = YList(self)
                                self._segment_path = lambda: "retransmission-list-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable, [], name, value)


                            class Retransmission(Entity):
                                """
                                OSPFv3 retransmission list information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_retransmission_sham_link
                                
                                	If true, sham link is retransmitted 
                                	**type**\:  bool
                                
                                .. attribute:: is_retransmissionvirtual_link
                                
                                	If true, virtual link is retransmitted 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_area_db
                                
                                	List of area scope entries
                                	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb>`
                                
                                .. attribute:: retransmission_asdb
                                
                                	List of AS scope entries
                                	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb>`
                                
                                .. attribute:: retransmission_length
                                
                                	Retransmission queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_sham_link_id
                                
                                	Retransmission sham link ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_timer
                                
                                	Amount of time remaining on retransmission timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissionvirtual_link_db
                                
                                	List of virtual link scope entries 
                                	**type**\: list of    :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb>`
                                
                                .. attribute:: retransmissionvirtual_link_id
                                
                                	Retransmission virtual link ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission, self).__init__()

                                    self.yang_name = "retransmission"
                                    self.yang_parent_name = "retransmission-list-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"retransmission-area-db" : ("retransmission_area_db", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb), "retransmission-asdb" : ("retransmission_asdb", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb), "retransmissionvirtual-link-db" : ("retransmissionvirtual_link_db", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_retransmission_sham_link = YLeaf(YType.boolean, "is-retransmission-sham-link")

                                    self.is_retransmissionvirtual_link = YLeaf(YType.boolean, "is-retransmissionvirtual-link")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.retransmission_length = YLeaf(YType.uint32, "retransmission-length")

                                    self.retransmission_neighbor_address = YLeaf(YType.str, "retransmission-neighbor-address")

                                    self.retransmission_sham_link_id = YLeaf(YType.uint32, "retransmission-sham-link-id")

                                    self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                    self.retransmissionvirtual_link_id = YLeaf(YType.uint32, "retransmissionvirtual-link-id")

                                    self.retransmission_area_db = YList(self)
                                    self.retransmission_asdb = YList(self)
                                    self.retransmissionvirtual_link_db = YList(self)
                                    self._segment_path = lambda: "retransmission"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission, ['interface_name', 'is_retransmission_sham_link', 'is_retransmissionvirtual_link', 'neighbor_address', 'retransmission_length', 'retransmission_neighbor_address', 'retransmission_sham_link_id', 'retransmission_timer', 'retransmissionvirtual_link_id'], name, value)


                                class RetransmissionAreaDb(Entity):
                                    """
                                    List of area scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb, self).__init__()

                                        self.yang_name = "retransmission-area-db"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                        self._segment_path = lambda: "retransmission-area-db"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                                class RetransmissionAsdb(Entity):
                                    """
                                    List of AS scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb, self).__init__()

                                        self.yang_name = "retransmission-asdb"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                        self._segment_path = lambda: "retransmission-asdb"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                                class RetransmissionvirtualLinkDb(Entity):
                                    """
                                    List of virtual link scope entries 
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb, self).__init__()

                                        self.yang_name = "retransmissionvirtual-link-db"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                        self._segment_path = lambda: "retransmissionvirtual-link-db"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                class BadChecksums(Entity):
                    """
                    Bad Checksum Packets information table
                    
                    .. attribute:: bad_checksum
                    
                    	Bad Checksum Packet information
                    	**type**\: list of    :py:class:`BadChecksum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.BadChecksums, self).__init__()

                        self.yang_name = "bad-checksums"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"bad-checksum" : ("bad_checksum", Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum)}

                        self.bad_checksum = YList(self)
                        self._segment_path = lambda: "bad-checksums"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BadChecksums, [], name, value)


                    class BadChecksum(Entity):
                        """
                        Bad Checksum Packet information
                        
                        .. attribute:: packet_number  <key>
                        
                        	Bad Checksum Packets number
                        	**type**\:  int
                        
                        	**range:** 0..9
                        
                        .. attribute:: computed_checksum
                        
                        	Computed Checksum
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_checksum
                        
                        	Received Checksum
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_data
                        
                        	Received Hexadecimal Data
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: timestamp
                        
                        	Packet Timestamp (relative to 1970/1/1 00\:00)
                        	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum, self).__init__()

                            self.yang_name = "bad-checksum"
                            self.yang_parent_name = "bad-checksums"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"timestamp" : ("timestamp", Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp)}
                            self._child_list_classes = {}

                            self.packet_number = YLeaf(YType.uint32, "packet-number")

                            self.computed_checksum = YLeaf(YType.uint16, "computed-checksum")

                            self.received_checksum = YLeaf(YType.uint16, "received-checksum")

                            self.received_data = YLeaf(YType.str, "received-data")

                            self.timestamp = Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp()
                            self.timestamp.parent = self
                            self._children_name_map["timestamp"] = "timestamp"
                            self._children_yang_names.add("timestamp")
                            self._segment_path = lambda: "bad-checksum" + "[packet-number='" + self.packet_number.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum, ['packet_number', 'computed_checksum', 'received_checksum', 'received_data'], name, value)


                        class Timestamp(Entity):
                            """
                            Packet Timestamp (relative to 1970/1/1 00\:00)
                            
                            .. attribute:: nanosecond
                            
                            	Nano seconds 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: second
                            
                            	Seconds 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp, self).__init__()

                                self.yang_name = "timestamp"
                                self.yang_parent_name = "bad-checksum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                self.second = YLeaf(YType.uint32, "second")
                                self._segment_path = lambda: "timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp, ['nanosecond', 'second'], name, value)


                class BorderRouters(Entity):
                    """
                    OSPFv3 border router information table
                    
                    .. attribute:: border_router
                    
                    	OSPFv3 border router information
                    	**type**\: list of    :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.BorderRouters, self).__init__()

                        self.yang_name = "border-routers"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"border-router" : ("border_router", Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter)}

                        self.border_router = YList(self)
                        self._segment_path = lambda: "border-routers"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BorderRouters, [], name, value)


                    class BorderRouter(Entity):
                        """
                        OSPFv3 border router information
                        
                        .. attribute:: border_router_id  <key>
                        
                        	Router address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: border_router_path
                        
                        	List of border router paths
                        	**type**\: list of    :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, self).__init__()

                            self.yang_name = "border-router"
                            self.yang_parent_name = "border-routers"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"border-router-path" : ("border_router_path", Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath)}

                            self.border_router_id = YLeaf(YType.str, "border-router-id")

                            self.border_router_path = YList(self)
                            self._segment_path = lambda: "border-router" + "[border-router-id='" + self.border_router_id.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, ['border_router_id'], name, value)


                        class BorderRouterPath(Entity):
                            """
                            List of border router paths
                            
                            .. attribute:: border_router_area_id
                            
                            	Area string in decimal or dotted\-decimal format 
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: border_router_next_hop
                            
                            	Next hop address 
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: border_router_type
                            
                            	Border router type 
                            	**type**\:   :py:class:`Ospfv3BorderRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3BorderRoute>`
                            
                            .. attribute:: interface_name
                            
                            	Next hop interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_intra_area_router
                            
                            	If true, intra\-area router else inter\-area router
                            	**type**\:  bool
                            
                            .. attribute:: spf_version
                            
                            	SPF version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, self).__init__()

                                self.yang_name = "border-router-path"
                                self.yang_parent_name = "border-router"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.border_router_area_id = YLeaf(YType.str, "border-router-area-id")

                                self.border_router_next_hop = YLeaf(YType.str, "border-router-next-hop")

                                self.border_router_route_metric = YLeaf(YType.uint32, "border-router-route-metric")

                                self.border_router_type = YLeaf(YType.enumeration, "border-router-type")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_intra_area_router = YLeaf(YType.boolean, "is-intra-area-router")

                                self.spf_version = YLeaf(YType.uint32, "spf-version")
                                self._segment_path = lambda: "border-router-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, ['border_router_area_id', 'border_router_next_hop', 'border_router_route_metric', 'border_router_type', 'interface_name', 'is_intra_area_router', 'spf_version'], name, value)


                class ConnectedRoutes(Entity):
                    """
                    OSPFv3 connected route information table
                    
                    .. attribute:: connected_route
                    
                    	OSPFv3 connected route information
                    	**type**\: list of    :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes, self).__init__()

                        self.yang_name = "connected-routes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"connected-route" : ("connected_route", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute)}

                        self.connected_route = YList(self)
                        self._segment_path = lambda: "connected-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes, [], name, value)


                    class ConnectedRoute(Entity):
                        """
                        OSPFv3 connected route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath>`
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute, self).__init__()

                            self.yang_name = "connected-route"
                            self.yang_parent_name = "connected-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"route-topology" : ("route_topology", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology)}
                            self._child_list_classes = {"route-path" : ("route_path", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath)}

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology()
                            self.route_topology.parent = self
                            self._children_name_map["route_topology"] = "route-topology"
                            self._children_yang_names.add("route-topology")

                            self.route_path = YList(self)
                            self._segment_path = lambda: "connected-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute, ['prefix', 'prefix_length'], name, value)


                        class RoutePath(Entity):
                            """
                            List of paths to this route
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "connected-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath)}
                                self._child_list_classes = {}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                self.route_path_next_hop = YLeaf(YType.str, "route-path-next-hop")

                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                self._children_yang_names.add("route-backup-path")
                                self._segment_path = lambda: "route-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath, ['interface_name', 'route_path_id', 'route_path_next_hop'], name, value)


                            class RouteBackupPath(Entity):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\:  bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\:  bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\:  bool
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\:  bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath, self).__init__()

                                    self.yang_name = "route-backup-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                    self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                    self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                    self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                    self.downstream = YLeaf(YType.boolean, "downstream")

                                    self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                    self.node_protect = YLeaf(YType.boolean, "node-protect")

                                    self.primary_path = YLeaf(YType.boolean, "primary-path")

                                    self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")
                                    self._segment_path = lambda: "route-backup-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                        class RouteTopology(Entity):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology, self).__init__()

                                self.yang_name = "route-topology"
                                self.yang_parent_name = "connected-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.route_cost = YLeaf(YType.uint32, "route-cost")

                                self.route_distance = YLeaf(YType.uint32, "route-distance")

                                self.route_id = YLeaf(YType.str, "route-id")

                                self.route_type = YLeaf(YType.uint32, "route-type")
                                self._segment_path = lambda: "route-topology"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology, ['route_cost', 'route_distance', 'route_id', 'route_type'], name, value)


                class DatabaseSummaryTable(Entity):
                    """
                    Database summary table
                    
                    .. attribute:: database_summary
                    
                    	Database Summary information
                    	**type**\:   :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable, self).__init__()

                        self.yang_name = "database-summary-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"database-summary" : ("database_summary", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary)}
                        self._child_list_classes = {}

                        self.database_summary = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary()
                        self.database_summary.parent = self
                        self._children_name_map["database_summary"] = "database-summary"
                        self._children_yang_names.add("database-summary")
                        self._segment_path = lambda: "database-summary-table"


                    class DatabaseSummary(Entity):
                        """
                        Database Summary information
                        
                        .. attribute:: area_database
                        
                        	OSPFv3 Area Database list 
                        	**type**\: list of    :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                        
                        .. attribute:: database_counters
                        
                        	OSPFv3 database counters 
                        	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                        
                        .. attribute:: database_router_id
                        
                        	Database router ID 
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_opaque_database_capable
                        
                        	If true, opaque database is capable 
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary, self).__init__()

                            self.yang_name = "database-summary"
                            self.yang_parent_name = "database-summary-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"database-counters" : ("database_counters", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters)}
                            self._child_list_classes = {"area-database" : ("area_database", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase)}

                            self.database_router_id = YLeaf(YType.str, "database-router-id")

                            self.is_opaque_database_capable = YLeaf(YType.boolean, "is-opaque-database-capable")

                            self.database_counters = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                            self.database_counters.parent = self
                            self._children_name_map["database_counters"] = "database-counters"
                            self._children_yang_names.add("database-counters")

                            self.area_database = YList(self)
                            self._segment_path = lambda: "database-summary"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary, ['database_router_id', 'is_opaque_database_capable'], name, value)


                        class AreaDatabase(Entity):
                            """
                            OSPFv3 Area Database list 
                            
                            .. attribute:: area_database_summary
                            
                            	Area database summary 
                            	**type**\:   :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                            
                            .. attribute:: lsa_area_id
                            
                            	Area ID in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, self).__init__()

                                self.yang_name = "area-database"
                                self.yang_parent_name = "database-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"area-database-summary" : ("area_database_summary", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary)}
                                self._child_list_classes = {}

                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                self.area_database_summary = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                self.area_database_summary.parent = self
                                self._children_name_map["area_database_summary"] = "area-database-summary"
                                self._children_yang_names.add("area-database-summary")
                                self._segment_path = lambda: "area-database"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, ['lsa_area_id'], name, value)


                            class AreaDatabaseSummary(Entity):
                                """
                                Area database summary 
                                
                                .. attribute:: deleted_lsa
                                
                                	deleted lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa
                                
                                	lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_checksum
                                
                                	lsa checksum
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_age_lsa
                                
                                	max age lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, self).__init__()

                                    self.yang_name = "area-database-summary"
                                    self.yang_parent_name = "area-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.deleted_lsa = YLeafList(YType.uint32, "deleted-lsa")

                                    self.lsa = YLeafList(YType.uint32, "lsa")

                                    self.lsa_checksum = YLeafList(YType.uint32, "lsa-checksum")

                                    self.max_age_lsa = YLeafList(YType.uint32, "max-age-lsa")
                                    self._segment_path = lambda: "area-database-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, ['deleted_lsa', 'lsa', 'lsa_checksum', 'max_age_lsa'], name, value)


                        class DatabaseCounters(Entity):
                            """
                            OSPFv3 database counters 
                            
                            .. attribute:: deleted_lsa
                            
                            	deleted lsa
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa
                            
                            	lsa
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_checksum
                            
                            	lsa checksum
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_age_lsa
                            
                            	max age lsa
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, self).__init__()

                                self.yang_name = "database-counters"
                                self.yang_parent_name = "database-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.deleted_lsa = YLeafList(YType.uint32, "deleted-lsa")

                                self.lsa = YLeafList(YType.uint32, "lsa")

                                self.lsa_checksum = YLeafList(YType.uint32, "lsa-checksum")

                                self.max_age_lsa = YLeafList(YType.uint32, "max-age-lsa")
                                self._segment_path = lambda: "database-counters"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, ['deleted_lsa', 'lsa', 'lsa_checksum', 'max_age_lsa'], name, value)


                class DatabaseTable(Entity):
                    """
                    OSPF Link State Database
                    
                    .. attribute:: lsa_internal_table
                    
                    	Database LSA information
                    	**type**\:   :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable>`
                    
                    .. attribute:: lsa_table
                    
                    	Database LSA information
                    	**type**\:   :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable, self).__init__()

                        self.yang_name = "database-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"lsa-internal-table" : ("lsa_internal_table", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable), "lsa-table" : ("lsa_table", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable)}
                        self._child_list_classes = {}

                        self.lsa_internal_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable()
                        self.lsa_internal_table.parent = self
                        self._children_name_map["lsa_internal_table"] = "lsa-internal-table"
                        self._children_yang_names.add("lsa-internal-table")

                        self.lsa_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable()
                        self.lsa_table.parent = self
                        self._children_name_map["lsa_table"] = "lsa-table"
                        self._children_yang_names.add("lsa-table")
                        self._segment_path = lambda: "database-table"


                    class LsaInternalTable(Entity):
                        """
                        Database LSA information
                        
                        .. attribute:: lsa
                        
                        	Database LSA information
                        	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable, self).__init__()

                            self.yang_name = "lsa-internal-table"
                            self.yang_parent_name = "database-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"lsa" : ("lsa", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa)}

                            self.lsa = YList(self)
                            self._segment_path = lambda: "lsa-internal-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable, [], name, value)


                        class Lsa(Entity):
                            """
                            Database LSA information
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	InterfaceName
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ls_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                            
                            .. attribute:: lsa_info
                            
                            	Summary of all LSAs or LSA specific information 
                            	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "lsa-internal-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"lsa-info" : ("lsa_info", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo)}
                                self._child_list_classes = {}

                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.ls_id = YLeaf(YType.int32, "ls-id")

                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                self.lsa_info.parent = self
                                self._children_name_map["lsa_info"] = "lsa-info"
                                self._children_yang_names.add("lsa-info")
                                self._segment_path = lambda: "lsa"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                            class LsaInfo(Entity):
                                """
                                Summary of all LSAs or LSA specific information 
                                
                                .. attribute:: external_lsa_type
                                
                                	External LSA
                                	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                
                                .. attribute:: grace_lsa
                                
                                	Grace LSA
                                	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                
                                .. attribute:: inter_area_prefix_lsa_type
                                
                                	Inter Area Prefix LSA
                                	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                
                                .. attribute:: inter_area_router_lsa_type
                                
                                	Inter Area Router LSA
                                	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                
                                .. attribute:: intra_area_prefix_lsa_type
                                
                                	Intra Area Prefix LSA
                                	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                
                                .. attribute:: link_lsa_type
                                
                                	Link LSA
                                	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                
                                .. attribute:: lsa_info_type
                                
                                	LSAInfoType
                                	**type**\:   :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                
                                .. attribute:: lsa_summary_info
                                
                                	Summary information of LSAs
                                	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                
                                .. attribute:: network_lsa_type
                                
                                	Network LSA
                                	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                
                                .. attribute:: nssalsa_type
                                
                                	NSSA External LSA
                                	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                
                                .. attribute:: router_lsa_type
                                
                                	Router LSA
                                	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                
                                .. attribute:: unknown_area_lsa_type
                                
                                	Unknown\-Area scope LSA
                                	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                
                                .. attribute:: unknown_aslsa_type
                                
                                	Unknown\-AS scope LSA
                                	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                
                                .. attribute:: unknown_link_lsa_type
                                
                                	Unknown Link Scope LSA
                                	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                
                                .. attribute:: unknown_lsa_type
                                
                                	Unknown LSA
                                	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, self).__init__()

                                    self.yang_name = "lsa-info"
                                    self.yang_parent_name = "lsa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType), "grace-lsa" : ("grace_lsa", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa), "inter-area-prefix-lsa-type" : ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType), "inter-area-router-lsa-type" : ("inter_area_router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType), "intra-area-prefix-lsa-type" : ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType), "link-lsa-type" : ("link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType), "lsa-summary-info" : ("lsa_summary_info", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo), "network-lsa-type" : ("network_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType), "nssalsa-type" : ("nssalsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType), "router-lsa-type" : ("router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType), "unknown-area-lsa-type" : ("unknown_area_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType), "unknown-aslsa-type" : ("unknown_aslsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType), "unknown-link-lsa-type" : ("unknown_link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType), "unknown-lsa-type" : ("unknown_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType)}
                                    self._child_list_classes = {}

                                    self.lsa_info_type = YLeaf(YType.enumeration, "lsa-info-type")

                                    self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                    self.external_lsa_type.parent = self
                                    self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                    self._children_yang_names.add("external-lsa-type")

                                    self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                    self.grace_lsa.parent = self
                                    self._children_name_map["grace_lsa"] = "grace-lsa"
                                    self._children_yang_names.add("grace-lsa")

                                    self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                    self.inter_area_prefix_lsa_type.parent = self
                                    self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"
                                    self._children_yang_names.add("inter-area-prefix-lsa-type")

                                    self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                    self.inter_area_router_lsa_type.parent = self
                                    self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"
                                    self._children_yang_names.add("inter-area-router-lsa-type")

                                    self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                    self.intra_area_prefix_lsa_type.parent = self
                                    self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"
                                    self._children_yang_names.add("intra-area-prefix-lsa-type")

                                    self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                    self.link_lsa_type.parent = self
                                    self._children_name_map["link_lsa_type"] = "link-lsa-type"
                                    self._children_yang_names.add("link-lsa-type")

                                    self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                    self.lsa_summary_info.parent = self
                                    self._children_name_map["lsa_summary_info"] = "lsa-summary-info"
                                    self._children_yang_names.add("lsa-summary-info")

                                    self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                    self.network_lsa_type.parent = self
                                    self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                    self._children_yang_names.add("network-lsa-type")

                                    self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                    self.nssalsa_type.parent = self
                                    self._children_name_map["nssalsa_type"] = "nssalsa-type"
                                    self._children_yang_names.add("nssalsa-type")

                                    self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                    self.router_lsa_type.parent = self
                                    self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                    self._children_yang_names.add("router-lsa-type")

                                    self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                    self.unknown_area_lsa_type.parent = self
                                    self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"
                                    self._children_yang_names.add("unknown-area-lsa-type")

                                    self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                    self.unknown_aslsa_type.parent = self
                                    self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"
                                    self._children_yang_names.add("unknown-aslsa-type")

                                    self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                    self.unknown_link_lsa_type.parent = self
                                    self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"
                                    self._children_yang_names.add("unknown-link-lsa-type")

                                    self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                    self.unknown_lsa_type.parent = self
                                    self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                    self._children_yang_names.add("unknown-lsa-type")
                                    self._segment_path = lambda: "lsa-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, ['lsa_info_type'], name, value)


                                class ExternalLsaType(Entity):
                                    """
                                    External LSA
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                        self.yang_name = "external-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.external_tag = YLeaf(YType.uint32, "external-tag")

                                        self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                        self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "external-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class GraceLsa(Entity):
                                    """
                                    Grace LSA
                                    
                                    .. attribute:: grace_period
                                    
                                    	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_reason
                                    
                                    	Reason for router restart
                                    	**type**\:   :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                        self.yang_name = "grace-lsa"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.grace_period = YLeaf(YType.uint32, "grace-period")

                                        self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "grace-lsa"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, ['grace_period', 'grace_reason'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "grace-lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "grace-lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class InterAreaPrefixLsaType(Entity):
                                    """
                                    Inter Area Prefix LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: prefix
                                    
                                    	LSA address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                        self.yang_name = "inter-area-prefix-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "inter-area-prefix-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, ['prefix', 'prefix_length', 'priority'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "inter-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "inter-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class InterAreaRouterLsaType(Entity):
                                    """
                                    Inter Area Router LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                        self.yang_name = "inter-area-router-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "inter-area-router-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, ['lsa_router_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "inter-area-router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "inter-area-router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class IntraAreaPrefixLsaType(Entity):
                                    """
                                    Intra Area Prefix LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                    
                                    .. attribute:: reference_advertised_router
                                    
                                    	Reference advertised router 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                        self.yang_name = "intra-area-prefix-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)}
                                        self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix)}

                                        self.reference_advertised_router = YLeaf(YType.str, "reference-advertised-router")

                                        self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                        self.reference_type = YLeaf(YType.enumeration, "reference-type")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                        self.prefix = YList(self)
                                        self._segment_path = lambda: "intra-area-prefix-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, ['reference_advertised_router', 'reference_lsa_id', 'reference_type'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class Prefix(Entity):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                            self.yang_name = "prefix"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                            self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                            self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.priority = YLeaf(YType.enumeration, "priority")
                                            self._segment_path = lambda: "prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                class LinkLsaType(Entity):
                                    """
                                    Link LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface handle
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_link_local
                                    
                                    	LSA link local 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                    
                                    .. attribute:: router_priority
                                    
                                    	Router priority 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                        self.yang_name = "link-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)}
                                        self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.lsa_link_local = YLeaf(YType.str, "lsa-link-local")

                                        self.router_priority = YLeaf(YType.uint8, "router-priority")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                        self.prefix = YList(self)
                                        self._segment_path = lambda: "link-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'lsa_link_local', 'router_priority', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class Prefix(Entity):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                            self.yang_name = "prefix"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                            self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                            self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.priority = YLeaf(YType.enumeration, "priority")
                                            self._segment_path = lambda: "prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                class LsaSummaryInfo(Entity):
                                    """
                                    Summary information of LSAs
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: links
                                    
                                    	Number of links
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 address Prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                        self.yang_name = "lsa-summary-info"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.links = YLeaf(YType.uint16, "links")

                                        self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                        self.reference_type = YLeaf(YType.uint16, "reference-type")

                                        self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "lsa-summary-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, ['interface_name', 'is_sham_link', 'is_virtual_link', 'links', 'lsa_router_id', 'prefix', 'prefix_length', 'reference_lsa_id', 'reference_type', 'router_la_bits', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "lsa-summary-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "lsa-summary-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class NetworkLsaType(Entity):
                                    """
                                    Network LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                    
                                    .. attribute:: neighbor_router
                                    
                                    	Neighbor router list
                                    	**type**\:  list of str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                        self.yang_name = "network-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.neighbor_router = YLeafList(YType.str, "neighbor-router")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "network-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, ['neighbor_router'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class NssalsaType(Entity):
                                    """
                                    NSSA External LSA
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                        self.yang_name = "nssalsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.external_tag = YLeaf(YType.uint32, "external-tag")

                                        self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                        self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "nssalsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "nssalsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "nssalsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class RouterLsaType(Entity):
                                    """
                                    Router LSA
                                    
                                    .. attribute:: link
                                    
                                    	List of links in this LSA
                                    	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rpf_path
                                    
                                    	Router LSA Reverse\-Path Forwarding information 
                                    	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                        self.yang_name = "router-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader), "rpf-path" : ("rpf_path", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath)}
                                        self._child_list_classes = {"link" : ("link", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link)}

                                        self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                        self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                        self.rpf_path.parent = self
                                        self._children_name_map["rpf_path"] = "rpf-path"
                                        self._children_yang_names.add("rpf-path")

                                        self.link = YList(self)
                                        self._segment_path = lambda: "router-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, ['router_la_bits'], name, value)


                                    class Link(Entity):
                                        """
                                        List of links in this LSA
                                        
                                        .. attribute:: link_interface_id
                                        
                                        	LSA link interface ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_metric
                                        
                                        	LSA link metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_neighbor_interface_id
                                        
                                        	LSA link neighbor interface ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_neighbor_router_id
                                        
                                        	LSA link neigbhor router id 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                            self.yang_name = "link"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.link_interface_id = YLeaf(YType.uint32, "link-interface-id")

                                            self.link_metric = YLeaf(YType.uint16, "link-metric")

                                            self.link_neighbor_interface_id = YLeaf(YType.uint32, "link-neighbor-interface-id")

                                            self.link_neighbor_router_id = YLeaf(YType.uint32, "link-neighbor-router-id")

                                            self.link_type = YLeaf(YType.enumeration, "link-type")
                                            self._segment_path = lambda: "link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, ['link_interface_id', 'link_metric', 'link_neighbor_interface_id', 'link_neighbor_router_id', 'link_type'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class RpfPath(Entity):
                                        """
                                        Router LSA Reverse\-Path Forwarding information 
                                        
                                        .. attribute:: interface_name
                                        
                                        	RPF multicast IDB 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: rpf_multicast_next_hop
                                        
                                        	RPF multicast next hop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                            self.yang_name = "rpf-path"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.rpf_multicast_next_hop = YLeaf(YType.uint32, "rpf-multicast-next-hop")
                                            self._segment_path = lambda: "rpf-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, ['interface_name', 'rpf_multicast_next_hop'], name, value)


                                class UnknownAreaLsaType(Entity):
                                    """
                                    Unknown\-Area scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                        self.yang_name = "unknown-area-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "unknown-area-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-area-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-area-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class UnknownAslsaType(Entity):
                                    """
                                    Unknown\-AS scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                        self.yang_name = "unknown-aslsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "unknown-aslsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-aslsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-aslsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class UnknownLinkLsaType(Entity):
                                    """
                                    Unknown Link Scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                        self.yang_name = "unknown-link-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "unknown-link-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class UnknownLsaType(Entity):
                                    """
                                    Unknown LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                        self.yang_name = "unknown-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "unknown-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                    class LsaTable(Entity):
                        """
                        Database LSA information
                        
                        .. attribute:: lsa
                        
                        	Database LSA information
                        	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable, self).__init__()

                            self.yang_name = "lsa-table"
                            self.yang_parent_name = "database-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"lsa" : ("lsa", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa)}

                            self.lsa = YList(self)
                            self._segment_path = lambda: "lsa-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable, [], name, value)


                        class Lsa(Entity):
                            """
                            Database LSA information
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	InterfaceName
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ls_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                            
                            .. attribute:: lsa_info
                            
                            	Summary of all LSAs or LSA specific information 
                            	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "lsa-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"lsa-info" : ("lsa_info", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo)}
                                self._child_list_classes = {}

                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.ls_id = YLeaf(YType.int32, "ls-id")

                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                self.lsa_info.parent = self
                                self._children_name_map["lsa_info"] = "lsa-info"
                                self._children_yang_names.add("lsa-info")
                                self._segment_path = lambda: "lsa"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                            class LsaInfo(Entity):
                                """
                                Summary of all LSAs or LSA specific information 
                                
                                .. attribute:: external_lsa_type
                                
                                	External LSA
                                	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                
                                .. attribute:: grace_lsa
                                
                                	Grace LSA
                                	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                
                                .. attribute:: inter_area_prefix_lsa_type
                                
                                	Inter Area Prefix LSA
                                	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                
                                .. attribute:: inter_area_router_lsa_type
                                
                                	Inter Area Router LSA
                                	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                
                                .. attribute:: intra_area_prefix_lsa_type
                                
                                	Intra Area Prefix LSA
                                	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                
                                .. attribute:: link_lsa_type
                                
                                	Link LSA
                                	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                
                                .. attribute:: lsa_info_type
                                
                                	LSAInfoType
                                	**type**\:   :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                
                                .. attribute:: lsa_summary_info
                                
                                	Summary information of LSAs
                                	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                
                                .. attribute:: network_lsa_type
                                
                                	Network LSA
                                	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                
                                .. attribute:: nssalsa_type
                                
                                	NSSA External LSA
                                	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                
                                .. attribute:: router_lsa_type
                                
                                	Router LSA
                                	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                
                                .. attribute:: unknown_area_lsa_type
                                
                                	Unknown\-Area scope LSA
                                	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                
                                .. attribute:: unknown_aslsa_type
                                
                                	Unknown\-AS scope LSA
                                	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                
                                .. attribute:: unknown_link_lsa_type
                                
                                	Unknown Link Scope LSA
                                	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                
                                .. attribute:: unknown_lsa_type
                                
                                	Unknown LSA
                                	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo, self).__init__()

                                    self.yang_name = "lsa-info"
                                    self.yang_parent_name = "lsa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType), "grace-lsa" : ("grace_lsa", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa), "inter-area-prefix-lsa-type" : ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType), "inter-area-router-lsa-type" : ("inter_area_router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType), "intra-area-prefix-lsa-type" : ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType), "link-lsa-type" : ("link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType), "lsa-summary-info" : ("lsa_summary_info", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo), "network-lsa-type" : ("network_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType), "nssalsa-type" : ("nssalsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType), "router-lsa-type" : ("router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType), "unknown-area-lsa-type" : ("unknown_area_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType), "unknown-aslsa-type" : ("unknown_aslsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType), "unknown-link-lsa-type" : ("unknown_link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType), "unknown-lsa-type" : ("unknown_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType)}
                                    self._child_list_classes = {}

                                    self.lsa_info_type = YLeaf(YType.enumeration, "lsa-info-type")

                                    self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                    self.external_lsa_type.parent = self
                                    self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                    self._children_yang_names.add("external-lsa-type")

                                    self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                    self.grace_lsa.parent = self
                                    self._children_name_map["grace_lsa"] = "grace-lsa"
                                    self._children_yang_names.add("grace-lsa")

                                    self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                    self.inter_area_prefix_lsa_type.parent = self
                                    self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"
                                    self._children_yang_names.add("inter-area-prefix-lsa-type")

                                    self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                    self.inter_area_router_lsa_type.parent = self
                                    self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"
                                    self._children_yang_names.add("inter-area-router-lsa-type")

                                    self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                    self.intra_area_prefix_lsa_type.parent = self
                                    self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"
                                    self._children_yang_names.add("intra-area-prefix-lsa-type")

                                    self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                    self.link_lsa_type.parent = self
                                    self._children_name_map["link_lsa_type"] = "link-lsa-type"
                                    self._children_yang_names.add("link-lsa-type")

                                    self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                    self.lsa_summary_info.parent = self
                                    self._children_name_map["lsa_summary_info"] = "lsa-summary-info"
                                    self._children_yang_names.add("lsa-summary-info")

                                    self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                    self.network_lsa_type.parent = self
                                    self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                    self._children_yang_names.add("network-lsa-type")

                                    self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                    self.nssalsa_type.parent = self
                                    self._children_name_map["nssalsa_type"] = "nssalsa-type"
                                    self._children_yang_names.add("nssalsa-type")

                                    self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                    self.router_lsa_type.parent = self
                                    self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                    self._children_yang_names.add("router-lsa-type")

                                    self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                    self.unknown_area_lsa_type.parent = self
                                    self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"
                                    self._children_yang_names.add("unknown-area-lsa-type")

                                    self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                    self.unknown_aslsa_type.parent = self
                                    self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"
                                    self._children_yang_names.add("unknown-aslsa-type")

                                    self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                    self.unknown_link_lsa_type.parent = self
                                    self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"
                                    self._children_yang_names.add("unknown-link-lsa-type")

                                    self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                    self.unknown_lsa_type.parent = self
                                    self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                    self._children_yang_names.add("unknown-lsa-type")
                                    self._segment_path = lambda: "lsa-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo, ['lsa_info_type'], name, value)


                                class ExternalLsaType(Entity):
                                    """
                                    External LSA
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                        self.yang_name = "external-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.external_tag = YLeaf(YType.uint32, "external-tag")

                                        self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                        self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "external-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class GraceLsa(Entity):
                                    """
                                    Grace LSA
                                    
                                    .. attribute:: grace_period
                                    
                                    	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_reason
                                    
                                    	Reason for router restart
                                    	**type**\:   :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                        self.yang_name = "grace-lsa"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.grace_period = YLeaf(YType.uint32, "grace-period")

                                        self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "grace-lsa"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, ['grace_period', 'grace_reason'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "grace-lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "grace-lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class InterAreaPrefixLsaType(Entity):
                                    """
                                    Inter Area Prefix LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: prefix
                                    
                                    	LSA address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                        self.yang_name = "inter-area-prefix-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "inter-area-prefix-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, ['prefix', 'prefix_length', 'priority'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "inter-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "inter-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class InterAreaRouterLsaType(Entity):
                                    """
                                    Inter Area Router LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                        self.yang_name = "inter-area-router-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "inter-area-router-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, ['lsa_router_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "inter-area-router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "inter-area-router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class IntraAreaPrefixLsaType(Entity):
                                    """
                                    Intra Area Prefix LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                    
                                    .. attribute:: reference_advertised_router
                                    
                                    	Reference advertised router 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                        self.yang_name = "intra-area-prefix-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)}
                                        self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix)}

                                        self.reference_advertised_router = YLeaf(YType.str, "reference-advertised-router")

                                        self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                        self.reference_type = YLeaf(YType.enumeration, "reference-type")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                        self.prefix = YList(self)
                                        self._segment_path = lambda: "intra-area-prefix-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, ['reference_advertised_router', 'reference_lsa_id', 'reference_type'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class Prefix(Entity):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                            self.yang_name = "prefix"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                            self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                            self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.priority = YLeaf(YType.enumeration, "priority")
                                            self._segment_path = lambda: "prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                class LinkLsaType(Entity):
                                    """
                                    Link LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface handle
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_link_local
                                    
                                    	LSA link local 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                    
                                    .. attribute:: router_priority
                                    
                                    	Router priority 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                        self.yang_name = "link-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)}
                                        self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.lsa_link_local = YLeaf(YType.str, "lsa-link-local")

                                        self.router_priority = YLeaf(YType.uint8, "router-priority")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                        self.prefix = YList(self)
                                        self._segment_path = lambda: "link-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'lsa_link_local', 'router_priority', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class Prefix(Entity):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                            self.yang_name = "prefix"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                            self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                            self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.priority = YLeaf(YType.enumeration, "priority")
                                            self._segment_path = lambda: "prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                class LsaSummaryInfo(Entity):
                                    """
                                    Summary information of LSAs
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: links
                                    
                                    	Number of links
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 address Prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                        self.yang_name = "lsa-summary-info"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.links = YLeaf(YType.uint16, "links")

                                        self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                        self.reference_type = YLeaf(YType.uint16, "reference-type")

                                        self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "lsa-summary-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, ['interface_name', 'is_sham_link', 'is_virtual_link', 'links', 'lsa_router_id', 'prefix', 'prefix_length', 'reference_lsa_id', 'reference_type', 'router_la_bits', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "lsa-summary-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "lsa-summary-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class NetworkLsaType(Entity):
                                    """
                                    Network LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                    
                                    .. attribute:: neighbor_router
                                    
                                    	Neighbor router list
                                    	**type**\:  list of str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                        self.yang_name = "network-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.neighbor_router = YLeafList(YType.str, "neighbor-router")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "network-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, ['neighbor_router'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class NssalsaType(Entity):
                                    """
                                    NSSA External LSA
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                        self.yang_name = "nssalsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.external_tag = YLeaf(YType.uint32, "external-tag")

                                        self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                        self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "nssalsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "nssalsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "nssalsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class RouterLsaType(Entity):
                                    """
                                    Router LSA
                                    
                                    .. attribute:: link
                                    
                                    	List of links in this LSA
                                    	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rpf_path
                                    
                                    	Router LSA Reverse\-Path Forwarding information 
                                    	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                        self.yang_name = "router-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader), "rpf-path" : ("rpf_path", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath)}
                                        self._child_list_classes = {"link" : ("link", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link)}

                                        self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                        self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                        self.rpf_path.parent = self
                                        self._children_name_map["rpf_path"] = "rpf-path"
                                        self._children_yang_names.add("rpf-path")

                                        self.link = YList(self)
                                        self._segment_path = lambda: "router-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, ['router_la_bits'], name, value)


                                    class Link(Entity):
                                        """
                                        List of links in this LSA
                                        
                                        .. attribute:: link_interface_id
                                        
                                        	LSA link interface ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_metric
                                        
                                        	LSA link metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_neighbor_interface_id
                                        
                                        	LSA link neighbor interface ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_neighbor_router_id
                                        
                                        	LSA link neigbhor router id 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                            self.yang_name = "link"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.link_interface_id = YLeaf(YType.uint32, "link-interface-id")

                                            self.link_metric = YLeaf(YType.uint16, "link-metric")

                                            self.link_neighbor_interface_id = YLeaf(YType.uint32, "link-neighbor-interface-id")

                                            self.link_neighbor_router_id = YLeaf(YType.uint32, "link-neighbor-router-id")

                                            self.link_type = YLeaf(YType.enumeration, "link-type")
                                            self._segment_path = lambda: "link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, ['link_interface_id', 'link_metric', 'link_neighbor_interface_id', 'link_neighbor_router_id', 'link_type'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class RpfPath(Entity):
                                        """
                                        Router LSA Reverse\-Path Forwarding information 
                                        
                                        .. attribute:: interface_name
                                        
                                        	RPF multicast IDB 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: rpf_multicast_next_hop
                                        
                                        	RPF multicast next hop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                            self.yang_name = "rpf-path"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.rpf_multicast_next_hop = YLeaf(YType.uint32, "rpf-multicast-next-hop")
                                            self._segment_path = lambda: "rpf-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, ['interface_name', 'rpf_multicast_next_hop'], name, value)


                                class UnknownAreaLsaType(Entity):
                                    """
                                    Unknown\-Area scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                        self.yang_name = "unknown-area-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "unknown-area-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-area-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-area-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class UnknownAslsaType(Entity):
                                    """
                                    Unknown\-AS scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                        self.yang_name = "unknown-aslsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "unknown-aslsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-aslsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-aslsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class UnknownLinkLsaType(Entity):
                                    """
                                    Unknown Link Scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                        self.yang_name = "unknown-link-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "unknown-link-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class UnknownLsaType(Entity):
                                    """
                                    Unknown LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                        self.yang_name = "unknown-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                        self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                        self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                        self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._children_yang_names.add("lsa-detail")

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "unknown-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                            self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                            self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                            self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                            self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                            self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                            self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                            self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                            self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                            self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                            self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                            self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                            self._segment_path = lambda: "lsa-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                            self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                            self.ls_id = YLeaf(YType.uint32, "ls-id")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                class ExternalRoutes(Entity):
                    """
                    OSPFv3 external route information table
                    
                    .. attribute:: external_route
                    
                    	OSPFv3 external route information
                    	**type**\: list of    :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes, self).__init__()

                        self.yang_name = "external-routes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"external-route" : ("external_route", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute)}

                        self.external_route = YList(self)
                        self._segment_path = lambda: "external-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes, [], name, value)


                    class ExternalRoute(Entity):
                        """
                        OSPFv3 external route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_extended_community
                        
                        	Extended communities in the route
                        	**type**\:   :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath>`
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute, self).__init__()

                            self.yang_name = "external-route"
                            self.yang_parent_name = "external-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"route-extended-community" : ("route_extended_community", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity), "route-topology" : ("route_topology", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology)}
                            self._child_list_classes = {"route-path" : ("route_path", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath)}

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.route_extended_community = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                            self.route_extended_community.parent = self
                            self._children_name_map["route_extended_community"] = "route-extended-community"
                            self._children_yang_names.add("route-extended-community")

                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology()
                            self.route_topology.parent = self
                            self._children_name_map["route_topology"] = "route-topology"
                            self._children_yang_names.add("route-topology")

                            self.route_path = YList(self)
                            self._segment_path = lambda: "external-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute, ['prefix', 'prefix_length'], name, value)


                        class RouteExtendedCommunity(Entity):
                            """
                            Extended communities in the route
                            
                            .. attribute:: extended_community_area_id
                            
                            	Area id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_domain_id_value
                            
                            	Domain ID value
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: extended_community_options
                            
                            	Route Options
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: extended_community_route_type
                            
                            	Route type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: extended_community_router_id
                            
                            	Router id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: extended_communityl_domain_id_type
                            
                            	Domain ID type
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__init__()

                                self.yang_name = "route-extended-community"
                                self.yang_parent_name = "external-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.extended_community_area_id = YLeaf(YType.uint32, "extended-community-area-id")

                                self.extended_community_domain_id_value = YLeaf(YType.str, "extended-community-domain-id-value")

                                self.extended_community_options = YLeaf(YType.uint8, "extended-community-options")

                                self.extended_community_route_type = YLeaf(YType.uint8, "extended-community-route-type")

                                self.extended_community_router_id = YLeaf(YType.str, "extended-community-router-id")

                                self.extended_communityl_domain_id_type = YLeaf(YType.uint16, "extended-communityl-domain-id-type")
                                self._segment_path = lambda: "route-extended-community"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, ['extended_community_area_id', 'extended_community_domain_id_value', 'extended_community_options', 'extended_community_route_type', 'extended_community_router_id', 'extended_communityl_domain_id_type'], name, value)


                        class RoutePath(Entity):
                            """
                            List of paths to this route
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "external-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath)}
                                self._child_list_classes = {}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                self.route_path_next_hop = YLeaf(YType.str, "route-path-next-hop")

                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                self._children_yang_names.add("route-backup-path")
                                self._segment_path = lambda: "route-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath, ['interface_name', 'route_path_id', 'route_path_next_hop'], name, value)


                            class RouteBackupPath(Entity):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\:  bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\:  bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\:  bool
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\:  bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath, self).__init__()

                                    self.yang_name = "route-backup-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                    self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                    self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                    self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                    self.downstream = YLeaf(YType.boolean, "downstream")

                                    self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                    self.node_protect = YLeaf(YType.boolean, "node-protect")

                                    self.primary_path = YLeaf(YType.boolean, "primary-path")

                                    self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")
                                    self._segment_path = lambda: "route-backup-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                        class RouteTopology(Entity):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology, self).__init__()

                                self.yang_name = "route-topology"
                                self.yang_parent_name = "external-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.route_cost = YLeaf(YType.uint32, "route-cost")

                                self.route_distance = YLeaf(YType.uint32, "route-distance")

                                self.route_id = YLeaf(YType.str, "route-id")

                                self.route_type = YLeaf(YType.uint32, "route-type")
                                self._segment_path = lambda: "route-topology"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology, ['route_cost', 'route_distance', 'route_id', 'route_type'], name, value)


                class FastReroutes(Entity):
                    """
                    OSPFv3 fast reroute topology information table
                    
                    .. attribute:: fast_reroute
                    
                    	OSPFv3 fast reroute topology information
                    	**type**\: list of    :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.FastReroutes, self).__init__()

                        self.yang_name = "fast-reroutes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"fast-reroute" : ("fast_reroute", Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute)}

                        self.fast_reroute = YList(self)
                        self._segment_path = lambda: "fast-reroutes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FastReroutes, [], name, value)


                    class FastReroute(Entity):
                        """
                        OSPFv3 fast reroute topology information
                        
                        .. attribute:: area_id
                        
                        	AreaID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: ipfrr_area_revision
                        
                        	IPFRR Topology Revision
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipfrr_router_id
                        
                        	OSPF Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipfrr_topo
                        
                        	IPFRR Topology entries
                        	**type**\: list of    :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo>`
                        
                        .. attribute:: ipfrr_topo_area_id
                        
                        	Area ID string in decimal or dotted decimal format
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "fast-reroutes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"ipfrr-topo" : ("ipfrr_topo", Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo)}

                            self.area_id = YLeaf(YType.int32, "area-id")

                            self.ipfrr_area_revision = YLeaf(YType.uint32, "ipfrr-area-revision")

                            self.ipfrr_router_id = YLeaf(YType.str, "ipfrr-router-id")

                            self.ipfrr_topo_area_id = YLeaf(YType.str, "ipfrr-topo-area-id")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.ipfrr_topo = YList(self)
                            self._segment_path = lambda: "fast-reroute"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute, ['area_id', 'ipfrr_area_revision', 'ipfrr_router_id', 'ipfrr_topo_area_id', 'router_id'], name, value)


                        class IpfrrTopo(Entity):
                            """
                            IPFRR Topology entries
                            
                            .. attribute:: distance
                            
                            	IPFRR Topology Distance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dr
                            
                            	IPFRR Topology DR entry
                            	**type**\:  bool
                            
                            .. attribute:: lsaid
                            
                            	IPFRR Topology LSA ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_sourced
                            
                            	IPFRR Topology Neighbor Sourced
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	IPFRR Topology Node ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: revision
                            
                            	IPFRR Topology Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: type4
                            
                            	IPFRR Topoogy Type\-4 entry
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo, self).__init__()

                                self.yang_name = "ipfrr-topo"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.distance = YLeaf(YType.uint32, "distance")

                                self.dr = YLeaf(YType.boolean, "dr")

                                self.lsaid = YLeaf(YType.uint32, "lsaid")

                                self.neighbor_sourced = YLeaf(YType.boolean, "neighbor-sourced")

                                self.node_id = YLeaf(YType.str, "node-id")

                                self.revision = YLeaf(YType.uint32, "revision")

                                self.type4 = YLeaf(YType.boolean, "type4")
                                self._segment_path = lambda: "ipfrr-topo"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo, ['distance', 'dr', 'lsaid', 'neighbor_sourced', 'node_id', 'revision', 'type4'], name, value)


                class FloodListProcessTable(Entity):
                    """
                    OSPFv3 flood list information table for all
                    areas
                    
                    .. attribute:: flood
                    
                    	OSPFv3 flood list information
                    	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable, self).__init__()

                        self.yang_name = "flood-list-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"flood" : ("flood", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood)}

                        self.flood = YList(self)
                        self._segment_path = lambda: "flood-list-process-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable, [], name, value)


                    class Flood(Entity):
                        """
                        OSPFv3 flood list information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: area_flood
                        
                        	Area scope floodlist
                        	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood>`
                        
                        .. attribute:: as_flood
                        
                        	AS scope floodlist
                        	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood>`
                        
                        .. attribute:: link_flood
                        
                        	Link floodlist
                        	**type**\: list of    :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood>`
                        
                        .. attribute:: ls_transmission_timer
                        
                        	Time until next LS transmission (ms) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: queue_length
                        
                        	Number of LSAs currently being flooded 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood, self).__init__()

                            self.yang_name = "flood"
                            self.yang_parent_name = "flood-list-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"area-flood" : ("area_flood", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood), "as-flood" : ("as_flood", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood), "link-flood" : ("link_flood", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.ls_transmission_timer = YLeaf(YType.uint32, "ls-transmission-timer")

                            self.queue_length = YLeaf(YType.uint32, "queue-length")

                            self.area_flood = YList(self)
                            self.as_flood = YList(self)
                            self.link_flood = YList(self)
                            self._segment_path = lambda: "flood" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood, ['interface_name', 'ls_transmission_timer', 'queue_length'], name, value)


                        class AreaFlood(Entity):
                            """
                            Area scope floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood, self).__init__()

                                self.yang_name = "area-flood"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                self._segment_path = lambda: "area-flood"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class AsFlood(Entity):
                            """
                            AS scope floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood, self).__init__()

                                self.yang_name = "as-flood"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                self._segment_path = lambda: "as-flood"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class LinkFlood(Entity):
                            """
                            Link floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood, self).__init__()

                                self.yang_name = "link-flood"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                self._segment_path = lambda: "link-flood"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                class InterfaceBriefProcessTable(Entity):
                    """
                    OSPFv3 interface brief information table for all
                    areas
                    
                    .. attribute:: interface_brief
                    
                    	Interface brief information
                    	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable, self).__init__()

                        self.yang_name = "interface-brief-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-brief" : ("interface_brief", Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief)}

                        self.interface_brief = YList(self)
                        self._segment_path = lambda: "interface-brief-process-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable, [], name, value)


                    class InterfaceBrief(Entity):
                        """
                        Interface brief information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_address
                        
                        	Interface IP address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_adjacent_neighbors
                        
                        	Total number of adjacent neighbors
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interface_link_cost
                        
                        	Interface link cost
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interface_neighbors
                        
                        	Total number of neighbors 
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: network_type
                        
                        	Network type
                        	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                        
                        .. attribute:: ospf_interface_state
                        
                        	Interface OSPF state
                        	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief, self).__init__()

                            self.yang_name = "interface-brief"
                            self.yang_parent_name = "interface-brief-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_address = YLeaf(YType.str, "interface-address")

                            self.interface_adjacent_neighbors = YLeaf(YType.uint16, "interface-adjacent-neighbors")

                            self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                            self.interface_neighbors = YLeaf(YType.uint16, "interface-neighbors")

                            self.network_type = YLeaf(YType.enumeration, "network-type")

                            self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                            self._segment_path = lambda: "interface-brief" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief, ['interface_name', 'interface_address', 'interface_adjacent_neighbors', 'interface_link_cost', 'interface_neighbors', 'network_type', 'ospf_interface_state'], name, value)


                class InterfaceProcessTable(Entity):
                    """
                    OSPFv3 interface information table for all areas
                    
                    .. attribute:: interface
                    
                    	OSPFv3 interface information
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable, self).__init__()

                        self.yang_name = "interface-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interface-process-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable, [], name, value)


                    class Interface(Entity):
                        """
                        OSPFv3 interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: active_interface
                        
                        	Active interface details 
                        	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface>`
                        
                        .. attribute:: adjacent_neighbor
                        
                        	Number of adjacent neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: backup_designated_router_address
                        
                        	Backup designated router interface address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: backup_designated_router_id
                        
                        	Backup designated router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: configured_ldp_sync
                        
                        	If true, configured as LDP sync
                        	**type**\:  bool
                        
                        .. attribute:: dead_interval
                        
                        	Configured dead interval (s) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: designated_router_address
                        
                        	Designated router interface address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: designated_router_id
                        
                        	Designated router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: hello_interval
                        
                        	Configured hello interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	Interface IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_authentication_spi
                        
                        	Interface authentication spi 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_authentication_transmit
                        
                        	Interface authentication transmit 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_bfd
                        
                        	BFD information 
                        	**type**\:   :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd>`
                        
                        .. attribute:: interface_dc_bitless_ls_as
                        
                        	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_encrypted_authentication_transmitted
                        
                        	Interface encrypted authentication transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_encryption_spi
                        
                        	Interface encryption spi
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_encryption_transmitted
                        
                        	Interface encryption transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_ldp_sync
                        
                        	If true, interface LDP sync is achieved
                        	**type**\:  bool
                        
                        .. attribute:: interface_link_cost
                        
                        	Interface link cost
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interface_neighbor
                        
                        	Information for neighbors on the interface
                        	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor>`
                        
                        .. attribute:: interface_number
                        
                        	Interface number 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_priority
                        
                        	Interface priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_references
                        
                        	Interface reference count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_retransmission_interval
                        
                        	Configured retransmit interval (s) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_router_id
                        
                        	Interface router ID 
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_state
                        
                        	Interface state
                        	**type**\:   :py:class:`ImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnum>`
                        
                        .. attribute:: is_demand_circuit_configured
                        
                        	If true, configured as demand circuit 
                        	**type**\:  bool
                        
                        .. attribute:: is_designated_router
                        
                        	If true, designated router
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_demand_circuit
                        
                        	If true, interface running as demand circuit
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_encryption_enabled
                        
                        	If true, interface encryption is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_flood_reduction
                        
                        	If true, interface flood reduction is active 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_ip_security_active
                        
                        	If true, interface IP security is active 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_ip_security_required
                        
                        	If true, interface IP security is required 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_line_up
                        
                        	If true, line protocol is up 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_lsa_filtered
                        
                        	Filter is configured for out going LSAs 
                        	**type**\:  bool
                        
                        .. attribute:: is_prefix_suppress
                        
                        	If true prefix suppression is enabled
                        	**type**\:  bool
                        
                        .. attribute:: network_lsa_flush_timer
                        
                        	The amount of time in seconds before flush timer for old network LSA expires 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: network_type
                        
                        	Network type
                        	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                        
                        .. attribute:: next_hello_time
                        
                        	Time until next Hello (s) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ospf_interface_state
                        
                        	Interface state
                        	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        .. attribute:: transmission_delay
                        
                        	Interface transmission delay (sec)
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: wait_interval
                        
                        	Configured wait interval (s) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"active-interface" : ("active_interface", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface), "interface-bfd" : ("interface_bfd", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd)}
                            self._child_list_classes = {"interface-neighbor" : ("interface_neighbor", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.adjacent_neighbor = YLeaf(YType.uint32, "adjacent-neighbor")

                            self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                            self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                            self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                            self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                            self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                            self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                            self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                            self.interface_address = YLeaf(YType.str, "interface-address")

                            self.interface_authentication_spi = YLeaf(YType.uint32, "interface-authentication-spi")

                            self.interface_authentication_transmit = YLeaf(YType.uint32, "interface-authentication-transmit")

                            self.interface_dc_bitless_ls_as = YLeaf(YType.uint32, "interface-dc-bitless-ls-as")

                            self.interface_encrypted_authentication_transmitted = YLeaf(YType.uint32, "interface-encrypted-authentication-transmitted")

                            self.interface_encryption_spi = YLeaf(YType.uint32, "interface-encryption-spi")

                            self.interface_encryption_transmitted = YLeaf(YType.uint32, "interface-encryption-transmitted")

                            self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                            self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                            self.interface_number = YLeaf(YType.uint32, "interface-number")

                            self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                            self.interface_references = YLeaf(YType.uint32, "interface-references")

                            self.interface_retransmission_interval = YLeaf(YType.uint32, "interface-retransmission-interval")

                            self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                            self.interface_state = YLeaf(YType.enumeration, "interface-state")

                            self.is_demand_circuit_configured = YLeaf(YType.boolean, "is-demand-circuit-configured")

                            self.is_designated_router = YLeaf(YType.boolean, "is-designated-router")

                            self.is_interface_demand_circuit = YLeaf(YType.boolean, "is-interface-demand-circuit")

                            self.is_interface_encryption_enabled = YLeaf(YType.boolean, "is-interface-encryption-enabled")

                            self.is_interface_flood_reduction = YLeaf(YType.boolean, "is-interface-flood-reduction")

                            self.is_interface_ip_security_active = YLeaf(YType.boolean, "is-interface-ip-security-active")

                            self.is_interface_ip_security_required = YLeaf(YType.boolean, "is-interface-ip-security-required")

                            self.is_interface_line_up = YLeaf(YType.boolean, "is-interface-line-up")

                            self.is_interface_lsa_filtered = YLeaf(YType.boolean, "is-interface-lsa-filtered")

                            self.is_prefix_suppress = YLeaf(YType.boolean, "is-prefix-suppress")

                            self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                            self.network_type = YLeaf(YType.enumeration, "network-type")

                            self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                            self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                            self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                            self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                            self.active_interface = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface()
                            self.active_interface.parent = self
                            self._children_name_map["active_interface"] = "active-interface"
                            self._children_yang_names.add("active-interface")

                            self.interface_bfd = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd()
                            self.interface_bfd.parent = self
                            self._children_name_map["interface_bfd"] = "interface-bfd"
                            self._children_yang_names.add("interface-bfd")

                            self.interface_neighbor = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface, ['interface_name', 'adjacent_neighbor', 'backup_designated_router_address', 'backup_designated_router_id', 'configured_ldp_sync', 'dead_interval', 'designated_router_address', 'designated_router_id', 'hello_interval', 'interface_address', 'interface_authentication_spi', 'interface_authentication_transmit', 'interface_dc_bitless_ls_as', 'interface_encrypted_authentication_transmitted', 'interface_encryption_spi', 'interface_encryption_transmitted', 'interface_ldp_sync', 'interface_link_cost', 'interface_number', 'interface_priority', 'interface_references', 'interface_retransmission_interval', 'interface_router_id', 'interface_state', 'is_demand_circuit_configured', 'is_designated_router', 'is_interface_demand_circuit', 'is_interface_encryption_enabled', 'is_interface_flood_reduction', 'is_interface_ip_security_active', 'is_interface_ip_security_required', 'is_interface_line_up', 'is_interface_lsa_filtered', 'is_prefix_suppress', 'network_lsa_flush_timer', 'network_type', 'next_hello_time', 'ospf_interface_state', 'transmission_delay', 'wait_interval'], name, value)


                        class ActiveInterface(Entity):
                            """
                            Active interface details 
                            
                            .. attribute:: flood_queue_length
                            
                            	Flood queue length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_scan_length
                            
                            	Last flood scan length 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_flood_index
                            
                            	Area scope LSAs flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_next_flood
                            
                            	Next LSA to flood (Area scope)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_next_flood_index
                            
                            	Index of next LSA to flood (Area scope) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_flood_index
                            
                            	AS scope LSAs flood index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_next_flood
                            
                            	Next LSA to flood (AS scope)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_next_flood_index
                            
                            	Index of next LSA to flood (AS scope)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_flood_pacing_timer
                            
                            	Time until next flood pacing timer (ms) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_flood_index
                            
                            	Interface flood link index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_next_flood
                            
                            	Interface link next flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_next_index
                            
                            	Interface link next information index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_neighbors
                            
                            	Total number of neighbors 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: last_flood_time
                            
                            	Last flood scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_flood_length
                            
                            	Maximum flood length 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_flood_time
                            
                            	Maximum flood time (ms) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: suppressed_hellos
                            
                            	Number of neighbors for which hellos are suppressed 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: wait_time
                            
                            	Wait time for DR/BDR selection (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface, self).__init__()

                                self.yang_name = "active-interface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.flood_queue_length = YLeaf(YType.uint32, "flood-queue-length")

                                self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                self.interface_link_flood_index = YLeaf(YType.uint32, "interface-link-flood-index")

                                self.interface_link_next_flood = YLeaf(YType.uint32, "interface-link-next-flood")

                                self.interface_link_next_index = YLeaf(YType.uint32, "interface-link-next-index")

                                self.interface_neighbors = YLeaf(YType.uint16, "interface-neighbors")

                                self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                self.suppressed_hellos = YLeaf(YType.uint16, "suppressed-hellos")

                                self.wait_time = YLeaf(YType.uint32, "wait-time")
                                self._segment_path = lambda: "active-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface, ['flood_queue_length', 'flood_scan_length', 'interface_area_flood_index', 'interface_area_next_flood', 'interface_area_next_flood_index', 'interface_as_flood_index', 'interface_as_next_flood', 'interface_as_next_flood_index', 'interface_flood_pacing_timer', 'interface_link_flood_index', 'interface_link_next_flood', 'interface_link_next_index', 'interface_neighbors', 'last_flood_time', 'maximum_flood_length', 'maximum_flood_time', 'suppressed_hellos', 'wait_time'], name, value)


                        class InterfaceBfd(Entity):
                            """
                            BFD information 
                            
                            .. attribute:: bfd_detection_multiplier
                            
                            	BFD detection multiplier 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_interval
                            
                            	BFD interval (ms) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD Enable Mode on the interface \- Default/Strict
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd, self).__init__()

                                self.yang_name = "interface-bfd"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.bfd_detection_multiplier = YLeaf(YType.uint32, "bfd-detection-multiplier")

                                self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                                self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")
                                self._segment_path = lambda: "interface-bfd"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd, ['bfd_detection_multiplier', 'bfd_interval', 'bfd_intf_enable_mode'], name, value)


                        class InterfaceNeighbor(Entity):
                            """
                            Information for neighbors on the interface
                            
                            .. attribute:: interface_neighbor_cost
                            
                            	Cost of link to neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_neighbor_id
                            
                            	Neighbor router ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_hello_suppressed
                            
                            	If true, hello is suppressed 
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_bdr
                            
                            	If true, backup designated router is found 
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_dr
                            
                            	If true, designated router is found 
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor, self).__init__()

                                self.yang_name = "interface-neighbor"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                self.is_hello_suppressed = YLeaf(YType.boolean, "is-hello-suppressed")

                                self.is_neighbor_bdr = YLeaf(YType.boolean, "is-neighbor-bdr")

                                self.is_neighbor_dr = YLeaf(YType.boolean, "is-neighbor-dr")
                                self._segment_path = lambda: "interface-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor, ['interface_neighbor_cost', 'interface_neighbor_id', 'is_hello_suppressed', 'is_neighbor_bdr', 'is_neighbor_dr'], name, value)


                class InternalRoutes(Entity):
                    """
                    OSPFv3 internal route information table
                    
                    .. attribute:: internal_route
                    
                    	OSPFv3 internal route information
                    	**type**\: list of    :py:class:`InternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes, self).__init__()

                        self.yang_name = "internal-routes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"internal-route" : ("internal_route", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute)}

                        self.internal_route = YList(self)
                        self._segment_path = lambda: "internal-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes, [], name, value)


                    class InternalRoute(Entity):
                        """
                        OSPFv3 internal route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_area_id
                        
                        	Route area ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath>`
                        
                        .. attribute:: route_source
                        
                        	List of topology source information
                        	**type**\: list of    :py:class:`RouteSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource>`
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute, self).__init__()

                            self.yang_name = "internal-route"
                            self.yang_parent_name = "internal-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"route-topology" : ("route_topology", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology)}
                            self._child_list_classes = {"route-path" : ("route_path", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath), "route-source" : ("route_source", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource)}

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology()
                            self.route_topology.parent = self
                            self._children_name_map["route_topology"] = "route-topology"
                            self._children_yang_names.add("route-topology")

                            self.route_path = YList(self)
                            self.route_source = YList(self)
                            self._segment_path = lambda: "internal-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute, ['prefix', 'prefix_length', 'route_area_id'], name, value)


                        class RoutePath(Entity):
                            """
                            List of paths to this route
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "internal-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath)}
                                self._child_list_classes = {}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                self.route_path_next_hop = YLeaf(YType.str, "route-path-next-hop")

                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                self._children_yang_names.add("route-backup-path")
                                self._segment_path = lambda: "route-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath, ['interface_name', 'route_path_id', 'route_path_next_hop'], name, value)


                            class RouteBackupPath(Entity):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\:  bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\:  bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\:  bool
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\:  bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath, self).__init__()

                                    self.yang_name = "route-backup-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                    self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                    self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                    self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                    self.downstream = YLeaf(YType.boolean, "downstream")

                                    self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                    self.node_protect = YLeaf(YType.boolean, "node-protect")

                                    self.primary_path = YLeaf(YType.boolean, "primary-path")

                                    self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")
                                    self._segment_path = lambda: "route-backup-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                        class RouteSource(Entity):
                            """
                            List of topology source information
                            
                            .. attribute:: route_source_adversting_router
                            
                            	Route source of the advertising router 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_source_id
                            
                            	Route source ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_source_lsa_type
                            
                            	Type of LSA advertising the prefix, see RFC5340
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource, self).__init__()

                                self.yang_name = "route-source"
                                self.yang_parent_name = "internal-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.route_source_adversting_router = YLeaf(YType.str, "route-source-adversting-router")

                                self.route_source_id = YLeaf(YType.str, "route-source-id")

                                self.route_source_lsa_type = YLeaf(YType.uint32, "route-source-lsa-type")
                                self._segment_path = lambda: "route-source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource, ['route_source_adversting_router', 'route_source_id', 'route_source_lsa_type'], name, value)


                        class RouteTopology(Entity):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology, self).__init__()

                                self.yang_name = "route-topology"
                                self.yang_parent_name = "internal-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.route_cost = YLeaf(YType.uint32, "route-cost")

                                self.route_distance = YLeaf(YType.uint32, "route-distance")

                                self.route_id = YLeaf(YType.str, "route-id")

                                self.route_type = YLeaf(YType.uint32, "route-type")
                                self._segment_path = lambda: "route-topology"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology, ['route_cost', 'route_distance', 'route_id', 'route_type'], name, value)


                class NeighborDetailProcessTable(Entity):
                    """
                    OSPFv3 neighbor information table for all areas
                    
                    .. attribute:: neighbor_detail
                    
                    	OSPFv3 neighbor detail information
                    	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable, self).__init__()

                        self.yang_name = "neighbor-detail-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail)}

                        self.neighbor_detail = YList(self)
                        self._segment_path = lambda: "neighbor-detail-process-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable, [], name, value)


                    class NeighborDetail(Entity):
                        """
                        OSPFv3 neighbor detail information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_neighbor_sham_link
                        
                        	If true, neighbor is on a sham link 
                        	**type**\:  bool
                        
                        .. attribute:: is_neighbor_virtual_link
                        
                        	If true, neighbor is on a virtual link 
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor IP Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_bfd_info
                        
                        	Neighbor BFD information
                        	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo>`
                        
                        .. attribute:: neighbor_dead_timer
                        
                        	Time until neighbor's dead timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_designated_router
                        
                        	Designated router 
                        	**type**\:  str
                        
                        	**length:** 0..9
                        
                        .. attribute:: neighbor_detail
                        
                        	Detailed OSPFv3 neighbor information 
                        	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail>`
                        
                        .. attribute:: neighbor_dr_priority
                        
                        	Neighbor's DR priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: neighbor_interface_id
                        
                        	Neighbor interface ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_sham_link_id
                        
                        	Neighbor sham link id 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_state
                        
                        	Neighbor's state
                        	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                        
                        .. attribute:: neighbor_up_time
                        
                        	Amount of time since the adjacency is up (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_virtual_link_id
                        
                        	Neighbor virtual link id 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail, self).__init__()

                            self.yang_name = "neighbor-detail"
                            self.yang_parent_name = "neighbor-detail-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"neighbor-bfd-info" : ("neighbor_bfd_info", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo), "neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_neighbor_sham_link = YLeaf(YType.boolean, "is-neighbor-sham-link")

                            self.is_neighbor_virtual_link = YLeaf(YType.boolean, "is-neighbor-virtual-link")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                            self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                            self.neighbor_designated_router = YLeaf(YType.str, "neighbor-designated-router")

                            self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                            self.neighbor_interface_id = YLeaf(YType.uint32, "neighbor-interface-id")

                            self.neighbor_sham_link_id = YLeaf(YType.uint32, "neighbor-sham-link-id")

                            self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                            self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                            self.neighbor_virtual_link_id = YLeaf(YType.uint32, "neighbor-virtual-link-id")

                            self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo()
                            self.neighbor_bfd_info.parent = self
                            self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                            self._children_yang_names.add("neighbor-bfd-info")

                            self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail()
                            self.neighbor_detail.parent = self
                            self._children_name_map["neighbor_detail"] = "neighbor-detail"
                            self._children_yang_names.add("neighbor-detail")
                            self._segment_path = lambda: "neighbor-detail"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail, ['interface_name', 'is_neighbor_sham_link', 'is_neighbor_virtual_link', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_designated_router', 'neighbor_dr_priority', 'neighbor_interface_id', 'neighbor_sham_link_id', 'neighbor_state', 'neighbor_up_time', 'neighbor_virtual_link_id'], name, value)


                        class NeighborBfdInfo(Entity):
                            """
                            Neighbor BFD information
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD enable mode \- Default/Strict
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_status_flag
                            
                            	Status of the BFD Session
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo, self).__init__()

                                self.yang_name = "neighbor-bfd-info"
                                self.yang_parent_name = "neighbor-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                self._segment_path = lambda: "neighbor-bfd-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                        class NeighborDetail(Entity):
                            """
                            Detailed OSPFv3 neighbor information 
                            
                            .. attribute:: interface_type
                            
                            	Interface type
                            	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                            
                            .. attribute:: is_neighbor_filtered
                            
                            	If true, filter outgoing LSAs 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_backup_designated_router_address
                            
                            	Address of backup designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_cost
                            
                            	Cost of path to this neighbor 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_designated_router_address
                            
                            	Address of designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_ignore_timer
                            
                            	Remaining time when ignore timer is running 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_option
                            
                            	 This is bitmask of neighbor's option field received 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmission
                            
                            	Retransmission information with this neighbor
                            	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission>`
                            
                            .. attribute:: next_poll_interval
                            
                            	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: pending_events
                            
                            	Number of pending events 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: poll_interval
                            
                            	Poll interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state_changes
                            
                            	Number of state changes 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail, self).__init__()

                                self.yang_name = "neighbor-detail"
                                self.yang_parent_name = "neighbor-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"neighbor-retransmission" : ("neighbor_retransmission", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission)}
                                self._child_list_classes = {}

                                self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                self.is_neighbor_filtered = YLeaf(YType.boolean, "is-neighbor-filtered")

                                self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                self.neighbor_ignore_timer = YLeaf(YType.uint32, "neighbor-ignore-timer")

                                self.neighbor_option = YLeaf(YType.uint32, "neighbor-option")

                                self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                self.pending_events = YLeaf(YType.uint16, "pending-events")

                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                self.state_changes = YLeaf(YType.uint16, "state-changes")

                                self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission()
                                self.neighbor_retransmission.parent = self
                                self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                self._children_yang_names.add("neighbor-retransmission")
                                self._segment_path = lambda: "neighbor-detail"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail, ['interface_type', 'is_neighbor_filtered', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_ignore_timer', 'neighbor_option', 'next_poll_interval', 'pending_events', 'poll_interval', 'state_changes'], name, value)


                            class NeighborRetransmission(Entity):
                                """
                                Retransmission information with this neighbor
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission, self).__init__()

                                    self.yang_name = "neighbor-retransmission"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                    self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                    self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                    self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                    self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                    self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                    self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                    self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                    self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                    self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                    self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                    self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                    self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                    self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                    self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                    self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                    self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                    self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                    self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                    self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                    self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                    self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                    self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                    self._segment_path = lambda: "neighbor-retransmission"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                class NeighborProcessTable(Entity):
                    """
                    OSPFv3 neighbor information table for all areas
                    
                    .. attribute:: neighbor
                    
                    	OSPFv3 neighbor detail information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable, self).__init__()

                        self.yang_name = "neighbor-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor" : ("neighbor", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor)}

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbor-process-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable, [], name, value)


                    class Neighbor(Entity):
                        """
                        OSPFv3 neighbor detail information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_neighbor_sham_link
                        
                        	If true, neighbor is on a sham link 
                        	**type**\:  bool
                        
                        .. attribute:: is_neighbor_virtual_link
                        
                        	If true, neighbor is on a virtual link 
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor IP Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_bfd_info
                        
                        	Neighbor BFD information
                        	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo>`
                        
                        .. attribute:: neighbor_dead_timer
                        
                        	Time until neighbor's dead timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_designated_router
                        
                        	Designated router 
                        	**type**\:  str
                        
                        	**length:** 0..9
                        
                        .. attribute:: neighbor_detail
                        
                        	Detailed OSPFv3 neighbor information 
                        	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail>`
                        
                        .. attribute:: neighbor_dr_priority
                        
                        	Neighbor's DR priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: neighbor_interface_id
                        
                        	Neighbor interface ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_sham_link_id
                        
                        	Neighbor sham link id 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_state
                        
                        	Neighbor's state
                        	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                        
                        .. attribute:: neighbor_up_time
                        
                        	Amount of time since the adjacency is up (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_virtual_link_id
                        
                        	Neighbor virtual link id 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbor-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"neighbor-bfd-info" : ("neighbor_bfd_info", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo), "neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_neighbor_sham_link = YLeaf(YType.boolean, "is-neighbor-sham-link")

                            self.is_neighbor_virtual_link = YLeaf(YType.boolean, "is-neighbor-virtual-link")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                            self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                            self.neighbor_designated_router = YLeaf(YType.str, "neighbor-designated-router")

                            self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                            self.neighbor_interface_id = YLeaf(YType.uint32, "neighbor-interface-id")

                            self.neighbor_sham_link_id = YLeaf(YType.uint32, "neighbor-sham-link-id")

                            self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                            self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                            self.neighbor_virtual_link_id = YLeaf(YType.uint32, "neighbor-virtual-link-id")

                            self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo()
                            self.neighbor_bfd_info.parent = self
                            self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                            self._children_yang_names.add("neighbor-bfd-info")

                            self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail()
                            self.neighbor_detail.parent = self
                            self._children_name_map["neighbor_detail"] = "neighbor-detail"
                            self._children_yang_names.add("neighbor-detail")
                            self._segment_path = lambda: "neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor, ['interface_name', 'is_neighbor_sham_link', 'is_neighbor_virtual_link', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_designated_router', 'neighbor_dr_priority', 'neighbor_interface_id', 'neighbor_sham_link_id', 'neighbor_state', 'neighbor_up_time', 'neighbor_virtual_link_id'], name, value)


                        class NeighborBfdInfo(Entity):
                            """
                            Neighbor BFD information
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD enable mode \- Default/Strict
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_status_flag
                            
                            	Status of the BFD Session
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo, self).__init__()

                                self.yang_name = "neighbor-bfd-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                self._segment_path = lambda: "neighbor-bfd-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                        class NeighborDetail(Entity):
                            """
                            Detailed OSPFv3 neighbor information 
                            
                            .. attribute:: interface_type
                            
                            	Interface type
                            	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                            
                            .. attribute:: is_neighbor_filtered
                            
                            	If true, filter outgoing LSAs 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_backup_designated_router_address
                            
                            	Address of backup designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_cost
                            
                            	Cost of path to this neighbor 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_designated_router_address
                            
                            	Address of designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_ignore_timer
                            
                            	Remaining time when ignore timer is running 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_option
                            
                            	 This is bitmask of neighbor's option field received 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmission
                            
                            	Retransmission information with this neighbor
                            	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                            
                            .. attribute:: next_poll_interval
                            
                            	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: pending_events
                            
                            	Number of pending events 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: poll_interval
                            
                            	Poll interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state_changes
                            
                            	Number of state changes 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail, self).__init__()

                                self.yang_name = "neighbor-detail"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"neighbor-retransmission" : ("neighbor_retransmission", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission)}
                                self._child_list_classes = {}

                                self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                self.is_neighbor_filtered = YLeaf(YType.boolean, "is-neighbor-filtered")

                                self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                self.neighbor_ignore_timer = YLeaf(YType.uint32, "neighbor-ignore-timer")

                                self.neighbor_option = YLeaf(YType.uint32, "neighbor-option")

                                self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                self.pending_events = YLeaf(YType.uint16, "pending-events")

                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                self.state_changes = YLeaf(YType.uint16, "state-changes")

                                self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                self.neighbor_retransmission.parent = self
                                self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                self._children_yang_names.add("neighbor-retransmission")
                                self._segment_path = lambda: "neighbor-detail"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail, ['interface_type', 'is_neighbor_filtered', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_ignore_timer', 'neighbor_option', 'next_poll_interval', 'pending_events', 'poll_interval', 'state_changes'], name, value)


                            class NeighborRetransmission(Entity):
                                """
                                Retransmission information with this neighbor
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission, self).__init__()

                                    self.yang_name = "neighbor-retransmission"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                    self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                    self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                    self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                    self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                    self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                    self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                    self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                    self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                    self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                    self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                    self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                    self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                    self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                    self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                    self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                    self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                    self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                    self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                    self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                    self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                    self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                    self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                    self._segment_path = lambda: "neighbor-retransmission"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                class ProtocolAreas(Entity):
                    """
                    Protocol area table 
                    
                    .. attribute:: protocol_area
                    
                    	Area information 
                    	**type**\: list of    :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas, self).__init__()

                        self.yang_name = "protocol-areas"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"protocol-area" : ("protocol_area", Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea)}

                        self.protocol_area = YList(self)
                        self._segment_path = lambda: "protocol-areas"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas, [], name, value)


                    class ProtocolArea(Entity):
                        """
                        Area information 
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: distribute_list_in
                        
                        	Distribute List In
                        	**type**\:  str
                        
                        .. attribute:: protocol_area_id
                        
                        	Area ID string in decimal and dotted\-decimal format
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: protocol_interface
                        
                        	Interface list
                        	**type**\: list of    :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea, self).__init__()

                            self.yang_name = "protocol-area"
                            self.yang_parent_name = "protocol-areas"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"protocol-interface" : ("protocol_interface", Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface)}

                            self.area_id = YLeaf(YType.str, "area-id")

                            self.distribute_list_in = YLeaf(YType.str, "distribute-list-in")

                            self.protocol_area_id = YLeaf(YType.str, "protocol-area-id")

                            self.protocol_interface = YList(self)
                            self._segment_path = lambda: "protocol-area" + "[area-id='" + self.area_id.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea, ['area_id', 'distribute_list_in', 'protocol_area_id'], name, value)


                        class ProtocolInterface(Entity):
                            """
                            Interface list
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: interface_name
                            
                            	Protocol interface name 
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__init__()

                                self.yang_name = "protocol-interface"
                                self.yang_parent_name = "protocol-area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.distribute_list_in = YLeaf(YType.str, "distribute-list-in")

                                self.interface_name = YLeaf(YType.str, "interface-name")
                                self._segment_path = lambda: "protocol-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface, ['distribute_list_in', 'interface_name'], name, value)


                class Redistributions(Entity):
                    """
                    Redistribution information table
                    
                    .. attribute:: redistribution
                    
                    	Redistribution information
                    	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.Redistributions, self).__init__()

                        self.yang_name = "redistributions"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"redistribution" : ("redistribution", Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution)}

                        self.redistribution = YList(self)
                        self._segment_path = lambda: "redistributions"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Redistributions, [], name, value)


                    class Redistribution(Entity):
                        """
                        Redistribution information
                        
                        .. attribute:: policy_name
                        
                        	Route policy name 
                        	**type**\:  str
                        
                        .. attribute:: process_id
                        
                        	Process ID 
                        	**type**\:  str
                        
                        	**length:** 0..40
                        
                        .. attribute:: process_name
                        
                        	Process name of a protocolbeing redistributed 
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: protocol_name
                        
                        	Protocol name that is redistributed
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: protocol_name_xr
                        
                        	Protocol name 
                        	**type**\:  str
                        
                        	**length:** 0..40
                        
                        .. attribute:: red_metric
                        
                        	red metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: red_metric_flag
                        
                        	red metric flag
                        	**type**\:  bool
                        
                        .. attribute:: red_metric_type
                        
                        	red metric type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: red_mtype_flag
                        
                        	red mtype flag
                        	**type**\:  bool
                        
                        .. attribute:: red_tag
                        
                        	red tag
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution, self).__init__()

                            self.yang_name = "redistribution"
                            self.yang_parent_name = "redistributions"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.process_id = YLeaf(YType.str, "process-id")

                            self.process_name = YLeaf(YType.str, "process-name")

                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                            self.protocol_name_xr = YLeaf(YType.str, "protocol-name-xr")

                            self.red_metric = YLeaf(YType.uint32, "red-metric")

                            self.red_metric_flag = YLeaf(YType.boolean, "red-metric-flag")

                            self.red_metric_type = YLeaf(YType.uint8, "red-metric-type")

                            self.red_mtype_flag = YLeaf(YType.boolean, "red-mtype-flag")

                            self.red_tag = YLeaf(YType.uint32, "red-tag")
                            self._segment_path = lambda: "redistribution"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution, ['policy_name', 'process_id', 'process_name', 'protocol_name', 'protocol_name_xr', 'red_metric', 'red_metric_flag', 'red_metric_type', 'red_mtype_flag', 'red_tag'], name, value)


                class RequestListProcessTable(Entity):
                    """
                    OSPFv3 request list information for all areas
                    
                    .. attribute:: request
                    
                    	OSPFv3 request list information
                    	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable, self).__init__()

                        self.yang_name = "request-list-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"request" : ("request", Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request)}

                        self.request = YList(self)
                        self._segment_path = lambda: "request-list-process-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable, [], name, value)


                    class Request(Entity):
                        """
                        OSPFv3 request list information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_request_sham_link
                        
                        	If true, sham link is requested 
                        	**type**\:  bool
                        
                        .. attribute:: is_request_virtual_link
                        
                        	If true, virtual link is requested 
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: request
                        
                        	List of request list entries
                        	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request>`
                        
                        .. attribute:: request_neighbor_address
                        
                        	Neighbor IP address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: request_sham_link_id
                        
                        	Request sham link ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: request_virtual_link_id
                        
                        	Request virtual link ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request, self).__init__()

                            self.yang_name = "request"
                            self.yang_parent_name = "request-list-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"request" : ("request", Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_request_sham_link = YLeaf(YType.boolean, "is-request-sham-link")

                            self.is_request_virtual_link = YLeaf(YType.boolean, "is-request-virtual-link")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                            self.request_sham_link_id = YLeaf(YType.uint32, "request-sham-link-id")

                            self.request_virtual_link_id = YLeaf(YType.uint32, "request-virtual-link-id")

                            self.request = YList(self)
                            self._segment_path = lambda: "request"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request, ['interface_name', 'is_request_sham_link', 'is_request_virtual_link', 'neighbor_address', 'request_neighbor_address', 'request_sham_link_id', 'request_virtual_link_id'], name, value)


                        class Request(Entity):
                            """
                            List of request list entries
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                self._segment_path = lambda: "request"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                class RetransmissionListProcessTable(Entity):
                    """
                    OSPFv3 retransmission list information table for
                    all areas
                    
                    .. attribute:: retransmission
                    
                    	OSPFv3 retransmission list information
                    	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable, self).__init__()

                        self.yang_name = "retransmission-list-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"retransmission" : ("retransmission", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission)}

                        self.retransmission = YList(self)
                        self._segment_path = lambda: "retransmission-list-process-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable, [], name, value)


                    class Retransmission(Entity):
                        """
                        OSPFv3 retransmission list information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_retransmission_sham_link
                        
                        	If true, sham link is retransmitted 
                        	**type**\:  bool
                        
                        .. attribute:: is_retransmissionvirtual_link
                        
                        	If true, virtual link is retransmitted 
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: retransmission_area_db
                        
                        	List of area scope entries
                        	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb>`
                        
                        .. attribute:: retransmission_asdb
                        
                        	List of AS scope entries
                        	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb>`
                        
                        .. attribute:: retransmission_length
                        
                        	Retransmission queue length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmission_neighbor_address
                        
                        	Neighbor IP address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: retransmission_sham_link_id
                        
                        	Retransmission sham link ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmission_timer
                        
                        	Amount of time remaining on retransmission timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmissionvirtual_link_db
                        
                        	List of virtual link scope entries 
                        	**type**\: list of    :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb>`
                        
                        .. attribute:: retransmissionvirtual_link_id
                        
                        	Retransmission virtual link ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission, self).__init__()

                            self.yang_name = "retransmission"
                            self.yang_parent_name = "retransmission-list-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"retransmission-area-db" : ("retransmission_area_db", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb), "retransmission-asdb" : ("retransmission_asdb", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb), "retransmissionvirtual-link-db" : ("retransmissionvirtual_link_db", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_retransmission_sham_link = YLeaf(YType.boolean, "is-retransmission-sham-link")

                            self.is_retransmissionvirtual_link = YLeaf(YType.boolean, "is-retransmissionvirtual-link")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.retransmission_length = YLeaf(YType.uint32, "retransmission-length")

                            self.retransmission_neighbor_address = YLeaf(YType.str, "retransmission-neighbor-address")

                            self.retransmission_sham_link_id = YLeaf(YType.uint32, "retransmission-sham-link-id")

                            self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                            self.retransmissionvirtual_link_id = YLeaf(YType.uint32, "retransmissionvirtual-link-id")

                            self.retransmission_area_db = YList(self)
                            self.retransmission_asdb = YList(self)
                            self.retransmissionvirtual_link_db = YList(self)
                            self._segment_path = lambda: "retransmission"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission, ['interface_name', 'is_retransmission_sham_link', 'is_retransmissionvirtual_link', 'neighbor_address', 'retransmission_length', 'retransmission_neighbor_address', 'retransmission_sham_link_id', 'retransmission_timer', 'retransmissionvirtual_link_id'], name, value)


                        class RetransmissionAreaDb(Entity):
                            """
                            List of area scope entries
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb, self).__init__()

                                self.yang_name = "retransmission-area-db"
                                self.yang_parent_name = "retransmission"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                self._segment_path = lambda: "retransmission-area-db"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class RetransmissionAsdb(Entity):
                            """
                            List of AS scope entries
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb, self).__init__()

                                self.yang_name = "retransmission-asdb"
                                self.yang_parent_name = "retransmission"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                self._segment_path = lambda: "retransmission-asdb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class RetransmissionvirtualLinkDb(Entity):
                            """
                            List of virtual link scope entries 
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb, self).__init__()

                                self.yang_name = "retransmissionvirtual-link-db"
                                self.yang_parent_name = "retransmission"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                self._segment_path = lambda: "retransmissionvirtual-link-db"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                class RouteSummary(Entity):
                    """
                    Summarize OSPFv3 local RIB tables
                    
                    .. attribute:: extern_one_route
                    
                    	Extern 1 route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: extern_two_route
                    
                    	Extern 2 route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inter_area_route
                    
                    	Inter route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: intra_area_route
                    
                    	Intra route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nssa_one_route
                    
                    	NSSA 1 route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nssa_two_route
                    
                    	NSSA 2 route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_route
                    
                    	Redistribution route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_connected
                    
                    	Route connected 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_id
                    
                    	Route summary of a route ID 
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: total_received_route
                    
                    	Total route received summary
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_sent_route
                    
                    	Total route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.RouteSummary, self).__init__()

                        self.yang_name = "route-summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.extern_one_route = YLeaf(YType.uint32, "extern-one-route")

                        self.extern_two_route = YLeaf(YType.uint32, "extern-two-route")

                        self.inter_area_route = YLeaf(YType.uint32, "inter-area-route")

                        self.intra_area_route = YLeaf(YType.uint32, "intra-area-route")

                        self.nssa_one_route = YLeaf(YType.uint32, "nssa-one-route")

                        self.nssa_two_route = YLeaf(YType.uint32, "nssa-two-route")

                        self.redistribution_route = YLeaf(YType.uint32, "redistribution-route")

                        self.route_connected = YLeaf(YType.uint32, "route-connected")

                        self.route_id = YLeaf(YType.str, "route-id")

                        self.total_received_route = YLeaf(YType.uint32, "total-received-route")

                        self.total_sent_route = YLeaf(YType.uint32, "total-sent-route")
                        self._segment_path = lambda: "route-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RouteSummary, ['extern_one_route', 'extern_two_route', 'inter_area_route', 'intra_area_route', 'nssa_one_route', 'nssa_two_route', 'redistribution_route', 'route_connected', 'route_id', 'total_received_route', 'total_sent_route'], name, value)


                class ShamLinkTable(Entity):
                    """
                    Sham link information
                    
                    .. attribute:: is_sham_link_authentication_enabled
                    
                    	If true, sham link authentication is enabled 
                    	**type**\:  bool
                    
                    .. attribute:: is_sham_link_encryption_enabled
                    
                    	If true, sham link encryption is enabled 
                    	**type**\:  bool
                    
                    .. attribute:: is_sham_link_ip_security_active
                    
                    	If true, Sham link IP security is active 
                    	**type**\:  bool
                    
                    .. attribute:: is_sham_link_ip_security_required
                    
                    	If true, sham link IP security is required 
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_area
                    
                    	Area id
                    	**type**\:  str
                    
                    .. attribute:: sham_link_authentication_transmit
                    
                    	Sham link authentication transmit 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_cost
                    
                    	Cost of the sham link
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: sham_link_dc_bitless_lsa
                    
                    	Number of LSA's with demand circuit bit not set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_dead_interval
                    
                    	Dead interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_demand_circuit
                    
                    	If true, the link runs as demand circuit
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_dest_address
                    
                    	Sham\-link dest
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_encrypted_authentication_transmitted
                    
                    	Sham link encrypted authentication transmitted 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_encryption_spi
                    
                    	Sham link encryption spi
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_encryption_transmitted
                    
                    	Sham link encryption transmitted 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_gr
                    
                    	If true, Gracefule restart in progress
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_gr_enabled
                    
                    	If true,  enabled
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_hello_interval
                    
                    	Hello interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_ifindex
                    
                    	Sham\-link ifindex
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_last_gr
                    
                    	Time in seconds since last GR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: sham_link_neighbor
                    
                    	Neighbor information
                    	**type**\:   :py:class:`ShamLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor>`
                    
                    .. attribute:: sham_link_neighbor_id
                    
                    	Neighbor on other end of this sham link
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_next_hello
                    
                    	Time until next hello (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_passive
                    
                    	If true, interface is passive
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_retransmission_interval
                    
                    	Retransmission interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_source_address
                    
                    	Sham\-link source
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_state
                    
                    	OSPF interface state for the sham link
                    	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                    
                    .. attribute:: sham_link_transmission_delay
                    
                    	Transmission delay in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sham_link_wait_interval
                    
                    	Wait interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_authentication_spi
                    
                    	Sham link authentication spi 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable, self).__init__()

                        self.yang_name = "sham-link-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"sham-link-neighbor" : ("sham_link_neighbor", Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor)}
                        self._child_list_classes = {}

                        self.is_sham_link_authentication_enabled = YLeaf(YType.boolean, "is-sham-link-authentication-enabled")

                        self.is_sham_link_encryption_enabled = YLeaf(YType.boolean, "is-sham-link-encryption-enabled")

                        self.is_sham_link_ip_security_active = YLeaf(YType.boolean, "is-sham-link-ip-security-active")

                        self.is_sham_link_ip_security_required = YLeaf(YType.boolean, "is-sham-link-ip-security-required")

                        self.sham_link_area = YLeaf(YType.str, "sham-link-area")

                        self.sham_link_authentication_transmit = YLeaf(YType.uint32, "sham-link-authentication-transmit")

                        self.sham_link_cost = YLeaf(YType.uint16, "sham-link-cost")

                        self.sham_link_dc_bitless_lsa = YLeaf(YType.uint32, "sham-link-dc-bitless-lsa")

                        self.sham_link_dead_interval = YLeaf(YType.uint32, "sham-link-dead-interval")

                        self.sham_link_demand_circuit = YLeaf(YType.boolean, "sham-link-demand-circuit")

                        self.sham_link_dest_address = YLeaf(YType.str, "sham-link-dest-address")

                        self.sham_link_encrypted_authentication_transmitted = YLeaf(YType.uint32, "sham-link-encrypted-authentication-transmitted")

                        self.sham_link_encryption_spi = YLeaf(YType.uint32, "sham-link-encryption-spi")

                        self.sham_link_encryption_transmitted = YLeaf(YType.uint32, "sham-link-encryption-transmitted")

                        self.sham_link_gr = YLeaf(YType.boolean, "sham-link-gr")

                        self.sham_link_gr_enabled = YLeaf(YType.boolean, "sham-link-gr-enabled")

                        self.sham_link_hello_interval = YLeaf(YType.uint32, "sham-link-hello-interval")

                        self.sham_link_ifindex = YLeaf(YType.uint32, "sham-link-ifindex")

                        self.sham_link_last_gr = YLeaf(YType.uint32, "sham-link-last-gr")

                        self.sham_link_neighbor_id = YLeaf(YType.str, "sham-link-neighbor-id")

                        self.sham_link_next_hello = YLeaf(YType.uint32, "sham-link-next-hello")

                        self.sham_link_passive = YLeaf(YType.boolean, "sham-link-passive")

                        self.sham_link_retransmission_interval = YLeaf(YType.uint32, "sham-link-retransmission-interval")

                        self.sham_link_source_address = YLeaf(YType.str, "sham-link-source-address")

                        self.sham_link_state = YLeaf(YType.enumeration, "sham-link-state")

                        self.sham_link_transmission_delay = YLeaf(YType.uint16, "sham-link-transmission-delay")

                        self.sham_link_wait_interval = YLeaf(YType.uint32, "sham-link-wait-interval")

                        self.virtual_link_authentication_spi = YLeaf(YType.uint32, "virtual-link-authentication-spi")

                        self.sham_link_neighbor = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor()
                        self.sham_link_neighbor.parent = self
                        self._children_name_map["sham_link_neighbor"] = "sham-link-neighbor"
                        self._children_yang_names.add("sham-link-neighbor")
                        self._segment_path = lambda: "sham-link-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable, ['is_sham_link_authentication_enabled', 'is_sham_link_encryption_enabled', 'is_sham_link_ip_security_active', 'is_sham_link_ip_security_required', 'sham_link_area', 'sham_link_authentication_transmit', 'sham_link_cost', 'sham_link_dc_bitless_lsa', 'sham_link_dead_interval', 'sham_link_demand_circuit', 'sham_link_dest_address', 'sham_link_encrypted_authentication_transmitted', 'sham_link_encryption_spi', 'sham_link_encryption_transmitted', 'sham_link_gr', 'sham_link_gr_enabled', 'sham_link_hello_interval', 'sham_link_ifindex', 'sham_link_last_gr', 'sham_link_neighbor_id', 'sham_link_next_hello', 'sham_link_passive', 'sham_link_retransmission_interval', 'sham_link_source_address', 'sham_link_state', 'sham_link_transmission_delay', 'sham_link_wait_interval', 'virtual_link_authentication_spi'], name, value)


                    class ShamLinkNeighbor(Entity):
                        """
                        Neighbor information
                        
                        .. attribute:: sham_link_retransmission
                        
                        	Neighbor retransmission info
                        	**type**\:   :py:class:`ShamLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission>`
                        
                        .. attribute:: sham_link_state
                        
                        	Adjacency state
                        	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                        
                        .. attribute:: sham_link_suppress_hello
                        
                        	If true Hellos suppressed
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor, self).__init__()

                            self.yang_name = "sham-link-neighbor"
                            self.yang_parent_name = "sham-link-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"sham-link-retransmission" : ("sham_link_retransmission", Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission)}
                            self._child_list_classes = {}

                            self.sham_link_state = YLeaf(YType.enumeration, "sham-link-state")

                            self.sham_link_suppress_hello = YLeaf(YType.boolean, "sham-link-suppress-hello")

                            self.sham_link_retransmission = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission()
                            self.sham_link_retransmission.parent = self
                            self._children_name_map["sham_link_retransmission"] = "sham-link-retransmission"
                            self._children_yang_names.add("sham-link-retransmission")
                            self._segment_path = lambda: "sham-link-neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor, ['sham_link_state', 'sham_link_suppress_hello'], name, value)


                        class ShamLinkRetransmission(Entity):
                            """
                            Neighbor retransmission info
                            
                            .. attribute:: area_first_flood
                            
                            	First flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_first_flood_index
                            
                            	Index of the first flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_flood_index
                            
                            	Area scope LSA's flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood
                            
                            	Next flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood_index
                            
                            	Index of next flood item for Area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood
                            
                            	First flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood_index
                            
                            	Index for first flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_flood_index
                            
                            	AS scope LSA's flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood
                            
                            	Next flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood_index
                            
                            	Index of next flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: database_descriptor_retransmissions
                            
                            	Number of database descriptor retransmissions during last exchange
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_length
                            
                            	Number of LSAs sent in last retransmission
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_time
                            
                            	Last retransmission scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood
                            
                            	Link first flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood_index
                            
                            	Link first flood information index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_flood_index
                            
                            	Link flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood
                            
                            	Link next flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood_index
                            
                            	Link next flood information index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_timer
                            
                            	Time until next LSA retransmission (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_length
                            
                            	Maximum number of LSAs sent in a retransmission
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_time
                            
                            	Maximum retransmission scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmissions
                            
                            	Number of neighbor retransmissions 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissions
                            
                            	Number of retransmissions for this neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission, self).__init__()

                                self.yang_name = "sham-link-retransmission"
                                self.yang_parent_name = "sham-link-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                self._segment_path = lambda: "sham-link-retransmission"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                class Summary(Entity):
                    """
                    OSPFv3 summary
                    
                    .. attribute:: ospfv3
                    
                    	OSPFv3 summary
                    	**type**\:   :py:class:`Ospfv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3>`
                    
                    .. attribute:: protocol
                    
                    	OSPFv3 protocol summary
                    	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol>`
                    
                    .. attribute:: route
                    
                    	OSPFv3 route summary
                    	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Route>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"ospfv3" : ("ospfv3", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3), "protocol" : ("protocol", Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol), "route" : ("route", Ospfv3.Processes.Process.DefaultVrf.Summary.Route)}
                        self._child_list_classes = {}

                        self.ospfv3 = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3()
                        self.ospfv3.parent = self
                        self._children_name_map["ospfv3"] = "ospfv3"
                        self._children_yang_names.add("ospfv3")

                        self.protocol = Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol()
                        self.protocol.parent = self
                        self._children_name_map["protocol"] = "protocol"
                        self._children_yang_names.add("protocol")

                        self.route = Ospfv3.Processes.Process.DefaultVrf.Summary.Route()
                        self.route.parent = self
                        self._children_name_map["route"] = "route"
                        self._children_yang_names.add("route")
                        self._segment_path = lambda: "summary"


                    class Ospfv3(Entity):
                        """
                        OSPFv3 summary
                        
                        .. attribute:: areas
                        
                        	Number of areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: as_dc_bitless_ls_as
                        
                        	Number of external and AS opaque LSAs with demand circut bit not set
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_do_not_age_ls_as
                        
                        	Number of external and AS opaque LSAs with do not age set 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_ls_as
                        
                        	Number of AS scope LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_lsa_flood_list_length
                        
                        	Length of AS LSAs flood list
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: context_name
                        
                        	Context name
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: default_metric
                        
                        	Default metric 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_metric_type
                        
                        	Default metric type 
                        	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                        
                        .. attribute:: default_policy_name
                        
                        	Default policy name 
                        	**type**\:  str
                        
                        .. attribute:: default_tag
                        
                        	Default tag 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: domain_id
                        
                        	Domain ID information
                        	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId>`
                        
                        .. attribute:: grace_resync_time
                        
                        	Grace time to resync 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_shutdown_state
                        
                        	Graceful shutdown state
                        	**type**\:   :py:class:`Ospfv3GracefulShutdownState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulShutdownState>`
                        
                        .. attribute:: ipfrr_tiebreakers
                        
                        	IPFRR\-Tiebreakers list
                        	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.IpfrrTiebreakers>`
                        
                        .. attribute:: is_area_border_router
                        
                        	If true, is an area border router
                        	**type**\:  bool
                        
                        .. attribute:: is_as_border_router
                        
                        	If true, is an AS border router
                        	**type**\:  bool
                        
                        .. attribute:: is_auto_cost
                        
                        	If true, auto cost is enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_default_always
                        
                        	If true, default always 
                        	**type**\:  bool
                        
                        .. attribute:: is_default_originated
                        
                        	If true, origin is by default 
                        	**type**\:  bool
                        
                        .. attribute:: is_default_policy
                        
                        	If true, is a default policy 
                        	**type**\:  bool
                        
                        .. attribute:: is_grace_restart_enabled
                        
                        	If true, grace restart is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_nsr_enabled
                        
                        	If true, NSR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_nsr_switchover_on_restart
                        
                        	Trigger RP Switchover on detectable process restart
                        	**type**\:  bool
                        
                        .. attribute:: is_opaque_capable
                        
                        	Opaque LSA capable 
                        	**type**\:  bool
                        
                        .. attribute:: is_role_standby
                        
                        	If true, the process is running as stanby role
                        	**type**\:  bool
                        
                        .. attribute:: is_router_id_stalled
                        
                        	Stalled Router ID 
                        	**type**\:  bool
                        
                        .. attribute:: last_nsf_time
                        
                        	 Length of time since the last NSF (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_flood_pacing_interval
                        
                        	LSA flood pacing timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_group_interval
                        
                        	LSA refresh interval (sec)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_hold_time
                        
                        	Second delay before generating next LSA (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_maximum_time
                        
                        	Maximum delay before generating an LSA (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_retransmission_pacing_interval
                        
                        	LSA retransmission pacing timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_start_time
                        
                        	Initial LSA throttle delay (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_interfaces
                        
                        	Maximum number of interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_paths
                        
                        	Maximum number of paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric
                        
                        	Redistribution metric 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_lsa_interval
                        
                        	Minimum time between LSA regeneration (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: normal_areas
                        
                        	Number of normal areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nssa_areas
                        
                        	Number of NSSA areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: opaque_lsa_checksum
                        
                        	Sum of opaque LSA checksum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: opaque_lsas
                        
                        	Number of opaque LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_limit
                        
                        	The number of redistributed prefixes allowed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_threshold
                        
                        	When the number of redistributed prefixes reaches this threshold, a warning message is issued 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reference_bandwidth
                        
                        	Reference Bandwdith
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role
                        
                        	Role, V1/V2 Active/Standby
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: snmp_trap_enabled
                        
                        	If true, snmp trap is enabled
                        	**type**\:  bool
                        
                        .. attribute:: spf_hold_time
                        
                        	Minimum delay time between SPF runs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_maximum_time
                        
                        	Maximum delay time between SPF runs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_start_time
                        
                        	Scheduling delay for SPF (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: stub_areas
                        
                        	Number of stub and total stub areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: stub_router
                        
                        	Stub Router Information
                        	**type**\: list of    :py:class:`StubRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3, self).__init__()

                            self.yang_name = "ospfv3"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"domain-id" : ("domain_id", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId)}
                            self._child_list_classes = {"ipfrr-tiebreakers" : ("ipfrr_tiebreakers", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.IpfrrTiebreakers), "stub-router" : ("stub_router", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter)}

                            self.areas = YLeaf(YType.uint16, "areas")

                            self.as_dc_bitless_ls_as = YLeaf(YType.uint32, "as-dc-bitless-ls-as")

                            self.as_do_not_age_ls_as = YLeaf(YType.uint32, "as-do-not-age-ls-as")

                            self.as_ls_as = YLeaf(YType.uint32, "as-ls-as")

                            self.as_lsa_flood_list_length = YLeaf(YType.uint32, "as-lsa-flood-list-length")

                            self.context_name = YLeaf(YType.str, "context-name")

                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                            self.default_metric_type = YLeaf(YType.enumeration, "default-metric-type")

                            self.default_policy_name = YLeaf(YType.str, "default-policy-name")

                            self.default_tag = YLeaf(YType.uint32, "default-tag")

                            self.grace_resync_time = YLeaf(YType.uint32, "grace-resync-time")

                            self.graceful_shutdown_state = YLeaf(YType.enumeration, "graceful-shutdown-state")

                            self.is_area_border_router = YLeaf(YType.boolean, "is-area-border-router")

                            self.is_as_border_router = YLeaf(YType.boolean, "is-as-border-router")

                            self.is_auto_cost = YLeaf(YType.boolean, "is-auto-cost")

                            self.is_default_always = YLeaf(YType.boolean, "is-default-always")

                            self.is_default_originated = YLeaf(YType.boolean, "is-default-originated")

                            self.is_default_policy = YLeaf(YType.boolean, "is-default-policy")

                            self.is_grace_restart_enabled = YLeaf(YType.boolean, "is-grace-restart-enabled")

                            self.is_nsr_enabled = YLeaf(YType.boolean, "is-nsr-enabled")

                            self.is_nsr_switchover_on_restart = YLeaf(YType.boolean, "is-nsr-switchover-on-restart")

                            self.is_opaque_capable = YLeaf(YType.boolean, "is-opaque-capable")

                            self.is_role_standby = YLeaf(YType.boolean, "is-role-standby")

                            self.is_router_id_stalled = YLeaf(YType.boolean, "is-router-id-stalled")

                            self.last_nsf_time = YLeaf(YType.uint32, "last-nsf-time")

                            self.lsa_flood_pacing_interval = YLeaf(YType.uint32, "lsa-flood-pacing-interval")

                            self.lsa_group_interval = YLeaf(YType.uint32, "lsa-group-interval")

                            self.lsa_hold_time = YLeaf(YType.uint32, "lsa-hold-time")

                            self.lsa_maximum_time = YLeaf(YType.uint32, "lsa-maximum-time")

                            self.lsa_retransmission_pacing_interval = YLeaf(YType.uint32, "lsa-retransmission-pacing-interval")

                            self.lsa_start_time = YLeaf(YType.uint32, "lsa-start-time")

                            self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                            self.maximum_paths = YLeaf(YType.uint32, "maximum-paths")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.minimum_lsa_interval = YLeaf(YType.uint32, "minimum-lsa-interval")

                            self.normal_areas = YLeaf(YType.uint16, "normal-areas")

                            self.nssa_areas = YLeaf(YType.uint16, "nssa-areas")

                            self.opaque_lsa_checksum = YLeaf(YType.uint32, "opaque-lsa-checksum")

                            self.opaque_lsas = YLeaf(YType.uint32, "opaque-lsas")

                            self.redistribution_limit = YLeaf(YType.uint32, "redistribution-limit")

                            self.redistribution_threshold = YLeaf(YType.uint32, "redistribution-threshold")

                            self.reference_bandwidth = YLeaf(YType.uint32, "reference-bandwidth")

                            self.role = YLeaf(YType.uint32, "role")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.snmp_trap_enabled = YLeaf(YType.boolean, "snmp-trap-enabled")

                            self.spf_hold_time = YLeaf(YType.uint32, "spf-hold-time")

                            self.spf_maximum_time = YLeaf(YType.uint32, "spf-maximum-time")

                            self.spf_start_time = YLeaf(YType.uint32, "spf-start-time")

                            self.stub_areas = YLeaf(YType.uint16, "stub-areas")

                            self.domain_id = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId()
                            self.domain_id.parent = self
                            self._children_name_map["domain_id"] = "domain-id"
                            self._children_yang_names.add("domain-id")

                            self.ipfrr_tiebreakers = YList(self)
                            self.stub_router = YList(self)
                            self._segment_path = lambda: "ospfv3"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3, ['areas', 'as_dc_bitless_ls_as', 'as_do_not_age_ls_as', 'as_ls_as', 'as_lsa_flood_list_length', 'context_name', 'default_metric', 'default_metric_type', 'default_policy_name', 'default_tag', 'grace_resync_time', 'graceful_shutdown_state', 'is_area_border_router', 'is_as_border_router', 'is_auto_cost', 'is_default_always', 'is_default_originated', 'is_default_policy', 'is_grace_restart_enabled', 'is_nsr_enabled', 'is_nsr_switchover_on_restart', 'is_opaque_capable', 'is_role_standby', 'is_router_id_stalled', 'last_nsf_time', 'lsa_flood_pacing_interval', 'lsa_group_interval', 'lsa_hold_time', 'lsa_maximum_time', 'lsa_retransmission_pacing_interval', 'lsa_start_time', 'maximum_interfaces', 'maximum_paths', 'metric', 'minimum_lsa_interval', 'normal_areas', 'nssa_areas', 'opaque_lsa_checksum', 'opaque_lsas', 'redistribution_limit', 'redistribution_threshold', 'reference_bandwidth', 'role', 'router_id', 'snmp_trap_enabled', 'spf_hold_time', 'spf_maximum_time', 'spf_start_time', 'stub_areas'], name, value)


                        class DomainId(Entity):
                            """
                            Domain ID information
                            
                            .. attribute:: primary_domain_id
                            
                            	Primary Domain ID
                            	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.PrimaryDomainId>`
                            
                            .. attribute:: secondary_domain_id
                            
                            	List of secondary domain IDs
                            	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.SecondaryDomainId>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId, self).__init__()

                                self.yang_name = "domain-id"
                                self.yang_parent_name = "ospfv3"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"primary-domain-id" : ("primary_domain_id", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.PrimaryDomainId)}
                                self._child_list_classes = {"secondary-domain-id" : ("secondary_domain_id", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.SecondaryDomainId)}

                                self.primary_domain_id = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.PrimaryDomainId()
                                self.primary_domain_id.parent = self
                                self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                self._children_yang_names.add("primary-domain-id")

                                self.secondary_domain_id = YList(self)
                                self._segment_path = lambda: "domain-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId, [], name, value)


                            class PrimaryDomainId(Entity):
                                """
                                Primary Domain ID
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.PrimaryDomainId, self).__init__()

                                    self.yang_name = "primary-domain-id"
                                    self.yang_parent_name = "domain-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                    self.domain_id_value = YLeaf(YType.str, "domain-id-value")
                                    self._segment_path = lambda: "primary-domain-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.PrimaryDomainId, ['domain_id_type', 'domain_id_value'], name, value)


                            class SecondaryDomainId(Entity):
                                """
                                List of secondary domain IDs
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.SecondaryDomainId, self).__init__()

                                    self.yang_name = "secondary-domain-id"
                                    self.yang_parent_name = "domain-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                    self.domain_id_value = YLeaf(YType.str, "domain-id-value")
                                    self._segment_path = lambda: "secondary-domain-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.DomainId.SecondaryDomainId, ['domain_id_type', 'domain_id_value'], name, value)


                        class IpfrrTiebreakers(Entity):
                            """
                            IPFRR\-Tiebreakers list
                            
                            .. attribute:: tiebreaker_index
                            
                            	Tiebreaker Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tiebreaker_type
                            
                            	Tiebreaker Type
                            	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.IpfrrTbrkr>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.IpfrrTiebreakers, self).__init__()

                                self.yang_name = "ipfrr-tiebreakers"
                                self.yang_parent_name = "ospfv3"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")
                                self._segment_path = lambda: "ipfrr-tiebreakers"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.IpfrrTiebreakers, ['tiebreaker_index', 'tiebreaker_type'], name, value)


                        class StubRouter(Entity):
                            """
                            Stub Router Information
                            
                            .. attribute:: abr_off_reason
                            
                            	Reason for being in ABR off mode
                            	**type**\:   :py:class:`StubRouterAbrOffReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterAbrOffReason>`
                            
                            .. attribute:: abr_resume_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when ABR duties were resumed
                            	**type**\:   :py:class:`AbrResumeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.AbrResumeTime>`
                            
                            .. attribute:: active
                            
                            	If true, stub router mode is active
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_metric
                            
                            	Metric for external LSAs in max\-metric mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: include_stub_links
                            
                            	If true, advertise maximum metric for stub links
                            	**type**\:  bool
                            
                            .. attribute:: mode
                            
                            	Stub router mode
                            	**type**\:   :py:class:`StubRouterMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterMode>`
                            
                            .. attribute:: remaining_time
                            
                            	Remaining time (in seconds) in stub router mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: set_reason
                            
                            	Reason for entering stub router mode
                            	**type**\:   :py:class:`StubRouterTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTrigger>`
                            
                            .. attribute:: start_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                            	**type**\:   :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.StartTime>`
                            
                            .. attribute:: summary_lsa_metric
                            
                            	Metric for summary LSAs in max\-metric mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: trigger
                            
                            	Triggers for entering stub router mode
                            	**type**\: list of    :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger>`
                            
                            .. attribute:: unset_reason
                            
                            	Reason for clearing stub router condition
                            	**type**\:   :py:class:`StubRouterExitReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReason>`
                            
                            .. attribute:: unset_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                            	**type**\:   :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.UnsetTime>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter, self).__init__()

                                self.yang_name = "stub-router"
                                self.yang_parent_name = "ospfv3"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"abr-resume-time" : ("abr_resume_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.AbrResumeTime), "start-time" : ("start_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.StartTime), "unset-time" : ("unset_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.UnsetTime)}
                                self._child_list_classes = {"trigger" : ("trigger", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger)}

                                self.abr_off_reason = YLeaf(YType.enumeration, "abr-off-reason")

                                self.active = YLeaf(YType.boolean, "active")

                                self.external_lsa_metric = YLeaf(YType.uint32, "external-lsa-metric")

                                self.include_stub_links = YLeaf(YType.boolean, "include-stub-links")

                                self.mode = YLeaf(YType.enumeration, "mode")

                                self.remaining_time = YLeaf(YType.uint32, "remaining-time")

                                self.set_reason = YLeaf(YType.enumeration, "set-reason")

                                self.summary_lsa_metric = YLeaf(YType.uint32, "summary-lsa-metric")

                                self.unset_reason = YLeaf(YType.enumeration, "unset-reason")

                                self.abr_resume_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.AbrResumeTime()
                                self.abr_resume_time.parent = self
                                self._children_name_map["abr_resume_time"] = "abr-resume-time"
                                self._children_yang_names.add("abr-resume-time")

                                self.start_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.StartTime()
                                self.start_time.parent = self
                                self._children_name_map["start_time"] = "start-time"
                                self._children_yang_names.add("start-time")

                                self.unset_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.UnsetTime()
                                self.unset_time.parent = self
                                self._children_name_map["unset_time"] = "unset-time"
                                self._children_yang_names.add("unset-time")

                                self.trigger = YList(self)
                                self._segment_path = lambda: "stub-router"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter, ['abr_off_reason', 'active', 'external_lsa_metric', 'include_stub_links', 'mode', 'remaining_time', 'set_reason', 'summary_lsa_metric', 'unset_reason'], name, value)


                            class AbrResumeTime(Entity):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when ABR
                                duties were resumed
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.AbrResumeTime, self).__init__()

                                    self.yang_name = "abr-resume-time"
                                    self.yang_parent_name = "stub-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "abr-resume-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.AbrResumeTime, ['nanosecond', 'second'], name, value)


                            class StartTime(Entity):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when stub
                                router mode was activated
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.StartTime, self).__init__()

                                    self.yang_name = "start-time"
                                    self.yang_parent_name = "stub-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "start-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.StartTime, ['nanosecond', 'second'], name, value)


                            class Trigger(Entity):
                                """
                                Triggers for entering stub router mode
                                
                                .. attribute:: start_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                	**type**\:   :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.StartTime>`
                                
                                .. attribute:: time
                                
                                	Time (in seconds) to stay in stub router mode
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: trigger
                                
                                	Stub Router Trigger type
                                	**type**\:   :py:class:`StubRouterTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTrigger>`
                                
                                .. attribute:: unset_reason
                                
                                	Reason for clearing stub router condition
                                	**type**\:   :py:class:`StubRouterExitReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReason>`
                                
                                .. attribute:: unset_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                	**type**\:   :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime>`
                                
                                .. attribute:: wait_for_bgp
                                
                                	If true, stub router is terminated when BGP converges
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger, self).__init__()

                                    self.yang_name = "trigger"
                                    self.yang_parent_name = "stub-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"start-time" : ("start_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.StartTime), "unset-time" : ("unset_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime)}
                                    self._child_list_classes = {}

                                    self.time = YLeaf(YType.uint32, "time")

                                    self.trigger = YLeaf(YType.enumeration, "trigger")

                                    self.unset_reason = YLeaf(YType.enumeration, "unset-reason")

                                    self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                                    self.start_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.StartTime()
                                    self.start_time.parent = self
                                    self._children_name_map["start_time"] = "start-time"
                                    self._children_yang_names.add("start-time")

                                    self.unset_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime()
                                    self.unset_time.parent = self
                                    self._children_name_map["unset_time"] = "unset-time"
                                    self._children_yang_names.add("unset-time")
                                    self._segment_path = lambda: "trigger"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger, ['time', 'trigger', 'unset_reason', 'wait_for_bgp'], name, value)


                                class StartTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router mode was activated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.StartTime, self).__init__()

                                        self.yang_name = "start-time"
                                        self.yang_parent_name = "trigger"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "start-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.StartTime, ['nanosecond', 'second'], name, value)


                                class UnsetTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router condition was cleared
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime, self).__init__()

                                        self.yang_name = "unset-time"
                                        self.yang_parent_name = "trigger"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "unset-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime, ['nanosecond', 'second'], name, value)


                            class UnsetTime(Entity):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when stub
                                router condition was cleared
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.UnsetTime, self).__init__()

                                    self.yang_name = "unset-time"
                                    self.yang_parent_name = "stub-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "unset-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3.StubRouter.UnsetTime, ['nanosecond', 'second'], name, value)


                    class Protocol(Entity):
                        """
                        OSPFv3 protocol summary
                        
                        .. attribute:: administrative_distance
                        
                        	Administrative distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: administrative_distance_external
                        
                        	Administrative Distance for External routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: administrative_distance_inter_area
                        
                        	Administrative Distance for Inter Area routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distribute_list_in
                        
                        	Distribute List In
                        	**type**\:  str
                        
                        .. attribute:: is_graceful_restart
                        
                        	If true, Graceful restart is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: protocol_router_id
                        
                        	Protocol router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol, self).__init__()

                            self.yang_name = "protocol"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.administrative_distance = YLeaf(YType.uint32, "administrative-distance")

                            self.administrative_distance_external = YLeaf(YType.uint32, "administrative-distance-external")

                            self.administrative_distance_inter_area = YLeaf(YType.uint32, "administrative-distance-inter-area")

                            self.distribute_list_in = YLeaf(YType.str, "distribute-list-in")

                            self.is_graceful_restart = YLeaf(YType.boolean, "is-graceful-restart")

                            self.protocol_router_id = YLeaf(YType.str, "protocol-router-id")
                            self._segment_path = lambda: "protocol"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol, ['administrative_distance', 'administrative_distance_external', 'administrative_distance_inter_area', 'distribute_list_in', 'is_graceful_restart', 'protocol_router_id'], name, value)


                    class Route(Entity):
                        """
                        OSPFv3 route summary
                        
                        .. attribute:: extern_one_route
                        
                        	Extern 1 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extern_two_route
                        
                        	Extern 2 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_area_route
                        
                        	Inter route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: intra_area_route
                        
                        	Intra route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_one_route
                        
                        	NSSA 1 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_two_route
                        
                        	NSSA 2 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_route
                        
                        	Redistribution route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_connected
                        
                        	Route connected 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_id
                        
                        	Route summary of a route ID 
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: total_received_route
                        
                        	Total route received summary
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_sent_route
                        
                        	Total route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Summary.Route, self).__init__()

                            self.yang_name = "route"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.extern_one_route = YLeaf(YType.uint32, "extern-one-route")

                            self.extern_two_route = YLeaf(YType.uint32, "extern-two-route")

                            self.inter_area_route = YLeaf(YType.uint32, "inter-area-route")

                            self.intra_area_route = YLeaf(YType.uint32, "intra-area-route")

                            self.nssa_one_route = YLeaf(YType.uint32, "nssa-one-route")

                            self.nssa_two_route = YLeaf(YType.uint32, "nssa-two-route")

                            self.redistribution_route = YLeaf(YType.uint32, "redistribution-route")

                            self.route_connected = YLeaf(YType.uint32, "route-connected")

                            self.route_id = YLeaf(YType.str, "route-id")

                            self.total_received_route = YLeaf(YType.uint32, "total-received-route")

                            self.total_sent_route = YLeaf(YType.uint32, "total-sent-route")
                            self._segment_path = lambda: "route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Route, ['extern_one_route', 'extern_two_route', 'inter_area_route', 'intra_area_route', 'nssa_one_route', 'nssa_two_route', 'redistribution_route', 'route_connected', 'route_id', 'total_received_route', 'total_sent_route'], name, value)


                class SummaryPrefixes(Entity):
                    """
                    Summary prefix information table
                    
                    .. attribute:: summary_prefix
                    
                    	Summary prefix information
                    	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes, self).__init__()

                        self.yang_name = "summary-prefixes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"summary-prefix" : ("summary_prefix", Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix)}

                        self.summary_prefix = YList(self)
                        self._segment_path = lambda: "summary-prefixes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes, [], name, value)


                    class SummaryPrefix(Entity):
                        """
                        Summary prefix information
                        
                        .. attribute:: prefix
                        
                        	Summary prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: prefix_metric
                        
                        	Prefix metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix_metric_type
                        
                        	Prefix metric type
                        	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                        
                        .. attribute:: tag
                        
                        	Tag
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, self).__init__()

                            self.yang_name = "summary-prefix"
                            self.yang_parent_name = "summary-prefixes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix_metric = YLeaf(YType.uint32, "prefix-metric")

                            self.prefix_metric_type = YLeaf(YType.enumeration, "prefix-metric-type")

                            self.tag = YLeaf(YType.uint32, "tag")
                            self._segment_path = lambda: "summary-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, ['prefix', 'prefix_length', 'prefix_metric', 'prefix_metric_type', 'tag'], name, value)


                class VirtualLink(Entity):
                    """
                    Virtual link information
                    
                    .. attribute:: interface_name
                    
                    	Interface on which this virtual link is formed
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_virtual_link_authentication_enabled
                    
                    	If true, virtual link authentication is enabled 
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_demand_circuit
                    
                    	If true, the link runs as demand circuit
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_encryption_enabled
                    
                    	If true, virtual link encryption is enabled 
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_ip_security_active
                    
                    	If true, Virtual link IP security is active 
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_ip_security_required
                    
                    	If true, virtual link IP security is required 
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_passive
                    
                    	If true, interface is passive
                    	**type**\:  bool
                    
                    .. attribute:: transit_area_id
                    
                    	Transit area id 
                    	**type**\:  str
                    
                    .. attribute:: virtual_link_authentication_spi
                    
                    	Virtual link authentication spi 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_authentication_transmit
                    
                    	Virtual link authentication transmit 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_cost
                    
                    	Cost of the virtual link
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtual_link_dc_bitless_lsa
                    
                    	Number of LSA's with demand circuit bit not set 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_dead_interval
                    
                    	Dead interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_encrypted_authentication_transmitted
                    
                    	Virtual link encrypted authentication transmitted 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_encryption_spi
                    
                    	Virtual link encryption spi
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_encryption_transmitted
                    
                    	Virtual link encryption transmitted 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_hello_interval
                    
                    	Hello interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_interface_number
                    
                    	Virtual link interface number 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_neighbor
                    
                    	Neighbor information 
                    	**type**\:   :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor>`
                    
                    .. attribute:: virtual_link_neighbor_address
                    
                    	Virtual link neighbor addresss 
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: virtual_link_neighbor_id
                    
                    	Neighbor on other end of this virtual link
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: virtual_link_next_hello
                    
                    	Time until next hello (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_retransmission_interval
                    
                    	Retransmission interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_state
                    
                    	OSPF interface state for the virtual link
                    	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                    
                    .. attribute:: virtual_link_wait_interval
                    
                    	Wait interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virual_link_transmission_delay
                    
                    	Transmission delay in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.VirtualLink, self).__init__()

                        self.yang_name = "virtual-link"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"virtual-link-neighbor" : ("virtual_link_neighbor", Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_link_authentication_enabled = YLeaf(YType.boolean, "is-virtual-link-authentication-enabled")

                        self.is_virtual_link_demand_circuit = YLeaf(YType.boolean, "is-virtual-link-demand-circuit")

                        self.is_virtual_link_encryption_enabled = YLeaf(YType.boolean, "is-virtual-link-encryption-enabled")

                        self.is_virtual_link_ip_security_active = YLeaf(YType.boolean, "is-virtual-link-ip-security-active")

                        self.is_virtual_link_ip_security_required = YLeaf(YType.boolean, "is-virtual-link-ip-security-required")

                        self.is_virtual_link_passive = YLeaf(YType.boolean, "is-virtual-link-passive")

                        self.transit_area_id = YLeaf(YType.str, "transit-area-id")

                        self.virtual_link_authentication_spi = YLeaf(YType.uint32, "virtual-link-authentication-spi")

                        self.virtual_link_authentication_transmit = YLeaf(YType.uint32, "virtual-link-authentication-transmit")

                        self.virtual_link_cost = YLeaf(YType.uint16, "virtual-link-cost")

                        self.virtual_link_dc_bitless_lsa = YLeaf(YType.uint32, "virtual-link-dc-bitless-lsa")

                        self.virtual_link_dead_interval = YLeaf(YType.uint32, "virtual-link-dead-interval")

                        self.virtual_link_encrypted_authentication_transmitted = YLeaf(YType.uint32, "virtual-link-encrypted-authentication-transmitted")

                        self.virtual_link_encryption_spi = YLeaf(YType.uint32, "virtual-link-encryption-spi")

                        self.virtual_link_encryption_transmitted = YLeaf(YType.uint32, "virtual-link-encryption-transmitted")

                        self.virtual_link_hello_interval = YLeaf(YType.uint32, "virtual-link-hello-interval")

                        self.virtual_link_interface_number = YLeaf(YType.uint32, "virtual-link-interface-number")

                        self.virtual_link_neighbor_address = YLeaf(YType.str, "virtual-link-neighbor-address")

                        self.virtual_link_neighbor_id = YLeaf(YType.str, "virtual-link-neighbor-id")

                        self.virtual_link_next_hello = YLeaf(YType.uint32, "virtual-link-next-hello")

                        self.virtual_link_retransmission_interval = YLeaf(YType.uint32, "virtual-link-retransmission-interval")

                        self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                        self.virtual_link_wait_interval = YLeaf(YType.uint32, "virtual-link-wait-interval")

                        self.virual_link_transmission_delay = YLeaf(YType.uint16, "virual-link-transmission-delay")

                        self.virtual_link_neighbor = Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor()
                        self.virtual_link_neighbor.parent = self
                        self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                        self._children_yang_names.add("virtual-link-neighbor")
                        self._segment_path = lambda: "virtual-link"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VirtualLink, ['interface_name', 'is_virtual_link_authentication_enabled', 'is_virtual_link_demand_circuit', 'is_virtual_link_encryption_enabled', 'is_virtual_link_ip_security_active', 'is_virtual_link_ip_security_required', 'is_virtual_link_passive', 'transit_area_id', 'virtual_link_authentication_spi', 'virtual_link_authentication_transmit', 'virtual_link_cost', 'virtual_link_dc_bitless_lsa', 'virtual_link_dead_interval', 'virtual_link_encrypted_authentication_transmitted', 'virtual_link_encryption_spi', 'virtual_link_encryption_transmitted', 'virtual_link_hello_interval', 'virtual_link_interface_number', 'virtual_link_neighbor_address', 'virtual_link_neighbor_id', 'virtual_link_next_hello', 'virtual_link_retransmission_interval', 'virtual_link_state', 'virtual_link_wait_interval', 'virual_link_transmission_delay'], name, value)


                    class VirtualLinkNeighbor(Entity):
                        """
                        Neighbor information 
                        
                        .. attribute:: is_virtual_link_hello_suppressed
                        
                        	If true, hello suppressed 
                        	**type**\:  bool
                        
                        .. attribute:: virtual_link_retransmission
                        
                        	Virtual link retransmission information 
                        	**type**\:   :py:class:`VirtualLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission>`
                        
                        .. attribute:: virtual_link_state
                        
                        	OSPF interface state for the virtual link
                        	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor, self).__init__()

                            self.yang_name = "virtual-link-neighbor"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"virtual-link-retransmission" : ("virtual_link_retransmission", Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission)}
                            self._child_list_classes = {}

                            self.is_virtual_link_hello_suppressed = YLeaf(YType.boolean, "is-virtual-link-hello-suppressed")

                            self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                            self.virtual_link_retransmission = Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission()
                            self.virtual_link_retransmission.parent = self
                            self._children_name_map["virtual_link_retransmission"] = "virtual-link-retransmission"
                            self._children_yang_names.add("virtual-link-retransmission")
                            self._segment_path = lambda: "virtual-link-neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor, ['is_virtual_link_hello_suppressed', 'virtual_link_state'], name, value)


                        class VirtualLinkRetransmission(Entity):
                            """
                            Virtual link retransmission information 
                            
                            .. attribute:: area_first_flood
                            
                            	First flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_first_flood_index
                            
                            	Index of the first flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_flood_index
                            
                            	Area scope LSA's flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood
                            
                            	Next flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood_index
                            
                            	Index of next flood item for Area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood
                            
                            	First flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood_index
                            
                            	Index for first flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_flood_index
                            
                            	AS scope LSA's flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood
                            
                            	Next flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood_index
                            
                            	Index of next flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: database_descriptor_retransmissions
                            
                            	Number of database descriptor retransmissions during last exchange
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_length
                            
                            	Number of LSAs sent in last retransmission
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_time
                            
                            	Last retransmission scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood
                            
                            	Link first flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood_index
                            
                            	Link first flood information index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_flood_index
                            
                            	Link flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood
                            
                            	Link next flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood_index
                            
                            	Link next flood information index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_timer
                            
                            	Time until next LSA retransmission (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_length
                            
                            	Maximum number of LSAs sent in a retransmission
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_time
                            
                            	Maximum retransmission scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmissions
                            
                            	Number of neighbor retransmissions 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissions
                            
                            	Number of retransmissions for this neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission, self).__init__()

                                self.yang_name = "virtual-link-retransmission"
                                self.yang_parent_name = "virtual-link-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                self._segment_path = lambda: "virtual-link-retransmission"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                class VrfStatistics(Entity):
                    """
                    Container for Statistics
                    
                    .. attribute:: prefix_priority_stats
                    
                    	OSPF Prefix SPF Prioritization statistics
                    	**type**\:   :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats>`
                    
                    .. attribute:: protocol_stats
                    
                    	Protocol table
                    	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats>`
                    
                    .. attribute:: rawio_stats
                    
                    	OSPF Prefix SPF Prioritization statistics
                    	**type**\:   :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats>`
                    
                    .. attribute:: spf_stats
                    
                    	OSPFv3 RIB batch statistics
                    	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats>`
                    
                    .. attribute:: vrf_rib_batch_stats
                    
                    	OSPFv3 RIB batch statistics
                    	**type**\:   :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics, self).__init__()

                        self.yang_name = "vrf-statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"prefix-priority-stats" : ("prefix_priority_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats), "protocol-stats" : ("protocol_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats), "rawio-stats" : ("rawio_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats), "spf-stats" : ("spf_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats), "vrf-rib-batch-stats" : ("vrf_rib_batch_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats)}
                        self._child_list_classes = {}

                        self.prefix_priority_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats()
                        self.prefix_priority_stats.parent = self
                        self._children_name_map["prefix_priority_stats"] = "prefix-priority-stats"
                        self._children_yang_names.add("prefix-priority-stats")

                        self.protocol_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats()
                        self.protocol_stats.parent = self
                        self._children_name_map["protocol_stats"] = "protocol-stats"
                        self._children_yang_names.add("protocol-stats")

                        self.rawio_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats()
                        self.rawio_stats.parent = self
                        self._children_name_map["rawio_stats"] = "rawio-stats"
                        self._children_yang_names.add("rawio-stats")

                        self.spf_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats()
                        self.spf_stats.parent = self
                        self._children_name_map["spf_stats"] = "spf-stats"
                        self._children_yang_names.add("spf-stats")

                        self.vrf_rib_batch_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats()
                        self.vrf_rib_batch_stats.parent = self
                        self._children_name_map["vrf_rib_batch_stats"] = "vrf-rib-batch-stats"
                        self._children_yang_names.add("vrf-rib-batch-stats")
                        self._segment_path = lambda: "vrf-statistics"


                    class PrefixPriorityStats(Entity):
                        """
                        OSPF Prefix SPF Prioritization statistics
                        
                        .. attribute:: critical
                        
                        	Critical priority classifications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high
                        
                        	High priority classifications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: low
                        
                        	Low priority classifications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: medium
                        
                        	Medium priority classifications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats, self).__init__()

                            self.yang_name = "prefix-priority-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.critical = YLeaf(YType.uint32, "critical")

                            self.high = YLeaf(YType.uint32, "high")

                            self.low = YLeaf(YType.uint32, "low")

                            self.medium = YLeaf(YType.uint32, "medium")
                            self._segment_path = lambda: "prefix-priority-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats, ['critical', 'high', 'low', 'medium'], name, value)


                    class ProtocolStats(Entity):
                        """
                        Protocol table
                        
                        .. attribute:: protocol_stat
                        
                        	Protocol statistics for an interface
                        	**type**\: list of    :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats, self).__init__()

                            self.yang_name = "protocol-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"protocol-stat" : ("protocol_stat", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat)}

                            self.protocol_stat = YList(self)
                            self._segment_path = lambda: "protocol-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats, [], name, value)


                        class ProtocolStat(Entity):
                            """
                            Protocol statistics for an interface
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: checksum_err
                            
                            	Checksum Errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_in_ls_as
                            
                            	Database Description LSAs in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_in_packets
                            
                            	Database Description Packets in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_out_ls_as
                            
                            	Database Description LSAs out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_out_packets
                            
                            	Database Description Packets out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dropped_in_gs
                            
                            	Dropped in GS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: hello_in_packets
                            
                            	Hello packets in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: hello_out_packets
                            
                            	Hello Out Packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_in_ls_as
                            
                            	LS Ack LSAs in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_in_packets
                            
                            	LS Acks Packets in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_out_ls_as
                            
                            	LS Ack LSAs out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_out_packets
                            
                            	LS Ack Packets out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_in_ls_as
                            
                            	LS Requests in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_in_packets
                            
                            	LSA Requests in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_out_ls_as
                            
                            	LS Reuqests LSAs out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_out_packets
                            
                            	LS Request Packets out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_ignored
                            
                            	LS Updates ignored
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_ls_as
                            
                            	LS Updates LSAs in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_packets
                            
                            	LS Updates Packets in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_out_ls_as
                            
                            	LS Update LSAs out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_out_packets
                            
                            	LS Update Packets out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: total_in_packets
                            
                            	Total inputs packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: total_out_packets
                            
                            	Total Out Packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat, self).__init__()

                                self.yang_name = "protocol-stat"
                                self.yang_parent_name = "protocol-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.checksum_err = YLeaf(YType.uint64, "checksum-err")

                                self.dbdes_in_ls_as = YLeaf(YType.uint64, "dbdes-in-ls-as")

                                self.dbdes_in_packets = YLeaf(YType.uint64, "dbdes-in-packets")

                                self.dbdes_out_ls_as = YLeaf(YType.uint64, "dbdes-out-ls-as")

                                self.dbdes_out_packets = YLeaf(YType.uint64, "dbdes-out-packets")

                                self.dropped_in_gs = YLeaf(YType.uint64, "dropped-in-gs")

                                self.hello_in_packets = YLeaf(YType.uint64, "hello-in-packets")

                                self.hello_out_packets = YLeaf(YType.uint64, "hello-out-packets")

                                self.ls_ack_in_ls_as = YLeaf(YType.uint64, "ls-ack-in-ls-as")

                                self.ls_ack_in_packets = YLeaf(YType.uint64, "ls-ack-in-packets")

                                self.ls_ack_out_ls_as = YLeaf(YType.uint64, "ls-ack-out-ls-as")

                                self.ls_ack_out_packets = YLeaf(YType.uint64, "ls-ack-out-packets")

                                self.ls_req_in_ls_as = YLeaf(YType.uint64, "ls-req-in-ls-as")

                                self.ls_req_in_packets = YLeaf(YType.uint64, "ls-req-in-packets")

                                self.ls_req_out_ls_as = YLeaf(YType.uint64, "ls-req-out-ls-as")

                                self.ls_req_out_packets = YLeaf(YType.uint64, "ls-req-out-packets")

                                self.ls_upd_in_ignored = YLeaf(YType.uint64, "ls-upd-in-ignored")

                                self.ls_upd_in_ls_as = YLeaf(YType.uint64, "ls-upd-in-ls-as")

                                self.ls_upd_in_packets = YLeaf(YType.uint64, "ls-upd-in-packets")

                                self.ls_upd_out_ls_as = YLeaf(YType.uint64, "ls-upd-out-ls-as")

                                self.ls_upd_out_packets = YLeaf(YType.uint64, "ls-upd-out-packets")

                                self.total_in_packets = YLeaf(YType.uint64, "total-in-packets")

                                self.total_out_packets = YLeaf(YType.uint64, "total-out-packets")
                                self._segment_path = lambda: "protocol-stat" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat, ['interface_name', 'checksum_err', 'dbdes_in_ls_as', 'dbdes_in_packets', 'dbdes_out_ls_as', 'dbdes_out_packets', 'dropped_in_gs', 'hello_in_packets', 'hello_out_packets', 'ls_ack_in_ls_as', 'ls_ack_in_packets', 'ls_ack_out_ls_as', 'ls_ack_out_packets', 'ls_req_in_ls_as', 'ls_req_in_packets', 'ls_req_out_ls_as', 'ls_req_out_packets', 'ls_upd_in_ignored', 'ls_upd_in_ls_as', 'ls_upd_in_packets', 'ls_upd_out_ls_as', 'ls_upd_out_packets', 'total_in_packets', 'total_out_packets'], name, value)


                    class RawioStats(Entity):
                        """
                        OSPF Prefix SPF Prioritization statistics
                        
                        .. attribute:: in_bytes
                        
                        	Received Bytes
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte
                        
                        .. attribute:: in_error_drops
                        
                        	In Error Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_handle_drops
                        
                        	In Handle Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_ipsec_drops
                        
                        	In IPSEC Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_long_packets
                        
                        	Received Long Packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_malloc_drops
                        
                        	In Malloc Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_packets
                        
                        	Received Packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_queue_drops
                        
                        	In Queue Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_short_drops
                        
                        	In Short Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_bytes
                        
                        	Sent Bytes
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte
                        
                        .. attribute:: out_error_drops
                        
                        	Error Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_ipsec_drops
                        
                        	Out IPSEC Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_nofd_drops
                        
                        	No FileDescriptor Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_nopak_drops
                        
                        	No Packet Buffers
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_packets
                        
                        	Packets Sent
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_pakapi_errors
                        
                        	PAK API Errors
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_close
                        
                        	Raw Connections Close
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_error
                        
                        	Raw Connections Error
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_open
                        
                        	Raw Connections Open
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_state
                        
                        	Raw Connection State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats, self).__init__()

                            self.yang_name = "rawio-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.in_bytes = YLeaf(YType.uint64, "in-bytes")

                            self.in_error_drops = YLeaf(YType.uint64, "in-error-drops")

                            self.in_handle_drops = YLeaf(YType.uint64, "in-handle-drops")

                            self.in_ipsec_drops = YLeaf(YType.uint64, "in-ipsec-drops")

                            self.in_long_packets = YLeaf(YType.uint64, "in-long-packets")

                            self.in_malloc_drops = YLeaf(YType.uint64, "in-malloc-drops")

                            self.in_packets = YLeaf(YType.uint64, "in-packets")

                            self.in_queue_drops = YLeaf(YType.uint64, "in-queue-drops")

                            self.in_short_drops = YLeaf(YType.uint64, "in-short-drops")

                            self.out_bytes = YLeaf(YType.uint64, "out-bytes")

                            self.out_error_drops = YLeaf(YType.uint64, "out-error-drops")

                            self.out_ipsec_drops = YLeaf(YType.uint64, "out-ipsec-drops")

                            self.out_nofd_drops = YLeaf(YType.uint64, "out-nofd-drops")

                            self.out_nopak_drops = YLeaf(YType.uint64, "out-nopak-drops")

                            self.out_packets = YLeaf(YType.uint64, "out-packets")

                            self.out_pakapi_errors = YLeaf(YType.uint64, "out-pakapi-errors")

                            self.raw_conn_close = YLeaf(YType.uint64, "raw-conn-close")

                            self.raw_conn_error = YLeaf(YType.uint64, "raw-conn-error")

                            self.raw_conn_open = YLeaf(YType.uint64, "raw-conn-open")

                            self.raw_conn_state = YLeaf(YType.uint32, "raw-conn-state")
                            self._segment_path = lambda: "rawio-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats, ['in_bytes', 'in_error_drops', 'in_handle_drops', 'in_ipsec_drops', 'in_long_packets', 'in_malloc_drops', 'in_packets', 'in_queue_drops', 'in_short_drops', 'out_bytes', 'out_error_drops', 'out_ipsec_drops', 'out_nofd_drops', 'out_nopak_drops', 'out_packets', 'out_pakapi_errors', 'raw_conn_close', 'raw_conn_error', 'raw_conn_open', 'raw_conn_state'], name, value)


                    class SpfStats(Entity):
                        """
                        OSPFv3 RIB batch statistics
                        
                        .. attribute:: spf_header
                        
                        	SPF statistics header
                        	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader>`
                        
                        .. attribute:: spf_runtime
                        
                        	List of SPF run\-time statistics
                        	**type**\: list of    :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats, self).__init__()

                            self.yang_name = "spf-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"spf-header" : ("spf_header", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader)}
                            self._child_list_classes = {"spf-runtime" : ("spf_runtime", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime)}

                            self.spf_header = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader()
                            self.spf_header.parent = self
                            self._children_name_map["spf_header"] = "spf-header"
                            self._children_yang_names.add("spf-header")

                            self.spf_runtime = YList(self)
                            self._segment_path = lambda: "spf-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats, [], name, value)


                        class SpfHeader(Entity):
                            """
                            SPF statistics header
                            
                            .. attribute:: area_summary
                            
                            	List of Areas with SPF statistics
                            	**type**\: list of    :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary>`
                            
                            .. attribute:: header_router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sp_fs
                            
                            	Number of SPF calculations
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader, self).__init__()

                                self.yang_name = "spf-header"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-summary" : ("area_summary", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary)}

                                self.header_router_id = YLeaf(YType.str, "header-router-id")

                                self.header_sp_fs = YLeaf(YType.uint32, "header-sp-fs")

                                self.area_summary = YList(self)
                                self._segment_path = lambda: "spf-header"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader, ['header_router_id', 'header_sp_fs'], name, value)


                            class AreaSummary(Entity):
                                """
                                List of Areas with SPF statistics
                                
                                .. attribute:: area_id
                                
                                	Area ID of the area SPF statistics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_fs
                                
                                	Number of SPF calculations
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary, self).__init__()

                                    self.yang_name = "area-summary"
                                    self.yang_parent_name = "spf-header"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.sp_fs = YLeaf(YType.uint32, "sp-fs")
                                    self._segment_path = lambda: "area-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary, ['area_id', 'sp_fs'], name, value)


                        class SpfRuntime(Entity):
                            """
                            List of SPF run\-time statistics
                            
                            .. attribute:: area_stat
                            
                            	List of per\-area SPF statistics
                            	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat>`
                            
                            .. attribute:: global_time
                            
                            	Global SPF times
                            	**type**\:   :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime>`
                            
                            .. attribute:: lsa
                            
                            	List of LSAs triggering the SPF calculation
                            	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa>`
                            
                            .. attribute:: lsa_changes
                            
                            	Number of LSA changes triggering an SPF calculation
                            	**type**\:  int
                            
                            	**range:** \-32768..32767
                            
                            .. attribute:: reason_flags
                            
                            	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: rib_add_routes
                            
                            	Number of routes added to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_delete_routes
                            
                            	Number of routes deleted from RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: start_time
                            
                            	SPF calculation start time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime, self).__init__()

                                self.yang_name = "spf-runtime"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"global-time" : ("global_time", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime)}
                                self._child_list_classes = {"area-stat" : ("area_stat", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat), "lsa" : ("lsa", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa)}

                                self.lsa_changes = YLeaf(YType.int16, "lsa-changes")

                                self.reason_flags = YLeaf(YType.str, "reason-flags")

                                self.rib_add_routes = YLeaf(YType.uint32, "rib-add-routes")

                                self.rib_delete_routes = YLeaf(YType.uint32, "rib-delete-routes")

                                self.start_time = YLeaf(YType.uint32, "start-time")

                                self.global_time = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime()
                                self.global_time.parent = self
                                self._children_name_map["global_time"] = "global-time"
                                self._children_yang_names.add("global-time")

                                self.area_stat = YList(self)
                                self.lsa = YList(self)
                                self._segment_path = lambda: "spf-runtime"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime, ['lsa_changes', 'reason_flags', 'rib_add_routes', 'rib_delete_routes', 'start_time'], name, value)


                            class AreaStat(Entity):
                                """
                                List of per\-area SPF statistics
                                
                                .. attribute:: spf_stat_area_id
                                
                                	Area ID for area of these SPF statistics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_stat_lsa_type_count
                                
                                	Counts of LSA types triggering an SPF calculation
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_stat_time
                                
                                	SPF time calculations
                                	**type**\:   :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat, self).__init__()

                                    self.yang_name = "area-stat"
                                    self.yang_parent_name = "spf-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"spf-stat-time" : ("spf_stat_time", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime)}
                                    self._child_list_classes = {}

                                    self.spf_stat_area_id = YLeaf(YType.uint32, "spf-stat-area-id")

                                    self.spf_stat_lsa_type_count = YLeafList(YType.uint32, "spf-stat-lsa-type-count")

                                    self.spf_stat_time = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                    self.spf_stat_time.parent = self
                                    self._children_name_map["spf_stat_time"] = "spf-stat-time"
                                    self._children_yang_names.add("spf-stat-time")
                                    self._segment_path = lambda: "area-stat"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat, ['spf_stat_area_id', 'spf_stat_lsa_type_count'], name, value)


                                class SpfStatTime(Entity):
                                    """
                                    SPF time calculations
                                    
                                    .. attribute:: dijkstra
                                    
                                    	Dijkstra time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix
                                    
                                    	External prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix_del
                                    
                                    	External prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix
                                    
                                    	Inter\-prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix
                                    
                                    	Intra\-prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_add
                                    
                                    	RIB add processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_del
                                    
                                    	RIB deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, self).__init__()

                                        self.yang_name = "spf-stat-time"
                                        self.yang_parent_name = "area-stat"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.dijkstra = YLeaf(YType.uint32, "dijkstra")

                                        self.external_prefix = YLeaf(YType.uint32, "external-prefix")

                                        self.external_prefix_del = YLeaf(YType.uint32, "external-prefix-del")

                                        self.inter_prefix = YLeaf(YType.uint32, "inter-prefix")

                                        self.inter_prefix_del = YLeaf(YType.uint32, "inter-prefix-del")

                                        self.intra_prefix = YLeaf(YType.uint32, "intra-prefix")

                                        self.intra_prefix_del = YLeaf(YType.uint32, "intra-prefix-del")

                                        self.rib_add = YLeaf(YType.uint32, "rib-add")

                                        self.rib_del = YLeaf(YType.uint32, "rib-del")
                                        self._segment_path = lambda: "spf-stat-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, ['dijkstra', 'external_prefix', 'external_prefix_del', 'inter_prefix', 'inter_prefix_del', 'intra_prefix', 'intra_prefix_del', 'rib_add', 'rib_del'], name, value)


                            class GlobalTime(Entity):
                                """
                                Global SPF times
                                
                                .. attribute:: dijkstra
                                
                                	Dijkstra time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix
                                
                                	External prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix_del
                                
                                	External prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix
                                
                                	Inter\-prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix
                                
                                	Intra\-prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_add
                                
                                	RIB add processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_del
                                
                                	RIB deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime, self).__init__()

                                    self.yang_name = "global-time"
                                    self.yang_parent_name = "spf-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.dijkstra = YLeaf(YType.uint32, "dijkstra")

                                    self.external_prefix = YLeaf(YType.uint32, "external-prefix")

                                    self.external_prefix_del = YLeaf(YType.uint32, "external-prefix-del")

                                    self.inter_prefix = YLeaf(YType.uint32, "inter-prefix")

                                    self.inter_prefix_del = YLeaf(YType.uint32, "inter-prefix-del")

                                    self.intra_prefix = YLeaf(YType.uint32, "intra-prefix")

                                    self.intra_prefix_del = YLeaf(YType.uint32, "intra-prefix-del")

                                    self.rib_add = YLeaf(YType.uint32, "rib-add")

                                    self.rib_del = YLeaf(YType.uint32, "rib-del")
                                    self._segment_path = lambda: "global-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime, ['dijkstra', 'external_prefix', 'external_prefix_del', 'inter_prefix', 'inter_prefix_del', 'intra_prefix', 'intra_prefix_del', 'rib_add', 'rib_del'], name, value)


                            class Lsa(Entity):
                                """
                                List of LSAs triggering the SPF calculation
                                
                                .. attribute:: lsa_advertising_router
                                
                                	Advertising router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_flush
                                
                                	If true, the LSA change is a flush
                                	**type**\:  bool
                                
                                .. attribute:: lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsa_type
                                
                                	LSA type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "spf-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.lsa_advertising_router = YLeaf(YType.str, "lsa-advertising-router")

                                    self.lsa_area_id = YLeaf(YType.uint32, "lsa-area-id")

                                    self.lsa_flush = YLeaf(YType.boolean, "lsa-flush")

                                    self.lsa_id = YLeaf(YType.str, "lsa-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")
                                    self._segment_path = lambda: "lsa"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa, ['lsa_advertising_router', 'lsa_area_id', 'lsa_flush', 'lsa_id', 'lsa_type'], name, value)


                    class VrfRibBatchStats(Entity):
                        """
                        OSPFv3 RIB batch statistics
                        
                        .. attribute:: batches_sent
                        
                        	No. of RIB batches sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_routes
                        
                        	Max No. of Routes in a batch
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_add
                        
                        	No. of paths added to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_add_errs
                        
                        	No. of paths add errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_del
                        
                        	No. of paths del sent to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_del_errs
                        
                        	No. of Paths del errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_pending
                        
                        	No. of paths waiting to be sent to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_sent
                        
                        	No. of Paths sent to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: routes_pending
                        
                        	No of Pending Routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: routes_sent
                        
                        	No. of Routes sent to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats, self).__init__()

                            self.yang_name = "vrf-rib-batch-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.batches_sent = YLeaf(YType.uint32, "batches-sent")

                            self.max_routes = YLeaf(YType.uint32, "max-routes")

                            self.paths_add = YLeaf(YType.uint32, "paths-add")

                            self.paths_add_errs = YLeaf(YType.uint32, "paths-add-errs")

                            self.paths_del = YLeaf(YType.uint32, "paths-del")

                            self.paths_del_errs = YLeaf(YType.uint32, "paths-del-errs")

                            self.paths_pending = YLeaf(YType.uint32, "paths-pending")

                            self.paths_sent = YLeaf(YType.uint32, "paths-sent")

                            self.routes_pending = YLeaf(YType.uint32, "routes-pending")

                            self.routes_sent = YLeaf(YType.uint32, "routes-sent")
                            self._segment_path = lambda: "vrf-rib-batch-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats, ['batches_sent', 'max_routes', 'paths_add', 'paths_add_errs', 'paths_del', 'paths_del_errs', 'paths_pending', 'paths_sent', 'routes_pending', 'routes_sent'], name, value)


            class Statistics(Entity):
                """
                Container for Statistics
                
                .. attribute:: issu_stats
                
                	OSPF ISSU statistics
                	**type**\:   :py:class:`IssuStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats>`
                
                .. attribute:: nsr_pl_stats
                
                	OSPF NSR packet library statistics
                	**type**\:   :py:class:`NsrPlStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats>`
                
                .. attribute:: nsr_stats
                
                	OSPF NSR statistics
                	**type**\:   :py:class:`NsrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats>`
                
                .. attribute:: prefix_priority_stats
                
                	OSPF Prefix SPF Prioritization statistics
                	**type**\:   :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.PrefixPriorityStats>`
                
                .. attribute:: protocol_stats
                
                	Protocol table
                	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.ProtocolStats>`
                
                .. attribute:: rawio_stats
                
                	OSPF Prefix SPF Prioritization statistics
                	**type**\:   :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RawioStats>`
                
                .. attribute:: rib_thread_stats
                
                	OSPFv3 RIB thread statistics
                	**type**\:   :py:class:`RibThreadStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats>`
                
                .. attribute:: spf_stats
                
                	OSPFv3 RIB batch statistics
                	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats>`
                
                .. attribute:: vrf_rib_batch_stats
                
                	OSPFv3 RIB batch statistics
                	**type**\:   :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.VrfRibBatchStats>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ospfv3.Processes.Process.Statistics, self).__init__()

                    self.yang_name = "statistics"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"issu-stats" : ("issu_stats", Ospfv3.Processes.Process.Statistics.IssuStats), "nsr-pl-stats" : ("nsr_pl_stats", Ospfv3.Processes.Process.Statistics.NsrPlStats), "nsr-stats" : ("nsr_stats", Ospfv3.Processes.Process.Statistics.NsrStats), "prefix-priority-stats" : ("prefix_priority_stats", Ospfv3.Processes.Process.Statistics.PrefixPriorityStats), "protocol-stats" : ("protocol_stats", Ospfv3.Processes.Process.Statistics.ProtocolStats), "rawio-stats" : ("rawio_stats", Ospfv3.Processes.Process.Statistics.RawioStats), "rib-thread-stats" : ("rib_thread_stats", Ospfv3.Processes.Process.Statistics.RibThreadStats), "spf-stats" : ("spf_stats", Ospfv3.Processes.Process.Statistics.SpfStats), "vrf-rib-batch-stats" : ("vrf_rib_batch_stats", Ospfv3.Processes.Process.Statistics.VrfRibBatchStats)}
                    self._child_list_classes = {}

                    self.issu_stats = Ospfv3.Processes.Process.Statistics.IssuStats()
                    self.issu_stats.parent = self
                    self._children_name_map["issu_stats"] = "issu-stats"
                    self._children_yang_names.add("issu-stats")

                    self.nsr_pl_stats = Ospfv3.Processes.Process.Statistics.NsrPlStats()
                    self.nsr_pl_stats.parent = self
                    self._children_name_map["nsr_pl_stats"] = "nsr-pl-stats"
                    self._children_yang_names.add("nsr-pl-stats")

                    self.nsr_stats = Ospfv3.Processes.Process.Statistics.NsrStats()
                    self.nsr_stats.parent = self
                    self._children_name_map["nsr_stats"] = "nsr-stats"
                    self._children_yang_names.add("nsr-stats")

                    self.prefix_priority_stats = Ospfv3.Processes.Process.Statistics.PrefixPriorityStats()
                    self.prefix_priority_stats.parent = self
                    self._children_name_map["prefix_priority_stats"] = "prefix-priority-stats"
                    self._children_yang_names.add("prefix-priority-stats")

                    self.protocol_stats = Ospfv3.Processes.Process.Statistics.ProtocolStats()
                    self.protocol_stats.parent = self
                    self._children_name_map["protocol_stats"] = "protocol-stats"
                    self._children_yang_names.add("protocol-stats")

                    self.rawio_stats = Ospfv3.Processes.Process.Statistics.RawioStats()
                    self.rawio_stats.parent = self
                    self._children_name_map["rawio_stats"] = "rawio-stats"
                    self._children_yang_names.add("rawio-stats")

                    self.rib_thread_stats = Ospfv3.Processes.Process.Statistics.RibThreadStats()
                    self.rib_thread_stats.parent = self
                    self._children_name_map["rib_thread_stats"] = "rib-thread-stats"
                    self._children_yang_names.add("rib-thread-stats")

                    self.spf_stats = Ospfv3.Processes.Process.Statistics.SpfStats()
                    self.spf_stats.parent = self
                    self._children_name_map["spf_stats"] = "spf-stats"
                    self._children_yang_names.add("spf-stats")

                    self.vrf_rib_batch_stats = Ospfv3.Processes.Process.Statistics.VrfRibBatchStats()
                    self.vrf_rib_batch_stats.parent = self
                    self._children_name_map["vrf_rib_batch_stats"] = "vrf-rib-batch-stats"
                    self._children_yang_names.add("vrf-rib-batch-stats")
                    self._segment_path = lambda: "statistics"


                class IssuStats(Entity):
                    """
                    OSPF ISSU statistics
                    
                    .. attribute:: nsr_conn_to_active_attempts
                    
                    	Attempts to connect to active
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_closes
                    
                    	Conn to active closes
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_errors
                    
                    	Conn to active errors
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_fails
                    
                    	Failures to connect to active
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_opens
                    
                    	Conn to active opens
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_fsm_state
                    
                    	FSM state
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_intf_seq_no
                    
                    	Interface TLV sequence no
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_init_sync_pend_count
                    
                    	Pending init\-sync LSA msgs
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_lsa_qad_mdata_count
                    
                    	LSA QAD pending msgs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_qad_qid
                    
                    	LSA QAD queue id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_mtu
                    
                    	Fabric MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_init_sync_pend_count
                    
                    	Pending init\-sync NBR msgs
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_nbr_qad_mdata_count
                    
                    	NBR QAD pending msg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_qad_qid
                    
                    	NBR QAD queue id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_seq_no
                    
                    	Neighbor TLV sequence no
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_node_id
                    
                    	My nodeid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_node_id
                    
                    	Partner NodeID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_version
                    
                    	Partner NSR version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_revision
                    
                    	NSR revision
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_rtr_thd_sched
                    
                    	Rtr thread NSR pulse handler stats
                    	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched>`
                    
                    .. attribute:: nsr_thd_stats
                    
                    	NSR thread scheduler stats
                    	**type**\:   :py:class:`NsrThdStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats>`
                    
                    .. attribute:: nsr_tmr_quant
                    
                    	Timers processed per pulse
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_version
                    
                    	NSR version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.IssuStats, self).__init__()

                        self.yang_name = "issu-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"nsr-rtr-thd-sched" : ("nsr_rtr_thd_sched", Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched), "nsr-thd-stats" : ("nsr_thd_stats", Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats)}
                        self._child_list_classes = {}

                        self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                        self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                        self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                        self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                        self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                        self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                        self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                        self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                        self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                        self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                        self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                        self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                        self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                        self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                        self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                        self.nsr_node_id = YLeaf(YType.uint32, "nsr-node-id")

                        self.nsr_peer_node_id = YLeaf(YType.uint32, "nsr-peer-node-id")

                        self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                        self.nsr_revision = YLeaf(YType.int32, "nsr-revision")

                        self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                        self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                        self.nsr_rtr_thd_sched = Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched()
                        self.nsr_rtr_thd_sched.parent = self
                        self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                        self._children_yang_names.add("nsr-rtr-thd-sched")

                        self.nsr_thd_stats = Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats()
                        self.nsr_thd_stats.parent = self
                        self._children_name_map["nsr_thd_stats"] = "nsr-thd-stats"
                        self._children_yang_names.add("nsr-thd-stats")
                        self._segment_path = lambda: "issu-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats, ['nsr_conn_to_active_attempts', 'nsr_conn_to_active_closes', 'nsr_conn_to_active_errors', 'nsr_conn_to_active_fails', 'nsr_conn_to_active_opens', 'nsr_fsm_state', 'nsr_intf_seq_no', 'nsr_lsa_init_sync_pend_count', 'nsr_lsa_qad_mdata_count', 'nsr_lsa_qad_qid', 'nsr_mtu', 'nsr_nbr_init_sync_pend_count', 'nsr_nbr_qad_mdata_count', 'nsr_nbr_qad_qid', 'nsr_nbr_seq_no', 'nsr_node_id', 'nsr_peer_node_id', 'nsr_peer_version', 'nsr_revision', 'nsr_tmr_quant', 'nsr_version'], name, value)


                    class NsrRtrThdSched(Entity):
                        """
                        Rtr thread NSR pulse handler stats
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri>`
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched, self).__init__()

                            self.yang_name = "nsr-rtr-thd-sched"
                            self.yang_parent_name = "issu-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri)}

                            self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                            self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                            self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                            self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                            self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                            self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                            self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                            self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                            self.nsr_pri = YList(self)
                            self._segment_path = lambda: "nsr-rtr-thd-sched"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                        class NsrPri(Entity):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:   :py:class:`OspfNsrSchedPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPri>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__init__()

                                self.yang_name = "nsr-pri"
                                self.yang_parent_name = "nsr-rtr-thd-sched"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                self.nsr_sched_pri = YLeaf(YType.enumeration, "nsr-sched-pri")

                                self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                self._segment_path = lambda: "nsr-pri"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                    class NsrThdStats(Entity):
                        """
                        NSR thread scheduler stats
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri>`
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats, self).__init__()

                            self.yang_name = "nsr-thd-stats"
                            self.yang_parent_name = "issu-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri)}

                            self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                            self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                            self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                            self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                            self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                            self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                            self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                            self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                            self.nsr_pri = YList(self)
                            self._segment_path = lambda: "nsr-thd-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                        class NsrPri(Entity):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:   :py:class:`OspfNsrSchedPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPri>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri, self).__init__()

                                self.yang_name = "nsr-pri"
                                self.yang_parent_name = "nsr-thd-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                self.nsr_sched_pri = YLeaf(YType.enumeration, "nsr-sched-pri")

                                self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                self._segment_path = lambda: "nsr-pri"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                class NsrPlStats(Entity):
                    """
                    OSPF NSR packet library statistics
                    
                    .. attribute:: ncd_pri
                    
                    	ncd pri
                    	**type**\: list of    :py:class:`NcdPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.NsrPlStats, self).__init__()

                        self.yang_name = "nsr-pl-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ncd-pri" : ("ncd_pri", Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri)}

                        self.ncd_pri = YList(self)
                        self._segment_path = lambda: "nsr-pl-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrPlStats, [], name, value)


                    class NcdPri(Entity):
                        """
                        ncd pri
                        
                        .. attribute:: num_recv
                        
                        	Total recvd
                        	**type**\:  list of int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: num_recv_drop
                        
                        	Recv Errors/drops
                        	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop>`
                        
                        .. attribute:: num_sent
                        
                        	Total sent
                        	**type**\:  list of int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: num_sent_drop
                        
                        	Sent Error/drops
                        	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri, self).__init__()

                            self.yang_name = "ncd-pri"
                            self.yang_parent_name = "nsr-pl-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"num-recv-drop" : ("num_recv_drop", Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop), "num-sent-drop" : ("num_sent_drop", Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop)}

                            self.num_recv = YLeafList(YType.uint64, "num-recv")

                            self.num_sent = YLeafList(YType.uint64, "num-sent")

                            self.num_recv_drop = YList(self)
                            self.num_sent_drop = YList(self)
                            self._segment_path = lambda: "ncd-pri"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri, ['num_recv', 'num_sent'], name, value)


                        class NumRecvDrop(Entity):
                            """
                            Recv Errors/drops
                            
                            .. attribute:: nsr_pl_recv_drop_array
                            
                            	nsr pl recv drop array
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__init__()

                                self.yang_name = "num-recv-drop"
                                self.yang_parent_name = "ncd-pri"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_pl_recv_drop_array = YLeafList(YType.uint32, "nsr-pl-recv-drop-array")
                                self._segment_path = lambda: "num-recv-drop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop, ['nsr_pl_recv_drop_array'], name, value)


                        class NumSentDrop(Entity):
                            """
                            Sent Error/drops
                            
                            .. attribute:: nsr_pl_send_drop_array
                            
                            	nsr pl send drop array
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__init__()

                                self.yang_name = "num-sent-drop"
                                self.yang_parent_name = "ncd-pri"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_pl_send_drop_array = YLeafList(YType.uint32, "nsr-pl-send-drop-array")
                                self._segment_path = lambda: "num-sent-drop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop, ['nsr_pl_send_drop_array'], name, value)


                class NsrStats(Entity):
                    """
                    OSPF NSR statistics
                    
                    .. attribute:: nsr_conn_to_active_attempts
                    
                    	Attempts to connect to active
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_closes
                    
                    	Conn to active closes
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_errors
                    
                    	Conn to active errors
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_fails
                    
                    	Failures to connect to active
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_opens
                    
                    	Conn to active opens
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_fsm_state
                    
                    	FSM state
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_intf_seq_no
                    
                    	Interface TLV sequence no
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_init_sync_pend_count
                    
                    	Pending init\-sync LSA msgs
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_lsa_qad_mdata_count
                    
                    	LSA QAD pending msgs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_qad_qid
                    
                    	LSA QAD queue id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_mtu
                    
                    	Fabric MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_init_sync_pend_count
                    
                    	Pending init\-sync NBR msgs
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_nbr_qad_mdata_count
                    
                    	NBR QAD pending msg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_qad_qid
                    
                    	NBR QAD queue id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_seq_no
                    
                    	Neighbor TLV sequence no
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_node_id
                    
                    	My nodeid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_node_id
                    
                    	Partner NodeID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_version
                    
                    	Partner NSR version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_revision
                    
                    	NSR revision
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_rtr_thd_sched
                    
                    	Rtr thread NSR pulse handler stats
                    	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched>`
                    
                    .. attribute:: nsr_thd_stats
                    
                    	NSR thread scheduler stats
                    	**type**\:   :py:class:`NsrThdStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats>`
                    
                    .. attribute:: nsr_tmr_quant
                    
                    	Timers processed per pulse
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_version
                    
                    	NSR version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.NsrStats, self).__init__()

                        self.yang_name = "nsr-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"nsr-rtr-thd-sched" : ("nsr_rtr_thd_sched", Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched), "nsr-thd-stats" : ("nsr_thd_stats", Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats)}
                        self._child_list_classes = {}

                        self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                        self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                        self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                        self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                        self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                        self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                        self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                        self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                        self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                        self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                        self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                        self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                        self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                        self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                        self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                        self.nsr_node_id = YLeaf(YType.uint32, "nsr-node-id")

                        self.nsr_peer_node_id = YLeaf(YType.uint32, "nsr-peer-node-id")

                        self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                        self.nsr_revision = YLeaf(YType.int32, "nsr-revision")

                        self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                        self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                        self.nsr_rtr_thd_sched = Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched()
                        self.nsr_rtr_thd_sched.parent = self
                        self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                        self._children_yang_names.add("nsr-rtr-thd-sched")

                        self.nsr_thd_stats = Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats()
                        self.nsr_thd_stats.parent = self
                        self._children_name_map["nsr_thd_stats"] = "nsr-thd-stats"
                        self._children_yang_names.add("nsr-thd-stats")
                        self._segment_path = lambda: "nsr-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats, ['nsr_conn_to_active_attempts', 'nsr_conn_to_active_closes', 'nsr_conn_to_active_errors', 'nsr_conn_to_active_fails', 'nsr_conn_to_active_opens', 'nsr_fsm_state', 'nsr_intf_seq_no', 'nsr_lsa_init_sync_pend_count', 'nsr_lsa_qad_mdata_count', 'nsr_lsa_qad_qid', 'nsr_mtu', 'nsr_nbr_init_sync_pend_count', 'nsr_nbr_qad_mdata_count', 'nsr_nbr_qad_qid', 'nsr_nbr_seq_no', 'nsr_node_id', 'nsr_peer_node_id', 'nsr_peer_version', 'nsr_revision', 'nsr_tmr_quant', 'nsr_version'], name, value)


                    class NsrRtrThdSched(Entity):
                        """
                        Rtr thread NSR pulse handler stats
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri>`
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched, self).__init__()

                            self.yang_name = "nsr-rtr-thd-sched"
                            self.yang_parent_name = "nsr-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri)}

                            self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                            self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                            self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                            self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                            self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                            self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                            self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                            self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                            self.nsr_pri = YList(self)
                            self._segment_path = lambda: "nsr-rtr-thd-sched"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                        class NsrPri(Entity):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:   :py:class:`OspfNsrSchedPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPri>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__init__()

                                self.yang_name = "nsr-pri"
                                self.yang_parent_name = "nsr-rtr-thd-sched"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                self.nsr_sched_pri = YLeaf(YType.enumeration, "nsr-sched-pri")

                                self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                self._segment_path = lambda: "nsr-pri"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                    class NsrThdStats(Entity):
                        """
                        NSR thread scheduler stats
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri>`
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats, self).__init__()

                            self.yang_name = "nsr-thd-stats"
                            self.yang_parent_name = "nsr-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri)}

                            self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                            self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                            self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                            self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                            self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                            self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                            self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                            self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                            self.nsr_pri = YList(self)
                            self._segment_path = lambda: "nsr-thd-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                        class NsrPri(Entity):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:   :py:class:`OspfNsrSchedPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPri>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri, self).__init__()

                                self.yang_name = "nsr-pri"
                                self.yang_parent_name = "nsr-thd-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                self.nsr_sched_pri = YLeaf(YType.enumeration, "nsr-sched-pri")

                                self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                self._segment_path = lambda: "nsr-pri"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                class PrefixPriorityStats(Entity):
                    """
                    OSPF Prefix SPF Prioritization statistics
                    
                    .. attribute:: critical
                    
                    	Critical priority classifications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: high
                    
                    	High priority classifications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: low
                    
                    	Low priority classifications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: medium
                    
                    	Medium priority classifications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.PrefixPriorityStats, self).__init__()

                        self.yang_name = "prefix-priority-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.critical = YLeaf(YType.uint32, "critical")

                        self.high = YLeaf(YType.uint32, "high")

                        self.low = YLeaf(YType.uint32, "low")

                        self.medium = YLeaf(YType.uint32, "medium")
                        self._segment_path = lambda: "prefix-priority-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.PrefixPriorityStats, ['critical', 'high', 'low', 'medium'], name, value)


                class ProtocolStats(Entity):
                    """
                    Protocol table
                    
                    .. attribute:: protocol_stat
                    
                    	Protocol statistics for an interface
                    	**type**\: list of    :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.ProtocolStats, self).__init__()

                        self.yang_name = "protocol-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"protocol-stat" : ("protocol_stat", Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat)}

                        self.protocol_stat = YList(self)
                        self._segment_path = lambda: "protocol-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.ProtocolStats, [], name, value)


                    class ProtocolStat(Entity):
                        """
                        Protocol statistics for an interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: checksum_err
                        
                        	Checksum Errors
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_in_ls_as
                        
                        	Database Description LSAs in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_in_packets
                        
                        	Database Description Packets in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_out_ls_as
                        
                        	Database Description LSAs out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_out_packets
                        
                        	Database Description Packets out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dropped_in_gs
                        
                        	Dropped in GS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_in_packets
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_out_packets
                        
                        	Hello Out Packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_in_ls_as
                        
                        	LS Ack LSAs in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_in_packets
                        
                        	LS Acks Packets in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_out_ls_as
                        
                        	LS Ack LSAs out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_out_packets
                        
                        	LS Ack Packets out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_in_ls_as
                        
                        	LS Requests in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_in_packets
                        
                        	LSA Requests in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_out_ls_as
                        
                        	LS Reuqests LSAs out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_out_packets
                        
                        	LS Request Packets out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_ignored
                        
                        	LS Updates ignored
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_ls_as
                        
                        	LS Updates LSAs in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_packets
                        
                        	LS Updates Packets in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_out_ls_as
                        
                        	LS Update LSAs out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_out_packets
                        
                        	LS Update Packets out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: total_in_packets
                        
                        	Total inputs packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: total_out_packets
                        
                        	Total Out Packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat, self).__init__()

                            self.yang_name = "protocol-stat"
                            self.yang_parent_name = "protocol-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.checksum_err = YLeaf(YType.uint64, "checksum-err")

                            self.dbdes_in_ls_as = YLeaf(YType.uint64, "dbdes-in-ls-as")

                            self.dbdes_in_packets = YLeaf(YType.uint64, "dbdes-in-packets")

                            self.dbdes_out_ls_as = YLeaf(YType.uint64, "dbdes-out-ls-as")

                            self.dbdes_out_packets = YLeaf(YType.uint64, "dbdes-out-packets")

                            self.dropped_in_gs = YLeaf(YType.uint64, "dropped-in-gs")

                            self.hello_in_packets = YLeaf(YType.uint64, "hello-in-packets")

                            self.hello_out_packets = YLeaf(YType.uint64, "hello-out-packets")

                            self.ls_ack_in_ls_as = YLeaf(YType.uint64, "ls-ack-in-ls-as")

                            self.ls_ack_in_packets = YLeaf(YType.uint64, "ls-ack-in-packets")

                            self.ls_ack_out_ls_as = YLeaf(YType.uint64, "ls-ack-out-ls-as")

                            self.ls_ack_out_packets = YLeaf(YType.uint64, "ls-ack-out-packets")

                            self.ls_req_in_ls_as = YLeaf(YType.uint64, "ls-req-in-ls-as")

                            self.ls_req_in_packets = YLeaf(YType.uint64, "ls-req-in-packets")

                            self.ls_req_out_ls_as = YLeaf(YType.uint64, "ls-req-out-ls-as")

                            self.ls_req_out_packets = YLeaf(YType.uint64, "ls-req-out-packets")

                            self.ls_upd_in_ignored = YLeaf(YType.uint64, "ls-upd-in-ignored")

                            self.ls_upd_in_ls_as = YLeaf(YType.uint64, "ls-upd-in-ls-as")

                            self.ls_upd_in_packets = YLeaf(YType.uint64, "ls-upd-in-packets")

                            self.ls_upd_out_ls_as = YLeaf(YType.uint64, "ls-upd-out-ls-as")

                            self.ls_upd_out_packets = YLeaf(YType.uint64, "ls-upd-out-packets")

                            self.total_in_packets = YLeaf(YType.uint64, "total-in-packets")

                            self.total_out_packets = YLeaf(YType.uint64, "total-out-packets")
                            self._segment_path = lambda: "protocol-stat" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat, ['interface_name', 'checksum_err', 'dbdes_in_ls_as', 'dbdes_in_packets', 'dbdes_out_ls_as', 'dbdes_out_packets', 'dropped_in_gs', 'hello_in_packets', 'hello_out_packets', 'ls_ack_in_ls_as', 'ls_ack_in_packets', 'ls_ack_out_ls_as', 'ls_ack_out_packets', 'ls_req_in_ls_as', 'ls_req_in_packets', 'ls_req_out_ls_as', 'ls_req_out_packets', 'ls_upd_in_ignored', 'ls_upd_in_ls_as', 'ls_upd_in_packets', 'ls_upd_out_ls_as', 'ls_upd_out_packets', 'total_in_packets', 'total_out_packets'], name, value)


                class RawioStats(Entity):
                    """
                    OSPF Prefix SPF Prioritization statistics
                    
                    .. attribute:: in_bytes
                    
                    	Received Bytes
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: in_error_drops
                    
                    	In Error Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_handle_drops
                    
                    	In Handle Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_ipsec_drops
                    
                    	In IPSEC Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_long_packets
                    
                    	Received Long Packets
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_malloc_drops
                    
                    	In Malloc Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_packets
                    
                    	Received Packets
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_queue_drops
                    
                    	In Queue Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_short_drops
                    
                    	In Short Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_bytes
                    
                    	Sent Bytes
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: out_error_drops
                    
                    	Error Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_ipsec_drops
                    
                    	Out IPSEC Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_nofd_drops
                    
                    	No FileDescriptor Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_nopak_drops
                    
                    	No Packet Buffers
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_packets
                    
                    	Packets Sent
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_pakapi_errors
                    
                    	PAK API Errors
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_close
                    
                    	Raw Connections Close
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_error
                    
                    	Raw Connections Error
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_open
                    
                    	Raw Connections Open
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_state
                    
                    	Raw Connection State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.RawioStats, self).__init__()

                        self.yang_name = "rawio-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.in_bytes = YLeaf(YType.uint64, "in-bytes")

                        self.in_error_drops = YLeaf(YType.uint64, "in-error-drops")

                        self.in_handle_drops = YLeaf(YType.uint64, "in-handle-drops")

                        self.in_ipsec_drops = YLeaf(YType.uint64, "in-ipsec-drops")

                        self.in_long_packets = YLeaf(YType.uint64, "in-long-packets")

                        self.in_malloc_drops = YLeaf(YType.uint64, "in-malloc-drops")

                        self.in_packets = YLeaf(YType.uint64, "in-packets")

                        self.in_queue_drops = YLeaf(YType.uint64, "in-queue-drops")

                        self.in_short_drops = YLeaf(YType.uint64, "in-short-drops")

                        self.out_bytes = YLeaf(YType.uint64, "out-bytes")

                        self.out_error_drops = YLeaf(YType.uint64, "out-error-drops")

                        self.out_ipsec_drops = YLeaf(YType.uint64, "out-ipsec-drops")

                        self.out_nofd_drops = YLeaf(YType.uint64, "out-nofd-drops")

                        self.out_nopak_drops = YLeaf(YType.uint64, "out-nopak-drops")

                        self.out_packets = YLeaf(YType.uint64, "out-packets")

                        self.out_pakapi_errors = YLeaf(YType.uint64, "out-pakapi-errors")

                        self.raw_conn_close = YLeaf(YType.uint64, "raw-conn-close")

                        self.raw_conn_error = YLeaf(YType.uint64, "raw-conn-error")

                        self.raw_conn_open = YLeaf(YType.uint64, "raw-conn-open")

                        self.raw_conn_state = YLeaf(YType.uint32, "raw-conn-state")
                        self._segment_path = lambda: "rawio-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.RawioStats, ['in_bytes', 'in_error_drops', 'in_handle_drops', 'in_ipsec_drops', 'in_long_packets', 'in_malloc_drops', 'in_packets', 'in_queue_drops', 'in_short_drops', 'out_bytes', 'out_error_drops', 'out_ipsec_drops', 'out_nofd_drops', 'out_nopak_drops', 'out_packets', 'out_pakapi_errors', 'raw_conn_close', 'raw_conn_error', 'raw_conn_open', 'raw_conn_state'], name, value)


                class RibThreadStats(Entity):
                    """
                    OSPFv3 RIB thread statistics
                    
                    .. attribute:: holdq
                    
                    	holdq
                    	**type**\: list of    :py:class:`Holdq <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq>`
                    
                    .. attribute:: rib_base_clock
                    
                    	Rib Base Clock
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: rib_base_time
                    
                    	rib base time
                    	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime>`
                    
                    .. attribute:: rib_batch_backup
                    
                    	Rib Batches Back up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_err
                    
                    	Batch errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_limit
                    
                    	Rib Batches Limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_no_table
                    
                    	Batches no table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_ok
                    
                    	Rib Batches Ok
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_purged
                    
                    	No. of Rib batches purged
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_sent
                    
                    	No. of Rib batches sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_some_err
                    
                    	Batches with some error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_drop_conn
                    
                    	Rib drop connections
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_drop_version
                    
                    	Rib drop version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_max_latency
                    
                    	Max time entry was in queue
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: rib_path_err
                    
                    	Route path errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_path_limit
                    
                    	Route path limits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_err
                    
                    	Route Errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_limit
                    
                    	Route table limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_some_err
                    
                    	Route some errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_sum_latency
                    
                    	Sum latencies to calc average
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: thread_q
                    
                    	Inter Thread Queue
                    	**type**\:   :py:class:`ThreadQ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ>`
                    
                    .. attribute:: wq_signals
                    
                    	Signals sent to RIB Thread
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: wq_thread_active
                    
                    	RIB Thread Active Indicator
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.RibThreadStats, self).__init__()

                        self.yang_name = "rib-thread-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"rib-base-time" : ("rib_base_time", Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime), "thread-q" : ("thread_q", Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ)}
                        self._child_list_classes = {"holdq" : ("holdq", Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq)}

                        self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                        self.rib_batch_backup = YLeaf(YType.uint32, "rib-batch-backup")

                        self.rib_batch_err = YLeaf(YType.uint32, "rib-batch-err")

                        self.rib_batch_limit = YLeaf(YType.uint32, "rib-batch-limit")

                        self.rib_batch_no_table = YLeaf(YType.uint32, "rib-batch-no-table")

                        self.rib_batch_ok = YLeaf(YType.uint32, "rib-batch-ok")

                        self.rib_batch_purged = YLeaf(YType.uint32, "rib-batch-purged")

                        self.rib_batch_sent = YLeaf(YType.uint32, "rib-batch-sent")

                        self.rib_batch_some_err = YLeaf(YType.uint32, "rib-batch-some-err")

                        self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                        self.rib_drop_version = YLeaf(YType.uint32, "rib-drop-version")

                        self.rib_max_latency = YLeaf(YType.uint64, "rib-max-latency")

                        self.rib_path_err = YLeaf(YType.uint32, "rib-path-err")

                        self.rib_path_limit = YLeaf(YType.uint32, "rib-path-limit")

                        self.rib_route_err = YLeaf(YType.uint32, "rib-route-err")

                        self.rib_route_limit = YLeaf(YType.uint32, "rib-route-limit")

                        self.rib_route_some_err = YLeaf(YType.uint32, "rib-route-some-err")

                        self.rib_sum_latency = YLeaf(YType.uint64, "rib-sum-latency")

                        self.wq_signals = YLeaf(YType.uint32, "wq-signals")

                        self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                        self.rib_base_time = Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime()
                        self.rib_base_time.parent = self
                        self._children_name_map["rib_base_time"] = "rib-base-time"
                        self._children_yang_names.add("rib-base-time")

                        self.thread_q = Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ()
                        self.thread_q.parent = self
                        self._children_name_map["thread_q"] = "thread-q"
                        self._children_yang_names.add("thread-q")

                        self.holdq = YList(self)
                        self._segment_path = lambda: "rib-thread-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.RibThreadStats, ['rib_base_clock', 'rib_batch_backup', 'rib_batch_err', 'rib_batch_limit', 'rib_batch_no_table', 'rib_batch_ok', 'rib_batch_purged', 'rib_batch_sent', 'rib_batch_some_err', 'rib_drop_conn', 'rib_drop_version', 'rib_max_latency', 'rib_path_err', 'rib_path_limit', 'rib_route_err', 'rib_route_limit', 'rib_route_some_err', 'rib_sum_latency', 'wq_signals', 'wq_thread_active'], name, value)


                    class Holdq(Entity):
                        """
                        holdq
                        
                        .. attribute:: wq_dequeue_errs
                        
                        	Dequeue Errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_dqtime
                        
                        	Last Entry Dequeue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_eneueue_errs
                        
                        	Enqueue Errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_eqtime
                        
                        	Head Entry Enqueue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_first_eqtime
                        
                        	First Entry Enqueue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_len_cur
                        
                        	Current Work Queue Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_len_max
                        
                        	Largest Work Queue Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_max_latency
                        
                        	Max Time Entry Was In Q
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_sum_latency
                        
                        	Sum Latencies To Calc Average
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_total_dequeued
                        
                        	Total Entries Dequeued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_total_enqueued
                        
                        	Total Entries Enqueued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq, self).__init__()

                            self.yang_name = "holdq"
                            self.yang_parent_name = "rib-thread-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.wq_dequeue_errs = YLeaf(YType.uint32, "wq-dequeue-errs")

                            self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                            self.wq_eneueue_errs = YLeaf(YType.uint32, "wq-eneueue-errs")

                            self.wq_eqtime = YLeaf(YType.uint64, "wq-eqtime")

                            self.wq_first_eqtime = YLeaf(YType.uint64, "wq-first-eqtime")

                            self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                            self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                            self.wq_max_latency = YLeaf(YType.uint64, "wq-max-latency")

                            self.wq_sum_latency = YLeaf(YType.uint64, "wq-sum-latency")

                            self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                            self.wq_total_enqueued = YLeaf(YType.uint32, "wq-total-enqueued")
                            self._segment_path = lambda: "holdq"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq, ['wq_dequeue_errs', 'wq_dqtime', 'wq_eneueue_errs', 'wq_eqtime', 'wq_first_eqtime', 'wq_len_cur', 'wq_len_max', 'wq_max_latency', 'wq_sum_latency', 'wq_total_dequeued', 'wq_total_enqueued'], name, value)


                    class RibBaseTime(Entity):
                        """
                        rib base time
                        
                        .. attribute:: nanosecond
                        
                        	Nano seconds 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: second
                        
                        	Seconds 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime, self).__init__()

                            self.yang_name = "rib-base-time"
                            self.yang_parent_name = "rib-thread-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                            self.second = YLeaf(YType.uint32, "second")
                            self._segment_path = lambda: "rib-base-time"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime, ['nanosecond', 'second'], name, value)


                    class ThreadQ(Entity):
                        """
                        Inter Thread Queue
                        
                        .. attribute:: wq_dequeue_errs
                        
                        	Dequeue Errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_dqtime
                        
                        	Last Entry Dequeue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_eneueue_errs
                        
                        	Enqueue Errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_eqtime
                        
                        	Head Entry Enqueue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_first_eqtime
                        
                        	First Entry Enqueue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_len_cur
                        
                        	Current Work Queue Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_len_max
                        
                        	Largest Work Queue Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_max_latency
                        
                        	Max Time Entry Was In Q
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_sum_latency
                        
                        	Sum Latencies To Calc Average
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_total_dequeued
                        
                        	Total Entries Dequeued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_total_enqueued
                        
                        	Total Entries Enqueued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ, self).__init__()

                            self.yang_name = "thread-q"
                            self.yang_parent_name = "rib-thread-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.wq_dequeue_errs = YLeaf(YType.uint32, "wq-dequeue-errs")

                            self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                            self.wq_eneueue_errs = YLeaf(YType.uint32, "wq-eneueue-errs")

                            self.wq_eqtime = YLeaf(YType.uint64, "wq-eqtime")

                            self.wq_first_eqtime = YLeaf(YType.uint64, "wq-first-eqtime")

                            self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                            self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                            self.wq_max_latency = YLeaf(YType.uint64, "wq-max-latency")

                            self.wq_sum_latency = YLeaf(YType.uint64, "wq-sum-latency")

                            self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                            self.wq_total_enqueued = YLeaf(YType.uint32, "wq-total-enqueued")
                            self._segment_path = lambda: "thread-q"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ, ['wq_dequeue_errs', 'wq_dqtime', 'wq_eneueue_errs', 'wq_eqtime', 'wq_first_eqtime', 'wq_len_cur', 'wq_len_max', 'wq_max_latency', 'wq_sum_latency', 'wq_total_dequeued', 'wq_total_enqueued'], name, value)


                class SpfStats(Entity):
                    """
                    OSPFv3 RIB batch statistics
                    
                    .. attribute:: spf_header
                    
                    	SPF statistics header
                    	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader>`
                    
                    .. attribute:: spf_runtime
                    
                    	List of SPF run\-time statistics
                    	**type**\: list of    :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.SpfStats, self).__init__()

                        self.yang_name = "spf-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"spf-header" : ("spf_header", Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader)}
                        self._child_list_classes = {"spf-runtime" : ("spf_runtime", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime)}

                        self.spf_header = Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader()
                        self.spf_header.parent = self
                        self._children_name_map["spf_header"] = "spf-header"
                        self._children_yang_names.add("spf-header")

                        self.spf_runtime = YList(self)
                        self._segment_path = lambda: "spf-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats, [], name, value)


                    class SpfHeader(Entity):
                        """
                        SPF statistics header
                        
                        .. attribute:: area_summary
                        
                        	List of Areas with SPF statistics
                        	**type**\: list of    :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary>`
                        
                        .. attribute:: header_router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: header_sp_fs
                        
                        	Number of SPF calculations
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader, self).__init__()

                            self.yang_name = "spf-header"
                            self.yang_parent_name = "spf-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"area-summary" : ("area_summary", Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary)}

                            self.header_router_id = YLeaf(YType.str, "header-router-id")

                            self.header_sp_fs = YLeaf(YType.uint32, "header-sp-fs")

                            self.area_summary = YList(self)
                            self._segment_path = lambda: "spf-header"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader, ['header_router_id', 'header_sp_fs'], name, value)


                        class AreaSummary(Entity):
                            """
                            List of Areas with SPF statistics
                            
                            .. attribute:: area_id
                            
                            	Area ID of the area SPF statistics
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_fs
                            
                            	Number of SPF calculations
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary, self).__init__()

                                self.yang_name = "area-summary"
                                self.yang_parent_name = "spf-header"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.area_id = YLeaf(YType.uint32, "area-id")

                                self.sp_fs = YLeaf(YType.uint32, "sp-fs")
                                self._segment_path = lambda: "area-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary, ['area_id', 'sp_fs'], name, value)


                    class SpfRuntime(Entity):
                        """
                        List of SPF run\-time statistics
                        
                        .. attribute:: area_stat
                        
                        	List of per\-area SPF statistics
                        	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat>`
                        
                        .. attribute:: global_time
                        
                        	Global SPF times
                        	**type**\:   :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime>`
                        
                        .. attribute:: lsa
                        
                        	List of LSAs triggering the SPF calculation
                        	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa>`
                        
                        .. attribute:: lsa_changes
                        
                        	Number of LSA changes triggering an SPF calculation
                        	**type**\:  int
                        
                        	**range:** \-32768..32767
                        
                        .. attribute:: reason_flags
                        
                        	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: rib_add_routes
                        
                        	Number of routes added to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rib_delete_routes
                        
                        	Number of routes deleted from RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: start_time
                        
                        	SPF calculation start time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime, self).__init__()

                            self.yang_name = "spf-runtime"
                            self.yang_parent_name = "spf-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"global-time" : ("global_time", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime)}
                            self._child_list_classes = {"area-stat" : ("area_stat", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat), "lsa" : ("lsa", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa)}

                            self.lsa_changes = YLeaf(YType.int16, "lsa-changes")

                            self.reason_flags = YLeaf(YType.str, "reason-flags")

                            self.rib_add_routes = YLeaf(YType.uint32, "rib-add-routes")

                            self.rib_delete_routes = YLeaf(YType.uint32, "rib-delete-routes")

                            self.start_time = YLeaf(YType.uint32, "start-time")

                            self.global_time = Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime()
                            self.global_time.parent = self
                            self._children_name_map["global_time"] = "global-time"
                            self._children_yang_names.add("global-time")

                            self.area_stat = YList(self)
                            self.lsa = YList(self)
                            self._segment_path = lambda: "spf-runtime"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime, ['lsa_changes', 'reason_flags', 'rib_add_routes', 'rib_delete_routes', 'start_time'], name, value)


                        class AreaStat(Entity):
                            """
                            List of per\-area SPF statistics
                            
                            .. attribute:: spf_stat_area_id
                            
                            	Area ID for area of these SPF statistics
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_stat_lsa_type_count
                            
                            	Counts of LSA types triggering an SPF calculation
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_stat_time
                            
                            	SPF time calculations
                            	**type**\:   :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat, self).__init__()

                                self.yang_name = "area-stat"
                                self.yang_parent_name = "spf-runtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"spf-stat-time" : ("spf_stat_time", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime)}
                                self._child_list_classes = {}

                                self.spf_stat_area_id = YLeaf(YType.uint32, "spf-stat-area-id")

                                self.spf_stat_lsa_type_count = YLeafList(YType.uint32, "spf-stat-lsa-type-count")

                                self.spf_stat_time = Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                self.spf_stat_time.parent = self
                                self._children_name_map["spf_stat_time"] = "spf-stat-time"
                                self._children_yang_names.add("spf-stat-time")
                                self._segment_path = lambda: "area-stat"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat, ['spf_stat_area_id', 'spf_stat_lsa_type_count'], name, value)


                            class SpfStatTime(Entity):
                                """
                                SPF time calculations
                                
                                .. attribute:: dijkstra
                                
                                	Dijkstra time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix
                                
                                	External prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix_del
                                
                                	External prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix
                                
                                	Inter\-prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix
                                
                                	Intra\-prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_add
                                
                                	RIB add processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_del
                                
                                	RIB deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, self).__init__()

                                    self.yang_name = "spf-stat-time"
                                    self.yang_parent_name = "area-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.dijkstra = YLeaf(YType.uint32, "dijkstra")

                                    self.external_prefix = YLeaf(YType.uint32, "external-prefix")

                                    self.external_prefix_del = YLeaf(YType.uint32, "external-prefix-del")

                                    self.inter_prefix = YLeaf(YType.uint32, "inter-prefix")

                                    self.inter_prefix_del = YLeaf(YType.uint32, "inter-prefix-del")

                                    self.intra_prefix = YLeaf(YType.uint32, "intra-prefix")

                                    self.intra_prefix_del = YLeaf(YType.uint32, "intra-prefix-del")

                                    self.rib_add = YLeaf(YType.uint32, "rib-add")

                                    self.rib_del = YLeaf(YType.uint32, "rib-del")
                                    self._segment_path = lambda: "spf-stat-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, ['dijkstra', 'external_prefix', 'external_prefix_del', 'inter_prefix', 'inter_prefix_del', 'intra_prefix', 'intra_prefix_del', 'rib_add', 'rib_del'], name, value)


                        class GlobalTime(Entity):
                            """
                            Global SPF times
                            
                            .. attribute:: dijkstra
                            
                            	Dijkstra time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_prefix
                            
                            	External prefix processing time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_prefix_del
                            
                            	External prefix deletion time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_prefix
                            
                            	Inter\-prefix processing time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_prefix_del
                            
                            	Intra\-prefix deletion time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_prefix
                            
                            	Intra\-prefix processing time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_prefix_del
                            
                            	Intra\-prefix deletion time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_add
                            
                            	RIB add processing time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_del
                            
                            	RIB deletion time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime, self).__init__()

                                self.yang_name = "global-time"
                                self.yang_parent_name = "spf-runtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.dijkstra = YLeaf(YType.uint32, "dijkstra")

                                self.external_prefix = YLeaf(YType.uint32, "external-prefix")

                                self.external_prefix_del = YLeaf(YType.uint32, "external-prefix-del")

                                self.inter_prefix = YLeaf(YType.uint32, "inter-prefix")

                                self.inter_prefix_del = YLeaf(YType.uint32, "inter-prefix-del")

                                self.intra_prefix = YLeaf(YType.uint32, "intra-prefix")

                                self.intra_prefix_del = YLeaf(YType.uint32, "intra-prefix-del")

                                self.rib_add = YLeaf(YType.uint32, "rib-add")

                                self.rib_del = YLeaf(YType.uint32, "rib-del")
                                self._segment_path = lambda: "global-time"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime, ['dijkstra', 'external_prefix', 'external_prefix_del', 'inter_prefix', 'inter_prefix_del', 'intra_prefix', 'intra_prefix_del', 'rib_add', 'rib_del'], name, value)


                        class Lsa(Entity):
                            """
                            List of LSAs triggering the SPF calculation
                            
                            .. attribute:: lsa_advertising_router
                            
                            	Advertising router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lsa_area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_flush
                            
                            	If true, the LSA change is a flush
                            	**type**\:  bool
                            
                            .. attribute:: lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lsa_type
                            
                            	LSA type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "spf-runtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.lsa_advertising_router = YLeaf(YType.str, "lsa-advertising-router")

                                self.lsa_area_id = YLeaf(YType.uint32, "lsa-area-id")

                                self.lsa_flush = YLeaf(YType.boolean, "lsa-flush")

                                self.lsa_id = YLeaf(YType.str, "lsa-id")

                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")
                                self._segment_path = lambda: "lsa"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa, ['lsa_advertising_router', 'lsa_area_id', 'lsa_flush', 'lsa_id', 'lsa_type'], name, value)


                class VrfRibBatchStats(Entity):
                    """
                    OSPFv3 RIB batch statistics
                    
                    .. attribute:: batches_sent
                    
                    	No. of RIB batches sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_routes
                    
                    	Max No. of Routes in a batch
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_add
                    
                    	No. of paths added to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_add_errs
                    
                    	No. of paths add errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_del
                    
                    	No. of paths del sent to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_del_errs
                    
                    	No. of Paths del errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_pending
                    
                    	No. of paths waiting to be sent to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_sent
                    
                    	No. of Paths sent to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routes_pending
                    
                    	No of Pending Routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routes_sent
                    
                    	No. of Routes sent to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.VrfRibBatchStats, self).__init__()

                        self.yang_name = "vrf-rib-batch-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.batches_sent = YLeaf(YType.uint32, "batches-sent")

                        self.max_routes = YLeaf(YType.uint32, "max-routes")

                        self.paths_add = YLeaf(YType.uint32, "paths-add")

                        self.paths_add_errs = YLeaf(YType.uint32, "paths-add-errs")

                        self.paths_del = YLeaf(YType.uint32, "paths-del")

                        self.paths_del_errs = YLeaf(YType.uint32, "paths-del-errs")

                        self.paths_pending = YLeaf(YType.uint32, "paths-pending")

                        self.paths_sent = YLeaf(YType.uint32, "paths-sent")

                        self.routes_pending = YLeaf(YType.uint32, "routes-pending")

                        self.routes_sent = YLeaf(YType.uint32, "routes-sent")
                        self._segment_path = lambda: "vrf-rib-batch-stats"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.VrfRibBatchStats, ['batches_sent', 'max_routes', 'paths_add', 'paths_add_errs', 'paths_del', 'paths_del_errs', 'paths_pending', 'paths_sent', 'routes_pending', 'routes_sent'], name, value)


            class Vrfs(Entity):
                """
                Table for each VRF
                
                .. attribute:: vrf
                
                	Operational data for a particular VRF (instance) in the OSPFv3 process
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ospfv3.Processes.Process.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"vrf" : ("vrf", Ospfv3.Processes.Process.Vrfs.Vrf)}

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for a particular VRF
                    (instance) in the OSPFv3 process
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: area_informations
                    
                    	OSPFv3 area information table
                    	**type**\:   :py:class:`AreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations>`
                    
                    .. attribute:: areas
                    
                    	OSPFv3 area table
                    	**type**\:   :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas>`
                    
                    .. attribute:: bad_checksums
                    
                    	Bad Checksum Packets information table
                    	**type**\:   :py:class:`BadChecksums <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums>`
                    
                    .. attribute:: border_routers
                    
                    	OSPFv3 border router information table
                    	**type**\:   :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters>`
                    
                    .. attribute:: connected_routes
                    
                    	OSPFv3 connected route information table
                    	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes>`
                    
                    .. attribute:: database_summary_table
                    
                    	Database summary table
                    	**type**\:   :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable>`
                    
                    .. attribute:: database_table
                    
                    	OSPF Link State Database
                    	**type**\:   :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable>`
                    
                    .. attribute:: external_routes
                    
                    	OSPFv3 external route information table
                    	**type**\:   :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes>`
                    
                    .. attribute:: fast_reroutes
                    
                    	OSPFv3 fast reroute topology information table
                    	**type**\:   :py:class:`FastReroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes>`
                    
                    .. attribute:: flood_list_process_table
                    
                    	OSPFv3 flood list information table for all areas
                    	**type**\:   :py:class:`FloodListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable>`
                    
                    .. attribute:: interface_brief_process_table
                    
                    	OSPFv3 interface brief information table for all areas
                    	**type**\:   :py:class:`InterfaceBriefProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable>`
                    
                    .. attribute:: interface_process_table
                    
                    	OSPFv3 interface information table for all areas
                    	**type**\:   :py:class:`InterfaceProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable>`
                    
                    .. attribute:: internal_routes
                    
                    	OSPFv3 internal route information table
                    	**type**\:   :py:class:`InternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes>`
                    
                    .. attribute:: neighbor_detail_process_table
                    
                    	OSPFv3 neighbor information table for all areas
                    	**type**\:   :py:class:`NeighborDetailProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable>`
                    
                    .. attribute:: neighbor_process_table
                    
                    	OSPFv3 neighbor information table for all areas
                    	**type**\:   :py:class:`NeighborProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable>`
                    
                    .. attribute:: protocol_areas
                    
                    	Protocol area table 
                    	**type**\:   :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas>`
                    
                    .. attribute:: redistributions
                    
                    	Redistribution information table
                    	**type**\:   :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions>`
                    
                    .. attribute:: request_list_process_table
                    
                    	OSPFv3 request list information for all areas
                    	**type**\:   :py:class:`RequestListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable>`
                    
                    .. attribute:: retransmission_list_process_table
                    
                    	OSPFv3 retransmission list information table for all areas
                    	**type**\:   :py:class:`RetransmissionListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable>`
                    
                    .. attribute:: route_summary
                    
                    	Summarize OSPFv3 local RIB tables
                    	**type**\:   :py:class:`RouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary>`
                    
                    .. attribute:: sham_link_table
                    
                    	Sham link information
                    	**type**\:   :py:class:`ShamLinkTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable>`
                    
                    .. attribute:: summary
                    
                    	OSPFv3 summary
                    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary>`
                    
                    .. attribute:: summary_prefixes
                    
                    	Summary prefix information table
                    	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes>`
                    
                    .. attribute:: virtual_link
                    
                    	Virtual link information
                    	**type**\:   :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink>`
                    
                    .. attribute:: vrf_statistics
                    
                    	Container for Statistics
                    	**type**\:   :py:class:`VrfStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"area-informations" : ("area_informations", Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations), "areas" : ("areas", Ospfv3.Processes.Process.Vrfs.Vrf.Areas), "bad-checksums" : ("bad_checksums", Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums), "border-routers" : ("border_routers", Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters), "connected-routes" : ("connected_routes", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes), "database-summary-table" : ("database_summary_table", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable), "database-table" : ("database_table", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable), "external-routes" : ("external_routes", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes), "fast-reroutes" : ("fast_reroutes", Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes), "flood-list-process-table" : ("flood_list_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable), "interface-brief-process-table" : ("interface_brief_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable), "interface-process-table" : ("interface_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable), "internal-routes" : ("internal_routes", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes), "neighbor-detail-process-table" : ("neighbor_detail_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable), "neighbor-process-table" : ("neighbor_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable), "protocol-areas" : ("protocol_areas", Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas), "redistributions" : ("redistributions", Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions), "request-list-process-table" : ("request_list_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable), "retransmission-list-process-table" : ("retransmission_list_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable), "route-summary" : ("route_summary", Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary), "sham-link-table" : ("sham_link_table", Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable), "summary" : ("summary", Ospfv3.Processes.Process.Vrfs.Vrf.Summary), "summary-prefixes" : ("summary_prefixes", Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes), "virtual-link" : ("virtual_link", Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink), "vrf-statistics" : ("vrf_statistics", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics)}
                        self._child_list_classes = {}

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.area_informations = Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations()
                        self.area_informations.parent = self
                        self._children_name_map["area_informations"] = "area-informations"
                        self._children_yang_names.add("area-informations")

                        self.areas = Ospfv3.Processes.Process.Vrfs.Vrf.Areas()
                        self.areas.parent = self
                        self._children_name_map["areas"] = "areas"
                        self._children_yang_names.add("areas")

                        self.bad_checksums = Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums()
                        self.bad_checksums.parent = self
                        self._children_name_map["bad_checksums"] = "bad-checksums"
                        self._children_yang_names.add("bad-checksums")

                        self.border_routers = Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters()
                        self.border_routers.parent = self
                        self._children_name_map["border_routers"] = "border-routers"
                        self._children_yang_names.add("border-routers")

                        self.connected_routes = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes()
                        self.connected_routes.parent = self
                        self._children_name_map["connected_routes"] = "connected-routes"
                        self._children_yang_names.add("connected-routes")

                        self.database_summary_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable()
                        self.database_summary_table.parent = self
                        self._children_name_map["database_summary_table"] = "database-summary-table"
                        self._children_yang_names.add("database-summary-table")

                        self.database_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable()
                        self.database_table.parent = self
                        self._children_name_map["database_table"] = "database-table"
                        self._children_yang_names.add("database-table")

                        self.external_routes = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes()
                        self.external_routes.parent = self
                        self._children_name_map["external_routes"] = "external-routes"
                        self._children_yang_names.add("external-routes")

                        self.fast_reroutes = Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes()
                        self.fast_reroutes.parent = self
                        self._children_name_map["fast_reroutes"] = "fast-reroutes"
                        self._children_yang_names.add("fast-reroutes")

                        self.flood_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable()
                        self.flood_list_process_table.parent = self
                        self._children_name_map["flood_list_process_table"] = "flood-list-process-table"
                        self._children_yang_names.add("flood-list-process-table")

                        self.interface_brief_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable()
                        self.interface_brief_process_table.parent = self
                        self._children_name_map["interface_brief_process_table"] = "interface-brief-process-table"
                        self._children_yang_names.add("interface-brief-process-table")

                        self.interface_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable()
                        self.interface_process_table.parent = self
                        self._children_name_map["interface_process_table"] = "interface-process-table"
                        self._children_yang_names.add("interface-process-table")

                        self.internal_routes = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes()
                        self.internal_routes.parent = self
                        self._children_name_map["internal_routes"] = "internal-routes"
                        self._children_yang_names.add("internal-routes")

                        self.neighbor_detail_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable()
                        self.neighbor_detail_process_table.parent = self
                        self._children_name_map["neighbor_detail_process_table"] = "neighbor-detail-process-table"
                        self._children_yang_names.add("neighbor-detail-process-table")

                        self.neighbor_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable()
                        self.neighbor_process_table.parent = self
                        self._children_name_map["neighbor_process_table"] = "neighbor-process-table"
                        self._children_yang_names.add("neighbor-process-table")

                        self.protocol_areas = Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas()
                        self.protocol_areas.parent = self
                        self._children_name_map["protocol_areas"] = "protocol-areas"
                        self._children_yang_names.add("protocol-areas")

                        self.redistributions = Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions()
                        self.redistributions.parent = self
                        self._children_name_map["redistributions"] = "redistributions"
                        self._children_yang_names.add("redistributions")

                        self.request_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable()
                        self.request_list_process_table.parent = self
                        self._children_name_map["request_list_process_table"] = "request-list-process-table"
                        self._children_yang_names.add("request-list-process-table")

                        self.retransmission_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable()
                        self.retransmission_list_process_table.parent = self
                        self._children_name_map["retransmission_list_process_table"] = "retransmission-list-process-table"
                        self._children_yang_names.add("retransmission-list-process-table")

                        self.route_summary = Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary()
                        self.route_summary.parent = self
                        self._children_name_map["route_summary"] = "route-summary"
                        self._children_yang_names.add("route-summary")

                        self.sham_link_table = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable()
                        self.sham_link_table.parent = self
                        self._children_name_map["sham_link_table"] = "sham-link-table"
                        self._children_yang_names.add("sham-link-table")

                        self.summary = Ospfv3.Processes.Process.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                        self._children_yang_names.add("summary")

                        self.summary_prefixes = Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                        self.summary_prefixes.parent = self
                        self._children_name_map["summary_prefixes"] = "summary-prefixes"
                        self._children_yang_names.add("summary-prefixes")

                        self.virtual_link = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink()
                        self.virtual_link.parent = self
                        self._children_name_map["virtual_link"] = "virtual-link"
                        self._children_yang_names.add("virtual-link")

                        self.vrf_statistics = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics()
                        self.vrf_statistics.parent = self
                        self._children_name_map["vrf_statistics"] = "vrf-statistics"
                        self._children_yang_names.add("vrf-statistics")
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf, ['vrf_name'], name, value)


                    class AreaInformations(Entity):
                        """
                        OSPFv3 area information table
                        
                        .. attribute:: area_information
                        
                        	OSPFv3 area information
                        	**type**\: list of    :py:class:`AreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations, self).__init__()

                            self.yang_name = "area-informations"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"area-information" : ("area_information", Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation)}

                            self.area_information = YList(self)
                            self._segment_path = lambda: "area-informations"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations, [], name, value)


                        class AreaInformation(Entity):
                            """
                            OSPFv3 area information
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_dc_bitless_ls_as
                            
                            	Number of LSA with demand circuit bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_interfaces
                            
                            	Number of interfaces in the area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: area_lfa_interface_count
                            
                            	Number of LFA enabled interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lfa_revision
                            
                            	Area LFA revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_opaque_lsas
                            
                            	Number of opaque LSAs in the area
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_per_prefix_lfa_interface_count
                            
                            	Number of Per Prefix LFA enabled interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_range
                            
                            	List of ranges to summarize
                            	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange>`
                            
                            .. attribute:: do_not_age_ls_as
                            
                            	Number of do not age LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_list_length
                            
                            	Number of LSAs which need to be flooded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: indication_ls_as
                            
                            	Number of indication LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_area_nssa
                            
                            	If true, area is a NSSA
                            	**type**\:  bool
                            
                            .. attribute:: is_area_stubbed
                            
                            	If true, stub area
                            	**type**\:  bool
                            
                            .. attribute:: is_area_total_stubbed
                            
                            	If true, totally stubby area
                            	**type**\:  bool
                            
                            .. attribute:: is_backbone_area_active
                            
                            	If true, Backbone area is active
                            	**type**\:  bool
                            
                            .. attribute:: is_nssa_default
                            
                            	If true, generate NSSA default route
                            	**type**\:  bool
                            
                            .. attribute:: is_nssa_translated
                            
                            	If true, perform 7/5 translation
                            	**type**\:  bool
                            
                            .. attribute:: is_rrr_enabled
                            
                            	If true, RRR is enabled
                            	**type**\:  bool
                            
                            .. attribute:: nssa_no_redistribution
                            
                            	If true, No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            .. attribute:: sp_fs
                            
                            	Number of SPF calculations run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: stub_default_cost
                            
                            	Default cost for Stub or NSSA area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation, self).__init__()

                                self.yang_name = "area-information"
                                self.yang_parent_name = "area-informations"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-range" : ("area_range", Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange)}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.area_dc_bitless_ls_as = YLeaf(YType.uint32, "area-dc-bitless-ls-as")

                                self.area_interfaces = YLeaf(YType.uint16, "area-interfaces")

                                self.area_lfa_interface_count = YLeaf(YType.uint32, "area-lfa-interface-count")

                                self.area_lfa_revision = YLeaf(YType.uint32, "area-lfa-revision")

                                self.area_opaque_lsa_checksum = YLeaf(YType.uint32, "area-opaque-lsa-checksum")

                                self.area_opaque_lsas = YLeaf(YType.uint32, "area-opaque-lsas")

                                self.area_per_prefix_lfa_interface_count = YLeaf(YType.uint32, "area-per-prefix-lfa-interface-count")

                                self.do_not_age_ls_as = YLeaf(YType.uint32, "do-not-age-ls-as")

                                self.flood_list_length = YLeaf(YType.uint32, "flood-list-length")

                                self.indication_ls_as = YLeaf(YType.uint32, "indication-ls-as")

                                self.is_area_nssa = YLeaf(YType.boolean, "is-area-nssa")

                                self.is_area_stubbed = YLeaf(YType.boolean, "is-area-stubbed")

                                self.is_area_total_stubbed = YLeaf(YType.boolean, "is-area-total-stubbed")

                                self.is_backbone_area_active = YLeaf(YType.boolean, "is-backbone-area-active")

                                self.is_nssa_default = YLeaf(YType.boolean, "is-nssa-default")

                                self.is_nssa_translated = YLeaf(YType.boolean, "is-nssa-translated")

                                self.is_rrr_enabled = YLeaf(YType.boolean, "is-rrr-enabled")

                                self.nssa_no_redistribution = YLeaf(YType.boolean, "nssa-no-redistribution")

                                self.sp_fs = YLeaf(YType.uint32, "sp-fs")

                                self.stub_default_cost = YLeaf(YType.uint16, "stub-default-cost")

                                self.area_range = YList(self)
                                self._segment_path = lambda: "area-information" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation, ['area_id', 'area_dc_bitless_ls_as', 'area_interfaces', 'area_lfa_interface_count', 'area_lfa_revision', 'area_opaque_lsa_checksum', 'area_opaque_lsas', 'area_per_prefix_lfa_interface_count', 'do_not_age_ls_as', 'flood_list_length', 'indication_ls_as', 'is_area_nssa', 'is_area_stubbed', 'is_area_total_stubbed', 'is_backbone_area_active', 'is_nssa_default', 'is_nssa_translated', 'is_rrr_enabled', 'nssa_no_redistribution', 'sp_fs', 'stub_default_cost'], name, value)


                            class AreaRange(Entity):
                                """
                                List of ranges to summarize
                                
                                .. attribute:: is_cost_configured
                                
                                	If true, cost is configured 
                                	**type**\:  bool
                                
                                .. attribute:: net_cost
                                
                                	Net cost 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_prefix
                                
                                	IP prefix for summarization
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: range_prefix_length
                                
                                	IP prefix length for summarization
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status
                                
                                	Area range status 
                                	**type**\:   :py:class:`Ospfv3AreaRangeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3AreaRangeStatus>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange, self).__init__()

                                    self.yang_name = "area-range"
                                    self.yang_parent_name = "area-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.is_cost_configured = YLeaf(YType.boolean, "is-cost-configured")

                                    self.net_cost = YLeaf(YType.uint32, "net-cost")

                                    self.range_prefix = YLeaf(YType.str, "range-prefix")

                                    self.range_prefix_length = YLeaf(YType.uint32, "range-prefix-length")

                                    self.status = YLeaf(YType.enumeration, "status")
                                    self._segment_path = lambda: "area-range"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange, ['is_cost_configured', 'net_cost', 'range_prefix', 'range_prefix_length', 'status'], name, value)


                    class Areas(Entity):
                        """
                        OSPFv3 area table
                        
                        .. attribute:: area
                        
                        	Per\-area information
                        	**type**\: list of    :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas, self).__init__()

                            self.yang_name = "areas"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"area" : ("area", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area)}

                            self.area = YList(self)
                            self._segment_path = lambda: "areas"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas, [], name, value)


                        class Area(Entity):
                            """
                            Per\-area information
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: database_summary_table
                            
                            	Database summary table
                            	**type**\:   :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable>`
                            
                            .. attribute:: database_table
                            
                            	OSPF Link State Database
                            	**type**\:   :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable>`
                            
                            .. attribute:: flood_list_table
                            
                            	OSPFv3 flood list information table for an area
                            	**type**\:   :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable>`
                            
                            .. attribute:: interface_brief_table
                            
                            	OSPFv3 interface brief information table for an area
                            	**type**\:   :py:class:`InterfaceBriefTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable>`
                            
                            .. attribute:: interface_table
                            
                            	OSPFv3 interface information table for an area
                            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable>`
                            
                            .. attribute:: neighbor_detail_table
                            
                            	OSPFv3 area neighbor information table
                            	**type**\:   :py:class:`NeighborDetailTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable>`
                            
                            .. attribute:: neighbor_table
                            
                            	OSPFv3 neighbor information table
                            	**type**\:   :py:class:`NeighborTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable>`
                            
                            .. attribute:: request_list_table
                            
                            	OSPFv3 request list information in an area
                            	**type**\:   :py:class:`RequestListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable>`
                            
                            .. attribute:: retransmission_list_table
                            
                            	OSPFv3 retransmission list information table in an area
                            	**type**\:   :py:class:`RetransmissionListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"database-summary-table" : ("database_summary_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable), "database-table" : ("database_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable), "flood-list-table" : ("flood_list_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable), "interface-brief-table" : ("interface_brief_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable), "interface-table" : ("interface_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable), "neighbor-detail-table" : ("neighbor_detail_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable), "neighbor-table" : ("neighbor_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable), "request-list-table" : ("request_list_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable), "retransmission-list-table" : ("retransmission_list_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable)}
                                self._child_list_classes = {}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.database_summary_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable()
                                self.database_summary_table.parent = self
                                self._children_name_map["database_summary_table"] = "database-summary-table"
                                self._children_yang_names.add("database-summary-table")

                                self.database_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable()
                                self.database_table.parent = self
                                self._children_name_map["database_table"] = "database-table"
                                self._children_yang_names.add("database-table")

                                self.flood_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable()
                                self.flood_list_table.parent = self
                                self._children_name_map["flood_list_table"] = "flood-list-table"
                                self._children_yang_names.add("flood-list-table")

                                self.interface_brief_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable()
                                self.interface_brief_table.parent = self
                                self._children_name_map["interface_brief_table"] = "interface-brief-table"
                                self._children_yang_names.add("interface-brief-table")

                                self.interface_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable()
                                self.interface_table.parent = self
                                self._children_name_map["interface_table"] = "interface-table"
                                self._children_yang_names.add("interface-table")

                                self.neighbor_detail_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable()
                                self.neighbor_detail_table.parent = self
                                self._children_name_map["neighbor_detail_table"] = "neighbor-detail-table"
                                self._children_yang_names.add("neighbor-detail-table")

                                self.neighbor_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable()
                                self.neighbor_table.parent = self
                                self._children_name_map["neighbor_table"] = "neighbor-table"
                                self._children_yang_names.add("neighbor-table")

                                self.request_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable()
                                self.request_list_table.parent = self
                                self._children_name_map["request_list_table"] = "request-list-table"
                                self._children_yang_names.add("request-list-table")

                                self.retransmission_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable()
                                self.retransmission_list_table.parent = self
                                self._children_name_map["retransmission_list_table"] = "retransmission-list-table"
                                self._children_yang_names.add("retransmission-list-table")
                                self._segment_path = lambda: "area" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area, ['area_id'], name, value)


                            class DatabaseSummaryTable(Entity):
                                """
                                Database summary table
                                
                                .. attribute:: database_summary
                                
                                	Database Summary information
                                	**type**\:   :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable, self).__init__()

                                    self.yang_name = "database-summary-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"database-summary" : ("database_summary", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary)}
                                    self._child_list_classes = {}

                                    self.database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary()
                                    self.database_summary.parent = self
                                    self._children_name_map["database_summary"] = "database-summary"
                                    self._children_yang_names.add("database-summary")
                                    self._segment_path = lambda: "database-summary-table"


                                class DatabaseSummary(Entity):
                                    """
                                    Database Summary information
                                    
                                    .. attribute:: area_database
                                    
                                    	OSPFv3 Area Database list 
                                    	**type**\: list of    :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                                    
                                    .. attribute:: database_counters
                                    
                                    	OSPFv3 database counters 
                                    	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                                    
                                    .. attribute:: database_router_id
                                    
                                    	Database router ID 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_opaque_database_capable
                                    
                                    	If true, opaque database is capable 
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary, self).__init__()

                                        self.yang_name = "database-summary"
                                        self.yang_parent_name = "database-summary-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"database-counters" : ("database_counters", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters)}
                                        self._child_list_classes = {"area-database" : ("area_database", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase)}

                                        self.database_router_id = YLeaf(YType.str, "database-router-id")

                                        self.is_opaque_database_capable = YLeaf(YType.boolean, "is-opaque-database-capable")

                                        self.database_counters = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                        self.database_counters.parent = self
                                        self._children_name_map["database_counters"] = "database-counters"
                                        self._children_yang_names.add("database-counters")

                                        self.area_database = YList(self)
                                        self._segment_path = lambda: "database-summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary, ['database_router_id', 'is_opaque_database_capable'], name, value)


                                    class AreaDatabase(Entity):
                                        """
                                        OSPFv3 Area Database list 
                                        
                                        .. attribute:: area_database_summary
                                        
                                        	Area database summary 
                                        	**type**\:   :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, self).__init__()

                                            self.yang_name = "area-database"
                                            self.yang_parent_name = "database-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"area-database-summary" : ("area_database_summary", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary)}
                                            self._child_list_classes = {}

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.area_database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                            self.area_database_summary.parent = self
                                            self._children_name_map["area_database_summary"] = "area-database-summary"
                                            self._children_yang_names.add("area-database-summary")
                                            self._segment_path = lambda: "area-database"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, ['lsa_area_id'], name, value)


                                        class AreaDatabaseSummary(Entity):
                                            """
                                            Area database summary 
                                            
                                            .. attribute:: deleted_lsa
                                            
                                            	deleted lsa
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa
                                            
                                            	lsa
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_checksum
                                            
                                            	lsa checksum
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_age_lsa
                                            
                                            	max age lsa
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, self).__init__()

                                                self.yang_name = "area-database-summary"
                                                self.yang_parent_name = "area-database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.deleted_lsa = YLeafList(YType.uint32, "deleted-lsa")

                                                self.lsa = YLeafList(YType.uint32, "lsa")

                                                self.lsa_checksum = YLeafList(YType.uint32, "lsa-checksum")

                                                self.max_age_lsa = YLeafList(YType.uint32, "max-age-lsa")
                                                self._segment_path = lambda: "area-database-summary"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, ['deleted_lsa', 'lsa', 'lsa_checksum', 'max_age_lsa'], name, value)


                                    class DatabaseCounters(Entity):
                                        """
                                        OSPFv3 database counters 
                                        
                                        .. attribute:: deleted_lsa
                                        
                                        	deleted lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa
                                        
                                        	lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_checksum
                                        
                                        	lsa checksum
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_age_lsa
                                        
                                        	max age lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, self).__init__()

                                            self.yang_name = "database-counters"
                                            self.yang_parent_name = "database-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.deleted_lsa = YLeafList(YType.uint32, "deleted-lsa")

                                            self.lsa = YLeafList(YType.uint32, "lsa")

                                            self.lsa_checksum = YLeafList(YType.uint32, "lsa-checksum")

                                            self.max_age_lsa = YLeafList(YType.uint32, "max-age-lsa")
                                            self._segment_path = lambda: "database-counters"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, ['deleted_lsa', 'lsa', 'lsa_checksum', 'max_age_lsa'], name, value)


                            class DatabaseTable(Entity):
                                """
                                OSPF Link State Database
                                
                                .. attribute:: lsa_internal_table
                                
                                	Database LSA information
                                	**type**\:   :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable>`
                                
                                .. attribute:: lsa_table
                                
                                	Database LSA information
                                	**type**\:   :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable, self).__init__()

                                    self.yang_name = "database-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"lsa-internal-table" : ("lsa_internal_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable), "lsa-table" : ("lsa_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable)}
                                    self._child_list_classes = {}

                                    self.lsa_internal_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable()
                                    self.lsa_internal_table.parent = self
                                    self._children_name_map["lsa_internal_table"] = "lsa-internal-table"
                                    self._children_yang_names.add("lsa-internal-table")

                                    self.lsa_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable()
                                    self.lsa_table.parent = self
                                    self._children_name_map["lsa_table"] = "lsa-table"
                                    self._children_yang_names.add("lsa-table")
                                    self._segment_path = lambda: "database-table"


                                class LsaInternalTable(Entity):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: lsa
                                    
                                    	Database LSA information
                                    	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable, self).__init__()

                                        self.yang_name = "lsa-internal-table"
                                        self.yang_parent_name = "database-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"lsa" : ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa)}

                                        self.lsa = YList(self)
                                        self._segment_path = lambda: "lsa-internal-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable, [], name, value)


                                    class Lsa(Entity):
                                        """
                                        Database LSA information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: interface_name
                                        
                                        	InterfaceName
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                        
                                        .. attribute:: lsa_info
                                        
                                        	Summary of all LSAs or LSA specific information 
                                        	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa, self).__init__()

                                            self.yang_name = "lsa"
                                            self.yang_parent_name = "lsa-internal-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-info" : ("lsa_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo)}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.area_id = YLeaf(YType.int32, "area-id")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.ls_id = YLeaf(YType.int32, "ls-id")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                            self.lsa_info.parent = self
                                            self._children_name_map["lsa_info"] = "lsa-info"
                                            self._children_yang_names.add("lsa-info")
                                            self._segment_path = lambda: "lsa"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                        class LsaInfo(Entity):
                                            """
                                            Summary of all LSAs or LSA specific information 
                                            
                                            .. attribute:: external_lsa_type
                                            
                                            	External LSA
                                            	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                            
                                            .. attribute:: grace_lsa
                                            
                                            	Grace LSA
                                            	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                            
                                            .. attribute:: inter_area_prefix_lsa_type
                                            
                                            	Inter Area Prefix LSA
                                            	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                            
                                            .. attribute:: inter_area_router_lsa_type
                                            
                                            	Inter Area Router LSA
                                            	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                            
                                            .. attribute:: intra_area_prefix_lsa_type
                                            
                                            	Intra Area Prefix LSA
                                            	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                            
                                            .. attribute:: link_lsa_type
                                            
                                            	Link LSA
                                            	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                            
                                            .. attribute:: lsa_info_type
                                            
                                            	LSAInfoType
                                            	**type**\:   :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                            
                                            .. attribute:: lsa_summary_info
                                            
                                            	Summary information of LSAs
                                            	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                            
                                            .. attribute:: network_lsa_type
                                            
                                            	Network LSA
                                            	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                            
                                            .. attribute:: nssalsa_type
                                            
                                            	NSSA External LSA
                                            	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                            
                                            .. attribute:: router_lsa_type
                                            
                                            	Router LSA
                                            	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                            
                                            .. attribute:: unknown_area_lsa_type
                                            
                                            	Unknown\-Area scope LSA
                                            	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                            
                                            .. attribute:: unknown_aslsa_type
                                            
                                            	Unknown\-AS scope LSA
                                            	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                            
                                            .. attribute:: unknown_link_lsa_type
                                            
                                            	Unknown Link Scope LSA
                                            	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                            
                                            .. attribute:: unknown_lsa_type
                                            
                                            	Unknown LSA
                                            	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, self).__init__()

                                                self.yang_name = "lsa-info"
                                                self.yang_parent_name = "lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType), "grace-lsa" : ("grace_lsa", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa), "inter-area-prefix-lsa-type" : ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType), "inter-area-router-lsa-type" : ("inter_area_router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType), "intra-area-prefix-lsa-type" : ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType), "link-lsa-type" : ("link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType), "lsa-summary-info" : ("lsa_summary_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo), "network-lsa-type" : ("network_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType), "nssalsa-type" : ("nssalsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType), "router-lsa-type" : ("router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType), "unknown-area-lsa-type" : ("unknown_area_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType), "unknown-aslsa-type" : ("unknown_aslsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType), "unknown-link-lsa-type" : ("unknown_link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType), "unknown-lsa-type" : ("unknown_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType)}
                                                self._child_list_classes = {}

                                                self.lsa_info_type = YLeaf(YType.enumeration, "lsa-info-type")

                                                self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                                self._children_yang_names.add("external-lsa-type")

                                                self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                                self.grace_lsa.parent = self
                                                self._children_name_map["grace_lsa"] = "grace-lsa"
                                                self._children_yang_names.add("grace-lsa")

                                                self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                                self.inter_area_prefix_lsa_type.parent = self
                                                self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"
                                                self._children_yang_names.add("inter-area-prefix-lsa-type")

                                                self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                                self.inter_area_router_lsa_type.parent = self
                                                self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"
                                                self._children_yang_names.add("inter-area-router-lsa-type")

                                                self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                                self.intra_area_prefix_lsa_type.parent = self
                                                self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"
                                                self._children_yang_names.add("intra-area-prefix-lsa-type")

                                                self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                                self.link_lsa_type.parent = self
                                                self._children_name_map["link_lsa_type"] = "link-lsa-type"
                                                self._children_yang_names.add("link-lsa-type")

                                                self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                                self.lsa_summary_info.parent = self
                                                self._children_name_map["lsa_summary_info"] = "lsa-summary-info"
                                                self._children_yang_names.add("lsa-summary-info")

                                                self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                                self._children_yang_names.add("network-lsa-type")

                                                self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                                self.nssalsa_type.parent = self
                                                self._children_name_map["nssalsa_type"] = "nssalsa-type"
                                                self._children_yang_names.add("nssalsa-type")

                                                self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                                self._children_yang_names.add("router-lsa-type")

                                                self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                                self.unknown_area_lsa_type.parent = self
                                                self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"
                                                self._children_yang_names.add("unknown-area-lsa-type")

                                                self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                                self.unknown_aslsa_type.parent = self
                                                self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"
                                                self._children_yang_names.add("unknown-aslsa-type")

                                                self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                                self.unknown_link_lsa_type.parent = self
                                                self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"
                                                self._children_yang_names.add("unknown-link-lsa-type")

                                                self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                                self.unknown_lsa_type.parent = self
                                                self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                                self._children_yang_names.add("unknown-lsa-type")
                                                self._segment_path = lambda: "lsa-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, ['lsa_info_type'], name, value)


                                            class ExternalLsaType(Entity):
                                                """
                                                External LSA
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                                    self.yang_name = "external-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                    self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                    self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.priority = YLeaf(YType.enumeration, "priority")

                                                    self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "external-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class GraceLsa(Entity):
                                                """
                                                Grace LSA
                                                
                                                .. attribute:: grace_period
                                                
                                                	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_reason
                                                
                                                	Reason for router restart
                                                	**type**\:   :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                                    self.yang_name = "grace-lsa"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.grace_period = YLeaf(YType.uint32, "grace-period")

                                                    self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "grace-lsa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, ['grace_period', 'grace_reason'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "grace-lsa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "grace-lsa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class InterAreaPrefixLsaType(Entity):
                                                """
                                                Inter Area Prefix LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: prefix
                                                
                                                	LSA address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                                    self.yang_name = "inter-area-prefix-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.priority = YLeaf(YType.enumeration, "priority")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "inter-area-prefix-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, ['prefix', 'prefix_length', 'priority'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class InterAreaRouterLsaType(Entity):
                                                """
                                                Inter Area Router LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                                    self.yang_name = "inter-area-router-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "inter-area-router-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, ['lsa_router_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "inter-area-router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "inter-area-router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class IntraAreaPrefixLsaType(Entity):
                                                """
                                                Intra Area Prefix LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                                
                                                .. attribute:: reference_advertised_router
                                                
                                                	Reference advertised router 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                                    self.yang_name = "intra-area-prefix-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)}
                                                    self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix)}

                                                    self.reference_advertised_router = YLeaf(YType.str, "reference-advertised-router")

                                                    self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                                    self.reference_type = YLeaf(YType.enumeration, "reference-type")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "intra-area-prefix-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, ['reference_advertised_router', 'reference_lsa_id', 'reference_type'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                        self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                        self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                        self.prefix = YLeaf(YType.str, "prefix")

                                                        self.priority = YLeaf(YType.enumeration, "priority")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                            class LinkLsaType(Entity):
                                                """
                                                Link LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface handle
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_link_local
                                                
                                                	LSA link local 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                                
                                                .. attribute:: router_priority
                                                
                                                	Router priority 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                                    self.yang_name = "link-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)}
                                                    self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix)}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.lsa_link_local = YLeaf(YType.str, "lsa-link-local")

                                                    self.router_priority = YLeaf(YType.uint8, "router-priority")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "link-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'lsa_link_local', 'router_priority', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                        self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                        self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                        self.prefix = YLeaf(YType.str, "prefix")

                                                        self.priority = YLeaf(YType.enumeration, "priority")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                            class LsaSummaryInfo(Entity):
                                                """
                                                Summary information of LSAs
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: links
                                                
                                                	Number of links
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 address Prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                                    self.yang_name = "lsa-summary-info"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.links = YLeaf(YType.uint16, "links")

                                                    self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                                    self.reference_type = YLeaf(YType.uint16, "reference-type")

                                                    self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "lsa-summary-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, ['interface_name', 'is_sham_link', 'is_virtual_link', 'links', 'lsa_router_id', 'prefix', 'prefix_length', 'reference_lsa_id', 'reference_type', 'router_la_bits', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "lsa-summary-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "lsa-summary-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class NetworkLsaType(Entity):
                                                """
                                                Network LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                                
                                                .. attribute:: neighbor_router
                                                
                                                	Neighbor router list
                                                	**type**\:  list of str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                                    self.yang_name = "network-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.neighbor_router = YLeafList(YType.str, "neighbor-router")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "network-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, ['neighbor_router'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class NssalsaType(Entity):
                                                """
                                                NSSA External LSA
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                                    self.yang_name = "nssalsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                    self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                    self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.priority = YLeaf(YType.enumeration, "priority")

                                                    self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "nssalsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "nssalsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "nssalsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class RouterLsaType(Entity):
                                                """
                                                Router LSA
                                                
                                                .. attribute:: link
                                                
                                                	List of links in this LSA
                                                	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rpf_path
                                                
                                                	Router LSA Reverse\-Path Forwarding information 
                                                	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                                    self.yang_name = "router-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader), "rpf-path" : ("rpf_path", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath)}
                                                    self._child_list_classes = {"link" : ("link", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link)}

                                                    self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")

                                                    self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                    self.rpf_path.parent = self
                                                    self._children_name_map["rpf_path"] = "rpf-path"
                                                    self._children_yang_names.add("rpf-path")

                                                    self.link = YList(self)
                                                    self._segment_path = lambda: "router-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, ['router_la_bits'], name, value)


                                                class Link(Entity):
                                                    """
                                                    List of links in this LSA
                                                    
                                                    .. attribute:: link_interface_id
                                                    
                                                    	LSA link interface ID 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	LSA link metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_neighbor_interface_id
                                                    
                                                    	LSA link neighbor interface ID 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_neighbor_router_id
                                                    
                                                    	LSA link neigbhor router id 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:   :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                        self.yang_name = "link"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.link_interface_id = YLeaf(YType.uint32, "link-interface-id")

                                                        self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                        self.link_neighbor_interface_id = YLeaf(YType.uint32, "link-neighbor-interface-id")

                                                        self.link_neighbor_router_id = YLeaf(YType.uint32, "link-neighbor-router-id")

                                                        self.link_type = YLeaf(YType.enumeration, "link-type")
                                                        self._segment_path = lambda: "link"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, ['link_interface_id', 'link_metric', 'link_neighbor_interface_id', 'link_neighbor_router_id', 'link_type'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                                class RpfPath(Entity):
                                                    """
                                                    Router LSA Reverse\-Path Forwarding information 
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	RPF multicast IDB 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: rpf_multicast_next_hop
                                                    
                                                    	RPF multicast next hop 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                        self.yang_name = "rpf-path"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.rpf_multicast_next_hop = YLeaf(YType.uint32, "rpf-multicast-next-hop")
                                                        self._segment_path = lambda: "rpf-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, ['interface_name', 'rpf_multicast_next_hop'], name, value)


                                            class UnknownAreaLsaType(Entity):
                                                """
                                                Unknown\-Area scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                                    self.yang_name = "unknown-area-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "unknown-area-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-area-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-area-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class UnknownAslsaType(Entity):
                                                """
                                                Unknown\-AS scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                                    self.yang_name = "unknown-aslsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "unknown-aslsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-aslsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-aslsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class UnknownLinkLsaType(Entity):
                                                """
                                                Unknown Link Scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                                    self.yang_name = "unknown-link-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "unknown-link-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class UnknownLsaType(Entity):
                                                """
                                                Unknown LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                                    self.yang_name = "unknown-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "unknown-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                class LsaTable(Entity):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: lsa
                                    
                                    	Database LSA information
                                    	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable, self).__init__()

                                        self.yang_name = "lsa-table"
                                        self.yang_parent_name = "database-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"lsa" : ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa)}

                                        self.lsa = YList(self)
                                        self._segment_path = lambda: "lsa-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable, [], name, value)


                                    class Lsa(Entity):
                                        """
                                        Database LSA information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: interface_name
                                        
                                        	InterfaceName
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                        
                                        .. attribute:: lsa_info
                                        
                                        	Summary of all LSAs or LSA specific information 
                                        	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa, self).__init__()

                                            self.yang_name = "lsa"
                                            self.yang_parent_name = "lsa-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-info" : ("lsa_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo)}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.area_id = YLeaf(YType.int32, "area-id")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.ls_id = YLeaf(YType.int32, "ls-id")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                            self.lsa_info.parent = self
                                            self._children_name_map["lsa_info"] = "lsa-info"
                                            self._children_yang_names.add("lsa-info")
                                            self._segment_path = lambda: "lsa"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                        class LsaInfo(Entity):
                                            """
                                            Summary of all LSAs or LSA specific information 
                                            
                                            .. attribute:: external_lsa_type
                                            
                                            	External LSA
                                            	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                            
                                            .. attribute:: grace_lsa
                                            
                                            	Grace LSA
                                            	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                            
                                            .. attribute:: inter_area_prefix_lsa_type
                                            
                                            	Inter Area Prefix LSA
                                            	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                            
                                            .. attribute:: inter_area_router_lsa_type
                                            
                                            	Inter Area Router LSA
                                            	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                            
                                            .. attribute:: intra_area_prefix_lsa_type
                                            
                                            	Intra Area Prefix LSA
                                            	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                            
                                            .. attribute:: link_lsa_type
                                            
                                            	Link LSA
                                            	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                            
                                            .. attribute:: lsa_info_type
                                            
                                            	LSAInfoType
                                            	**type**\:   :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                            
                                            .. attribute:: lsa_summary_info
                                            
                                            	Summary information of LSAs
                                            	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                            
                                            .. attribute:: network_lsa_type
                                            
                                            	Network LSA
                                            	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                            
                                            .. attribute:: nssalsa_type
                                            
                                            	NSSA External LSA
                                            	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                            
                                            .. attribute:: router_lsa_type
                                            
                                            	Router LSA
                                            	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                            
                                            .. attribute:: unknown_area_lsa_type
                                            
                                            	Unknown\-Area scope LSA
                                            	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                            
                                            .. attribute:: unknown_aslsa_type
                                            
                                            	Unknown\-AS scope LSA
                                            	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                            
                                            .. attribute:: unknown_link_lsa_type
                                            
                                            	Unknown Link Scope LSA
                                            	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                            
                                            .. attribute:: unknown_lsa_type
                                            
                                            	Unknown LSA
                                            	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo, self).__init__()

                                                self.yang_name = "lsa-info"
                                                self.yang_parent_name = "lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType), "grace-lsa" : ("grace_lsa", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa), "inter-area-prefix-lsa-type" : ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType), "inter-area-router-lsa-type" : ("inter_area_router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType), "intra-area-prefix-lsa-type" : ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType), "link-lsa-type" : ("link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType), "lsa-summary-info" : ("lsa_summary_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo), "network-lsa-type" : ("network_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType), "nssalsa-type" : ("nssalsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType), "router-lsa-type" : ("router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType), "unknown-area-lsa-type" : ("unknown_area_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType), "unknown-aslsa-type" : ("unknown_aslsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType), "unknown-link-lsa-type" : ("unknown_link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType), "unknown-lsa-type" : ("unknown_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType)}
                                                self._child_list_classes = {}

                                                self.lsa_info_type = YLeaf(YType.enumeration, "lsa-info-type")

                                                self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                                self._children_yang_names.add("external-lsa-type")

                                                self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                                self.grace_lsa.parent = self
                                                self._children_name_map["grace_lsa"] = "grace-lsa"
                                                self._children_yang_names.add("grace-lsa")

                                                self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                                self.inter_area_prefix_lsa_type.parent = self
                                                self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"
                                                self._children_yang_names.add("inter-area-prefix-lsa-type")

                                                self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                                self.inter_area_router_lsa_type.parent = self
                                                self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"
                                                self._children_yang_names.add("inter-area-router-lsa-type")

                                                self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                                self.intra_area_prefix_lsa_type.parent = self
                                                self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"
                                                self._children_yang_names.add("intra-area-prefix-lsa-type")

                                                self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                                self.link_lsa_type.parent = self
                                                self._children_name_map["link_lsa_type"] = "link-lsa-type"
                                                self._children_yang_names.add("link-lsa-type")

                                                self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                                self.lsa_summary_info.parent = self
                                                self._children_name_map["lsa_summary_info"] = "lsa-summary-info"
                                                self._children_yang_names.add("lsa-summary-info")

                                                self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                                self._children_yang_names.add("network-lsa-type")

                                                self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                                self.nssalsa_type.parent = self
                                                self._children_name_map["nssalsa_type"] = "nssalsa-type"
                                                self._children_yang_names.add("nssalsa-type")

                                                self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                                self._children_yang_names.add("router-lsa-type")

                                                self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                                self.unknown_area_lsa_type.parent = self
                                                self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"
                                                self._children_yang_names.add("unknown-area-lsa-type")

                                                self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                                self.unknown_aslsa_type.parent = self
                                                self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"
                                                self._children_yang_names.add("unknown-aslsa-type")

                                                self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                                self.unknown_link_lsa_type.parent = self
                                                self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"
                                                self._children_yang_names.add("unknown-link-lsa-type")

                                                self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                                self.unknown_lsa_type.parent = self
                                                self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                                self._children_yang_names.add("unknown-lsa-type")
                                                self._segment_path = lambda: "lsa-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo, ['lsa_info_type'], name, value)


                                            class ExternalLsaType(Entity):
                                                """
                                                External LSA
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                                    self.yang_name = "external-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                    self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                    self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.priority = YLeaf(YType.enumeration, "priority")

                                                    self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "external-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class GraceLsa(Entity):
                                                """
                                                Grace LSA
                                                
                                                .. attribute:: grace_period
                                                
                                                	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_reason
                                                
                                                	Reason for router restart
                                                	**type**\:   :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                                    self.yang_name = "grace-lsa"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.grace_period = YLeaf(YType.uint32, "grace-period")

                                                    self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "grace-lsa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, ['grace_period', 'grace_reason'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "grace-lsa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "grace-lsa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class InterAreaPrefixLsaType(Entity):
                                                """
                                                Inter Area Prefix LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: prefix
                                                
                                                	LSA address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                                    self.yang_name = "inter-area-prefix-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.priority = YLeaf(YType.enumeration, "priority")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "inter-area-prefix-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, ['prefix', 'prefix_length', 'priority'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class InterAreaRouterLsaType(Entity):
                                                """
                                                Inter Area Router LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                                    self.yang_name = "inter-area-router-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "inter-area-router-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, ['lsa_router_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "inter-area-router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "inter-area-router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class IntraAreaPrefixLsaType(Entity):
                                                """
                                                Intra Area Prefix LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                                
                                                .. attribute:: reference_advertised_router
                                                
                                                	Reference advertised router 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                                    self.yang_name = "intra-area-prefix-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)}
                                                    self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix)}

                                                    self.reference_advertised_router = YLeaf(YType.str, "reference-advertised-router")

                                                    self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                                    self.reference_type = YLeaf(YType.enumeration, "reference-type")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "intra-area-prefix-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, ['reference_advertised_router', 'reference_lsa_id', 'reference_type'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                        self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                        self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                        self.prefix = YLeaf(YType.str, "prefix")

                                                        self.priority = YLeaf(YType.enumeration, "priority")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                            class LinkLsaType(Entity):
                                                """
                                                Link LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface handle
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_link_local
                                                
                                                	LSA link local 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                                
                                                .. attribute:: router_priority
                                                
                                                	Router priority 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                                    self.yang_name = "link-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)}
                                                    self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix)}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.lsa_link_local = YLeaf(YType.str, "lsa-link-local")

                                                    self.router_priority = YLeaf(YType.uint8, "router-priority")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "link-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'lsa_link_local', 'router_priority', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                        self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                        self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                        self.prefix = YLeaf(YType.str, "prefix")

                                                        self.priority = YLeaf(YType.enumeration, "priority")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                            class LsaSummaryInfo(Entity):
                                                """
                                                Summary information of LSAs
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: links
                                                
                                                	Number of links
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 address Prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                                    self.yang_name = "lsa-summary-info"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.links = YLeaf(YType.uint16, "links")

                                                    self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                                    self.reference_type = YLeaf(YType.uint16, "reference-type")

                                                    self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "lsa-summary-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, ['interface_name', 'is_sham_link', 'is_virtual_link', 'links', 'lsa_router_id', 'prefix', 'prefix_length', 'reference_lsa_id', 'reference_type', 'router_la_bits', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "lsa-summary-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "lsa-summary-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class NetworkLsaType(Entity):
                                                """
                                                Network LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                                
                                                .. attribute:: neighbor_router
                                                
                                                	Neighbor router list
                                                	**type**\:  list of str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                                    self.yang_name = "network-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.neighbor_router = YLeafList(YType.str, "neighbor-router")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "network-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, ['neighbor_router'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class NssalsaType(Entity):
                                                """
                                                NSSA External LSA
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                                    self.yang_name = "nssalsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                    self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                                    self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.priority = YLeaf(YType.enumeration, "priority")

                                                    self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "nssalsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "nssalsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "nssalsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class RouterLsaType(Entity):
                                                """
                                                Router LSA
                                                
                                                .. attribute:: link
                                                
                                                	List of links in this LSA
                                                	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rpf_path
                                                
                                                	Router LSA Reverse\-Path Forwarding information 
                                                	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                                    self.yang_name = "router-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader), "rpf-path" : ("rpf_path", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath)}
                                                    self._child_list_classes = {"link" : ("link", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link)}

                                                    self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")

                                                    self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                    self.rpf_path.parent = self
                                                    self._children_name_map["rpf_path"] = "rpf-path"
                                                    self._children_yang_names.add("rpf-path")

                                                    self.link = YList(self)
                                                    self._segment_path = lambda: "router-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, ['router_la_bits'], name, value)


                                                class Link(Entity):
                                                    """
                                                    List of links in this LSA
                                                    
                                                    .. attribute:: link_interface_id
                                                    
                                                    	LSA link interface ID 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	LSA link metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_neighbor_interface_id
                                                    
                                                    	LSA link neighbor interface ID 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_neighbor_router_id
                                                    
                                                    	LSA link neigbhor router id 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:   :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                        self.yang_name = "link"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.link_interface_id = YLeaf(YType.uint32, "link-interface-id")

                                                        self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                        self.link_neighbor_interface_id = YLeaf(YType.uint32, "link-neighbor-interface-id")

                                                        self.link_neighbor_router_id = YLeaf(YType.uint32, "link-neighbor-router-id")

                                                        self.link_type = YLeaf(YType.enumeration, "link-type")
                                                        self._segment_path = lambda: "link"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, ['link_interface_id', 'link_metric', 'link_neighbor_interface_id', 'link_neighbor_router_id', 'link_type'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                                class RpfPath(Entity):
                                                    """
                                                    Router LSA Reverse\-Path Forwarding information 
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	RPF multicast IDB 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: rpf_multicast_next_hop
                                                    
                                                    	RPF multicast next hop 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                        self.yang_name = "rpf-path"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.rpf_multicast_next_hop = YLeaf(YType.uint32, "rpf-multicast-next-hop")
                                                        self._segment_path = lambda: "rpf-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, ['interface_name', 'rpf_multicast_next_hop'], name, value)


                                            class UnknownAreaLsaType(Entity):
                                                """
                                                Unknown\-Area scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                                    self.yang_name = "unknown-area-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "unknown-area-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-area-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-area-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class UnknownAslsaType(Entity):
                                                """
                                                Unknown\-AS scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                                    self.yang_name = "unknown-aslsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "unknown-aslsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-aslsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-aslsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class UnknownLinkLsaType(Entity):
                                                """
                                                Unknown Link Scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                                    self.yang_name = "unknown-link-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "unknown-link-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                            class UnknownLsaType(Entity):
                                                """
                                                Unknown LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                                    self.yang_name = "unknown-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                                    self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                                    self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                                    self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._children_yang_names.add("lsa-detail")

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"
                                                    self._children_yang_names.add("lsa-header")
                                                    self._segment_path = lambda: "unknown-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                                        self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                        self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                        self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                        self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                        self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                        self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                        self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                        self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                        self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                        self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                        self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                        self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                        self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                        self._segment_path = lambda: "lsa-detail"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                                        self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                        self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                        self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                        self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                        self._segment_path = lambda: "lsa-header"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                            class FloodListTable(Entity):
                                """
                                OSPFv3 flood list information table for an
                                area
                                
                                .. attribute:: flood
                                
                                	OSPFv3 flood list information
                                	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable, self).__init__()

                                    self.yang_name = "flood-list-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"flood" : ("flood", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood)}

                                    self.flood = YList(self)
                                    self._segment_path = lambda: "flood-list-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable, [], name, value)


                                class Flood(Entity):
                                    """
                                    OSPFv3 flood list information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: area_flood
                                    
                                    	Area scope floodlist
                                    	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood>`
                                    
                                    .. attribute:: as_flood
                                    
                                    	AS scope floodlist
                                    	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood>`
                                    
                                    .. attribute:: link_flood
                                    
                                    	Link floodlist
                                    	**type**\: list of    :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood>`
                                    
                                    .. attribute:: ls_transmission_timer
                                    
                                    	Time until next LS transmission (ms) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: queue_length
                                    
                                    	Number of LSAs currently being flooded 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "flood-list-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"area-flood" : ("area_flood", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood), "as-flood" : ("as_flood", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood), "link-flood" : ("link_flood", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.ls_transmission_timer = YLeaf(YType.uint32, "ls-transmission-timer")

                                        self.queue_length = YLeaf(YType.uint32, "queue-length")

                                        self.area_flood = YList(self)
                                        self.as_flood = YList(self)
                                        self.link_flood = YList(self)
                                        self._segment_path = lambda: "flood" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood, ['interface_name', 'ls_transmission_timer', 'queue_length'], name, value)


                                    class AreaFlood(Entity):
                                        """
                                        Area scope floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood, self).__init__()

                                            self.yang_name = "area-flood"
                                            self.yang_parent_name = "flood"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                            self._segment_path = lambda: "area-flood"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                                    class AsFlood(Entity):
                                        """
                                        AS scope floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood, self).__init__()

                                            self.yang_name = "as-flood"
                                            self.yang_parent_name = "flood"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                            self._segment_path = lambda: "as-flood"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                                    class LinkFlood(Entity):
                                        """
                                        Link floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood, self).__init__()

                                            self.yang_name = "link-flood"
                                            self.yang_parent_name = "flood"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                            self._segment_path = lambda: "link-flood"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class InterfaceBriefTable(Entity):
                                """
                                OSPFv3 interface brief information table for
                                an area
                                
                                .. attribute:: interface_brief
                                
                                	Interface brief information
                                	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable, self).__init__()

                                    self.yang_name = "interface-brief-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface-brief" : ("interface_brief", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief)}

                                    self.interface_brief = YList(self)
                                    self._segment_path = lambda: "interface-brief-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable, [], name, value)


                                class InterfaceBrief(Entity):
                                    """
                                    Interface brief information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_adjacent_neighbors
                                    
                                    	Total number of adjacent neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbors
                                    
                                    	Total number of neighbors 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: network_type
                                    
                                    	Network type
                                    	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief, self).__init__()

                                        self.yang_name = "interface-brief"
                                        self.yang_parent_name = "interface-brief-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface_address = YLeaf(YType.str, "interface-address")

                                        self.interface_adjacent_neighbors = YLeaf(YType.uint16, "interface-adjacent-neighbors")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbors = YLeaf(YType.uint16, "interface-neighbors")

                                        self.network_type = YLeaf(YType.enumeration, "network-type")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                        self._segment_path = lambda: "interface-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief, ['interface_name', 'interface_address', 'interface_adjacent_neighbors', 'interface_link_cost', 'interface_neighbors', 'network_type', 'ospf_interface_state'], name, value)


                            class InterfaceTable(Entity):
                                """
                                OSPFv3 interface information table for an area
                                
                                .. attribute:: interface
                                
                                	OSPFv3 interface information
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable, self).__init__()

                                    self.yang_name = "interface-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface" : ("interface", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface)}

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interface-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable, [], name, value)


                                class Interface(Entity):
                                    """
                                    OSPFv3 interface information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: active_interface
                                    
                                    	Active interface details 
                                    	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface>`
                                    
                                    .. attribute:: adjacent_neighbor
                                    
                                    	Number of adjacent neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_designated_router_address
                                    
                                    	Backup designated router interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_designated_router_id
                                    
                                    	Backup designated router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: configured_ldp_sync
                                    
                                    	If true, configured as LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Configured dead interval (s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: designated_router_address
                                    
                                    	Designated router interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: designated_router_id
                                    
                                    	Designated router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Configured hello interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_authentication_spi
                                    
                                    	Interface authentication spi 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_authentication_transmit
                                    
                                    	Interface authentication transmit 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_bfd
                                    
                                    	BFD information 
                                    	**type**\:   :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd>`
                                    
                                    .. attribute:: interface_dc_bitless_ls_as
                                    
                                    	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_encrypted_authentication_transmitted
                                    
                                    	Interface encrypted authentication transmitted 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_encryption_spi
                                    
                                    	Interface encryption spi
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_encryption_transmitted
                                    
                                    	Interface encryption transmitted 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_ldp_sync
                                    
                                    	If true, interface LDP sync is achieved
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor
                                    
                                    	Information for neighbors on the interface
                                    	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor>`
                                    
                                    .. attribute:: interface_number
                                    
                                    	Interface number 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_priority
                                    
                                    	Interface priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_references
                                    
                                    	Interface reference count 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_retransmission_interval
                                    
                                    	Configured retransmit interval (s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_router_id
                                    
                                    	Interface router ID 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_state
                                    
                                    	Interface state
                                    	**type**\:   :py:class:`ImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnum>`
                                    
                                    .. attribute:: is_demand_circuit_configured
                                    
                                    	If true, configured as demand circuit 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_designated_router
                                    
                                    	If true, designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_demand_circuit
                                    
                                    	If true, interface running as demand circuit
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_encryption_enabled
                                    
                                    	If true, interface encryption is enabled 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_flood_reduction
                                    
                                    	If true, interface flood reduction is active 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_ip_security_active
                                    
                                    	If true, interface IP security is active 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_ip_security_required
                                    
                                    	If true, interface IP security is required 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_line_up
                                    
                                    	If true, line protocol is up 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_lsa_filtered
                                    
                                    	Filter is configured for out going LSAs 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_suppress
                                    
                                    	If true prefix suppression is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: network_lsa_flush_timer
                                    
                                    	The amount of time in seconds before flush timer for old network LSA expires 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: network_type
                                    
                                    	Network type
                                    	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                    
                                    .. attribute:: next_hello_time
                                    
                                    	Time until next Hello (s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface state
                                    	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                                    
                                    .. attribute:: transmission_delay
                                    
                                    	Interface transmission delay (sec)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: wait_interval
                                    
                                    	Configured wait interval (s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interface-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"active-interface" : ("active_interface", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface), "interface-bfd" : ("interface_bfd", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd)}
                                        self._child_list_classes = {"interface-neighbor" : ("interface_neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.adjacent_neighbor = YLeaf(YType.uint32, "adjacent-neighbor")

                                        self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                        self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                        self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                        self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                        self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                        self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.interface_address = YLeaf(YType.str, "interface-address")

                                        self.interface_authentication_spi = YLeaf(YType.uint32, "interface-authentication-spi")

                                        self.interface_authentication_transmit = YLeaf(YType.uint32, "interface-authentication-transmit")

                                        self.interface_dc_bitless_ls_as = YLeaf(YType.uint32, "interface-dc-bitless-ls-as")

                                        self.interface_encrypted_authentication_transmitted = YLeaf(YType.uint32, "interface-encrypted-authentication-transmitted")

                                        self.interface_encryption_spi = YLeaf(YType.uint32, "interface-encryption-spi")

                                        self.interface_encryption_transmitted = YLeaf(YType.uint32, "interface-encryption-transmitted")

                                        self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_number = YLeaf(YType.uint32, "interface-number")

                                        self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                        self.interface_references = YLeaf(YType.uint32, "interface-references")

                                        self.interface_retransmission_interval = YLeaf(YType.uint32, "interface-retransmission-interval")

                                        self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                        self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                        self.is_demand_circuit_configured = YLeaf(YType.boolean, "is-demand-circuit-configured")

                                        self.is_designated_router = YLeaf(YType.boolean, "is-designated-router")

                                        self.is_interface_demand_circuit = YLeaf(YType.boolean, "is-interface-demand-circuit")

                                        self.is_interface_encryption_enabled = YLeaf(YType.boolean, "is-interface-encryption-enabled")

                                        self.is_interface_flood_reduction = YLeaf(YType.boolean, "is-interface-flood-reduction")

                                        self.is_interface_ip_security_active = YLeaf(YType.boolean, "is-interface-ip-security-active")

                                        self.is_interface_ip_security_required = YLeaf(YType.boolean, "is-interface-ip-security-required")

                                        self.is_interface_line_up = YLeaf(YType.boolean, "is-interface-line-up")

                                        self.is_interface_lsa_filtered = YLeaf(YType.boolean, "is-interface-lsa-filtered")

                                        self.is_prefix_suppress = YLeaf(YType.boolean, "is-prefix-suppress")

                                        self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                        self.network_type = YLeaf(YType.enumeration, "network-type")

                                        self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                        self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                        self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                        self.active_interface = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface()
                                        self.active_interface.parent = self
                                        self._children_name_map["active_interface"] = "active-interface"
                                        self._children_yang_names.add("active-interface")

                                        self.interface_bfd = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd()
                                        self.interface_bfd.parent = self
                                        self._children_name_map["interface_bfd"] = "interface-bfd"
                                        self._children_yang_names.add("interface-bfd")

                                        self.interface_neighbor = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface, ['interface_name', 'adjacent_neighbor', 'backup_designated_router_address', 'backup_designated_router_id', 'configured_ldp_sync', 'dead_interval', 'designated_router_address', 'designated_router_id', 'hello_interval', 'interface_address', 'interface_authentication_spi', 'interface_authentication_transmit', 'interface_dc_bitless_ls_as', 'interface_encrypted_authentication_transmitted', 'interface_encryption_spi', 'interface_encryption_transmitted', 'interface_ldp_sync', 'interface_link_cost', 'interface_number', 'interface_priority', 'interface_references', 'interface_retransmission_interval', 'interface_router_id', 'interface_state', 'is_demand_circuit_configured', 'is_designated_router', 'is_interface_demand_circuit', 'is_interface_encryption_enabled', 'is_interface_flood_reduction', 'is_interface_ip_security_active', 'is_interface_ip_security_required', 'is_interface_line_up', 'is_interface_lsa_filtered', 'is_prefix_suppress', 'network_lsa_flush_timer', 'network_type', 'next_hello_time', 'ospf_interface_state', 'transmission_delay', 'wait_interval'], name, value)


                                    class ActiveInterface(Entity):
                                        """
                                        Active interface details 
                                        
                                        .. attribute:: flood_queue_length
                                        
                                        	Flood queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flood_scan_length
                                        
                                        	Last flood scan length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_flood_index
                                        
                                        	Area scope LSAs flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood
                                        
                                        	Next LSA to flood (Area scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood_index
                                        
                                        	Index of next LSA to flood (Area scope) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_flood_index
                                        
                                        	AS scope LSAs flood index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood
                                        
                                        	Next LSA to flood (AS scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood_index
                                        
                                        	Index of next LSA to flood (AS scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_flood_pacing_timer
                                        
                                        	Time until next flood pacing timer (ms) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_flood_index
                                        
                                        	Interface flood link index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_next_flood
                                        
                                        	Interface link next flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_next_index
                                        
                                        	Interface link next information index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbors
                                        
                                        	Total number of neighbors 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: last_flood_time
                                        
                                        	Last flood scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_length
                                        
                                        	Maximum flood length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_time
                                        
                                        	Maximum flood time (ms) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppressed_hellos
                                        
                                        	Number of neighbors for which hellos are suppressed 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: wait_time
                                        
                                        	Wait time for DR/BDR selection (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface, self).__init__()

                                            self.yang_name = "active-interface"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.flood_queue_length = YLeaf(YType.uint32, "flood-queue-length")

                                            self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                            self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                            self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                            self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                            self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                            self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                            self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                            self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                            self.interface_link_flood_index = YLeaf(YType.uint32, "interface-link-flood-index")

                                            self.interface_link_next_flood = YLeaf(YType.uint32, "interface-link-next-flood")

                                            self.interface_link_next_index = YLeaf(YType.uint32, "interface-link-next-index")

                                            self.interface_neighbors = YLeaf(YType.uint16, "interface-neighbors")

                                            self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                            self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                            self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                            self.suppressed_hellos = YLeaf(YType.uint16, "suppressed-hellos")

                                            self.wait_time = YLeaf(YType.uint32, "wait-time")
                                            self._segment_path = lambda: "active-interface"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface, ['flood_queue_length', 'flood_scan_length', 'interface_area_flood_index', 'interface_area_next_flood', 'interface_area_next_flood_index', 'interface_as_flood_index', 'interface_as_next_flood', 'interface_as_next_flood_index', 'interface_flood_pacing_timer', 'interface_link_flood_index', 'interface_link_next_flood', 'interface_link_next_index', 'interface_neighbors', 'last_flood_time', 'maximum_flood_length', 'maximum_flood_time', 'suppressed_hellos', 'wait_time'], name, value)


                                    class InterfaceBfd(Entity):
                                        """
                                        BFD information 
                                        
                                        .. attribute:: bfd_detection_multiplier
                                        
                                        	BFD detection multiplier 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_interval
                                        
                                        	BFD interval (ms) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD Enable Mode on the interface \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd, self).__init__()

                                            self.yang_name = "interface-bfd"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.bfd_detection_multiplier = YLeaf(YType.uint32, "bfd-detection-multiplier")

                                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")
                                            self._segment_path = lambda: "interface-bfd"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd, ['bfd_detection_multiplier', 'bfd_interval', 'bfd_intf_enable_mode'], name, value)


                                    class InterfaceNeighbor(Entity):
                                        """
                                        Information for neighbors on the interface
                                        
                                        .. attribute:: interface_neighbor_cost
                                        
                                        	Cost of link to neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbor_id
                                        
                                        	Neighbor router ID 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_hello_suppressed
                                        
                                        	If true, hello is suppressed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_bdr
                                        
                                        	If true, backup designated router is found 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_dr
                                        
                                        	If true, designated router is found 
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor, self).__init__()

                                            self.yang_name = "interface-neighbor"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                            self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                            self.is_hello_suppressed = YLeaf(YType.boolean, "is-hello-suppressed")

                                            self.is_neighbor_bdr = YLeaf(YType.boolean, "is-neighbor-bdr")

                                            self.is_neighbor_dr = YLeaf(YType.boolean, "is-neighbor-dr")
                                            self._segment_path = lambda: "interface-neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor, ['interface_neighbor_cost', 'interface_neighbor_id', 'is_hello_suppressed', 'is_neighbor_bdr', 'is_neighbor_dr'], name, value)


                            class NeighborDetailTable(Entity):
                                """
                                OSPFv3 area neighbor information table
                                
                                .. attribute:: neighbor_detail
                                
                                	OSPFv3 neighbor detail information
                                	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable, self).__init__()

                                    self.yang_name = "neighbor-detail-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail)}

                                    self.neighbor_detail = YList(self)
                                    self._segment_path = lambda: "neighbor-detail-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable, [], name, value)


                                class NeighborDetail(Entity):
                                    """
                                    OSPFv3 neighbor detail information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_neighbor_sham_link
                                    
                                    	If true, neighbor is on a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_virtual_link
                                    
                                    	If true, neighbor is on a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_info
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_designated_router
                                    
                                    	Designated router 
                                    	**type**\:  str
                                    
                                    	**length:** 0..9
                                    
                                    .. attribute:: neighbor_detail
                                    
                                    	Detailed OSPFv3 neighbor information 
                                    	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail>`
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_interface_id
                                    
                                    	Neighbor interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_sham_link_id
                                    
                                    	Neighbor sham link id 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_virtual_link_id
                                    
                                    	Neighbor virtual link id 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail, self).__init__()

                                        self.yang_name = "neighbor-detail"
                                        self.yang_parent_name = "neighbor-detail-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-bfd-info" : ("neighbor_bfd_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo), "neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_neighbor_sham_link = YLeaf(YType.boolean, "is-neighbor-sham-link")

                                        self.is_neighbor_virtual_link = YLeaf(YType.boolean, "is-neighbor-virtual-link")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                        self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                        self.neighbor_designated_router = YLeaf(YType.str, "neighbor-designated-router")

                                        self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                        self.neighbor_interface_id = YLeaf(YType.uint32, "neighbor-interface-id")

                                        self.neighbor_sham_link_id = YLeaf(YType.uint32, "neighbor-sham-link-id")

                                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                        self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                        self.neighbor_virtual_link_id = YLeaf(YType.uint32, "neighbor-virtual-link-id")

                                        self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo()
                                        self.neighbor_bfd_info.parent = self
                                        self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                        self._children_yang_names.add("neighbor-bfd-info")

                                        self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail()
                                        self.neighbor_detail.parent = self
                                        self._children_name_map["neighbor_detail"] = "neighbor-detail"
                                        self._children_yang_names.add("neighbor-detail")
                                        self._segment_path = lambda: "neighbor-detail"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail, ['interface_name', 'is_neighbor_sham_link', 'is_neighbor_virtual_link', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_designated_router', 'neighbor_dr_priority', 'neighbor_interface_id', 'neighbor_sham_link_id', 'neighbor_state', 'neighbor_up_time', 'neighbor_virtual_link_id'], name, value)


                                    class NeighborBfdInfo(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo, self).__init__()

                                            self.yang_name = "neighbor-bfd-info"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                            self._segment_path = lambda: "neighbor-bfd-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                                    class NeighborDetail(Entity):
                                        """
                                        Detailed OSPFv3 neighbor information 
                                        
                                        .. attribute:: interface_type
                                        
                                        	Interface type
                                        	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                        
                                        .. attribute:: is_neighbor_filtered
                                        
                                        	If true, filter outgoing LSAs 
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_backup_designated_router_address
                                        
                                        	Address of backup designated router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_cost
                                        
                                        	Cost of path to this neighbor 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_designated_router_address
                                        
                                        	Address of designated router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_ignore_timer
                                        
                                        	Remaining time when ignore timer is running 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_option
                                        
                                        	 This is bitmask of neighbor's option field received 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission
                                        
                                        	Retransmission information with this neighbor
                                        	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission>`
                                        
                                        .. attribute:: next_poll_interval
                                        
                                        	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: pending_events
                                        
                                        	Number of pending events 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: poll_interval
                                        
                                        	Poll interval (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_changes
                                        
                                        	Number of state changes 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail, self).__init__()

                                            self.yang_name = "neighbor-detail"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-retransmission" : ("neighbor_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission)}
                                            self._child_list_classes = {}

                                            self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                            self.is_neighbor_filtered = YLeaf(YType.boolean, "is-neighbor-filtered")

                                            self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                            self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                            self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                            self.neighbor_ignore_timer = YLeaf(YType.uint32, "neighbor-ignore-timer")

                                            self.neighbor_option = YLeaf(YType.uint32, "neighbor-option")

                                            self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                            self.pending_events = YLeaf(YType.uint16, "pending-events")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.state_changes = YLeaf(YType.uint16, "state-changes")

                                            self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission()
                                            self.neighbor_retransmission.parent = self
                                            self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                            self._children_yang_names.add("neighbor-retransmission")
                                            self._segment_path = lambda: "neighbor-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail, ['interface_type', 'is_neighbor_filtered', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_ignore_timer', 'neighbor_option', 'next_poll_interval', 'pending_events', 'poll_interval', 'state_changes'], name, value)


                                        class NeighborRetransmission(Entity):
                                            """
                                            Retransmission information with this neighbor
                                            
                                            .. attribute:: area_first_flood
                                            
                                            	First flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_first_flood_index
                                            
                                            	Index of the first flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_flood_index
                                            
                                            	Area scope LSA's flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood
                                            
                                            	Next flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood_index
                                            
                                            	Index of next flood item for Area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood
                                            
                                            	First flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood_index
                                            
                                            	Index for first flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_flood_index
                                            
                                            	AS scope LSA's flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood
                                            
                                            	Next flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood_index
                                            
                                            	Index of next flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: database_descriptor_retransmissions
                                            
                                            	Number of database descriptor retransmissions during last exchange
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_length
                                            
                                            	Number of LSAs sent in last retransmission
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_time
                                            
                                            	Last retransmission scan time (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood
                                            
                                            	Link first flood information 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood_index
                                            
                                            	Link first flood information index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_flood_index
                                            
                                            	Link flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood
                                            
                                            	Link next flood information 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood_index
                                            
                                            	Link next flood information index 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_retransmission_timer
                                            
                                            	Time until next LSA retransmission (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_length
                                            
                                            	Maximum number of LSAs sent in a retransmission
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_time
                                            
                                            	Maximum retransmission scan time (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_retransmissions
                                            
                                            	Number of neighbor retransmissions 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: retransmissions
                                            
                                            	Number of retransmissions for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission, self).__init__()

                                                self.yang_name = "neighbor-retransmission"
                                                self.yang_parent_name = "neighbor-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                                self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                                self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                                self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                                self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                                self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                                self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                                self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                                self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                                self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                                self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                                self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                                self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                                self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                                self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                                self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                                self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                                self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                                self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                                self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                                self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                                self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                                self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                                self._segment_path = lambda: "neighbor-retransmission"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail.NeighborRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                            class NeighborTable(Entity):
                                """
                                OSPFv3 neighbor information table
                                
                                .. attribute:: neighbor
                                
                                	OSPFv3 neighbor detail information
                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable, self).__init__()

                                    self.yang_name = "neighbor-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"neighbor" : ("neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor)}

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "neighbor-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    OSPFv3 neighbor detail information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_neighbor_sham_link
                                    
                                    	If true, neighbor is on a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_virtual_link
                                    
                                    	If true, neighbor is on a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_info
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_designated_router
                                    
                                    	Designated router 
                                    	**type**\:  str
                                    
                                    	**length:** 0..9
                                    
                                    .. attribute:: neighbor_detail
                                    
                                    	Detailed OSPFv3 neighbor information 
                                    	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail>`
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_interface_id
                                    
                                    	Neighbor interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_sham_link_id
                                    
                                    	Neighbor sham link id 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_virtual_link_id
                                    
                                    	Neighbor virtual link id 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "neighbor-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-bfd-info" : ("neighbor_bfd_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo), "neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_neighbor_sham_link = YLeaf(YType.boolean, "is-neighbor-sham-link")

                                        self.is_neighbor_virtual_link = YLeaf(YType.boolean, "is-neighbor-virtual-link")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                        self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                        self.neighbor_designated_router = YLeaf(YType.str, "neighbor-designated-router")

                                        self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                        self.neighbor_interface_id = YLeaf(YType.uint32, "neighbor-interface-id")

                                        self.neighbor_sham_link_id = YLeaf(YType.uint32, "neighbor-sham-link-id")

                                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                        self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                        self.neighbor_virtual_link_id = YLeaf(YType.uint32, "neighbor-virtual-link-id")

                                        self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo()
                                        self.neighbor_bfd_info.parent = self
                                        self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                        self._children_yang_names.add("neighbor-bfd-info")

                                        self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail()
                                        self.neighbor_detail.parent = self
                                        self._children_name_map["neighbor_detail"] = "neighbor-detail"
                                        self._children_yang_names.add("neighbor-detail")
                                        self._segment_path = lambda: "neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor, ['interface_name', 'is_neighbor_sham_link', 'is_neighbor_virtual_link', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_designated_router', 'neighbor_dr_priority', 'neighbor_interface_id', 'neighbor_sham_link_id', 'neighbor_state', 'neighbor_up_time', 'neighbor_virtual_link_id'], name, value)


                                    class NeighborBfdInfo(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo, self).__init__()

                                            self.yang_name = "neighbor-bfd-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                            self._segment_path = lambda: "neighbor-bfd-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                                    class NeighborDetail(Entity):
                                        """
                                        Detailed OSPFv3 neighbor information 
                                        
                                        .. attribute:: interface_type
                                        
                                        	Interface type
                                        	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                        
                                        .. attribute:: is_neighbor_filtered
                                        
                                        	If true, filter outgoing LSAs 
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_backup_designated_router_address
                                        
                                        	Address of backup designated router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_cost
                                        
                                        	Cost of path to this neighbor 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_designated_router_address
                                        
                                        	Address of designated router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_ignore_timer
                                        
                                        	Remaining time when ignore timer is running 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_option
                                        
                                        	 This is bitmask of neighbor's option field received 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission
                                        
                                        	Retransmission information with this neighbor
                                        	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                        
                                        .. attribute:: next_poll_interval
                                        
                                        	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: pending_events
                                        
                                        	Number of pending events 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: poll_interval
                                        
                                        	Poll interval (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_changes
                                        
                                        	Number of state changes 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail, self).__init__()

                                            self.yang_name = "neighbor-detail"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-retransmission" : ("neighbor_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission)}
                                            self._child_list_classes = {}

                                            self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                            self.is_neighbor_filtered = YLeaf(YType.boolean, "is-neighbor-filtered")

                                            self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                            self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                            self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                            self.neighbor_ignore_timer = YLeaf(YType.uint32, "neighbor-ignore-timer")

                                            self.neighbor_option = YLeaf(YType.uint32, "neighbor-option")

                                            self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                            self.pending_events = YLeaf(YType.uint16, "pending-events")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.state_changes = YLeaf(YType.uint16, "state-changes")

                                            self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                            self.neighbor_retransmission.parent = self
                                            self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                            self._children_yang_names.add("neighbor-retransmission")
                                            self._segment_path = lambda: "neighbor-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail, ['interface_type', 'is_neighbor_filtered', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_ignore_timer', 'neighbor_option', 'next_poll_interval', 'pending_events', 'poll_interval', 'state_changes'], name, value)


                                        class NeighborRetransmission(Entity):
                                            """
                                            Retransmission information with this neighbor
                                            
                                            .. attribute:: area_first_flood
                                            
                                            	First flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_first_flood_index
                                            
                                            	Index of the first flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_flood_index
                                            
                                            	Area scope LSA's flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood
                                            
                                            	Next flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood_index
                                            
                                            	Index of next flood item for Area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood
                                            
                                            	First flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood_index
                                            
                                            	Index for first flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_flood_index
                                            
                                            	AS scope LSA's flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood
                                            
                                            	Next flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood_index
                                            
                                            	Index of next flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: database_descriptor_retransmissions
                                            
                                            	Number of database descriptor retransmissions during last exchange
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_length
                                            
                                            	Number of LSAs sent in last retransmission
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_time
                                            
                                            	Last retransmission scan time (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood
                                            
                                            	Link first flood information 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood_index
                                            
                                            	Link first flood information index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_flood_index
                                            
                                            	Link flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood
                                            
                                            	Link next flood information 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood_index
                                            
                                            	Link next flood information index 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_retransmission_timer
                                            
                                            	Time until next LSA retransmission (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_length
                                            
                                            	Maximum number of LSAs sent in a retransmission
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_time
                                            
                                            	Maximum retransmission scan time (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_retransmissions
                                            
                                            	Number of neighbor retransmissions 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: retransmissions
                                            
                                            	Number of retransmissions for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission, self).__init__()

                                                self.yang_name = "neighbor-retransmission"
                                                self.yang_parent_name = "neighbor-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                                self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                                self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                                self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                                self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                                self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                                self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                                self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                                self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                                self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                                self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                                self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                                self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                                self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                                self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                                self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                                self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                                self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                                self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                                self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                                self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                                self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                                self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                                self._segment_path = lambda: "neighbor-retransmission"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                            class RequestListTable(Entity):
                                """
                                OSPFv3 request list information in an area
                                
                                .. attribute:: request
                                
                                	OSPFv3 request list information
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable, self).__init__()

                                    self.yang_name = "request-list-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"request" : ("request", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request)}

                                    self.request = YList(self)
                                    self._segment_path = lambda: "request-list-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable, [], name, value)


                                class Request(Entity):
                                    """
                                    OSPFv3 request list information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_request_sham_link
                                    
                                    	If true, sham link is requested 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_request_virtual_link
                                    
                                    	If true, virtual link is requested 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request
                                    
                                    	List of request list entries
                                    	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request>`
                                    
                                    .. attribute:: request_neighbor_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request_sham_link_id
                                    
                                    	Request sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: request_virtual_link_id
                                    
                                    	Request virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "request-list-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"request" : ("request", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_request_sham_link = YLeaf(YType.boolean, "is-request-sham-link")

                                        self.is_request_virtual_link = YLeaf(YType.boolean, "is-request-virtual-link")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                        self.request_sham_link_id = YLeaf(YType.uint32, "request-sham-link-id")

                                        self.request_virtual_link_id = YLeaf(YType.uint32, "request-virtual-link-id")

                                        self.request = YList(self)
                                        self._segment_path = lambda: "request"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request, ['interface_name', 'is_request_sham_link', 'is_request_virtual_link', 'neighbor_address', 'request_neighbor_address', 'request_sham_link_id', 'request_virtual_link_id'], name, value)


                                    class Request(Entity):
                                        """
                                        List of request list entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request, self).__init__()

                                            self.yang_name = "request"
                                            self.yang_parent_name = "request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                            self._segment_path = lambda: "request"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class RetransmissionListTable(Entity):
                                """
                                OSPFv3 retransmission list information table
                                in an area
                                
                                .. attribute:: retransmission
                                
                                	OSPFv3 retransmission list information
                                	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable, self).__init__()

                                    self.yang_name = "retransmission-list-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"retransmission" : ("retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission)}

                                    self.retransmission = YList(self)
                                    self._segment_path = lambda: "retransmission-list-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable, [], name, value)


                                class Retransmission(Entity):
                                    """
                                    OSPFv3 retransmission list information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: is_retransmission_sham_link
                                    
                                    	If true, sham link is retransmitted 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_retransmissionvirtual_link
                                    
                                    	If true, virtual link is retransmitted 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_area_db
                                    
                                    	List of area scope entries
                                    	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb>`
                                    
                                    .. attribute:: retransmission_asdb
                                    
                                    	List of AS scope entries
                                    	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb>`
                                    
                                    .. attribute:: retransmission_length
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmission_neighbor_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_sham_link_id
                                    
                                    	Retransmission sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmission_timer
                                    
                                    	Amount of time remaining on retransmission timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissionvirtual_link_db
                                    
                                    	List of virtual link scope entries 
                                    	**type**\: list of    :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb>`
                                    
                                    .. attribute:: retransmissionvirtual_link_id
                                    
                                    	Retransmission virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission, self).__init__()

                                        self.yang_name = "retransmission"
                                        self.yang_parent_name = "retransmission-list-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"retransmission-area-db" : ("retransmission_area_db", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb), "retransmission-asdb" : ("retransmission_asdb", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb), "retransmissionvirtual-link-db" : ("retransmissionvirtual_link_db", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.is_retransmission_sham_link = YLeaf(YType.boolean, "is-retransmission-sham-link")

                                        self.is_retransmissionvirtual_link = YLeaf(YType.boolean, "is-retransmissionvirtual-link")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.retransmission_length = YLeaf(YType.uint32, "retransmission-length")

                                        self.retransmission_neighbor_address = YLeaf(YType.str, "retransmission-neighbor-address")

                                        self.retransmission_sham_link_id = YLeaf(YType.uint32, "retransmission-sham-link-id")

                                        self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                        self.retransmissionvirtual_link_id = YLeaf(YType.uint32, "retransmissionvirtual-link-id")

                                        self.retransmission_area_db = YList(self)
                                        self.retransmission_asdb = YList(self)
                                        self.retransmissionvirtual_link_db = YList(self)
                                        self._segment_path = lambda: "retransmission"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission, ['interface_name', 'is_retransmission_sham_link', 'is_retransmissionvirtual_link', 'neighbor_address', 'retransmission_length', 'retransmission_neighbor_address', 'retransmission_sham_link_id', 'retransmission_timer', 'retransmissionvirtual_link_id'], name, value)


                                    class RetransmissionAreaDb(Entity):
                                        """
                                        List of area scope entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb, self).__init__()

                                            self.yang_name = "retransmission-area-db"
                                            self.yang_parent_name = "retransmission"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                            self._segment_path = lambda: "retransmission-area-db"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                                    class RetransmissionAsdb(Entity):
                                        """
                                        List of AS scope entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb, self).__init__()

                                            self.yang_name = "retransmission-asdb"
                                            self.yang_parent_name = "retransmission"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                            self._segment_path = lambda: "retransmission-asdb"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                                    class RetransmissionvirtualLinkDb(Entity):
                                        """
                                        List of virtual link scope entries 
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb, self).__init__()

                                            self.yang_name = "retransmissionvirtual-link-db"
                                            self.yang_parent_name = "retransmission"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                            self._segment_path = lambda: "retransmissionvirtual-link-db"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                    class BadChecksums(Entity):
                        """
                        Bad Checksum Packets information table
                        
                        .. attribute:: bad_checksum
                        
                        	Bad Checksum Packet information
                        	**type**\: list of    :py:class:`BadChecksum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums, self).__init__()

                            self.yang_name = "bad-checksums"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"bad-checksum" : ("bad_checksum", Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum)}

                            self.bad_checksum = YList(self)
                            self._segment_path = lambda: "bad-checksums"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums, [], name, value)


                        class BadChecksum(Entity):
                            """
                            Bad Checksum Packet information
                            
                            .. attribute:: packet_number  <key>
                            
                            	Bad Checksum Packets number
                            	**type**\:  int
                            
                            	**range:** 0..9
                            
                            .. attribute:: computed_checksum
                            
                            	Computed Checksum
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: received_checksum
                            
                            	Received Checksum
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: received_data
                            
                            	Received Hexadecimal Data
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: timestamp
                            
                            	Packet Timestamp (relative to 1970/1/1 00\:00)
                            	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum, self).__init__()

                                self.yang_name = "bad-checksum"
                                self.yang_parent_name = "bad-checksums"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"timestamp" : ("timestamp", Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp)}
                                self._child_list_classes = {}

                                self.packet_number = YLeaf(YType.uint32, "packet-number")

                                self.computed_checksum = YLeaf(YType.uint16, "computed-checksum")

                                self.received_checksum = YLeaf(YType.uint16, "received-checksum")

                                self.received_data = YLeaf(YType.str, "received-data")

                                self.timestamp = Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp()
                                self.timestamp.parent = self
                                self._children_name_map["timestamp"] = "timestamp"
                                self._children_yang_names.add("timestamp")
                                self._segment_path = lambda: "bad-checksum" + "[packet-number='" + self.packet_number.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum, ['packet_number', 'computed_checksum', 'received_checksum', 'received_data'], name, value)


                            class Timestamp(Entity):
                                """
                                Packet Timestamp (relative to 1970/1/1 00\:00)
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp, self).__init__()

                                    self.yang_name = "timestamp"
                                    self.yang_parent_name = "bad-checksum"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp, ['nanosecond', 'second'], name, value)


                    class BorderRouters(Entity):
                        """
                        OSPFv3 border router information table
                        
                        .. attribute:: border_router
                        
                        	OSPFv3 border router information
                        	**type**\: list of    :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters, self).__init__()

                            self.yang_name = "border-routers"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"border-router" : ("border_router", Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter)}

                            self.border_router = YList(self)
                            self._segment_path = lambda: "border-routers"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters, [], name, value)


                        class BorderRouter(Entity):
                            """
                            OSPFv3 border router information
                            
                            .. attribute:: border_router_id  <key>
                            
                            	Router address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_path
                            
                            	List of border router paths
                            	**type**\: list of    :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, self).__init__()

                                self.yang_name = "border-router"
                                self.yang_parent_name = "border-routers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"border-router-path" : ("border_router_path", Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath)}

                                self.border_router_id = YLeaf(YType.str, "border-router-id")

                                self.border_router_path = YList(self)
                                self._segment_path = lambda: "border-router" + "[border-router-id='" + self.border_router_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, ['border_router_id'], name, value)


                            class BorderRouterPath(Entity):
                                """
                                List of border router paths
                                
                                .. attribute:: border_router_area_id
                                
                                	Area string in decimal or dotted\-decimal format 
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: border_router_next_hop
                                
                                	Next hop address 
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: border_router_route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: border_router_type
                                
                                	Border router type 
                                	**type**\:   :py:class:`Ospfv3BorderRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3BorderRoute>`
                                
                                .. attribute:: interface_name
                                
                                	Next hop interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: is_intra_area_router
                                
                                	If true, intra\-area router else inter\-area router
                                	**type**\:  bool
                                
                                .. attribute:: spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, self).__init__()

                                    self.yang_name = "border-router-path"
                                    self.yang_parent_name = "border-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.border_router_area_id = YLeaf(YType.str, "border-router-area-id")

                                    self.border_router_next_hop = YLeaf(YType.str, "border-router-next-hop")

                                    self.border_router_route_metric = YLeaf(YType.uint32, "border-router-route-metric")

                                    self.border_router_type = YLeaf(YType.enumeration, "border-router-type")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_intra_area_router = YLeaf(YType.boolean, "is-intra-area-router")

                                    self.spf_version = YLeaf(YType.uint32, "spf-version")
                                    self._segment_path = lambda: "border-router-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, ['border_router_area_id', 'border_router_next_hop', 'border_router_route_metric', 'border_router_type', 'interface_name', 'is_intra_area_router', 'spf_version'], name, value)


                    class ConnectedRoutes(Entity):
                        """
                        OSPFv3 connected route information table
                        
                        .. attribute:: connected_route
                        
                        	OSPFv3 connected route information
                        	**type**\: list of    :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes, self).__init__()

                            self.yang_name = "connected-routes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"connected-route" : ("connected_route", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute)}

                            self.connected_route = YList(self)
                            self._segment_path = lambda: "connected-routes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes, [], name, value)


                        class ConnectedRoute(Entity):
                            """
                            OSPFv3 connected route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath>`
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute, self).__init__()

                                self.yang_name = "connected-route"
                                self.yang_parent_name = "connected-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-topology" : ("route_topology", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology()
                                self.route_topology.parent = self
                                self._children_name_map["route_topology"] = "route-topology"
                                self._children_yang_names.add("route-topology")

                                self.route_path = YList(self)
                                self._segment_path = lambda: "connected-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute, ['prefix', 'prefix_length'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "connected-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                    self.route_path_next_hop = YLeaf(YType.str, "route-path-next-hop")

                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                    self._children_yang_names.add("route-backup-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath, ['interface_name', 'route_path_id', 'route_path_next_hop'], name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                        self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                        self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                        self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                        self.downstream = YLeaf(YType.boolean, "downstream")

                                        self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                        self.node_protect = YLeaf(YType.boolean, "node-protect")

                                        self.primary_path = YLeaf(YType.boolean, "primary-path")

                                        self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")
                                        self._segment_path = lambda: "route-backup-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                            class RouteTopology(Entity):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology, self).__init__()

                                    self.yang_name = "route-topology"
                                    self.yang_parent_name = "connected-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.route_cost = YLeaf(YType.uint32, "route-cost")

                                    self.route_distance = YLeaf(YType.uint32, "route-distance")

                                    self.route_id = YLeaf(YType.str, "route-id")

                                    self.route_type = YLeaf(YType.uint32, "route-type")
                                    self._segment_path = lambda: "route-topology"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology, ['route_cost', 'route_distance', 'route_id', 'route_type'], name, value)


                    class DatabaseSummaryTable(Entity):
                        """
                        Database summary table
                        
                        .. attribute:: database_summary
                        
                        	Database Summary information
                        	**type**\:   :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable, self).__init__()

                            self.yang_name = "database-summary-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"database-summary" : ("database_summary", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary)}
                            self._child_list_classes = {}

                            self.database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary()
                            self.database_summary.parent = self
                            self._children_name_map["database_summary"] = "database-summary"
                            self._children_yang_names.add("database-summary")
                            self._segment_path = lambda: "database-summary-table"


                        class DatabaseSummary(Entity):
                            """
                            Database Summary information
                            
                            .. attribute:: area_database
                            
                            	OSPFv3 Area Database list 
                            	**type**\: list of    :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                            
                            .. attribute:: database_counters
                            
                            	OSPFv3 database counters 
                            	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                            
                            .. attribute:: database_router_id
                            
                            	Database router ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_opaque_database_capable
                            
                            	If true, opaque database is capable 
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary, self).__init__()

                                self.yang_name = "database-summary"
                                self.yang_parent_name = "database-summary-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"database-counters" : ("database_counters", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters)}
                                self._child_list_classes = {"area-database" : ("area_database", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase)}

                                self.database_router_id = YLeaf(YType.str, "database-router-id")

                                self.is_opaque_database_capable = YLeaf(YType.boolean, "is-opaque-database-capable")

                                self.database_counters = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                self.database_counters.parent = self
                                self._children_name_map["database_counters"] = "database-counters"
                                self._children_yang_names.add("database-counters")

                                self.area_database = YList(self)
                                self._segment_path = lambda: "database-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary, ['database_router_id', 'is_opaque_database_capable'], name, value)


                            class AreaDatabase(Entity):
                                """
                                OSPFv3 Area Database list 
                                
                                .. attribute:: area_database_summary
                                
                                	Area database summary 
                                	**type**\:   :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, self).__init__()

                                    self.yang_name = "area-database"
                                    self.yang_parent_name = "database-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"area-database-summary" : ("area_database_summary", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary)}
                                    self._child_list_classes = {}

                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                    self.area_database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                    self.area_database_summary.parent = self
                                    self._children_name_map["area_database_summary"] = "area-database-summary"
                                    self._children_yang_names.add("area-database-summary")
                                    self._segment_path = lambda: "area-database"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, ['lsa_area_id'], name, value)


                                class AreaDatabaseSummary(Entity):
                                    """
                                    Area database summary 
                                    
                                    .. attribute:: deleted_lsa
                                    
                                    	deleted lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa
                                    
                                    	lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_checksum
                                    
                                    	lsa checksum
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_age_lsa
                                    
                                    	max age lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, self).__init__()

                                        self.yang_name = "area-database-summary"
                                        self.yang_parent_name = "area-database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.deleted_lsa = YLeafList(YType.uint32, "deleted-lsa")

                                        self.lsa = YLeafList(YType.uint32, "lsa")

                                        self.lsa_checksum = YLeafList(YType.uint32, "lsa-checksum")

                                        self.max_age_lsa = YLeafList(YType.uint32, "max-age-lsa")
                                        self._segment_path = lambda: "area-database-summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, ['deleted_lsa', 'lsa', 'lsa_checksum', 'max_age_lsa'], name, value)


                            class DatabaseCounters(Entity):
                                """
                                OSPFv3 database counters 
                                
                                .. attribute:: deleted_lsa
                                
                                	deleted lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa
                                
                                	lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_checksum
                                
                                	lsa checksum
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_age_lsa
                                
                                	max age lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, self).__init__()

                                    self.yang_name = "database-counters"
                                    self.yang_parent_name = "database-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.deleted_lsa = YLeafList(YType.uint32, "deleted-lsa")

                                    self.lsa = YLeafList(YType.uint32, "lsa")

                                    self.lsa_checksum = YLeafList(YType.uint32, "lsa-checksum")

                                    self.max_age_lsa = YLeafList(YType.uint32, "max-age-lsa")
                                    self._segment_path = lambda: "database-counters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, ['deleted_lsa', 'lsa', 'lsa_checksum', 'max_age_lsa'], name, value)


                    class DatabaseTable(Entity):
                        """
                        OSPF Link State Database
                        
                        .. attribute:: lsa_internal_table
                        
                        	Database LSA information
                        	**type**\:   :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable>`
                        
                        .. attribute:: lsa_table
                        
                        	Database LSA information
                        	**type**\:   :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable, self).__init__()

                            self.yang_name = "database-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"lsa-internal-table" : ("lsa_internal_table", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable), "lsa-table" : ("lsa_table", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable)}
                            self._child_list_classes = {}

                            self.lsa_internal_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable()
                            self.lsa_internal_table.parent = self
                            self._children_name_map["lsa_internal_table"] = "lsa-internal-table"
                            self._children_yang_names.add("lsa-internal-table")

                            self.lsa_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable()
                            self.lsa_table.parent = self
                            self._children_name_map["lsa_table"] = "lsa-table"
                            self._children_yang_names.add("lsa-table")
                            self._segment_path = lambda: "database-table"


                        class LsaInternalTable(Entity):
                            """
                            Database LSA information
                            
                            .. attribute:: lsa
                            
                            	Database LSA information
                            	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable, self).__init__()

                                self.yang_name = "lsa-internal-table"
                                self.yang_parent_name = "database-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"lsa" : ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa)}

                                self.lsa = YList(self)
                                self._segment_path = lambda: "lsa-internal-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable, [], name, value)


                            class Lsa(Entity):
                                """
                                Database LSA information
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: interface_name
                                
                                	InterfaceName
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                
                                .. attribute:: lsa_info
                                
                                	Summary of all LSAs or LSA specific information 
                                	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "lsa-internal-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"lsa-info" : ("lsa_info", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo)}
                                    self._child_list_classes = {}

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.ls_id = YLeaf(YType.int32, "ls-id")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                    self.lsa_info.parent = self
                                    self._children_name_map["lsa_info"] = "lsa-info"
                                    self._children_yang_names.add("lsa-info")
                                    self._segment_path = lambda: "lsa"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                class LsaInfo(Entity):
                                    """
                                    Summary of all LSAs or LSA specific information 
                                    
                                    .. attribute:: external_lsa_type
                                    
                                    	External LSA
                                    	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                    
                                    .. attribute:: grace_lsa
                                    
                                    	Grace LSA
                                    	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                    
                                    .. attribute:: inter_area_prefix_lsa_type
                                    
                                    	Inter Area Prefix LSA
                                    	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                    
                                    .. attribute:: inter_area_router_lsa_type
                                    
                                    	Inter Area Router LSA
                                    	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                    
                                    .. attribute:: intra_area_prefix_lsa_type
                                    
                                    	Intra Area Prefix LSA
                                    	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                    
                                    .. attribute:: link_lsa_type
                                    
                                    	Link LSA
                                    	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                    
                                    .. attribute:: lsa_info_type
                                    
                                    	LSAInfoType
                                    	**type**\:   :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                    
                                    .. attribute:: lsa_summary_info
                                    
                                    	Summary information of LSAs
                                    	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                    
                                    .. attribute:: network_lsa_type
                                    
                                    	Network LSA
                                    	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                    
                                    .. attribute:: nssalsa_type
                                    
                                    	NSSA External LSA
                                    	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                    
                                    .. attribute:: router_lsa_type
                                    
                                    	Router LSA
                                    	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                    
                                    .. attribute:: unknown_area_lsa_type
                                    
                                    	Unknown\-Area scope LSA
                                    	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                    
                                    .. attribute:: unknown_aslsa_type
                                    
                                    	Unknown\-AS scope LSA
                                    	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                    
                                    .. attribute:: unknown_link_lsa_type
                                    
                                    	Unknown Link Scope LSA
                                    	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                    
                                    .. attribute:: unknown_lsa_type
                                    
                                    	Unknown LSA
                                    	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, self).__init__()

                                        self.yang_name = "lsa-info"
                                        self.yang_parent_name = "lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType), "grace-lsa" : ("grace_lsa", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa), "inter-area-prefix-lsa-type" : ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType), "inter-area-router-lsa-type" : ("inter_area_router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType), "intra-area-prefix-lsa-type" : ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType), "link-lsa-type" : ("link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType), "lsa-summary-info" : ("lsa_summary_info", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo), "network-lsa-type" : ("network_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType), "nssalsa-type" : ("nssalsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType), "router-lsa-type" : ("router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType), "unknown-area-lsa-type" : ("unknown_area_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType), "unknown-aslsa-type" : ("unknown_aslsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType), "unknown-link-lsa-type" : ("unknown_link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType), "unknown-lsa-type" : ("unknown_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType)}
                                        self._child_list_classes = {}

                                        self.lsa_info_type = YLeaf(YType.enumeration, "lsa-info-type")

                                        self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                        self.external_lsa_type.parent = self
                                        self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                        self._children_yang_names.add("external-lsa-type")

                                        self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                        self.grace_lsa.parent = self
                                        self._children_name_map["grace_lsa"] = "grace-lsa"
                                        self._children_yang_names.add("grace-lsa")

                                        self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                        self.inter_area_prefix_lsa_type.parent = self
                                        self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"
                                        self._children_yang_names.add("inter-area-prefix-lsa-type")

                                        self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                        self.inter_area_router_lsa_type.parent = self
                                        self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"
                                        self._children_yang_names.add("inter-area-router-lsa-type")

                                        self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                        self.intra_area_prefix_lsa_type.parent = self
                                        self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"
                                        self._children_yang_names.add("intra-area-prefix-lsa-type")

                                        self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                        self.link_lsa_type.parent = self
                                        self._children_name_map["link_lsa_type"] = "link-lsa-type"
                                        self._children_yang_names.add("link-lsa-type")

                                        self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                        self.lsa_summary_info.parent = self
                                        self._children_name_map["lsa_summary_info"] = "lsa-summary-info"
                                        self._children_yang_names.add("lsa-summary-info")

                                        self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                        self.network_lsa_type.parent = self
                                        self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                        self._children_yang_names.add("network-lsa-type")

                                        self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                        self.nssalsa_type.parent = self
                                        self._children_name_map["nssalsa_type"] = "nssalsa-type"
                                        self._children_yang_names.add("nssalsa-type")

                                        self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                        self.router_lsa_type.parent = self
                                        self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                        self._children_yang_names.add("router-lsa-type")

                                        self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                        self.unknown_area_lsa_type.parent = self
                                        self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"
                                        self._children_yang_names.add("unknown-area-lsa-type")

                                        self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                        self.unknown_aslsa_type.parent = self
                                        self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"
                                        self._children_yang_names.add("unknown-aslsa-type")

                                        self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                        self.unknown_link_lsa_type.parent = self
                                        self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"
                                        self._children_yang_names.add("unknown-link-lsa-type")

                                        self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                        self.unknown_lsa_type.parent = self
                                        self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                        self._children_yang_names.add("unknown-lsa-type")
                                        self._segment_path = lambda: "lsa-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, ['lsa_info_type'], name, value)


                                    class ExternalLsaType(Entity):
                                        """
                                        External LSA
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                            self.yang_name = "external-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.external_tag = YLeaf(YType.uint32, "external-tag")

                                            self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                            self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                            self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                            self.priority = YLeaf(YType.enumeration, "priority")

                                            self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "external-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class GraceLsa(Entity):
                                        """
                                        Grace LSA
                                        
                                        .. attribute:: grace_period
                                        
                                        	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_reason
                                        
                                        	Reason for router restart
                                        	**type**\:   :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                            self.yang_name = "grace-lsa"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.grace_period = YLeaf(YType.uint32, "grace-period")

                                            self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "grace-lsa"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, ['grace_period', 'grace_reason'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "grace-lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "grace-lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class InterAreaPrefixLsaType(Entity):
                                        """
                                        Inter Area Prefix LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: prefix
                                        
                                        	LSA address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                            self.yang_name = "inter-area-prefix-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                            self.priority = YLeaf(YType.enumeration, "priority")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "inter-area-prefix-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, ['prefix', 'prefix_length', 'priority'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class InterAreaRouterLsaType(Entity):
                                        """
                                        Inter Area Router LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                            self.yang_name = "inter-area-router-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "inter-area-router-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, ['lsa_router_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "inter-area-router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "inter-area-router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class IntraAreaPrefixLsaType(Entity):
                                        """
                                        Intra Area Prefix LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                        
                                        .. attribute:: reference_advertised_router
                                        
                                        	Reference advertised router 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                            self.yang_name = "intra-area-prefix-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)}
                                            self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix)}

                                            self.reference_advertised_router = YLeaf(YType.str, "reference-advertised-router")

                                            self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                            self.reference_type = YLeaf(YType.enumeration, "reference-type")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                            self.prefix = YList(self)
                                            self._segment_path = lambda: "intra-area-prefix-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, ['reference_advertised_router', 'reference_lsa_id', 'reference_type'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class Prefix(Entity):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.priority = YLeaf(YType.enumeration, "priority")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                    class LinkLsaType(Entity):
                                        """
                                        Link LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface handle
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_link_local
                                        
                                        	LSA link local 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                        
                                        .. attribute:: router_priority
                                        
                                        	Router priority 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                            self.yang_name = "link-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)}
                                            self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.lsa_link_local = YLeaf(YType.str, "lsa-link-local")

                                            self.router_priority = YLeaf(YType.uint8, "router-priority")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                            self.prefix = YList(self)
                                            self._segment_path = lambda: "link-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'lsa_link_local', 'router_priority', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class Prefix(Entity):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.priority = YLeaf(YType.enumeration, "priority")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                    class LsaSummaryInfo(Entity):
                                        """
                                        Summary information of LSAs
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: links
                                        
                                        	Number of links
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 address Prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                            self.yang_name = "lsa-summary-info"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.links = YLeaf(YType.uint16, "links")

                                            self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                            self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                            self.reference_type = YLeaf(YType.uint16, "reference-type")

                                            self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "lsa-summary-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, ['interface_name', 'is_sham_link', 'is_virtual_link', 'links', 'lsa_router_id', 'prefix', 'prefix_length', 'reference_lsa_id', 'reference_type', 'router_la_bits', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "lsa-summary-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "lsa-summary-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class NetworkLsaType(Entity):
                                        """
                                        Network LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                        
                                        .. attribute:: neighbor_router
                                        
                                        	Neighbor router list
                                        	**type**\:  list of str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                            self.yang_name = "network-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.neighbor_router = YLeafList(YType.str, "neighbor-router")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "network-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, ['neighbor_router'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class NssalsaType(Entity):
                                        """
                                        NSSA External LSA
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                            self.yang_name = "nssalsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.external_tag = YLeaf(YType.uint32, "external-tag")

                                            self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                            self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                            self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                            self.priority = YLeaf(YType.enumeration, "priority")

                                            self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "nssalsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "nssalsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "nssalsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class RouterLsaType(Entity):
                                        """
                                        Router LSA
                                        
                                        .. attribute:: link
                                        
                                        	List of links in this LSA
                                        	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rpf_path
                                        
                                        	Router LSA Reverse\-Path Forwarding information 
                                        	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                            self.yang_name = "router-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader), "rpf-path" : ("rpf_path", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath)}
                                            self._child_list_classes = {"link" : ("link", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link)}

                                            self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                            self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                            self.rpf_path.parent = self
                                            self._children_name_map["rpf_path"] = "rpf-path"
                                            self._children_yang_names.add("rpf-path")

                                            self.link = YList(self)
                                            self._segment_path = lambda: "router-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, ['router_la_bits'], name, value)


                                        class Link(Entity):
                                            """
                                            List of links in this LSA
                                            
                                            .. attribute:: link_interface_id
                                            
                                            	LSA link interface ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_metric
                                            
                                            	LSA link metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_neighbor_interface_id
                                            
                                            	LSA link neighbor interface ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_neighbor_router_id
                                            
                                            	LSA link neigbhor router id 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:   :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                self.yang_name = "link"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.link_interface_id = YLeaf(YType.uint32, "link-interface-id")

                                                self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                self.link_neighbor_interface_id = YLeaf(YType.uint32, "link-neighbor-interface-id")

                                                self.link_neighbor_router_id = YLeaf(YType.uint32, "link-neighbor-router-id")

                                                self.link_type = YLeaf(YType.enumeration, "link-type")
                                                self._segment_path = lambda: "link"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, ['link_interface_id', 'link_metric', 'link_neighbor_interface_id', 'link_neighbor_router_id', 'link_type'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class RpfPath(Entity):
                                            """
                                            Router LSA Reverse\-Path Forwarding information 
                                            
                                            .. attribute:: interface_name
                                            
                                            	RPF multicast IDB 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: rpf_multicast_next_hop
                                            
                                            	RPF multicast next hop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                self.yang_name = "rpf-path"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.rpf_multicast_next_hop = YLeaf(YType.uint32, "rpf-multicast-next-hop")
                                                self._segment_path = lambda: "rpf-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, ['interface_name', 'rpf_multicast_next_hop'], name, value)


                                    class UnknownAreaLsaType(Entity):
                                        """
                                        Unknown\-Area scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                            self.yang_name = "unknown-area-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "unknown-area-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-area-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-area-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class UnknownAslsaType(Entity):
                                        """
                                        Unknown\-AS scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                            self.yang_name = "unknown-aslsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "unknown-aslsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-aslsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-aslsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class UnknownLinkLsaType(Entity):
                                        """
                                        Unknown Link Scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                            self.yang_name = "unknown-link-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "unknown-link-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class UnknownLsaType(Entity):
                                        """
                                        Unknown LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                            self.yang_name = "unknown-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "unknown-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                        class LsaTable(Entity):
                            """
                            Database LSA information
                            
                            .. attribute:: lsa
                            
                            	Database LSA information
                            	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable, self).__init__()

                                self.yang_name = "lsa-table"
                                self.yang_parent_name = "database-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"lsa" : ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa)}

                                self.lsa = YList(self)
                                self._segment_path = lambda: "lsa-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable, [], name, value)


                            class Lsa(Entity):
                                """
                                Database LSA information
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: interface_name
                                
                                	InterfaceName
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                
                                .. attribute:: lsa_info
                                
                                	Summary of all LSAs or LSA specific information 
                                	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "lsa-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"lsa-info" : ("lsa_info", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo)}
                                    self._child_list_classes = {}

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.ls_id = YLeaf(YType.int32, "ls-id")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                    self.lsa_info.parent = self
                                    self._children_name_map["lsa_info"] = "lsa-info"
                                    self._children_yang_names.add("lsa-info")
                                    self._segment_path = lambda: "lsa"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                class LsaInfo(Entity):
                                    """
                                    Summary of all LSAs or LSA specific information 
                                    
                                    .. attribute:: external_lsa_type
                                    
                                    	External LSA
                                    	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                    
                                    .. attribute:: grace_lsa
                                    
                                    	Grace LSA
                                    	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                    
                                    .. attribute:: inter_area_prefix_lsa_type
                                    
                                    	Inter Area Prefix LSA
                                    	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                    
                                    .. attribute:: inter_area_router_lsa_type
                                    
                                    	Inter Area Router LSA
                                    	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                    
                                    .. attribute:: intra_area_prefix_lsa_type
                                    
                                    	Intra Area Prefix LSA
                                    	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                    
                                    .. attribute:: link_lsa_type
                                    
                                    	Link LSA
                                    	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                    
                                    .. attribute:: lsa_info_type
                                    
                                    	LSAInfoType
                                    	**type**\:   :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                    
                                    .. attribute:: lsa_summary_info
                                    
                                    	Summary information of LSAs
                                    	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                    
                                    .. attribute:: network_lsa_type
                                    
                                    	Network LSA
                                    	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                    
                                    .. attribute:: nssalsa_type
                                    
                                    	NSSA External LSA
                                    	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                    
                                    .. attribute:: router_lsa_type
                                    
                                    	Router LSA
                                    	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                    
                                    .. attribute:: unknown_area_lsa_type
                                    
                                    	Unknown\-Area scope LSA
                                    	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                    
                                    .. attribute:: unknown_aslsa_type
                                    
                                    	Unknown\-AS scope LSA
                                    	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                    
                                    .. attribute:: unknown_link_lsa_type
                                    
                                    	Unknown Link Scope LSA
                                    	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                    
                                    .. attribute:: unknown_lsa_type
                                    
                                    	Unknown LSA
                                    	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo, self).__init__()

                                        self.yang_name = "lsa-info"
                                        self.yang_parent_name = "lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType), "grace-lsa" : ("grace_lsa", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa), "inter-area-prefix-lsa-type" : ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType), "inter-area-router-lsa-type" : ("inter_area_router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType), "intra-area-prefix-lsa-type" : ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType), "link-lsa-type" : ("link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType), "lsa-summary-info" : ("lsa_summary_info", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo), "network-lsa-type" : ("network_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType), "nssalsa-type" : ("nssalsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType), "router-lsa-type" : ("router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType), "unknown-area-lsa-type" : ("unknown_area_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType), "unknown-aslsa-type" : ("unknown_aslsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType), "unknown-link-lsa-type" : ("unknown_link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType), "unknown-lsa-type" : ("unknown_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType)}
                                        self._child_list_classes = {}

                                        self.lsa_info_type = YLeaf(YType.enumeration, "lsa-info-type")

                                        self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                        self.external_lsa_type.parent = self
                                        self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                        self._children_yang_names.add("external-lsa-type")

                                        self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                        self.grace_lsa.parent = self
                                        self._children_name_map["grace_lsa"] = "grace-lsa"
                                        self._children_yang_names.add("grace-lsa")

                                        self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                        self.inter_area_prefix_lsa_type.parent = self
                                        self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"
                                        self._children_yang_names.add("inter-area-prefix-lsa-type")

                                        self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                        self.inter_area_router_lsa_type.parent = self
                                        self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"
                                        self._children_yang_names.add("inter-area-router-lsa-type")

                                        self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                        self.intra_area_prefix_lsa_type.parent = self
                                        self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"
                                        self._children_yang_names.add("intra-area-prefix-lsa-type")

                                        self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                        self.link_lsa_type.parent = self
                                        self._children_name_map["link_lsa_type"] = "link-lsa-type"
                                        self._children_yang_names.add("link-lsa-type")

                                        self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                        self.lsa_summary_info.parent = self
                                        self._children_name_map["lsa_summary_info"] = "lsa-summary-info"
                                        self._children_yang_names.add("lsa-summary-info")

                                        self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                        self.network_lsa_type.parent = self
                                        self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                        self._children_yang_names.add("network-lsa-type")

                                        self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                        self.nssalsa_type.parent = self
                                        self._children_name_map["nssalsa_type"] = "nssalsa-type"
                                        self._children_yang_names.add("nssalsa-type")

                                        self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                        self.router_lsa_type.parent = self
                                        self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                        self._children_yang_names.add("router-lsa-type")

                                        self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                        self.unknown_area_lsa_type.parent = self
                                        self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"
                                        self._children_yang_names.add("unknown-area-lsa-type")

                                        self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                        self.unknown_aslsa_type.parent = self
                                        self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"
                                        self._children_yang_names.add("unknown-aslsa-type")

                                        self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                        self.unknown_link_lsa_type.parent = self
                                        self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"
                                        self._children_yang_names.add("unknown-link-lsa-type")

                                        self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                        self.unknown_lsa_type.parent = self
                                        self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                        self._children_yang_names.add("unknown-lsa-type")
                                        self._segment_path = lambda: "lsa-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo, ['lsa_info_type'], name, value)


                                    class ExternalLsaType(Entity):
                                        """
                                        External LSA
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                            self.yang_name = "external-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.external_tag = YLeaf(YType.uint32, "external-tag")

                                            self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                            self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                            self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                            self.priority = YLeaf(YType.enumeration, "priority")

                                            self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "external-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class GraceLsa(Entity):
                                        """
                                        Grace LSA
                                        
                                        .. attribute:: grace_period
                                        
                                        	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_reason
                                        
                                        	Reason for router restart
                                        	**type**\:   :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                            self.yang_name = "grace-lsa"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.grace_period = YLeaf(YType.uint32, "grace-period")

                                            self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "grace-lsa"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, ['grace_period', 'grace_reason'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "grace-lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "grace-lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class InterAreaPrefixLsaType(Entity):
                                        """
                                        Inter Area Prefix LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: prefix
                                        
                                        	LSA address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                            self.yang_name = "inter-area-prefix-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                            self.priority = YLeaf(YType.enumeration, "priority")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "inter-area-prefix-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, ['prefix', 'prefix_length', 'priority'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class InterAreaRouterLsaType(Entity):
                                        """
                                        Inter Area Router LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                            self.yang_name = "inter-area-router-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "inter-area-router-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, ['lsa_router_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "inter-area-router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "inter-area-router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class IntraAreaPrefixLsaType(Entity):
                                        """
                                        Intra Area Prefix LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                        
                                        .. attribute:: reference_advertised_router
                                        
                                        	Reference advertised router 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                            self.yang_name = "intra-area-prefix-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)}
                                            self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix)}

                                            self.reference_advertised_router = YLeaf(YType.str, "reference-advertised-router")

                                            self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                            self.reference_type = YLeaf(YType.enumeration, "reference-type")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                            self.prefix = YList(self)
                                            self._segment_path = lambda: "intra-area-prefix-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, ['reference_advertised_router', 'reference_lsa_id', 'reference_type'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class Prefix(Entity):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.priority = YLeaf(YType.enumeration, "priority")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                    class LinkLsaType(Entity):
                                        """
                                        Link LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface handle
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_link_local
                                        
                                        	LSA link local 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                        
                                        .. attribute:: router_priority
                                        
                                        	Router priority 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                            self.yang_name = "link-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)}
                                            self._child_list_classes = {"prefix" : ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.lsa_link_local = YLeaf(YType.str, "lsa-link-local")

                                            self.router_priority = YLeaf(YType.uint8, "router-priority")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                            self.prefix = YList(self)
                                            self._segment_path = lambda: "link-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'lsa_link_local', 'router_priority', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class Prefix(Entity):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ospfv3_prefix_length = YLeaf(YType.uint8, "ospfv3-prefix-length")

                                                self.ospfv3_prefix_metric = YLeaf(YType.uint16, "ospfv3-prefix-metric")

                                                self.ospfv3_prefix_options = YLeaf(YType.uint8, "ospfv3-prefix-options")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.priority = YLeaf(YType.enumeration, "priority")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, ['ospfv3_prefix_length', 'ospfv3_prefix_metric', 'ospfv3_prefix_options', 'prefix', 'priority'], name, value)


                                    class LsaSummaryInfo(Entity):
                                        """
                                        Summary information of LSAs
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: links
                                        
                                        	Number of links
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 address Prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                            self.yang_name = "lsa-summary-info"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.links = YLeaf(YType.uint16, "links")

                                            self.lsa_router_id = YLeaf(YType.uint32, "lsa-router-id")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                            self.reference_lsa_id = YLeaf(YType.uint32, "reference-lsa-id")

                                            self.reference_type = YLeaf(YType.uint16, "reference-type")

                                            self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "lsa-summary-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, ['interface_name', 'is_sham_link', 'is_virtual_link', 'links', 'lsa_router_id', 'prefix', 'prefix_length', 'reference_lsa_id', 'reference_type', 'router_la_bits', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "lsa-summary-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "lsa-summary-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class NetworkLsaType(Entity):
                                        """
                                        Network LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                        
                                        .. attribute:: neighbor_router
                                        
                                        	Neighbor router list
                                        	**type**\:  list of str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                            self.yang_name = "network-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.neighbor_router = YLeafList(YType.str, "neighbor-router")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "network-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, ['neighbor_router'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class NssalsaType(Entity):
                                        """
                                        NSSA External LSA
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                            self.yang_name = "nssalsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.external_tag = YLeaf(YType.uint32, "external-tag")

                                            self.forwarding_address = YLeaf(YType.str, "forwarding-address")

                                            self.is_forwarding_address_set = YLeaf(YType.boolean, "is-forwarding-address-set")

                                            self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                            self.priority = YLeaf(YType.enumeration, "priority")

                                            self.tos_cost = YLeaf(YType.uint32, "tos-cost")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "nssalsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, ['external_tag', 'forwarding_address', 'is_forwarding_address_set', 'metric_type', 'prefix', 'prefix_length', 'priority', 'tos_cost'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "nssalsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "nssalsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class RouterLsaType(Entity):
                                        """
                                        Router LSA
                                        
                                        .. attribute:: link
                                        
                                        	List of links in this LSA
                                        	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rpf_path
                                        
                                        	Router LSA Reverse\-Path Forwarding information 
                                        	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                            self.yang_name = "router-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader), "rpf-path" : ("rpf_path", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath)}
                                            self._child_list_classes = {"link" : ("link", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link)}

                                            self.router_la_bits = YLeaf(YType.uint8, "router-la-bits")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                            self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                            self.rpf_path.parent = self
                                            self._children_name_map["rpf_path"] = "rpf-path"
                                            self._children_yang_names.add("rpf-path")

                                            self.link = YList(self)
                                            self._segment_path = lambda: "router-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, ['router_la_bits'], name, value)


                                        class Link(Entity):
                                            """
                                            List of links in this LSA
                                            
                                            .. attribute:: link_interface_id
                                            
                                            	LSA link interface ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_metric
                                            
                                            	LSA link metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_neighbor_interface_id
                                            
                                            	LSA link neighbor interface ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_neighbor_router_id
                                            
                                            	LSA link neigbhor router id 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:   :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                self.yang_name = "link"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.link_interface_id = YLeaf(YType.uint32, "link-interface-id")

                                                self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                self.link_neighbor_interface_id = YLeaf(YType.uint32, "link-neighbor-interface-id")

                                                self.link_neighbor_router_id = YLeaf(YType.uint32, "link-neighbor-router-id")

                                                self.link_type = YLeaf(YType.enumeration, "link-type")
                                                self._segment_path = lambda: "link"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, ['link_interface_id', 'link_metric', 'link_neighbor_interface_id', 'link_neighbor_router_id', 'link_type'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                        class RpfPath(Entity):
                                            """
                                            Router LSA Reverse\-Path Forwarding information 
                                            
                                            .. attribute:: interface_name
                                            
                                            	RPF multicast IDB 
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: rpf_multicast_next_hop
                                            
                                            	RPF multicast next hop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                self.yang_name = "rpf-path"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.rpf_multicast_next_hop = YLeaf(YType.uint32, "rpf-multicast-next-hop")
                                                self._segment_path = lambda: "rpf-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, ['interface_name', 'rpf_multicast_next_hop'], name, value)


                                    class UnknownAreaLsaType(Entity):
                                        """
                                        Unknown\-Area scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                            self.yang_name = "unknown-area-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "unknown-area-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-area-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-area-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class UnknownAslsaType(Entity):
                                        """
                                        Unknown\-AS scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                            self.yang_name = "unknown-aslsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "unknown-aslsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-aslsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-aslsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class UnknownLinkLsaType(Entity):
                                        """
                                        Unknown Link Scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                            self.yang_name = "unknown-link-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "unknown-link-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                                    class UnknownLsaType(Entity):
                                        """
                                        Unknown LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                            self.yang_name = "unknown-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail" : ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail), "lsa-header" : ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.is_sham_link = YLeaf(YType.boolean, "is-sham-link")

                                            self.is_virtual_link = YLeaf(YType.boolean, "is-virtual-link")

                                            self.sham_link_id = YLeaf(YType.uint32, "sham-link-id")

                                            self.virtual_link_id = YLeaf(YType.uint32, "virtual-link-id")

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._children_yang_names.add("lsa-detail")

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "unknown-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, ['interface_name', 'is_sham_link', 'is_virtual_link', 'sham_link_id', 'virtual_link_id'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.is_acknowledged = YLeaf(YType.boolean, "is-acknowledged")

                                                self.is_advertising_router_reachable = YLeaf(YType.boolean, "is-advertising-router-reachable")

                                                self.is_deleted = YLeaf(YType.boolean, "is-deleted")

                                                self.is_flood_pending = YLeaf(YType.boolean, "is-flood-pending")

                                                self.is_maximum_aged = YLeaf(YType.boolean, "is-maximum-aged")

                                                self.is_neighbor_exchange = YLeaf(YType.boolean, "is-neighbor-exchange")

                                                self.is_no_delete = YLeaf(YType.boolean, "is-no-delete")

                                                self.is_nsr_ack_pending = YLeaf(YType.boolean, "is-nsr-ack-pending")

                                                self.is_partial_spf = YLeaf(YType.boolean, "is-partial-spf")

                                                self.is_routing_bit = YLeaf(YType.boolean, "is-routing-bit")

                                                self.is_routing_table = YLeaf(YType.boolean, "is-routing-table")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_length = YLeaf(YType.uint16, "lsa-length")

                                                self.lsa_sync_state = YLeaf(YType.enumeration, "lsa-sync-state")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")
                                                self._segment_path = lambda: "lsa-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, ['free_time', 'is_acknowledged', 'is_advertising_router_reachable', 'is_deleted', 'is_flood_pending', 'is_maximum_aged', 'is_neighbor_exchange', 'is_no_delete', 'is_nsr_ack_pending', 'is_partial_spf', 'is_routing_bit', 'is_routing_table', 'lsa_flood_required_post_fail_over', 'lsa_length', 'lsa_sync_state', 'minute_table_index', 'nsr_flood_required', 'rate_limit', 'second_table_index'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.is_do_not_age_lsa = YLeaf(YType.boolean, "is-do-not-age-lsa")

                                                self.is_graceful_restart_active = YLeaf(YType.boolean, "is-graceful-restart-active")

                                                self.ls_id = YLeaf(YType.uint32, "ls-id")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsa_type = YLeaf(YType.uint16, "lsa-type")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, ['advertising_router', 'checksum', 'is_do_not_age_lsa', 'is_graceful_restart_active', 'ls_id', 'lsa_age', 'lsa_area_id', 'lsa_type', 'sequence_number'], name, value)


                    class ExternalRoutes(Entity):
                        """
                        OSPFv3 external route information table
                        
                        .. attribute:: external_route
                        
                        	OSPFv3 external route information
                        	**type**\: list of    :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes, self).__init__()

                            self.yang_name = "external-routes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"external-route" : ("external_route", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute)}

                            self.external_route = YList(self)
                            self._segment_path = lambda: "external-routes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes, [], name, value)


                        class ExternalRoute(Entity):
                            """
                            OSPFv3 external route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_extended_community
                            
                            	Extended communities in the route
                            	**type**\:   :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath>`
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute, self).__init__()

                                self.yang_name = "external-route"
                                self.yang_parent_name = "external-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-extended-community" : ("route_extended_community", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity), "route-topology" : ("route_topology", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                self.route_extended_community = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                self.route_extended_community.parent = self
                                self._children_name_map["route_extended_community"] = "route-extended-community"
                                self._children_yang_names.add("route-extended-community")

                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology()
                                self.route_topology.parent = self
                                self._children_name_map["route_topology"] = "route-topology"
                                self._children_yang_names.add("route-topology")

                                self.route_path = YList(self)
                                self._segment_path = lambda: "external-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute, ['prefix', 'prefix_length'], name, value)


                            class RouteExtendedCommunity(Entity):
                                """
                                Extended communities in the route
                                
                                .. attribute:: extended_community_area_id
                                
                                	Area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extended_community_options
                                
                                	Route Options
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_router_id
                                
                                	Router id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: extended_communityl_domain_id_type
                                
                                	Domain ID type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__init__()

                                    self.yang_name = "route-extended-community"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.extended_community_area_id = YLeaf(YType.uint32, "extended-community-area-id")

                                    self.extended_community_domain_id_value = YLeaf(YType.str, "extended-community-domain-id-value")

                                    self.extended_community_options = YLeaf(YType.uint8, "extended-community-options")

                                    self.extended_community_route_type = YLeaf(YType.uint8, "extended-community-route-type")

                                    self.extended_community_router_id = YLeaf(YType.str, "extended-community-router-id")

                                    self.extended_communityl_domain_id_type = YLeaf(YType.uint16, "extended-communityl-domain-id-type")
                                    self._segment_path = lambda: "route-extended-community"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, ['extended_community_area_id', 'extended_community_domain_id_value', 'extended_community_options', 'extended_community_route_type', 'extended_community_router_id', 'extended_communityl_domain_id_type'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                    self.route_path_next_hop = YLeaf(YType.str, "route-path-next-hop")

                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                    self._children_yang_names.add("route-backup-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath, ['interface_name', 'route_path_id', 'route_path_next_hop'], name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                        self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                        self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                        self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                        self.downstream = YLeaf(YType.boolean, "downstream")

                                        self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                        self.node_protect = YLeaf(YType.boolean, "node-protect")

                                        self.primary_path = YLeaf(YType.boolean, "primary-path")

                                        self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")
                                        self._segment_path = lambda: "route-backup-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                            class RouteTopology(Entity):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology, self).__init__()

                                    self.yang_name = "route-topology"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.route_cost = YLeaf(YType.uint32, "route-cost")

                                    self.route_distance = YLeaf(YType.uint32, "route-distance")

                                    self.route_id = YLeaf(YType.str, "route-id")

                                    self.route_type = YLeaf(YType.uint32, "route-type")
                                    self._segment_path = lambda: "route-topology"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology, ['route_cost', 'route_distance', 'route_id', 'route_type'], name, value)


                    class FastReroutes(Entity):
                        """
                        OSPFv3 fast reroute topology information table
                        
                        .. attribute:: fast_reroute
                        
                        	OSPFv3 fast reroute topology information
                        	**type**\: list of    :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes, self).__init__()

                            self.yang_name = "fast-reroutes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"fast-reroute" : ("fast_reroute", Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute)}

                            self.fast_reroute = YList(self)
                            self._segment_path = lambda: "fast-reroutes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes, [], name, value)


                        class FastReroute(Entity):
                            """
                            OSPFv3 fast reroute topology information
                            
                            .. attribute:: area_id
                            
                            	AreaID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ipfrr_area_revision
                            
                            	IPFRR Topology Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipfrr_router_id
                            
                            	OSPF Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipfrr_topo
                            
                            	IPFRR Topology entries
                            	**type**\: list of    :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo>`
                            
                            .. attribute:: ipfrr_topo_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute, self).__init__()

                                self.yang_name = "fast-reroute"
                                self.yang_parent_name = "fast-reroutes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ipfrr-topo" : ("ipfrr_topo", Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo)}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.ipfrr_area_revision = YLeaf(YType.uint32, "ipfrr-area-revision")

                                self.ipfrr_router_id = YLeaf(YType.str, "ipfrr-router-id")

                                self.ipfrr_topo_area_id = YLeaf(YType.str, "ipfrr-topo-area-id")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.ipfrr_topo = YList(self)
                                self._segment_path = lambda: "fast-reroute"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute, ['area_id', 'ipfrr_area_revision', 'ipfrr_router_id', 'ipfrr_topo_area_id', 'router_id'], name, value)


                            class IpfrrTopo(Entity):
                                """
                                IPFRR Topology entries
                                
                                .. attribute:: distance
                                
                                	IPFRR Topology Distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dr
                                
                                	IPFRR Topology DR entry
                                	**type**\:  bool
                                
                                .. attribute:: lsaid
                                
                                	IPFRR Topology LSA ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_sourced
                                
                                	IPFRR Topology Neighbor Sourced
                                	**type**\:  bool
                                
                                .. attribute:: node_id
                                
                                	IPFRR Topology Node ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: revision
                                
                                	IPFRR Topology Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: type4
                                
                                	IPFRR Topoogy Type\-4 entry
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo, self).__init__()

                                    self.yang_name = "ipfrr-topo"
                                    self.yang_parent_name = "fast-reroute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.distance = YLeaf(YType.uint32, "distance")

                                    self.dr = YLeaf(YType.boolean, "dr")

                                    self.lsaid = YLeaf(YType.uint32, "lsaid")

                                    self.neighbor_sourced = YLeaf(YType.boolean, "neighbor-sourced")

                                    self.node_id = YLeaf(YType.str, "node-id")

                                    self.revision = YLeaf(YType.uint32, "revision")

                                    self.type4 = YLeaf(YType.boolean, "type4")
                                    self._segment_path = lambda: "ipfrr-topo"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo, ['distance', 'dr', 'lsaid', 'neighbor_sourced', 'node_id', 'revision', 'type4'], name, value)


                    class FloodListProcessTable(Entity):
                        """
                        OSPFv3 flood list information table for all
                        areas
                        
                        .. attribute:: flood
                        
                        	OSPFv3 flood list information
                        	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable, self).__init__()

                            self.yang_name = "flood-list-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flood" : ("flood", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood)}

                            self.flood = YList(self)
                            self._segment_path = lambda: "flood-list-process-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable, [], name, value)


                        class Flood(Entity):
                            """
                            OSPFv3 flood list information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: area_flood
                            
                            	Area scope floodlist
                            	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood>`
                            
                            .. attribute:: as_flood
                            
                            	AS scope floodlist
                            	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood>`
                            
                            .. attribute:: link_flood
                            
                            	Link floodlist
                            	**type**\: list of    :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood>`
                            
                            .. attribute:: ls_transmission_timer
                            
                            	Time until next LS transmission (ms) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: queue_length
                            
                            	Number of LSAs currently being flooded 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood, self).__init__()

                                self.yang_name = "flood"
                                self.yang_parent_name = "flood-list-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-flood" : ("area_flood", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood), "as-flood" : ("as_flood", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood), "link-flood" : ("link_flood", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.ls_transmission_timer = YLeaf(YType.uint32, "ls-transmission-timer")

                                self.queue_length = YLeaf(YType.uint32, "queue-length")

                                self.area_flood = YList(self)
                                self.as_flood = YList(self)
                                self.link_flood = YList(self)
                                self._segment_path = lambda: "flood" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood, ['interface_name', 'ls_transmission_timer', 'queue_length'], name, value)


                            class AreaFlood(Entity):
                                """
                                Area scope floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood, self).__init__()

                                    self.yang_name = "area-flood"
                                    self.yang_parent_name = "flood"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                    self._segment_path = lambda: "area-flood"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class AsFlood(Entity):
                                """
                                AS scope floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood, self).__init__()

                                    self.yang_name = "as-flood"
                                    self.yang_parent_name = "flood"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                    self._segment_path = lambda: "as-flood"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class LinkFlood(Entity):
                                """
                                Link floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood, self).__init__()

                                    self.yang_name = "link-flood"
                                    self.yang_parent_name = "flood"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                    self._segment_path = lambda: "link-flood"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                    class InterfaceBriefProcessTable(Entity):
                        """
                        OSPFv3 interface brief information table for all
                        areas
                        
                        .. attribute:: interface_brief
                        
                        	Interface brief information
                        	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable, self).__init__()

                            self.yang_name = "interface-brief-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"interface-brief" : ("interface_brief", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief)}

                            self.interface_brief = YList(self)
                            self._segment_path = lambda: "interface-brief-process-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable, [], name, value)


                        class InterfaceBrief(Entity):
                            """
                            Interface brief information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: interface_address
                            
                            	Interface IP address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_adjacent_neighbors
                            
                            	Total number of adjacent neighbors
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_neighbors
                            
                            	Total number of neighbors 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: network_type
                            
                            	Network type
                            	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface OSPF state
                            	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief, self).__init__()

                                self.yang_name = "interface-brief"
                                self.yang_parent_name = "interface-brief-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_adjacent_neighbors = YLeaf(YType.uint16, "interface-adjacent-neighbors")

                                self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                self.interface_neighbors = YLeaf(YType.uint16, "interface-neighbors")

                                self.network_type = YLeaf(YType.enumeration, "network-type")

                                self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                self._segment_path = lambda: "interface-brief" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief, ['interface_name', 'interface_address', 'interface_adjacent_neighbors', 'interface_link_cost', 'interface_neighbors', 'network_type', 'ospf_interface_state'], name, value)


                    class InterfaceProcessTable(Entity):
                        """
                        OSPFv3 interface information table for all areas
                        
                        .. attribute:: interface
                        
                        	OSPFv3 interface information
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable, self).__init__()

                            self.yang_name = "interface-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"interface" : ("interface", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface)}

                            self.interface = YList(self)
                            self._segment_path = lambda: "interface-process-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable, [], name, value)


                        class Interface(Entity):
                            """
                            OSPFv3 interface information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: active_interface
                            
                            	Active interface details 
                            	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface>`
                            
                            .. attribute:: adjacent_neighbor
                            
                            	Number of adjacent neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: backup_designated_router_address
                            
                            	Backup designated router interface address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: backup_designated_router_id
                            
                            	Backup designated router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: configured_ldp_sync
                            
                            	If true, configured as LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: dead_interval
                            
                            	Configured dead interval (s) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: designated_router_address
                            
                            	Designated router interface address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: designated_router_id
                            
                            	Designated router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: hello_interval
                            
                            	Configured hello interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_address
                            
                            	Interface IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_authentication_spi
                            
                            	Interface authentication spi 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_authentication_transmit
                            
                            	Interface authentication transmit 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_bfd
                            
                            	BFD information 
                            	**type**\:   :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd>`
                            
                            .. attribute:: interface_dc_bitless_ls_as
                            
                            	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_encrypted_authentication_transmitted
                            
                            	Interface encrypted authentication transmitted 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_encryption_spi
                            
                            	Interface encryption spi
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_encryption_transmitted
                            
                            	Interface encryption transmitted 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_ldp_sync
                            
                            	If true, interface LDP sync is achieved
                            	**type**\:  bool
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_neighbor
                            
                            	Information for neighbors on the interface
                            	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor>`
                            
                            .. attribute:: interface_number
                            
                            	Interface number 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_priority
                            
                            	Interface priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_references
                            
                            	Interface reference count 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_retransmission_interval
                            
                            	Configured retransmit interval (s) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_router_id
                            
                            	Interface router ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_state
                            
                            	Interface state
                            	**type**\:   :py:class:`ImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnum>`
                            
                            .. attribute:: is_demand_circuit_configured
                            
                            	If true, configured as demand circuit 
                            	**type**\:  bool
                            
                            .. attribute:: is_designated_router
                            
                            	If true, designated router
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_demand_circuit
                            
                            	If true, interface running as demand circuit
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_encryption_enabled
                            
                            	If true, interface encryption is enabled 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_flood_reduction
                            
                            	If true, interface flood reduction is active 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_ip_security_active
                            
                            	If true, interface IP security is active 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_ip_security_required
                            
                            	If true, interface IP security is required 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_line_up
                            
                            	If true, line protocol is up 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_lsa_filtered
                            
                            	Filter is configured for out going LSAs 
                            	**type**\:  bool
                            
                            .. attribute:: is_prefix_suppress
                            
                            	If true prefix suppression is enabled
                            	**type**\:  bool
                            
                            .. attribute:: network_lsa_flush_timer
                            
                            	The amount of time in seconds before flush timer for old network LSA expires 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: network_type
                            
                            	Network type
                            	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                            
                            .. attribute:: next_hello_time
                            
                            	Time until next Hello (s) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface state
                            	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                            
                            .. attribute:: transmission_delay
                            
                            	Interface transmission delay (sec)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: wait_interval
                            
                            	Configured wait interval (s) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interface-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"active-interface" : ("active_interface", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface), "interface-bfd" : ("interface_bfd", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd)}
                                self._child_list_classes = {"interface-neighbor" : ("interface_neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.adjacent_neighbor = YLeaf(YType.uint32, "adjacent-neighbor")

                                self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_authentication_spi = YLeaf(YType.uint32, "interface-authentication-spi")

                                self.interface_authentication_transmit = YLeaf(YType.uint32, "interface-authentication-transmit")

                                self.interface_dc_bitless_ls_as = YLeaf(YType.uint32, "interface-dc-bitless-ls-as")

                                self.interface_encrypted_authentication_transmitted = YLeaf(YType.uint32, "interface-encrypted-authentication-transmitted")

                                self.interface_encryption_spi = YLeaf(YType.uint32, "interface-encryption-spi")

                                self.interface_encryption_transmitted = YLeaf(YType.uint32, "interface-encryption-transmitted")

                                self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                self.interface_number = YLeaf(YType.uint32, "interface-number")

                                self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                self.interface_references = YLeaf(YType.uint32, "interface-references")

                                self.interface_retransmission_interval = YLeaf(YType.uint32, "interface-retransmission-interval")

                                self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                self.is_demand_circuit_configured = YLeaf(YType.boolean, "is-demand-circuit-configured")

                                self.is_designated_router = YLeaf(YType.boolean, "is-designated-router")

                                self.is_interface_demand_circuit = YLeaf(YType.boolean, "is-interface-demand-circuit")

                                self.is_interface_encryption_enabled = YLeaf(YType.boolean, "is-interface-encryption-enabled")

                                self.is_interface_flood_reduction = YLeaf(YType.boolean, "is-interface-flood-reduction")

                                self.is_interface_ip_security_active = YLeaf(YType.boolean, "is-interface-ip-security-active")

                                self.is_interface_ip_security_required = YLeaf(YType.boolean, "is-interface-ip-security-required")

                                self.is_interface_line_up = YLeaf(YType.boolean, "is-interface-line-up")

                                self.is_interface_lsa_filtered = YLeaf(YType.boolean, "is-interface-lsa-filtered")

                                self.is_prefix_suppress = YLeaf(YType.boolean, "is-prefix-suppress")

                                self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                self.network_type = YLeaf(YType.enumeration, "network-type")

                                self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                self.active_interface = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface()
                                self.active_interface.parent = self
                                self._children_name_map["active_interface"] = "active-interface"
                                self._children_yang_names.add("active-interface")

                                self.interface_bfd = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd()
                                self.interface_bfd.parent = self
                                self._children_name_map["interface_bfd"] = "interface-bfd"
                                self._children_yang_names.add("interface-bfd")

                                self.interface_neighbor = YList(self)
                                self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface, ['interface_name', 'adjacent_neighbor', 'backup_designated_router_address', 'backup_designated_router_id', 'configured_ldp_sync', 'dead_interval', 'designated_router_address', 'designated_router_id', 'hello_interval', 'interface_address', 'interface_authentication_spi', 'interface_authentication_transmit', 'interface_dc_bitless_ls_as', 'interface_encrypted_authentication_transmitted', 'interface_encryption_spi', 'interface_encryption_transmitted', 'interface_ldp_sync', 'interface_link_cost', 'interface_number', 'interface_priority', 'interface_references', 'interface_retransmission_interval', 'interface_router_id', 'interface_state', 'is_demand_circuit_configured', 'is_designated_router', 'is_interface_demand_circuit', 'is_interface_encryption_enabled', 'is_interface_flood_reduction', 'is_interface_ip_security_active', 'is_interface_ip_security_required', 'is_interface_line_up', 'is_interface_lsa_filtered', 'is_prefix_suppress', 'network_lsa_flush_timer', 'network_type', 'next_hello_time', 'ospf_interface_state', 'transmission_delay', 'wait_interval'], name, value)


                            class ActiveInterface(Entity):
                                """
                                Active interface details 
                                
                                .. attribute:: flood_queue_length
                                
                                	Flood queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flood_scan_length
                                
                                	Last flood scan length 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_flood_index
                                
                                	Area scope LSAs flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood
                                
                                	Next LSA to flood (Area scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood_index
                                
                                	Index of next LSA to flood (Area scope) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_flood_index
                                
                                	AS scope LSAs flood index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood
                                
                                	Next LSA to flood (AS scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood_index
                                
                                	Index of next LSA to flood (AS scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_flood_pacing_timer
                                
                                	Time until next flood pacing timer (ms) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_flood_index
                                
                                	Interface flood link index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_next_flood
                                
                                	Interface link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_next_index
                                
                                	Interface link next information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbors
                                
                                	Total number of neighbors 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: last_flood_time
                                
                                	Last flood scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_length
                                
                                	Maximum flood length 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_time
                                
                                	Maximum flood time (ms) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: suppressed_hellos
                                
                                	Number of neighbors for which hellos are suppressed 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: wait_time
                                
                                	Wait time for DR/BDR selection (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface, self).__init__()

                                    self.yang_name = "active-interface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.flood_queue_length = YLeaf(YType.uint32, "flood-queue-length")

                                    self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                    self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                    self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                    self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                    self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                    self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                    self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                    self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                    self.interface_link_flood_index = YLeaf(YType.uint32, "interface-link-flood-index")

                                    self.interface_link_next_flood = YLeaf(YType.uint32, "interface-link-next-flood")

                                    self.interface_link_next_index = YLeaf(YType.uint32, "interface-link-next-index")

                                    self.interface_neighbors = YLeaf(YType.uint16, "interface-neighbors")

                                    self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                    self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                    self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                    self.suppressed_hellos = YLeaf(YType.uint16, "suppressed-hellos")

                                    self.wait_time = YLeaf(YType.uint32, "wait-time")
                                    self._segment_path = lambda: "active-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface, ['flood_queue_length', 'flood_scan_length', 'interface_area_flood_index', 'interface_area_next_flood', 'interface_area_next_flood_index', 'interface_as_flood_index', 'interface_as_next_flood', 'interface_as_next_flood_index', 'interface_flood_pacing_timer', 'interface_link_flood_index', 'interface_link_next_flood', 'interface_link_next_index', 'interface_neighbors', 'last_flood_time', 'maximum_flood_length', 'maximum_flood_time', 'suppressed_hellos', 'wait_time'], name, value)


                            class InterfaceBfd(Entity):
                                """
                                BFD information 
                                
                                .. attribute:: bfd_detection_multiplier
                                
                                	BFD detection multiplier 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_interval
                                
                                	BFD interval (ms) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD Enable Mode on the interface \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd, self).__init__()

                                    self.yang_name = "interface-bfd"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bfd_detection_multiplier = YLeaf(YType.uint32, "bfd-detection-multiplier")

                                    self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")
                                    self._segment_path = lambda: "interface-bfd"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd, ['bfd_detection_multiplier', 'bfd_interval', 'bfd_intf_enable_mode'], name, value)


                            class InterfaceNeighbor(Entity):
                                """
                                Information for neighbors on the interface
                                
                                .. attribute:: interface_neighbor_cost
                                
                                	Cost of link to neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbor_id
                                
                                	Neighbor router ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_hello_suppressed
                                
                                	If true, hello is suppressed 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_bdr
                                
                                	If true, backup designated router is found 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_dr
                                
                                	If true, designated router is found 
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor, self).__init__()

                                    self.yang_name = "interface-neighbor"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                    self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                    self.is_hello_suppressed = YLeaf(YType.boolean, "is-hello-suppressed")

                                    self.is_neighbor_bdr = YLeaf(YType.boolean, "is-neighbor-bdr")

                                    self.is_neighbor_dr = YLeaf(YType.boolean, "is-neighbor-dr")
                                    self._segment_path = lambda: "interface-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor, ['interface_neighbor_cost', 'interface_neighbor_id', 'is_hello_suppressed', 'is_neighbor_bdr', 'is_neighbor_dr'], name, value)


                    class InternalRoutes(Entity):
                        """
                        OSPFv3 internal route information table
                        
                        .. attribute:: internal_route
                        
                        	OSPFv3 internal route information
                        	**type**\: list of    :py:class:`InternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes, self).__init__()

                            self.yang_name = "internal-routes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"internal-route" : ("internal_route", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute)}

                            self.internal_route = YList(self)
                            self._segment_path = lambda: "internal-routes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes, [], name, value)


                        class InternalRoute(Entity):
                            """
                            OSPFv3 internal route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_area_id
                            
                            	Route area ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath>`
                            
                            .. attribute:: route_source
                            
                            	List of topology source information
                            	**type**\: list of    :py:class:`RouteSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource>`
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute, self).__init__()

                                self.yang_name = "internal-route"
                                self.yang_parent_name = "internal-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-topology" : ("route_topology", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath), "route-source" : ("route_source", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology()
                                self.route_topology.parent = self
                                self._children_name_map["route_topology"] = "route-topology"
                                self._children_yang_names.add("route-topology")

                                self.route_path = YList(self)
                                self.route_source = YList(self)
                                self._segment_path = lambda: "internal-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute, ['prefix', 'prefix_length', 'route_area_id'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "internal-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                    self.route_path_next_hop = YLeaf(YType.str, "route-path-next-hop")

                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                    self._children_yang_names.add("route-backup-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath, ['interface_name', 'route_path_id', 'route_path_next_hop'], name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                        self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                        self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                        self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                        self.downstream = YLeaf(YType.boolean, "downstream")

                                        self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                        self.node_protect = YLeaf(YType.boolean, "node-protect")

                                        self.primary_path = YLeaf(YType.boolean, "primary-path")

                                        self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")
                                        self._segment_path = lambda: "route-backup-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                            class RouteSource(Entity):
                                """
                                List of topology source information
                                
                                .. attribute:: route_source_adversting_router
                                
                                	Route source of the advertising router 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_source_id
                                
                                	Route source ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_source_lsa_type
                                
                                	Type of LSA advertising the prefix, see RFC5340
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource, self).__init__()

                                    self.yang_name = "route-source"
                                    self.yang_parent_name = "internal-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.route_source_adversting_router = YLeaf(YType.str, "route-source-adversting-router")

                                    self.route_source_id = YLeaf(YType.str, "route-source-id")

                                    self.route_source_lsa_type = YLeaf(YType.uint32, "route-source-lsa-type")
                                    self._segment_path = lambda: "route-source"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource, ['route_source_adversting_router', 'route_source_id', 'route_source_lsa_type'], name, value)


                            class RouteTopology(Entity):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology, self).__init__()

                                    self.yang_name = "route-topology"
                                    self.yang_parent_name = "internal-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.route_cost = YLeaf(YType.uint32, "route-cost")

                                    self.route_distance = YLeaf(YType.uint32, "route-distance")

                                    self.route_id = YLeaf(YType.str, "route-id")

                                    self.route_type = YLeaf(YType.uint32, "route-type")
                                    self._segment_path = lambda: "route-topology"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology, ['route_cost', 'route_distance', 'route_id', 'route_type'], name, value)


                    class NeighborDetailProcessTable(Entity):
                        """
                        OSPFv3 neighbor information table for all areas
                        
                        .. attribute:: neighbor_detail
                        
                        	OSPFv3 neighbor detail information
                        	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable, self).__init__()

                            self.yang_name = "neighbor-detail-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail)}

                            self.neighbor_detail = YList(self)
                            self._segment_path = lambda: "neighbor-detail-process-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable, [], name, value)


                        class NeighborDetail(Entity):
                            """
                            OSPFv3 neighbor detail information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_neighbor_sham_link
                            
                            	If true, neighbor is on a sham link 
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_virtual_link
                            
                            	If true, neighbor is on a virtual link 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor IP Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_bfd_info
                            
                            	Neighbor BFD information
                            	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo>`
                            
                            .. attribute:: neighbor_dead_timer
                            
                            	Time until neighbor's dead timer expires (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_designated_router
                            
                            	Designated router 
                            	**type**\:  str
                            
                            	**length:** 0..9
                            
                            .. attribute:: neighbor_detail
                            
                            	Detailed OSPFv3 neighbor information 
                            	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail>`
                            
                            .. attribute:: neighbor_dr_priority
                            
                            	Neighbor's DR priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_interface_id
                            
                            	Neighbor interface ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_sham_link_id
                            
                            	Neighbor sham link id 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_state
                            
                            	Neighbor's state
                            	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                            
                            .. attribute:: neighbor_up_time
                            
                            	Amount of time since the adjacency is up (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_virtual_link_id
                            
                            	Neighbor virtual link id 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail, self).__init__()

                                self.yang_name = "neighbor-detail"
                                self.yang_parent_name = "neighbor-detail-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"neighbor-bfd-info" : ("neighbor_bfd_info", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo), "neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail)}
                                self._child_list_classes = {}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_neighbor_sham_link = YLeaf(YType.boolean, "is-neighbor-sham-link")

                                self.is_neighbor_virtual_link = YLeaf(YType.boolean, "is-neighbor-virtual-link")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                self.neighbor_designated_router = YLeaf(YType.str, "neighbor-designated-router")

                                self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                self.neighbor_interface_id = YLeaf(YType.uint32, "neighbor-interface-id")

                                self.neighbor_sham_link_id = YLeaf(YType.uint32, "neighbor-sham-link-id")

                                self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                self.neighbor_virtual_link_id = YLeaf(YType.uint32, "neighbor-virtual-link-id")

                                self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo()
                                self.neighbor_bfd_info.parent = self
                                self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                self._children_yang_names.add("neighbor-bfd-info")

                                self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail()
                                self.neighbor_detail.parent = self
                                self._children_name_map["neighbor_detail"] = "neighbor-detail"
                                self._children_yang_names.add("neighbor-detail")
                                self._segment_path = lambda: "neighbor-detail"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail, ['interface_name', 'is_neighbor_sham_link', 'is_neighbor_virtual_link', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_designated_router', 'neighbor_dr_priority', 'neighbor_interface_id', 'neighbor_sham_link_id', 'neighbor_state', 'neighbor_up_time', 'neighbor_virtual_link_id'], name, value)


                            class NeighborBfdInfo(Entity):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo, self).__init__()

                                    self.yang_name = "neighbor-bfd-info"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                    self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                    self._segment_path = lambda: "neighbor-bfd-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                            class NeighborDetail(Entity):
                                """
                                Detailed OSPFv3 neighbor information 
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                
                                .. attribute:: is_neighbor_filtered
                                
                                	If true, filter outgoing LSAs 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_ignore_timer
                                
                                	Remaining time when ignore timer is running 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmask of neighbor's option field received 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmission
                                
                                	Retransmission information with this neighbor
                                	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission>`
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_changes
                                
                                	Number of state changes 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-retransmission" : ("neighbor_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission)}
                                    self._child_list_classes = {}

                                    self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                    self.is_neighbor_filtered = YLeaf(YType.boolean, "is-neighbor-filtered")

                                    self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                    self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                    self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                    self.neighbor_ignore_timer = YLeaf(YType.uint32, "neighbor-ignore-timer")

                                    self.neighbor_option = YLeaf(YType.uint32, "neighbor-option")

                                    self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                    self.pending_events = YLeaf(YType.uint16, "pending-events")

                                    self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                    self.state_changes = YLeaf(YType.uint16, "state-changes")

                                    self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission()
                                    self.neighbor_retransmission.parent = self
                                    self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                    self._children_yang_names.add("neighbor-retransmission")
                                    self._segment_path = lambda: "neighbor-detail"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail, ['interface_type', 'is_neighbor_filtered', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_ignore_timer', 'neighbor_option', 'next_poll_interval', 'pending_events', 'poll_interval', 'state_changes'], name, value)


                                class NeighborRetransmission(Entity):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: area_first_flood
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flood_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: database_descriptor_retransmissions
                                    
                                    	Number of database descriptor retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood
                                    
                                    	Link first flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood_index
                                    
                                    	Link first flood information index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_flood_index
                                    
                                    	Link flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood
                                    
                                    	Link next flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood_index
                                    
                                    	Link next flood information index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmissions
                                    
                                    	Number of neighbor retransmissions 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission, self).__init__()

                                        self.yang_name = "neighbor-retransmission"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                        self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                        self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                        self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                        self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                        self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                        self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                        self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                        self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                        self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                        self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                        self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                        self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                        self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                        self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                        self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                        self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                        self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                        self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                        self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                        self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                        self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                        self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                        self._segment_path = lambda: "neighbor-retransmission"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail.NeighborRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                    class NeighborProcessTable(Entity):
                        """
                        OSPFv3 neighbor information table for all areas
                        
                        .. attribute:: neighbor
                        
                        	OSPFv3 neighbor detail information
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable, self).__init__()

                            self.yang_name = "neighbor-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor" : ("neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor)}

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbor-process-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable, [], name, value)


                        class Neighbor(Entity):
                            """
                            OSPFv3 neighbor detail information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_neighbor_sham_link
                            
                            	If true, neighbor is on a sham link 
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_virtual_link
                            
                            	If true, neighbor is on a virtual link 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor IP Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_bfd_info
                            
                            	Neighbor BFD information
                            	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo>`
                            
                            .. attribute:: neighbor_dead_timer
                            
                            	Time until neighbor's dead timer expires (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_designated_router
                            
                            	Designated router 
                            	**type**\:  str
                            
                            	**length:** 0..9
                            
                            .. attribute:: neighbor_detail
                            
                            	Detailed OSPFv3 neighbor information 
                            	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail>`
                            
                            .. attribute:: neighbor_dr_priority
                            
                            	Neighbor's DR priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_interface_id
                            
                            	Neighbor interface ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_sham_link_id
                            
                            	Neighbor sham link id 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_state
                            
                            	Neighbor's state
                            	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                            
                            .. attribute:: neighbor_up_time
                            
                            	Amount of time since the adjacency is up (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_virtual_link_id
                            
                            	Neighbor virtual link id 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbor-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"neighbor-bfd-info" : ("neighbor_bfd_info", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo), "neighbor-detail" : ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail)}
                                self._child_list_classes = {}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_neighbor_sham_link = YLeaf(YType.boolean, "is-neighbor-sham-link")

                                self.is_neighbor_virtual_link = YLeaf(YType.boolean, "is-neighbor-virtual-link")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                self.neighbor_designated_router = YLeaf(YType.str, "neighbor-designated-router")

                                self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                self.neighbor_interface_id = YLeaf(YType.uint32, "neighbor-interface-id")

                                self.neighbor_sham_link_id = YLeaf(YType.uint32, "neighbor-sham-link-id")

                                self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                self.neighbor_virtual_link_id = YLeaf(YType.uint32, "neighbor-virtual-link-id")

                                self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo()
                                self.neighbor_bfd_info.parent = self
                                self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                self._children_yang_names.add("neighbor-bfd-info")

                                self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail()
                                self.neighbor_detail.parent = self
                                self._children_name_map["neighbor_detail"] = "neighbor-detail"
                                self._children_yang_names.add("neighbor-detail")
                                self._segment_path = lambda: "neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor, ['interface_name', 'is_neighbor_sham_link', 'is_neighbor_virtual_link', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_designated_router', 'neighbor_dr_priority', 'neighbor_interface_id', 'neighbor_sham_link_id', 'neighbor_state', 'neighbor_up_time', 'neighbor_virtual_link_id'], name, value)


                            class NeighborBfdInfo(Entity):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo, self).__init__()

                                    self.yang_name = "neighbor-bfd-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                    self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                    self._segment_path = lambda: "neighbor-bfd-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                            class NeighborDetail(Entity):
                                """
                                Detailed OSPFv3 neighbor information 
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:   :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                
                                .. attribute:: is_neighbor_filtered
                                
                                	If true, filter outgoing LSAs 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_ignore_timer
                                
                                	Remaining time when ignore timer is running 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmask of neighbor's option field received 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmission
                                
                                	Retransmission information with this neighbor
                                	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_changes
                                
                                	Number of state changes 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-retransmission" : ("neighbor_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission)}
                                    self._child_list_classes = {}

                                    self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                    self.is_neighbor_filtered = YLeaf(YType.boolean, "is-neighbor-filtered")

                                    self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                    self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                    self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                    self.neighbor_ignore_timer = YLeaf(YType.uint32, "neighbor-ignore-timer")

                                    self.neighbor_option = YLeaf(YType.uint32, "neighbor-option")

                                    self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                    self.pending_events = YLeaf(YType.uint16, "pending-events")

                                    self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                    self.state_changes = YLeaf(YType.uint16, "state-changes")

                                    self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                    self.neighbor_retransmission.parent = self
                                    self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                    self._children_yang_names.add("neighbor-retransmission")
                                    self._segment_path = lambda: "neighbor-detail"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail, ['interface_type', 'is_neighbor_filtered', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_ignore_timer', 'neighbor_option', 'next_poll_interval', 'pending_events', 'poll_interval', 'state_changes'], name, value)


                                class NeighborRetransmission(Entity):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: area_first_flood
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flood_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: database_descriptor_retransmissions
                                    
                                    	Number of database descriptor retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood
                                    
                                    	Link first flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood_index
                                    
                                    	Link first flood information index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_flood_index
                                    
                                    	Link flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood
                                    
                                    	Link next flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood_index
                                    
                                    	Link next flood information index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmissions
                                    
                                    	Number of neighbor retransmissions 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission, self).__init__()

                                        self.yang_name = "neighbor-retransmission"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                        self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                        self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                        self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                        self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                        self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                        self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                        self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                        self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                        self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                        self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                        self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                        self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                        self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                        self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                        self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                        self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                        self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                        self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                        self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                        self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                        self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                        self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                        self._segment_path = lambda: "neighbor-retransmission"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                    class ProtocolAreas(Entity):
                        """
                        Protocol area table 
                        
                        .. attribute:: protocol_area
                        
                        	Area information 
                        	**type**\: list of    :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas, self).__init__()

                            self.yang_name = "protocol-areas"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"protocol-area" : ("protocol_area", Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea)}

                            self.protocol_area = YList(self)
                            self._segment_path = lambda: "protocol-areas"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas, [], name, value)


                        class ProtocolArea(Entity):
                            """
                            Area information 
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: protocol_area_id
                            
                            	Area ID string in decimal and dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: protocol_interface
                            
                            	Interface list
                            	**type**\: list of    :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea, self).__init__()

                                self.yang_name = "protocol-area"
                                self.yang_parent_name = "protocol-areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"protocol-interface" : ("protocol_interface", Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface)}

                                self.area_id = YLeaf(YType.str, "area-id")

                                self.distribute_list_in = YLeaf(YType.str, "distribute-list-in")

                                self.protocol_area_id = YLeaf(YType.str, "protocol-area-id")

                                self.protocol_interface = YList(self)
                                self._segment_path = lambda: "protocol-area" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea, ['area_id', 'distribute_list_in', 'protocol_area_id'], name, value)


                            class ProtocolInterface(Entity):
                                """
                                Interface list
                                
                                .. attribute:: distribute_list_in
                                
                                	Distribute List In
                                	**type**\:  str
                                
                                .. attribute:: interface_name
                                
                                	Protocol interface name 
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__init__()

                                    self.yang_name = "protocol-interface"
                                    self.yang_parent_name = "protocol-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.distribute_list_in = YLeaf(YType.str, "distribute-list-in")

                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                    self._segment_path = lambda: "protocol-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface, ['distribute_list_in', 'interface_name'], name, value)


                    class Redistributions(Entity):
                        """
                        Redistribution information table
                        
                        .. attribute:: redistribution
                        
                        	Redistribution information
                        	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions, self).__init__()

                            self.yang_name = "redistributions"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"redistribution" : ("redistribution", Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution)}

                            self.redistribution = YList(self)
                            self._segment_path = lambda: "redistributions"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions, [], name, value)


                        class Redistribution(Entity):
                            """
                            Redistribution information
                            
                            .. attribute:: policy_name
                            
                            	Route policy name 
                            	**type**\:  str
                            
                            .. attribute:: process_id
                            
                            	Process ID 
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: process_name
                            
                            	Process name of a protocolbeing redistributed 
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: protocol_name
                            
                            	Protocol name that is redistributed
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: protocol_name_xr
                            
                            	Protocol name 
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: red_metric
                            
                            	red metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: red_metric_flag
                            
                            	red metric flag
                            	**type**\:  bool
                            
                            .. attribute:: red_metric_type
                            
                            	red metric type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: red_mtype_flag
                            
                            	red mtype flag
                            	**type**\:  bool
                            
                            .. attribute:: red_tag
                            
                            	red tag
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution, self).__init__()

                                self.yang_name = "redistribution"
                                self.yang_parent_name = "redistributions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.process_id = YLeaf(YType.str, "process-id")

                                self.process_name = YLeaf(YType.str, "process-name")

                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                self.protocol_name_xr = YLeaf(YType.str, "protocol-name-xr")

                                self.red_metric = YLeaf(YType.uint32, "red-metric")

                                self.red_metric_flag = YLeaf(YType.boolean, "red-metric-flag")

                                self.red_metric_type = YLeaf(YType.uint8, "red-metric-type")

                                self.red_mtype_flag = YLeaf(YType.boolean, "red-mtype-flag")

                                self.red_tag = YLeaf(YType.uint32, "red-tag")
                                self._segment_path = lambda: "redistribution"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution, ['policy_name', 'process_id', 'process_name', 'protocol_name', 'protocol_name_xr', 'red_metric', 'red_metric_flag', 'red_metric_type', 'red_mtype_flag', 'red_tag'], name, value)


                    class RequestListProcessTable(Entity):
                        """
                        OSPFv3 request list information for all areas
                        
                        .. attribute:: request
                        
                        	OSPFv3 request list information
                        	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable, self).__init__()

                            self.yang_name = "request-list-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"request" : ("request", Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request)}

                            self.request = YList(self)
                            self._segment_path = lambda: "request-list-process-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable, [], name, value)


                        class Request(Entity):
                            """
                            OSPFv3 request list information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_request_sham_link
                            
                            	If true, sham link is requested 
                            	**type**\:  bool
                            
                            .. attribute:: is_request_virtual_link
                            
                            	If true, virtual link is requested 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request
                            
                            	List of request list entries
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request>`
                            
                            .. attribute:: request_neighbor_address
                            
                            	Neighbor IP address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request_sham_link_id
                            
                            	Request sham link ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: request_virtual_link_id
                            
                            	Request virtual link ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "request-list-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"request" : ("request", Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_request_sham_link = YLeaf(YType.boolean, "is-request-sham-link")

                                self.is_request_virtual_link = YLeaf(YType.boolean, "is-request-virtual-link")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                self.request_sham_link_id = YLeaf(YType.uint32, "request-sham-link-id")

                                self.request_virtual_link_id = YLeaf(YType.uint32, "request-virtual-link-id")

                                self.request = YList(self)
                                self._segment_path = lambda: "request"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request, ['interface_name', 'is_request_sham_link', 'is_request_virtual_link', 'neighbor_address', 'request_neighbor_address', 'request_sham_link_id', 'request_virtual_link_id'], name, value)


                            class Request(Entity):
                                """
                                List of request list entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                    self._segment_path = lambda: "request"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                    class RetransmissionListProcessTable(Entity):
                        """
                        OSPFv3 retransmission list information table for
                        all areas
                        
                        .. attribute:: retransmission
                        
                        	OSPFv3 retransmission list information
                        	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable, self).__init__()

                            self.yang_name = "retransmission-list-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"retransmission" : ("retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission)}

                            self.retransmission = YList(self)
                            self._segment_path = lambda: "retransmission-list-process-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable, [], name, value)


                        class Retransmission(Entity):
                            """
                            OSPFv3 retransmission list information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_retransmission_sham_link
                            
                            	If true, sham link is retransmitted 
                            	**type**\:  bool
                            
                            .. attribute:: is_retransmissionvirtual_link
                            
                            	If true, virtual link is retransmitted 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_area_db
                            
                            	List of area scope entries
                            	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb>`
                            
                            .. attribute:: retransmission_asdb
                            
                            	List of AS scope entries
                            	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb>`
                            
                            .. attribute:: retransmission_length
                            
                            	Retransmission queue length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmission_neighbor_address
                            
                            	Neighbor IP address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_sham_link_id
                            
                            	Retransmission sham link ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmission_timer
                            
                            	Amount of time remaining on retransmission timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissionvirtual_link_db
                            
                            	List of virtual link scope entries 
                            	**type**\: list of    :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb>`
                            
                            .. attribute:: retransmissionvirtual_link_id
                            
                            	Retransmission virtual link ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission, self).__init__()

                                self.yang_name = "retransmission"
                                self.yang_parent_name = "retransmission-list-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"retransmission-area-db" : ("retransmission_area_db", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb), "retransmission-asdb" : ("retransmission_asdb", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb), "retransmissionvirtual-link-db" : ("retransmissionvirtual_link_db", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_retransmission_sham_link = YLeaf(YType.boolean, "is-retransmission-sham-link")

                                self.is_retransmissionvirtual_link = YLeaf(YType.boolean, "is-retransmissionvirtual-link")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.retransmission_length = YLeaf(YType.uint32, "retransmission-length")

                                self.retransmission_neighbor_address = YLeaf(YType.str, "retransmission-neighbor-address")

                                self.retransmission_sham_link_id = YLeaf(YType.uint32, "retransmission-sham-link-id")

                                self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                self.retransmissionvirtual_link_id = YLeaf(YType.uint32, "retransmissionvirtual-link-id")

                                self.retransmission_area_db = YList(self)
                                self.retransmission_asdb = YList(self)
                                self.retransmissionvirtual_link_db = YList(self)
                                self._segment_path = lambda: "retransmission"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission, ['interface_name', 'is_retransmission_sham_link', 'is_retransmissionvirtual_link', 'neighbor_address', 'retransmission_length', 'retransmission_neighbor_address', 'retransmission_sham_link_id', 'retransmission_timer', 'retransmissionvirtual_link_id'], name, value)


                            class RetransmissionAreaDb(Entity):
                                """
                                List of area scope entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb, self).__init__()

                                    self.yang_name = "retransmission-area-db"
                                    self.yang_parent_name = "retransmission"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                    self._segment_path = lambda: "retransmission-area-db"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class RetransmissionAsdb(Entity):
                                """
                                List of AS scope entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb, self).__init__()

                                    self.yang_name = "retransmission-asdb"
                                    self.yang_parent_name = "retransmission"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                    self._segment_path = lambda: "retransmission-asdb"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class RetransmissionvirtualLinkDb(Entity):
                                """
                                List of virtual link scope entries 
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb, self).__init__()

                                    self.yang_name = "retransmissionvirtual-link-db"
                                    self.yang_parent_name = "retransmission"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_id = YLeaf(YType.str, "header-lsa-id")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.int32, "header-sequence-number")
                                    self._segment_path = lambda: "retransmissionvirtual-link-db"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb, ['header_advertising_router', 'header_lsa_age', 'header_lsa_id', 'header_lsa_type', 'header_sequence_number'], name, value)


                    class RouteSummary(Entity):
                        """
                        Summarize OSPFv3 local RIB tables
                        
                        .. attribute:: extern_one_route
                        
                        	Extern 1 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extern_two_route
                        
                        	Extern 2 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_area_route
                        
                        	Inter route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: intra_area_route
                        
                        	Intra route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_one_route
                        
                        	NSSA 1 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_two_route
                        
                        	NSSA 2 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_route
                        
                        	Redistribution route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_connected
                        
                        	Route connected 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_id
                        
                        	Route summary of a route ID 
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: total_received_route
                        
                        	Total route received summary
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_sent_route
                        
                        	Total route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary, self).__init__()

                            self.yang_name = "route-summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.extern_one_route = YLeaf(YType.uint32, "extern-one-route")

                            self.extern_two_route = YLeaf(YType.uint32, "extern-two-route")

                            self.inter_area_route = YLeaf(YType.uint32, "inter-area-route")

                            self.intra_area_route = YLeaf(YType.uint32, "intra-area-route")

                            self.nssa_one_route = YLeaf(YType.uint32, "nssa-one-route")

                            self.nssa_two_route = YLeaf(YType.uint32, "nssa-two-route")

                            self.redistribution_route = YLeaf(YType.uint32, "redistribution-route")

                            self.route_connected = YLeaf(YType.uint32, "route-connected")

                            self.route_id = YLeaf(YType.str, "route-id")

                            self.total_received_route = YLeaf(YType.uint32, "total-received-route")

                            self.total_sent_route = YLeaf(YType.uint32, "total-sent-route")
                            self._segment_path = lambda: "route-summary"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary, ['extern_one_route', 'extern_two_route', 'inter_area_route', 'intra_area_route', 'nssa_one_route', 'nssa_two_route', 'redistribution_route', 'route_connected', 'route_id', 'total_received_route', 'total_sent_route'], name, value)


                    class ShamLinkTable(Entity):
                        """
                        Sham link information
                        
                        .. attribute:: is_sham_link_authentication_enabled
                        
                        	If true, sham link authentication is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_sham_link_encryption_enabled
                        
                        	If true, sham link encryption is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_sham_link_ip_security_active
                        
                        	If true, Sham link IP security is active 
                        	**type**\:  bool
                        
                        .. attribute:: is_sham_link_ip_security_required
                        
                        	If true, sham link IP security is required 
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_area
                        
                        	Area id
                        	**type**\:  str
                        
                        .. attribute:: sham_link_authentication_transmit
                        
                        	Sham link authentication transmit 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_cost
                        
                        	Cost of the sham link
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sham_link_dc_bitless_lsa
                        
                        	Number of LSA's with demand circuit bit not set
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_dead_interval
                        
                        	Dead interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_demand_circuit
                        
                        	If true, the link runs as demand circuit
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_dest_address
                        
                        	Sham\-link dest
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_encrypted_authentication_transmitted
                        
                        	Sham link encrypted authentication transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_encryption_spi
                        
                        	Sham link encryption spi
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_encryption_transmitted
                        
                        	Sham link encryption transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_gr
                        
                        	If true, Gracefule restart in progress
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_gr_enabled
                        
                        	If true,  enabled
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_hello_interval
                        
                        	Hello interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_ifindex
                        
                        	Sham\-link ifindex
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_last_gr
                        
                        	Time in seconds since last GR
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: sham_link_neighbor
                        
                        	Neighbor information
                        	**type**\:   :py:class:`ShamLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor>`
                        
                        .. attribute:: sham_link_neighbor_id
                        
                        	Neighbor on other end of this sham link
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_next_hello
                        
                        	Time until next hello (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_passive
                        
                        	If true, interface is passive
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_retransmission_interval
                        
                        	Retransmission interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_source_address
                        
                        	Sham\-link source
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_state
                        
                        	OSPF interface state for the sham link
                        	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        .. attribute:: sham_link_transmission_delay
                        
                        	Transmission delay in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: sham_link_wait_interval
                        
                        	Wait interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_authentication_spi
                        
                        	Sham link authentication spi 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable, self).__init__()

                            self.yang_name = "sham-link-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"sham-link-neighbor" : ("sham_link_neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor)}
                            self._child_list_classes = {}

                            self.is_sham_link_authentication_enabled = YLeaf(YType.boolean, "is-sham-link-authentication-enabled")

                            self.is_sham_link_encryption_enabled = YLeaf(YType.boolean, "is-sham-link-encryption-enabled")

                            self.is_sham_link_ip_security_active = YLeaf(YType.boolean, "is-sham-link-ip-security-active")

                            self.is_sham_link_ip_security_required = YLeaf(YType.boolean, "is-sham-link-ip-security-required")

                            self.sham_link_area = YLeaf(YType.str, "sham-link-area")

                            self.sham_link_authentication_transmit = YLeaf(YType.uint32, "sham-link-authentication-transmit")

                            self.sham_link_cost = YLeaf(YType.uint16, "sham-link-cost")

                            self.sham_link_dc_bitless_lsa = YLeaf(YType.uint32, "sham-link-dc-bitless-lsa")

                            self.sham_link_dead_interval = YLeaf(YType.uint32, "sham-link-dead-interval")

                            self.sham_link_demand_circuit = YLeaf(YType.boolean, "sham-link-demand-circuit")

                            self.sham_link_dest_address = YLeaf(YType.str, "sham-link-dest-address")

                            self.sham_link_encrypted_authentication_transmitted = YLeaf(YType.uint32, "sham-link-encrypted-authentication-transmitted")

                            self.sham_link_encryption_spi = YLeaf(YType.uint32, "sham-link-encryption-spi")

                            self.sham_link_encryption_transmitted = YLeaf(YType.uint32, "sham-link-encryption-transmitted")

                            self.sham_link_gr = YLeaf(YType.boolean, "sham-link-gr")

                            self.sham_link_gr_enabled = YLeaf(YType.boolean, "sham-link-gr-enabled")

                            self.sham_link_hello_interval = YLeaf(YType.uint32, "sham-link-hello-interval")

                            self.sham_link_ifindex = YLeaf(YType.uint32, "sham-link-ifindex")

                            self.sham_link_last_gr = YLeaf(YType.uint32, "sham-link-last-gr")

                            self.sham_link_neighbor_id = YLeaf(YType.str, "sham-link-neighbor-id")

                            self.sham_link_next_hello = YLeaf(YType.uint32, "sham-link-next-hello")

                            self.sham_link_passive = YLeaf(YType.boolean, "sham-link-passive")

                            self.sham_link_retransmission_interval = YLeaf(YType.uint32, "sham-link-retransmission-interval")

                            self.sham_link_source_address = YLeaf(YType.str, "sham-link-source-address")

                            self.sham_link_state = YLeaf(YType.enumeration, "sham-link-state")

                            self.sham_link_transmission_delay = YLeaf(YType.uint16, "sham-link-transmission-delay")

                            self.sham_link_wait_interval = YLeaf(YType.uint32, "sham-link-wait-interval")

                            self.virtual_link_authentication_spi = YLeaf(YType.uint32, "virtual-link-authentication-spi")

                            self.sham_link_neighbor = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor()
                            self.sham_link_neighbor.parent = self
                            self._children_name_map["sham_link_neighbor"] = "sham-link-neighbor"
                            self._children_yang_names.add("sham-link-neighbor")
                            self._segment_path = lambda: "sham-link-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable, ['is_sham_link_authentication_enabled', 'is_sham_link_encryption_enabled', 'is_sham_link_ip_security_active', 'is_sham_link_ip_security_required', 'sham_link_area', 'sham_link_authentication_transmit', 'sham_link_cost', 'sham_link_dc_bitless_lsa', 'sham_link_dead_interval', 'sham_link_demand_circuit', 'sham_link_dest_address', 'sham_link_encrypted_authentication_transmitted', 'sham_link_encryption_spi', 'sham_link_encryption_transmitted', 'sham_link_gr', 'sham_link_gr_enabled', 'sham_link_hello_interval', 'sham_link_ifindex', 'sham_link_last_gr', 'sham_link_neighbor_id', 'sham_link_next_hello', 'sham_link_passive', 'sham_link_retransmission_interval', 'sham_link_source_address', 'sham_link_state', 'sham_link_transmission_delay', 'sham_link_wait_interval', 'virtual_link_authentication_spi'], name, value)


                        class ShamLinkNeighbor(Entity):
                            """
                            Neighbor information
                            
                            .. attribute:: sham_link_retransmission
                            
                            	Neighbor retransmission info
                            	**type**\:   :py:class:`ShamLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission>`
                            
                            .. attribute:: sham_link_state
                            
                            	Adjacency state
                            	**type**\:   :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                            
                            .. attribute:: sham_link_suppress_hello
                            
                            	If true Hellos suppressed
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor, self).__init__()

                                self.yang_name = "sham-link-neighbor"
                                self.yang_parent_name = "sham-link-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sham-link-retransmission" : ("sham_link_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission)}
                                self._child_list_classes = {}

                                self.sham_link_state = YLeaf(YType.enumeration, "sham-link-state")

                                self.sham_link_suppress_hello = YLeaf(YType.boolean, "sham-link-suppress-hello")

                                self.sham_link_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission()
                                self.sham_link_retransmission.parent = self
                                self._children_name_map["sham_link_retransmission"] = "sham-link-retransmission"
                                self._children_yang_names.add("sham-link-retransmission")
                                self._segment_path = lambda: "sham-link-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor, ['sham_link_state', 'sham_link_suppress_hello'], name, value)


                            class ShamLinkRetransmission(Entity):
                                """
                                Neighbor retransmission info
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission, self).__init__()

                                    self.yang_name = "sham-link-retransmission"
                                    self.yang_parent_name = "sham-link-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                    self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                    self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                    self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                    self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                    self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                    self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                    self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                    self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                    self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                    self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                    self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                    self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                    self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                    self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                    self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                    self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                    self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                    self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                    self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                    self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                    self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                    self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                    self._segment_path = lambda: "sham-link-retransmission"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                    class Summary(Entity):
                        """
                        OSPFv3 summary
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3 summary
                        	**type**\:   :py:class:`Ospfv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3>`
                        
                        .. attribute:: protocol
                        
                        	OSPFv3 protocol summary
                        	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol>`
                        
                        .. attribute:: route
                        
                        	OSPFv3 route summary
                        	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ospfv3" : ("ospfv3", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3), "protocol" : ("protocol", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol), "route" : ("route", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route)}
                            self._child_list_classes = {}

                            self.ospfv3 = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3()
                            self.ospfv3.parent = self
                            self._children_name_map["ospfv3"] = "ospfv3"
                            self._children_yang_names.add("ospfv3")

                            self.protocol = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"
                            self._children_yang_names.add("protocol")

                            self.route = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._children_yang_names.add("route")
                            self._segment_path = lambda: "summary"


                        class Ospfv3(Entity):
                            """
                            OSPFv3 summary
                            
                            .. attribute:: areas
                            
                            	Number of areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_dc_bitless_ls_as
                            
                            	Number of external and AS opaque LSAs with demand circut bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_do_not_age_ls_as
                            
                            	Number of external and AS opaque LSAs with do not age set 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_ls_as
                            
                            	Number of AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_lsa_flood_list_length
                            
                            	Length of AS LSAs flood list
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context_name
                            
                            	Context name
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: default_metric
                            
                            	Default metric 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_metric_type
                            
                            	Default metric type 
                            	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                            
                            .. attribute:: default_policy_name
                            
                            	Default policy name 
                            	**type**\:  str
                            
                            .. attribute:: default_tag
                            
                            	Default tag 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: domain_id
                            
                            	Domain ID information
                            	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId>`
                            
                            .. attribute:: grace_resync_time
                            
                            	Grace time to resync 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_state
                            
                            	Graceful shutdown state
                            	**type**\:   :py:class:`Ospfv3GracefulShutdownState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulShutdownState>`
                            
                            .. attribute:: ipfrr_tiebreakers
                            
                            	IPFRR\-Tiebreakers list
                            	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.IpfrrTiebreakers>`
                            
                            .. attribute:: is_area_border_router
                            
                            	If true, is an area border router
                            	**type**\:  bool
                            
                            .. attribute:: is_as_border_router
                            
                            	If true, is an AS border router
                            	**type**\:  bool
                            
                            .. attribute:: is_auto_cost
                            
                            	If true, auto cost is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_default_always
                            
                            	If true, default always 
                            	**type**\:  bool
                            
                            .. attribute:: is_default_originated
                            
                            	If true, origin is by default 
                            	**type**\:  bool
                            
                            .. attribute:: is_default_policy
                            
                            	If true, is a default policy 
                            	**type**\:  bool
                            
                            .. attribute:: is_grace_restart_enabled
                            
                            	If true, grace restart is enabled 
                            	**type**\:  bool
                            
                            .. attribute:: is_nsr_enabled
                            
                            	If true, NSR is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_nsr_switchover_on_restart
                            
                            	Trigger RP Switchover on detectable process restart
                            	**type**\:  bool
                            
                            .. attribute:: is_opaque_capable
                            
                            	Opaque LSA capable 
                            	**type**\:  bool
                            
                            .. attribute:: is_role_standby
                            
                            	If true, the process is running as stanby role
                            	**type**\:  bool
                            
                            .. attribute:: is_router_id_stalled
                            
                            	Stalled Router ID 
                            	**type**\:  bool
                            
                            .. attribute:: last_nsf_time
                            
                            	 Length of time since the last NSF (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_flood_pacing_interval
                            
                            	LSA flood pacing timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_group_interval
                            
                            	LSA refresh interval (sec)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_hold_time
                            
                            	Second delay before generating next LSA (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_maximum_time
                            
                            	Maximum delay before generating an LSA (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_pacing_interval
                            
                            	LSA retransmission pacing timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_start_time
                            
                            	Initial LSA throttle delay (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_interfaces
                            
                            	Maximum number of interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_paths
                            
                            	Maximum number of paths
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric
                            
                            	Redistribution metric 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: minimum_lsa_interval
                            
                            	Minimum time between LSA regeneration (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: normal_areas
                            
                            	Number of normal areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nssa_areas
                            
                            	Number of NSSA areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksum
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: opaque_lsas
                            
                            	Number of opaque LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_limit
                            
                            	The number of redistributed prefixes allowed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_threshold
                            
                            	When the number of redistributed prefixes reaches this threshold, a warning message is issued 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reference_bandwidth
                            
                            	Reference Bandwdith
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: role
                            
                            	Role, V1/V2 Active/Standby
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: snmp_trap_enabled
                            
                            	If true, snmp trap is enabled
                            	**type**\:  bool
                            
                            .. attribute:: spf_hold_time
                            
                            	Minimum delay time between SPF runs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_maximum_time
                            
                            	Maximum delay time between SPF runs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_start_time
                            
                            	Scheduling delay for SPF (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: stub_areas
                            
                            	Number of stub and total stub areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: stub_router
                            
                            	Stub Router Information
                            	**type**\: list of    :py:class:`StubRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"domain-id" : ("domain_id", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId)}
                                self._child_list_classes = {"ipfrr-tiebreakers" : ("ipfrr_tiebreakers", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.IpfrrTiebreakers), "stub-router" : ("stub_router", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter)}

                                self.areas = YLeaf(YType.uint16, "areas")

                                self.as_dc_bitless_ls_as = YLeaf(YType.uint32, "as-dc-bitless-ls-as")

                                self.as_do_not_age_ls_as = YLeaf(YType.uint32, "as-do-not-age-ls-as")

                                self.as_ls_as = YLeaf(YType.uint32, "as-ls-as")

                                self.as_lsa_flood_list_length = YLeaf(YType.uint32, "as-lsa-flood-list-length")

                                self.context_name = YLeaf(YType.str, "context-name")

                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                self.default_metric_type = YLeaf(YType.enumeration, "default-metric-type")

                                self.default_policy_name = YLeaf(YType.str, "default-policy-name")

                                self.default_tag = YLeaf(YType.uint32, "default-tag")

                                self.grace_resync_time = YLeaf(YType.uint32, "grace-resync-time")

                                self.graceful_shutdown_state = YLeaf(YType.enumeration, "graceful-shutdown-state")

                                self.is_area_border_router = YLeaf(YType.boolean, "is-area-border-router")

                                self.is_as_border_router = YLeaf(YType.boolean, "is-as-border-router")

                                self.is_auto_cost = YLeaf(YType.boolean, "is-auto-cost")

                                self.is_default_always = YLeaf(YType.boolean, "is-default-always")

                                self.is_default_originated = YLeaf(YType.boolean, "is-default-originated")

                                self.is_default_policy = YLeaf(YType.boolean, "is-default-policy")

                                self.is_grace_restart_enabled = YLeaf(YType.boolean, "is-grace-restart-enabled")

                                self.is_nsr_enabled = YLeaf(YType.boolean, "is-nsr-enabled")

                                self.is_nsr_switchover_on_restart = YLeaf(YType.boolean, "is-nsr-switchover-on-restart")

                                self.is_opaque_capable = YLeaf(YType.boolean, "is-opaque-capable")

                                self.is_role_standby = YLeaf(YType.boolean, "is-role-standby")

                                self.is_router_id_stalled = YLeaf(YType.boolean, "is-router-id-stalled")

                                self.last_nsf_time = YLeaf(YType.uint32, "last-nsf-time")

                                self.lsa_flood_pacing_interval = YLeaf(YType.uint32, "lsa-flood-pacing-interval")

                                self.lsa_group_interval = YLeaf(YType.uint32, "lsa-group-interval")

                                self.lsa_hold_time = YLeaf(YType.uint32, "lsa-hold-time")

                                self.lsa_maximum_time = YLeaf(YType.uint32, "lsa-maximum-time")

                                self.lsa_retransmission_pacing_interval = YLeaf(YType.uint32, "lsa-retransmission-pacing-interval")

                                self.lsa_start_time = YLeaf(YType.uint32, "lsa-start-time")

                                self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                                self.maximum_paths = YLeaf(YType.uint32, "maximum-paths")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.minimum_lsa_interval = YLeaf(YType.uint32, "minimum-lsa-interval")

                                self.normal_areas = YLeaf(YType.uint16, "normal-areas")

                                self.nssa_areas = YLeaf(YType.uint16, "nssa-areas")

                                self.opaque_lsa_checksum = YLeaf(YType.uint32, "opaque-lsa-checksum")

                                self.opaque_lsas = YLeaf(YType.uint32, "opaque-lsas")

                                self.redistribution_limit = YLeaf(YType.uint32, "redistribution-limit")

                                self.redistribution_threshold = YLeaf(YType.uint32, "redistribution-threshold")

                                self.reference_bandwidth = YLeaf(YType.uint32, "reference-bandwidth")

                                self.role = YLeaf(YType.uint32, "role")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.snmp_trap_enabled = YLeaf(YType.boolean, "snmp-trap-enabled")

                                self.spf_hold_time = YLeaf(YType.uint32, "spf-hold-time")

                                self.spf_maximum_time = YLeaf(YType.uint32, "spf-maximum-time")

                                self.spf_start_time = YLeaf(YType.uint32, "spf-start-time")

                                self.stub_areas = YLeaf(YType.uint16, "stub-areas")

                                self.domain_id = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId()
                                self.domain_id.parent = self
                                self._children_name_map["domain_id"] = "domain-id"
                                self._children_yang_names.add("domain-id")

                                self.ipfrr_tiebreakers = YList(self)
                                self.stub_router = YList(self)
                                self._segment_path = lambda: "ospfv3"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3, ['areas', 'as_dc_bitless_ls_as', 'as_do_not_age_ls_as', 'as_ls_as', 'as_lsa_flood_list_length', 'context_name', 'default_metric', 'default_metric_type', 'default_policy_name', 'default_tag', 'grace_resync_time', 'graceful_shutdown_state', 'is_area_border_router', 'is_as_border_router', 'is_auto_cost', 'is_default_always', 'is_default_originated', 'is_default_policy', 'is_grace_restart_enabled', 'is_nsr_enabled', 'is_nsr_switchover_on_restart', 'is_opaque_capable', 'is_role_standby', 'is_router_id_stalled', 'last_nsf_time', 'lsa_flood_pacing_interval', 'lsa_group_interval', 'lsa_hold_time', 'lsa_maximum_time', 'lsa_retransmission_pacing_interval', 'lsa_start_time', 'maximum_interfaces', 'maximum_paths', 'metric', 'minimum_lsa_interval', 'normal_areas', 'nssa_areas', 'opaque_lsa_checksum', 'opaque_lsas', 'redistribution_limit', 'redistribution_threshold', 'reference_bandwidth', 'role', 'router_id', 'snmp_trap_enabled', 'spf_hold_time', 'spf_maximum_time', 'spf_start_time', 'stub_areas'], name, value)


                            class DomainId(Entity):
                                """
                                Domain ID information
                                
                                .. attribute:: primary_domain_id
                                
                                	Primary Domain ID
                                	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.PrimaryDomainId>`
                                
                                .. attribute:: secondary_domain_id
                                
                                	List of secondary domain IDs
                                	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.SecondaryDomainId>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId, self).__init__()

                                    self.yang_name = "domain-id"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"primary-domain-id" : ("primary_domain_id", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.PrimaryDomainId)}
                                    self._child_list_classes = {"secondary-domain-id" : ("secondary_domain_id", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.SecondaryDomainId)}

                                    self.primary_domain_id = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.PrimaryDomainId()
                                    self.primary_domain_id.parent = self
                                    self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                    self._children_yang_names.add("primary-domain-id")

                                    self.secondary_domain_id = YList(self)
                                    self._segment_path = lambda: "domain-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId, [], name, value)


                                class PrimaryDomainId(Entity):
                                    """
                                    Primary Domain ID
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.PrimaryDomainId, self).__init__()

                                        self.yang_name = "primary-domain-id"
                                        self.yang_parent_name = "domain-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                        self.domain_id_value = YLeaf(YType.str, "domain-id-value")
                                        self._segment_path = lambda: "primary-domain-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.PrimaryDomainId, ['domain_id_type', 'domain_id_value'], name, value)


                                class SecondaryDomainId(Entity):
                                    """
                                    List of secondary domain IDs
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.SecondaryDomainId, self).__init__()

                                        self.yang_name = "secondary-domain-id"
                                        self.yang_parent_name = "domain-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                        self.domain_id_value = YLeaf(YType.str, "domain-id-value")
                                        self._segment_path = lambda: "secondary-domain-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.DomainId.SecondaryDomainId, ['domain_id_type', 'domain_id_value'], name, value)


                            class IpfrrTiebreakers(Entity):
                                """
                                IPFRR\-Tiebreakers list
                                
                                .. attribute:: tiebreaker_index
                                
                                	Tiebreaker Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tiebreaker_type
                                
                                	Tiebreaker Type
                                	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.IpfrrTbrkr>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.IpfrrTiebreakers, self).__init__()

                                    self.yang_name = "ipfrr-tiebreakers"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")
                                    self._segment_path = lambda: "ipfrr-tiebreakers"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.IpfrrTiebreakers, ['tiebreaker_index', 'tiebreaker_type'], name, value)


                            class StubRouter(Entity):
                                """
                                Stub Router Information
                                
                                .. attribute:: abr_off_reason
                                
                                	Reason for being in ABR off mode
                                	**type**\:   :py:class:`StubRouterAbrOffReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterAbrOffReason>`
                                
                                .. attribute:: abr_resume_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when ABR duties were resumed
                                	**type**\:   :py:class:`AbrResumeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.AbrResumeTime>`
                                
                                .. attribute:: active
                                
                                	If true, stub router mode is active
                                	**type**\:  bool
                                
                                .. attribute:: external_lsa_metric
                                
                                	Metric for external LSAs in max\-metric mode
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: include_stub_links
                                
                                	If true, advertise maximum metric for stub links
                                	**type**\:  bool
                                
                                .. attribute:: mode
                                
                                	Stub router mode
                                	**type**\:   :py:class:`StubRouterMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterMode>`
                                
                                .. attribute:: remaining_time
                                
                                	Remaining time (in seconds) in stub router mode
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: set_reason
                                
                                	Reason for entering stub router mode
                                	**type**\:   :py:class:`StubRouterTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTrigger>`
                                
                                .. attribute:: start_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                	**type**\:   :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.StartTime>`
                                
                                .. attribute:: summary_lsa_metric
                                
                                	Metric for summary LSAs in max\-metric mode
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: trigger
                                
                                	Triggers for entering stub router mode
                                	**type**\: list of    :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger>`
                                
                                .. attribute:: unset_reason
                                
                                	Reason for clearing stub router condition
                                	**type**\:   :py:class:`StubRouterExitReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReason>`
                                
                                .. attribute:: unset_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                	**type**\:   :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.UnsetTime>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter, self).__init__()

                                    self.yang_name = "stub-router"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"abr-resume-time" : ("abr_resume_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.AbrResumeTime), "start-time" : ("start_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.StartTime), "unset-time" : ("unset_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.UnsetTime)}
                                    self._child_list_classes = {"trigger" : ("trigger", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger)}

                                    self.abr_off_reason = YLeaf(YType.enumeration, "abr-off-reason")

                                    self.active = YLeaf(YType.boolean, "active")

                                    self.external_lsa_metric = YLeaf(YType.uint32, "external-lsa-metric")

                                    self.include_stub_links = YLeaf(YType.boolean, "include-stub-links")

                                    self.mode = YLeaf(YType.enumeration, "mode")

                                    self.remaining_time = YLeaf(YType.uint32, "remaining-time")

                                    self.set_reason = YLeaf(YType.enumeration, "set-reason")

                                    self.summary_lsa_metric = YLeaf(YType.uint32, "summary-lsa-metric")

                                    self.unset_reason = YLeaf(YType.enumeration, "unset-reason")

                                    self.abr_resume_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.AbrResumeTime()
                                    self.abr_resume_time.parent = self
                                    self._children_name_map["abr_resume_time"] = "abr-resume-time"
                                    self._children_yang_names.add("abr-resume-time")

                                    self.start_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.StartTime()
                                    self.start_time.parent = self
                                    self._children_name_map["start_time"] = "start-time"
                                    self._children_yang_names.add("start-time")

                                    self.unset_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.UnsetTime()
                                    self.unset_time.parent = self
                                    self._children_name_map["unset_time"] = "unset-time"
                                    self._children_yang_names.add("unset-time")

                                    self.trigger = YList(self)
                                    self._segment_path = lambda: "stub-router"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter, ['abr_off_reason', 'active', 'external_lsa_metric', 'include_stub_links', 'mode', 'remaining_time', 'set_reason', 'summary_lsa_metric', 'unset_reason'], name, value)


                                class AbrResumeTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when ABR
                                    duties were resumed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.AbrResumeTime, self).__init__()

                                        self.yang_name = "abr-resume-time"
                                        self.yang_parent_name = "stub-router"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "abr-resume-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.AbrResumeTime, ['nanosecond', 'second'], name, value)


                                class StartTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router mode was activated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.StartTime, self).__init__()

                                        self.yang_name = "start-time"
                                        self.yang_parent_name = "stub-router"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "start-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.StartTime, ['nanosecond', 'second'], name, value)


                                class Trigger(Entity):
                                    """
                                    Triggers for entering stub router mode
                                    
                                    .. attribute:: start_time
                                    
                                    	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                    	**type**\:   :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.StartTime>`
                                    
                                    .. attribute:: time
                                    
                                    	Time (in seconds) to stay in stub router mode
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: trigger
                                    
                                    	Stub Router Trigger type
                                    	**type**\:   :py:class:`StubRouterTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTrigger>`
                                    
                                    .. attribute:: unset_reason
                                    
                                    	Reason for clearing stub router condition
                                    	**type**\:   :py:class:`StubRouterExitReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReason>`
                                    
                                    .. attribute:: unset_time
                                    
                                    	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                    	**type**\:   :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime>`
                                    
                                    .. attribute:: wait_for_bgp
                                    
                                    	If true, stub router is terminated when BGP converges
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger, self).__init__()

                                        self.yang_name = "trigger"
                                        self.yang_parent_name = "stub-router"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"start-time" : ("start_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.StartTime), "unset-time" : ("unset_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime)}
                                        self._child_list_classes = {}

                                        self.time = YLeaf(YType.uint32, "time")

                                        self.trigger = YLeaf(YType.enumeration, "trigger")

                                        self.unset_reason = YLeaf(YType.enumeration, "unset-reason")

                                        self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                                        self.start_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.StartTime()
                                        self.start_time.parent = self
                                        self._children_name_map["start_time"] = "start-time"
                                        self._children_yang_names.add("start-time")

                                        self.unset_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime()
                                        self.unset_time.parent = self
                                        self._children_name_map["unset_time"] = "unset-time"
                                        self._children_yang_names.add("unset-time")
                                        self._segment_path = lambda: "trigger"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger, ['time', 'trigger', 'unset_reason', 'wait_for_bgp'], name, value)


                                    class StartTime(Entity):
                                        """
                                        Timestamp (relative to 1970/1/1 00\:00) when stub
                                        router mode was activated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nano seconds 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: second
                                        
                                        	Seconds 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.StartTime, self).__init__()

                                            self.yang_name = "start-time"
                                            self.yang_parent_name = "trigger"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "start-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.StartTime, ['nanosecond', 'second'], name, value)


                                    class UnsetTime(Entity):
                                        """
                                        Timestamp (relative to 1970/1/1 00\:00) when stub
                                        router condition was cleared
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nano seconds 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: second
                                        
                                        	Seconds 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime, self).__init__()

                                            self.yang_name = "unset-time"
                                            self.yang_parent_name = "trigger"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "unset-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.Trigger.UnsetTime, ['nanosecond', 'second'], name, value)


                                class UnsetTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router condition was cleared
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.UnsetTime, self).__init__()

                                        self.yang_name = "unset-time"
                                        self.yang_parent_name = "stub-router"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "unset-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3.StubRouter.UnsetTime, ['nanosecond', 'second'], name, value)


                        class Protocol(Entity):
                            """
                            OSPFv3 protocol summary
                            
                            .. attribute:: administrative_distance
                            
                            	Administrative distance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: administrative_distance_external
                            
                            	Administrative Distance for External routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: administrative_distance_inter_area
                            
                            	Administrative Distance for Inter Area routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: is_graceful_restart
                            
                            	If true, Graceful restart is enabled 
                            	**type**\:  bool
                            
                            .. attribute:: protocol_router_id
                            
                            	Protocol router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.administrative_distance = YLeaf(YType.uint32, "administrative-distance")

                                self.administrative_distance_external = YLeaf(YType.uint32, "administrative-distance-external")

                                self.administrative_distance_inter_area = YLeaf(YType.uint32, "administrative-distance-inter-area")

                                self.distribute_list_in = YLeaf(YType.str, "distribute-list-in")

                                self.is_graceful_restart = YLeaf(YType.boolean, "is-graceful-restart")

                                self.protocol_router_id = YLeaf(YType.str, "protocol-router-id")
                                self._segment_path = lambda: "protocol"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol, ['administrative_distance', 'administrative_distance_external', 'administrative_distance_inter_area', 'distribute_list_in', 'is_graceful_restart', 'protocol_router_id'], name, value)


                        class Route(Entity):
                            """
                            OSPFv3 route summary
                            
                            .. attribute:: extern_one_route
                            
                            	Extern 1 route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extern_two_route
                            
                            	Extern 2 route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_area_route
                            
                            	Inter route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_area_route
                            
                            	Intra route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nssa_one_route
                            
                            	NSSA 1 route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nssa_two_route
                            
                            	NSSA 2 route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_route
                            
                            	Redistribution route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_connected
                            
                            	Route connected 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_id
                            
                            	Route summary of a route ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: total_received_route
                            
                            	Total route received summary
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_sent_route
                            
                            	Total route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.extern_one_route = YLeaf(YType.uint32, "extern-one-route")

                                self.extern_two_route = YLeaf(YType.uint32, "extern-two-route")

                                self.inter_area_route = YLeaf(YType.uint32, "inter-area-route")

                                self.intra_area_route = YLeaf(YType.uint32, "intra-area-route")

                                self.nssa_one_route = YLeaf(YType.uint32, "nssa-one-route")

                                self.nssa_two_route = YLeaf(YType.uint32, "nssa-two-route")

                                self.redistribution_route = YLeaf(YType.uint32, "redistribution-route")

                                self.route_connected = YLeaf(YType.uint32, "route-connected")

                                self.route_id = YLeaf(YType.str, "route-id")

                                self.total_received_route = YLeaf(YType.uint32, "total-received-route")

                                self.total_sent_route = YLeaf(YType.uint32, "total-sent-route")
                                self._segment_path = lambda: "route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route, ['extern_one_route', 'extern_two_route', 'inter_area_route', 'intra_area_route', 'nssa_one_route', 'nssa_two_route', 'redistribution_route', 'route_connected', 'route_id', 'total_received_route', 'total_sent_route'], name, value)


                    class SummaryPrefixes(Entity):
                        """
                        Summary prefix information table
                        
                        .. attribute:: summary_prefix
                        
                        	Summary prefix information
                        	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__init__()

                            self.yang_name = "summary-prefixes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"summary-prefix" : ("summary_prefix", Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix)}

                            self.summary_prefix = YList(self)
                            self._segment_path = lambda: "summary-prefixes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes, [], name, value)


                        class SummaryPrefix(Entity):
                            """
                            Summary prefix information
                            
                            .. attribute:: prefix
                            
                            	Summary prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: prefix_metric
                            
                            	Prefix metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_metric_type
                            
                            	Prefix metric type
                            	**type**\:   :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                            
                            .. attribute:: tag
                            
                            	Tag
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "summary-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                self.prefix_metric = YLeaf(YType.uint32, "prefix-metric")

                                self.prefix_metric_type = YLeaf(YType.enumeration, "prefix-metric-type")

                                self.tag = YLeaf(YType.uint32, "tag")
                                self._segment_path = lambda: "summary-prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, ['prefix', 'prefix_length', 'prefix_metric', 'prefix_metric_type', 'tag'], name, value)


                    class VirtualLink(Entity):
                        """
                        Virtual link information
                        
                        .. attribute:: interface_name
                        
                        	Interface on which this virtual link is formed
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_virtual_link_authentication_enabled
                        
                        	If true, virtual link authentication is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_demand_circuit
                        
                        	If true, the link runs as demand circuit
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_encryption_enabled
                        
                        	If true, virtual link encryption is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_ip_security_active
                        
                        	If true, Virtual link IP security is active 
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_ip_security_required
                        
                        	If true, virtual link IP security is required 
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_passive
                        
                        	If true, interface is passive
                        	**type**\:  bool
                        
                        .. attribute:: transit_area_id
                        
                        	Transit area id 
                        	**type**\:  str
                        
                        .. attribute:: virtual_link_authentication_spi
                        
                        	Virtual link authentication spi 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_authentication_transmit
                        
                        	Virtual link authentication transmit 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_cost
                        
                        	Cost of the virtual link
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtual_link_dc_bitless_lsa
                        
                        	Number of LSA's with demand circuit bit not set 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_dead_interval
                        
                        	Dead interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_encrypted_authentication_transmitted
                        
                        	Virtual link encrypted authentication transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_encryption_spi
                        
                        	Virtual link encryption spi
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_encryption_transmitted
                        
                        	Virtual link encryption transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_hello_interval
                        
                        	Hello interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_interface_number
                        
                        	Virtual link interface number 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_neighbor
                        
                        	Neighbor information 
                        	**type**\:   :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor>`
                        
                        .. attribute:: virtual_link_neighbor_address
                        
                        	Virtual link neighbor addresss 
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: virtual_link_neighbor_id
                        
                        	Neighbor on other end of this virtual link
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: virtual_link_next_hello
                        
                        	Time until next hello (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_retransmission_interval
                        
                        	Retransmission interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_state
                        
                        	OSPF interface state for the virtual link
                        	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        .. attribute:: virtual_link_wait_interval
                        
                        	Wait interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virual_link_transmission_delay
                        
                        	Transmission delay in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink, self).__init__()

                            self.yang_name = "virtual-link"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"virtual-link-neighbor" : ("virtual_link_neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_link_authentication_enabled = YLeaf(YType.boolean, "is-virtual-link-authentication-enabled")

                            self.is_virtual_link_demand_circuit = YLeaf(YType.boolean, "is-virtual-link-demand-circuit")

                            self.is_virtual_link_encryption_enabled = YLeaf(YType.boolean, "is-virtual-link-encryption-enabled")

                            self.is_virtual_link_ip_security_active = YLeaf(YType.boolean, "is-virtual-link-ip-security-active")

                            self.is_virtual_link_ip_security_required = YLeaf(YType.boolean, "is-virtual-link-ip-security-required")

                            self.is_virtual_link_passive = YLeaf(YType.boolean, "is-virtual-link-passive")

                            self.transit_area_id = YLeaf(YType.str, "transit-area-id")

                            self.virtual_link_authentication_spi = YLeaf(YType.uint32, "virtual-link-authentication-spi")

                            self.virtual_link_authentication_transmit = YLeaf(YType.uint32, "virtual-link-authentication-transmit")

                            self.virtual_link_cost = YLeaf(YType.uint16, "virtual-link-cost")

                            self.virtual_link_dc_bitless_lsa = YLeaf(YType.uint32, "virtual-link-dc-bitless-lsa")

                            self.virtual_link_dead_interval = YLeaf(YType.uint32, "virtual-link-dead-interval")

                            self.virtual_link_encrypted_authentication_transmitted = YLeaf(YType.uint32, "virtual-link-encrypted-authentication-transmitted")

                            self.virtual_link_encryption_spi = YLeaf(YType.uint32, "virtual-link-encryption-spi")

                            self.virtual_link_encryption_transmitted = YLeaf(YType.uint32, "virtual-link-encryption-transmitted")

                            self.virtual_link_hello_interval = YLeaf(YType.uint32, "virtual-link-hello-interval")

                            self.virtual_link_interface_number = YLeaf(YType.uint32, "virtual-link-interface-number")

                            self.virtual_link_neighbor_address = YLeaf(YType.str, "virtual-link-neighbor-address")

                            self.virtual_link_neighbor_id = YLeaf(YType.str, "virtual-link-neighbor-id")

                            self.virtual_link_next_hello = YLeaf(YType.uint32, "virtual-link-next-hello")

                            self.virtual_link_retransmission_interval = YLeaf(YType.uint32, "virtual-link-retransmission-interval")

                            self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                            self.virtual_link_wait_interval = YLeaf(YType.uint32, "virtual-link-wait-interval")

                            self.virual_link_transmission_delay = YLeaf(YType.uint16, "virual-link-transmission-delay")

                            self.virtual_link_neighbor = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor()
                            self.virtual_link_neighbor.parent = self
                            self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                            self._children_yang_names.add("virtual-link-neighbor")
                            self._segment_path = lambda: "virtual-link"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink, ['interface_name', 'is_virtual_link_authentication_enabled', 'is_virtual_link_demand_circuit', 'is_virtual_link_encryption_enabled', 'is_virtual_link_ip_security_active', 'is_virtual_link_ip_security_required', 'is_virtual_link_passive', 'transit_area_id', 'virtual_link_authentication_spi', 'virtual_link_authentication_transmit', 'virtual_link_cost', 'virtual_link_dc_bitless_lsa', 'virtual_link_dead_interval', 'virtual_link_encrypted_authentication_transmitted', 'virtual_link_encryption_spi', 'virtual_link_encryption_transmitted', 'virtual_link_hello_interval', 'virtual_link_interface_number', 'virtual_link_neighbor_address', 'virtual_link_neighbor_id', 'virtual_link_next_hello', 'virtual_link_retransmission_interval', 'virtual_link_state', 'virtual_link_wait_interval', 'virual_link_transmission_delay'], name, value)


                        class VirtualLinkNeighbor(Entity):
                            """
                            Neighbor information 
                            
                            .. attribute:: is_virtual_link_hello_suppressed
                            
                            	If true, hello suppressed 
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_retransmission
                            
                            	Virtual link retransmission information 
                            	**type**\:   :py:class:`VirtualLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission>`
                            
                            .. attribute:: virtual_link_state
                            
                            	OSPF interface state for the virtual link
                            	**type**\:   :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor, self).__init__()

                                self.yang_name = "virtual-link-neighbor"
                                self.yang_parent_name = "virtual-link"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"virtual-link-retransmission" : ("virtual_link_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission)}
                                self._child_list_classes = {}

                                self.is_virtual_link_hello_suppressed = YLeaf(YType.boolean, "is-virtual-link-hello-suppressed")

                                self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                self.virtual_link_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission()
                                self.virtual_link_retransmission.parent = self
                                self._children_name_map["virtual_link_retransmission"] = "virtual-link-retransmission"
                                self._children_yang_names.add("virtual-link-retransmission")
                                self._segment_path = lambda: "virtual-link-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor, ['is_virtual_link_hello_suppressed', 'virtual_link_state'], name, value)


                            class VirtualLinkRetransmission(Entity):
                                """
                                Virtual link retransmission information 
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission, self).__init__()

                                    self.yang_name = "virtual-link-retransmission"
                                    self.yang_parent_name = "virtual-link-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.area_first_flood = YLeaf(YType.uint32, "area-first-flood")

                                    self.area_first_flood_index = YLeaf(YType.uint32, "area-first-flood-index")

                                    self.area_flood_index = YLeaf(YType.uint32, "area-flood-index")

                                    self.area_next_flood = YLeaf(YType.uint32, "area-next-flood")

                                    self.area_next_flood_index = YLeaf(YType.uint32, "area-next-flood-index")

                                    self.as_first_flood = YLeaf(YType.uint32, "as-first-flood")

                                    self.as_first_flood_index = YLeaf(YType.uint32, "as-first-flood-index")

                                    self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                    self.as_next_flood = YLeaf(YType.uint32, "as-next-flood")

                                    self.as_next_flood_index = YLeaf(YType.uint32, "as-next-flood-index")

                                    self.database_descriptor_retransmissions = YLeaf(YType.uint32, "database-descriptor-retransmissions")

                                    self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                    self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                    self.link_first_flood = YLeaf(YType.uint32, "link-first-flood")

                                    self.link_first_flood_index = YLeaf(YType.uint32, "link-first-flood-index")

                                    self.link_flood_index = YLeaf(YType.uint32, "link-flood-index")

                                    self.link_next_flood = YLeaf(YType.uint32, "link-next-flood")

                                    self.link_next_flood_index = YLeaf(YType.uint32, "link-next-flood-index")

                                    self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                    self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                    self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                    self.neighbor_retransmissions = YLeaf(YType.uint32, "neighbor-retransmissions")

                                    self.retransmissions = YLeaf(YType.uint32, "retransmissions")
                                    self._segment_path = lambda: "virtual-link-retransmission"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission, ['area_first_flood', 'area_first_flood_index', 'area_flood_index', 'area_next_flood', 'area_next_flood_index', 'as_first_flood', 'as_first_flood_index', 'as_flood_index', 'as_next_flood', 'as_next_flood_index', 'database_descriptor_retransmissions', 'last_retransmission_length', 'last_retransmission_time', 'link_first_flood', 'link_first_flood_index', 'link_flood_index', 'link_next_flood', 'link_next_flood_index', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmissions', 'retransmissions'], name, value)


                    class VrfStatistics(Entity):
                        """
                        Container for Statistics
                        
                        .. attribute:: prefix_priority_stats
                        
                        	OSPF Prefix SPF Prioritization statistics
                        	**type**\:   :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats>`
                        
                        .. attribute:: protocol_stats
                        
                        	Protocol table
                        	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats>`
                        
                        .. attribute:: rawio_stats
                        
                        	OSPF Prefix SPF Prioritization statistics
                        	**type**\:   :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats>`
                        
                        .. attribute:: spf_stats
                        
                        	OSPFv3 RIB batch statistics
                        	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats>`
                        
                        .. attribute:: vrf_rib_batch_stats
                        
                        	OSPFv3 RIB batch statistics
                        	**type**\:   :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics, self).__init__()

                            self.yang_name = "vrf-statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"prefix-priority-stats" : ("prefix_priority_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats), "protocol-stats" : ("protocol_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats), "rawio-stats" : ("rawio_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats), "spf-stats" : ("spf_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats), "vrf-rib-batch-stats" : ("vrf_rib_batch_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats)}
                            self._child_list_classes = {}

                            self.prefix_priority_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats()
                            self.prefix_priority_stats.parent = self
                            self._children_name_map["prefix_priority_stats"] = "prefix-priority-stats"
                            self._children_yang_names.add("prefix-priority-stats")

                            self.protocol_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats()
                            self.protocol_stats.parent = self
                            self._children_name_map["protocol_stats"] = "protocol-stats"
                            self._children_yang_names.add("protocol-stats")

                            self.rawio_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats()
                            self.rawio_stats.parent = self
                            self._children_name_map["rawio_stats"] = "rawio-stats"
                            self._children_yang_names.add("rawio-stats")

                            self.spf_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats()
                            self.spf_stats.parent = self
                            self._children_name_map["spf_stats"] = "spf-stats"
                            self._children_yang_names.add("spf-stats")

                            self.vrf_rib_batch_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats()
                            self.vrf_rib_batch_stats.parent = self
                            self._children_name_map["vrf_rib_batch_stats"] = "vrf-rib-batch-stats"
                            self._children_yang_names.add("vrf-rib-batch-stats")
                            self._segment_path = lambda: "vrf-statistics"


                        class PrefixPriorityStats(Entity):
                            """
                            OSPF Prefix SPF Prioritization statistics
                            
                            .. attribute:: critical
                            
                            	Critical priority classifications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high
                            
                            	High priority classifications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low
                            
                            	Low priority classifications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: medium
                            
                            	Medium priority classifications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats, self).__init__()

                                self.yang_name = "prefix-priority-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.critical = YLeaf(YType.uint32, "critical")

                                self.high = YLeaf(YType.uint32, "high")

                                self.low = YLeaf(YType.uint32, "low")

                                self.medium = YLeaf(YType.uint32, "medium")
                                self._segment_path = lambda: "prefix-priority-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats, ['critical', 'high', 'low', 'medium'], name, value)


                        class ProtocolStats(Entity):
                            """
                            Protocol table
                            
                            .. attribute:: protocol_stat
                            
                            	Protocol statistics for an interface
                            	**type**\: list of    :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats, self).__init__()

                                self.yang_name = "protocol-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"protocol-stat" : ("protocol_stat", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat)}

                                self.protocol_stat = YList(self)
                                self._segment_path = lambda: "protocol-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats, [], name, value)


                            class ProtocolStat(Entity):
                                """
                                Protocol statistics for an interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: checksum_err
                                
                                	Checksum Errors
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_in_ls_as
                                
                                	Database Description LSAs in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_in_packets
                                
                                	Database Description Packets in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_out_ls_as
                                
                                	Database Description LSAs out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_out_packets
                                
                                	Database Description Packets out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dropped_in_gs
                                
                                	Dropped in GS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: hello_in_packets
                                
                                	Hello packets in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: hello_out_packets
                                
                                	Hello Out Packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_in_ls_as
                                
                                	LS Ack LSAs in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_in_packets
                                
                                	LS Acks Packets in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_out_ls_as
                                
                                	LS Ack LSAs out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_out_packets
                                
                                	LS Ack Packets out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_in_ls_as
                                
                                	LS Requests in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_in_packets
                                
                                	LSA Requests in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_out_ls_as
                                
                                	LS Reuqests LSAs out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_out_packets
                                
                                	LS Request Packets out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_ignored
                                
                                	LS Updates ignored
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_ls_as
                                
                                	LS Updates LSAs in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_packets
                                
                                	LS Updates Packets in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_out_ls_as
                                
                                	LS Update LSAs out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_out_packets
                                
                                	LS Update Packets out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_in_packets
                                
                                	Total inputs packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_out_packets
                                
                                	Total Out Packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat, self).__init__()

                                    self.yang_name = "protocol-stat"
                                    self.yang_parent_name = "protocol-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.checksum_err = YLeaf(YType.uint64, "checksum-err")

                                    self.dbdes_in_ls_as = YLeaf(YType.uint64, "dbdes-in-ls-as")

                                    self.dbdes_in_packets = YLeaf(YType.uint64, "dbdes-in-packets")

                                    self.dbdes_out_ls_as = YLeaf(YType.uint64, "dbdes-out-ls-as")

                                    self.dbdes_out_packets = YLeaf(YType.uint64, "dbdes-out-packets")

                                    self.dropped_in_gs = YLeaf(YType.uint64, "dropped-in-gs")

                                    self.hello_in_packets = YLeaf(YType.uint64, "hello-in-packets")

                                    self.hello_out_packets = YLeaf(YType.uint64, "hello-out-packets")

                                    self.ls_ack_in_ls_as = YLeaf(YType.uint64, "ls-ack-in-ls-as")

                                    self.ls_ack_in_packets = YLeaf(YType.uint64, "ls-ack-in-packets")

                                    self.ls_ack_out_ls_as = YLeaf(YType.uint64, "ls-ack-out-ls-as")

                                    self.ls_ack_out_packets = YLeaf(YType.uint64, "ls-ack-out-packets")

                                    self.ls_req_in_ls_as = YLeaf(YType.uint64, "ls-req-in-ls-as")

                                    self.ls_req_in_packets = YLeaf(YType.uint64, "ls-req-in-packets")

                                    self.ls_req_out_ls_as = YLeaf(YType.uint64, "ls-req-out-ls-as")

                                    self.ls_req_out_packets = YLeaf(YType.uint64, "ls-req-out-packets")

                                    self.ls_upd_in_ignored = YLeaf(YType.uint64, "ls-upd-in-ignored")

                                    self.ls_upd_in_ls_as = YLeaf(YType.uint64, "ls-upd-in-ls-as")

                                    self.ls_upd_in_packets = YLeaf(YType.uint64, "ls-upd-in-packets")

                                    self.ls_upd_out_ls_as = YLeaf(YType.uint64, "ls-upd-out-ls-as")

                                    self.ls_upd_out_packets = YLeaf(YType.uint64, "ls-upd-out-packets")

                                    self.total_in_packets = YLeaf(YType.uint64, "total-in-packets")

                                    self.total_out_packets = YLeaf(YType.uint64, "total-out-packets")
                                    self._segment_path = lambda: "protocol-stat" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat, ['interface_name', 'checksum_err', 'dbdes_in_ls_as', 'dbdes_in_packets', 'dbdes_out_ls_as', 'dbdes_out_packets', 'dropped_in_gs', 'hello_in_packets', 'hello_out_packets', 'ls_ack_in_ls_as', 'ls_ack_in_packets', 'ls_ack_out_ls_as', 'ls_ack_out_packets', 'ls_req_in_ls_as', 'ls_req_in_packets', 'ls_req_out_ls_as', 'ls_req_out_packets', 'ls_upd_in_ignored', 'ls_upd_in_ls_as', 'ls_upd_in_packets', 'ls_upd_out_ls_as', 'ls_upd_out_packets', 'total_in_packets', 'total_out_packets'], name, value)


                        class RawioStats(Entity):
                            """
                            OSPF Prefix SPF Prioritization statistics
                            
                            .. attribute:: in_bytes
                            
                            	Received Bytes
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte
                            
                            .. attribute:: in_error_drops
                            
                            	In Error Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_handle_drops
                            
                            	In Handle Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_ipsec_drops
                            
                            	In IPSEC Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_long_packets
                            
                            	Received Long Packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_malloc_drops
                            
                            	In Malloc Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_packets
                            
                            	Received Packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_queue_drops
                            
                            	In Queue Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_short_drops
                            
                            	In Short Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_bytes
                            
                            	Sent Bytes
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte
                            
                            .. attribute:: out_error_drops
                            
                            	Error Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_ipsec_drops
                            
                            	Out IPSEC Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_nofd_drops
                            
                            	No FileDescriptor Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_nopak_drops
                            
                            	No Packet Buffers
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_packets
                            
                            	Packets Sent
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_pakapi_errors
                            
                            	PAK API Errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_close
                            
                            	Raw Connections Close
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_error
                            
                            	Raw Connections Error
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_open
                            
                            	Raw Connections Open
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_state
                            
                            	Raw Connection State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats, self).__init__()

                                self.yang_name = "rawio-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.in_bytes = YLeaf(YType.uint64, "in-bytes")

                                self.in_error_drops = YLeaf(YType.uint64, "in-error-drops")

                                self.in_handle_drops = YLeaf(YType.uint64, "in-handle-drops")

                                self.in_ipsec_drops = YLeaf(YType.uint64, "in-ipsec-drops")

                                self.in_long_packets = YLeaf(YType.uint64, "in-long-packets")

                                self.in_malloc_drops = YLeaf(YType.uint64, "in-malloc-drops")

                                self.in_packets = YLeaf(YType.uint64, "in-packets")

                                self.in_queue_drops = YLeaf(YType.uint64, "in-queue-drops")

                                self.in_short_drops = YLeaf(YType.uint64, "in-short-drops")

                                self.out_bytes = YLeaf(YType.uint64, "out-bytes")

                                self.out_error_drops = YLeaf(YType.uint64, "out-error-drops")

                                self.out_ipsec_drops = YLeaf(YType.uint64, "out-ipsec-drops")

                                self.out_nofd_drops = YLeaf(YType.uint64, "out-nofd-drops")

                                self.out_nopak_drops = YLeaf(YType.uint64, "out-nopak-drops")

                                self.out_packets = YLeaf(YType.uint64, "out-packets")

                                self.out_pakapi_errors = YLeaf(YType.uint64, "out-pakapi-errors")

                                self.raw_conn_close = YLeaf(YType.uint64, "raw-conn-close")

                                self.raw_conn_error = YLeaf(YType.uint64, "raw-conn-error")

                                self.raw_conn_open = YLeaf(YType.uint64, "raw-conn-open")

                                self.raw_conn_state = YLeaf(YType.uint32, "raw-conn-state")
                                self._segment_path = lambda: "rawio-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats, ['in_bytes', 'in_error_drops', 'in_handle_drops', 'in_ipsec_drops', 'in_long_packets', 'in_malloc_drops', 'in_packets', 'in_queue_drops', 'in_short_drops', 'out_bytes', 'out_error_drops', 'out_ipsec_drops', 'out_nofd_drops', 'out_nopak_drops', 'out_packets', 'out_pakapi_errors', 'raw_conn_close', 'raw_conn_error', 'raw_conn_open', 'raw_conn_state'], name, value)


                        class SpfStats(Entity):
                            """
                            OSPFv3 RIB batch statistics
                            
                            .. attribute:: spf_header
                            
                            	SPF statistics header
                            	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader>`
                            
                            .. attribute:: spf_runtime
                            
                            	List of SPF run\-time statistics
                            	**type**\: list of    :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats, self).__init__()

                                self.yang_name = "spf-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"spf-header" : ("spf_header", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader)}
                                self._child_list_classes = {"spf-runtime" : ("spf_runtime", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime)}

                                self.spf_header = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader()
                                self.spf_header.parent = self
                                self._children_name_map["spf_header"] = "spf-header"
                                self._children_yang_names.add("spf-header")

                                self.spf_runtime = YList(self)
                                self._segment_path = lambda: "spf-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats, [], name, value)


                            class SpfHeader(Entity):
                                """
                                SPF statistics header
                                
                                .. attribute:: area_summary
                                
                                	List of Areas with SPF statistics
                                	**type**\: list of    :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary>`
                                
                                .. attribute:: header_router_id
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sp_fs
                                
                                	Number of SPF calculations
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader, self).__init__()

                                    self.yang_name = "spf-header"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"area-summary" : ("area_summary", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary)}

                                    self.header_router_id = YLeaf(YType.str, "header-router-id")

                                    self.header_sp_fs = YLeaf(YType.uint32, "header-sp-fs")

                                    self.area_summary = YList(self)
                                    self._segment_path = lambda: "spf-header"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader, ['header_router_id', 'header_sp_fs'], name, value)


                                class AreaSummary(Entity):
                                    """
                                    List of Areas with SPF statistics
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID of the area SPF statistics
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sp_fs
                                    
                                    	Number of SPF calculations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary, self).__init__()

                                        self.yang_name = "area-summary"
                                        self.yang_parent_name = "spf-header"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.sp_fs = YLeaf(YType.uint32, "sp-fs")
                                        self._segment_path = lambda: "area-summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary, ['area_id', 'sp_fs'], name, value)


                            class SpfRuntime(Entity):
                                """
                                List of SPF run\-time statistics
                                
                                .. attribute:: area_stat
                                
                                	List of per\-area SPF statistics
                                	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat>`
                                
                                .. attribute:: global_time
                                
                                	Global SPF times
                                	**type**\:   :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime>`
                                
                                .. attribute:: lsa
                                
                                	List of LSAs triggering the SPF calculation
                                	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa>`
                                
                                .. attribute:: lsa_changes
                                
                                	Number of LSA changes triggering an SPF calculation
                                	**type**\:  int
                                
                                	**range:** \-32768..32767
                                
                                .. attribute:: reason_flags
                                
                                	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: rib_add_routes
                                
                                	Number of routes added to RIB
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_delete_routes
                                
                                	Number of routes deleted from RIB
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: start_time
                                
                                	SPF calculation start time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime, self).__init__()

                                    self.yang_name = "spf-runtime"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"global-time" : ("global_time", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime)}
                                    self._child_list_classes = {"area-stat" : ("area_stat", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat), "lsa" : ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa)}

                                    self.lsa_changes = YLeaf(YType.int16, "lsa-changes")

                                    self.reason_flags = YLeaf(YType.str, "reason-flags")

                                    self.rib_add_routes = YLeaf(YType.uint32, "rib-add-routes")

                                    self.rib_delete_routes = YLeaf(YType.uint32, "rib-delete-routes")

                                    self.start_time = YLeaf(YType.uint32, "start-time")

                                    self.global_time = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime()
                                    self.global_time.parent = self
                                    self._children_name_map["global_time"] = "global-time"
                                    self._children_yang_names.add("global-time")

                                    self.area_stat = YList(self)
                                    self.lsa = YList(self)
                                    self._segment_path = lambda: "spf-runtime"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime, ['lsa_changes', 'reason_flags', 'rib_add_routes', 'rib_delete_routes', 'start_time'], name, value)


                                class AreaStat(Entity):
                                    """
                                    List of per\-area SPF statistics
                                    
                                    .. attribute:: spf_stat_area_id
                                    
                                    	Area ID for area of these SPF statistics
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_stat_lsa_type_count
                                    
                                    	Counts of LSA types triggering an SPF calculation
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_stat_time
                                    
                                    	SPF time calculations
                                    	**type**\:   :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat, self).__init__()

                                        self.yang_name = "area-stat"
                                        self.yang_parent_name = "spf-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"spf-stat-time" : ("spf_stat_time", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime)}
                                        self._child_list_classes = {}

                                        self.spf_stat_area_id = YLeaf(YType.uint32, "spf-stat-area-id")

                                        self.spf_stat_lsa_type_count = YLeafList(YType.uint32, "spf-stat-lsa-type-count")

                                        self.spf_stat_time = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                        self.spf_stat_time.parent = self
                                        self._children_name_map["spf_stat_time"] = "spf-stat-time"
                                        self._children_yang_names.add("spf-stat-time")
                                        self._segment_path = lambda: "area-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat, ['spf_stat_area_id', 'spf_stat_lsa_type_count'], name, value)


                                    class SpfStatTime(Entity):
                                        """
                                        SPF time calculations
                                        
                                        .. attribute:: dijkstra
                                        
                                        	Dijkstra time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_prefix
                                        
                                        	External prefix processing time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_prefix_del
                                        
                                        	External prefix deletion time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inter_prefix
                                        
                                        	Inter\-prefix processing time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inter_prefix_del
                                        
                                        	Intra\-prefix deletion time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: intra_prefix
                                        
                                        	Intra\-prefix processing time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: intra_prefix_del
                                        
                                        	Intra\-prefix deletion time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_add
                                        
                                        	RIB add processing time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_del
                                        
                                        	RIB deletion time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, self).__init__()

                                            self.yang_name = "spf-stat-time"
                                            self.yang_parent_name = "area-stat"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.dijkstra = YLeaf(YType.uint32, "dijkstra")

                                            self.external_prefix = YLeaf(YType.uint32, "external-prefix")

                                            self.external_prefix_del = YLeaf(YType.uint32, "external-prefix-del")

                                            self.inter_prefix = YLeaf(YType.uint32, "inter-prefix")

                                            self.inter_prefix_del = YLeaf(YType.uint32, "inter-prefix-del")

                                            self.intra_prefix = YLeaf(YType.uint32, "intra-prefix")

                                            self.intra_prefix_del = YLeaf(YType.uint32, "intra-prefix-del")

                                            self.rib_add = YLeaf(YType.uint32, "rib-add")

                                            self.rib_del = YLeaf(YType.uint32, "rib-del")
                                            self._segment_path = lambda: "spf-stat-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, ['dijkstra', 'external_prefix', 'external_prefix_del', 'inter_prefix', 'inter_prefix_del', 'intra_prefix', 'intra_prefix_del', 'rib_add', 'rib_del'], name, value)


                                class GlobalTime(Entity):
                                    """
                                    Global SPF times
                                    
                                    .. attribute:: dijkstra
                                    
                                    	Dijkstra time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix
                                    
                                    	External prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix_del
                                    
                                    	External prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix
                                    
                                    	Inter\-prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix
                                    
                                    	Intra\-prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_add
                                    
                                    	RIB add processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_del
                                    
                                    	RIB deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime, self).__init__()

                                        self.yang_name = "global-time"
                                        self.yang_parent_name = "spf-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.dijkstra = YLeaf(YType.uint32, "dijkstra")

                                        self.external_prefix = YLeaf(YType.uint32, "external-prefix")

                                        self.external_prefix_del = YLeaf(YType.uint32, "external-prefix-del")

                                        self.inter_prefix = YLeaf(YType.uint32, "inter-prefix")

                                        self.inter_prefix_del = YLeaf(YType.uint32, "inter-prefix-del")

                                        self.intra_prefix = YLeaf(YType.uint32, "intra-prefix")

                                        self.intra_prefix_del = YLeaf(YType.uint32, "intra-prefix-del")

                                        self.rib_add = YLeaf(YType.uint32, "rib-add")

                                        self.rib_del = YLeaf(YType.uint32, "rib-del")
                                        self._segment_path = lambda: "global-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime, ['dijkstra', 'external_prefix', 'external_prefix_del', 'inter_prefix', 'inter_prefix_del', 'intra_prefix', 'intra_prefix_del', 'rib_add', 'rib_del'], name, value)


                                class Lsa(Entity):
                                    """
                                    List of LSAs triggering the SPF calculation
                                    
                                    .. attribute:: lsa_advertising_router
                                    
                                    	Advertising router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_flush
                                    
                                    	If true, the LSA change is a flush
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "spf-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.lsa_advertising_router = YLeaf(YType.str, "lsa-advertising-router")

                                        self.lsa_area_id = YLeaf(YType.uint32, "lsa-area-id")

                                        self.lsa_flush = YLeaf(YType.boolean, "lsa-flush")

                                        self.lsa_id = YLeaf(YType.str, "lsa-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")
                                        self._segment_path = lambda: "lsa"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa, ['lsa_advertising_router', 'lsa_area_id', 'lsa_flush', 'lsa_id', 'lsa_type'], name, value)


                        class VrfRibBatchStats(Entity):
                            """
                            OSPFv3 RIB batch statistics
                            
                            .. attribute:: batches_sent
                            
                            	No. of RIB batches sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_routes
                            
                            	Max No. of Routes in a batch
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add
                            
                            	No. of paths added to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add_errs
                            
                            	No. of paths add errors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del
                            
                            	No. of paths del sent to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del_errs
                            
                            	No. of Paths del errors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_pending
                            
                            	No. of paths waiting to be sent to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_sent
                            
                            	No. of Paths sent to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes_pending
                            
                            	No of Pending Routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes_sent
                            
                            	No. of Routes sent to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats, self).__init__()

                                self.yang_name = "vrf-rib-batch-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.batches_sent = YLeaf(YType.uint32, "batches-sent")

                                self.max_routes = YLeaf(YType.uint32, "max-routes")

                                self.paths_add = YLeaf(YType.uint32, "paths-add")

                                self.paths_add_errs = YLeaf(YType.uint32, "paths-add-errs")

                                self.paths_del = YLeaf(YType.uint32, "paths-del")

                                self.paths_del_errs = YLeaf(YType.uint32, "paths-del-errs")

                                self.paths_pending = YLeaf(YType.uint32, "paths-pending")

                                self.paths_sent = YLeaf(YType.uint32, "paths-sent")

                                self.routes_pending = YLeaf(YType.uint32, "routes-pending")

                                self.routes_sent = YLeaf(YType.uint32, "routes-sent")
                                self._segment_path = lambda: "vrf-rib-batch-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats, ['batches_sent', 'max_routes', 'paths_add', 'paths_add_errs', 'paths_del', 'paths_del_errs', 'paths_pending', 'paths_sent', 'routes_pending', 'routes_sent'], name, value)

    def clone_ptr(self):
        self._top_entity = Ospfv3()
        return self._top_entity

