""" Cisco_IOS_XR_mpls_ldp_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR mpls\-ldp package operational data.

This module contains definitions
for the following management objects\:
  mpls\-ldp\: MPLS LDP operational data

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class DhcbState(Enum):
    """
    DhcbState

    DHCB State Type

    .. data:: none = 0

    	None

    .. data:: dhcb_active = 1

    	Active

    .. data:: dhcb_passive = 2

    	Passive

    .. data:: dhcb_active_passive = 3

    	Active and Passive

    """

    none = Enum.YLeaf(0, "none")

    dhcb_active = Enum.YLeaf(1, "dhcb-active")

    dhcb_passive = Enum.YLeaf(2, "dhcb-passive")

    dhcb_active_passive = Enum.YLeaf(3, "dhcb-active-passive")


class L2vpnLdpPwAgi(Enum):
    """
    L2vpnLdpPwAgi

    L2vpn ldp pw agi

    .. data:: rd = 0

    	AGI type RD

    """

    rd = Enum.YLeaf(0, "rd")


class L2vpnLdpPwAii(Enum):
    """
    L2vpnLdpPwAii

    L2vpn ldp pw aii

    .. data:: local_id = 0

    	AII Type 1

    .. data:: type2 = 1

    	AII Type 2

    """

    local_id = Enum.YLeaf(0, "local-id")

    type2 = Enum.YLeaf(1, "type2")


class L2vpnLdpPwFec(Enum):
    """
    L2vpnLdpPwFec

    L2vpn ldp pw fec

    .. data:: fec128 = 0

    	FEC 128 pseudowire type

    .. data:: fec129 = 1

    	FEC 129 pseudowire type

    .. data:: fec130 = 2

    	FEC 130 pseudowire type

    .. data:: invalid = 3

    	FEC not applicable

    """

    fec128 = Enum.YLeaf(0, "fec128")

    fec129 = Enum.YLeaf(1, "fec129")

    fec130 = Enum.YLeaf(2, "fec130")

    invalid = Enum.YLeaf(3, "invalid")


class LabelValue(Enum):
    """
    LabelValue

    Label Value Type

    .. data:: mpls_label = 0

    	MPLS Label

    .. data:: un_labelled = 1

    	Unlabelled

    .. data:: unknown = 2

    	Unknown label

    """

    mpls_label = Enum.YLeaf(0, "mpls-label")

    un_labelled = Enum.YLeaf(1, "un-labelled")

    unknown = Enum.YLeaf(2, "unknown")


class LdpAdjUnionDiscrim(Enum):
    """
    LdpAdjUnionDiscrim

    MPLS LDP Hello Type

    .. data:: link_hello = 0

    	Link hello

    .. data:: targeted_hello = 1

    	Targeted hello

    """

    link_hello = Enum.YLeaf(0, "link-hello")

    targeted_hello = Enum.YLeaf(1, "targeted-hello")


class LdpAf(Enum):
    """
    LdpAf

    Ldp af

    .. data:: ldp_show_af_none = 0

    	No Address Family

    .. data:: ldp_show_af_ipv4 = 1

    	IPv4 AFI

    .. data:: ldp_show_af_ipv6 = 2

    	IPv6 AFI

    .. data:: ldp_show_af_ipv4_ipv6 = 3

    	Both IPv4/IPv6 AFIs

    """

    ldp_show_af_none = Enum.YLeaf(0, "ldp-show-af-none")

    ldp_show_af_ipv4 = Enum.YLeaf(1, "ldp-show-af-ipv4")

    ldp_show_af_ipv6 = Enum.YLeaf(2, "ldp-show-af-ipv6")

    ldp_show_af_ipv4_ipv6 = Enum.YLeaf(3, "ldp-show-af-ipv4-ipv6")


class LdpAfId(Enum):
    """
    LdpAfId

    Ldp af id

    .. data:: ldp_af_id_none = 0

    	No Address Family

    .. data:: ldp_af_id_ipv4 = 2

    	IPv4 AFI

    .. data:: ldp_af_id_ipv6 = 10

    	IPv6 AFI

    """

    ldp_af_id_none = Enum.YLeaf(0, "ldp-af-id-none")

    ldp_af_id_ipv4 = Enum.YLeaf(2, "ldp-af-id-ipv4")

    ldp_af_id_ipv6 = Enum.YLeaf(10, "ldp-af-id-ipv6")


class LdpFwdUnlblRsn(Enum):
    """
    LdpFwdUnlblRsn

    Ldp fwd unlbl rsn

    .. data:: ldp_fwd_labelled = 0

    	ldp fwd labelled

    .. data:: ldp_fwd_un_labelled_vrf_down = 1

    	ldp fwd un labelled vrf down

    .. data:: ldp_fwd_un_labelled_no_nh = 2

    	ldp fwd un labelled no nh

    .. data:: ldp_fwd_un_labelled_recursive_path = 3

    	ldp fwd un labelled recursive path

    .. data:: ldp_fwd_un_labelled_intf_not_ldp = 4

    	ldp fwd un labelled intf not ldp

    .. data:: ldp_fwd_un_labelled_no_rmt = 5

    	ldp fwd un labelled no rmt

    .. data:: ldp_fwd_un_labelled_no_ldp_adj = 6

    	ldp fwd un labelled no ldp adj

    .. data:: ldp_fwd_un_labelled_no_session = 7

    	ldp fwd un labelled no session

    .. data:: ldp_fwd_un_labelled_unknown = 8

    	ldp fwd un labelled unknown

    """

    ldp_fwd_labelled = Enum.YLeaf(0, "ldp-fwd-labelled")

    ldp_fwd_un_labelled_vrf_down = Enum.YLeaf(1, "ldp-fwd-un-labelled-vrf-down")

    ldp_fwd_un_labelled_no_nh = Enum.YLeaf(2, "ldp-fwd-un-labelled-no-nh")

    ldp_fwd_un_labelled_recursive_path = Enum.YLeaf(3, "ldp-fwd-un-labelled-recursive-path")

    ldp_fwd_un_labelled_intf_not_ldp = Enum.YLeaf(4, "ldp-fwd-un-labelled-intf-not-ldp")

    ldp_fwd_un_labelled_no_rmt = Enum.YLeaf(5, "ldp-fwd-un-labelled-no-rmt")

    ldp_fwd_un_labelled_no_ldp_adj = Enum.YLeaf(6, "ldp-fwd-un-labelled-no-ldp-adj")

    ldp_fwd_un_labelled_no_session = Enum.YLeaf(7, "ldp-fwd-un-labelled-no-session")

    ldp_fwd_un_labelled_unknown = Enum.YLeaf(8, "ldp-fwd-un-labelled-unknown")


class LdpIgpSyncDownReason(Enum):
    """
    LdpIgpSyncDownReason

    Reason IGP Sync Not Achieved

    .. data:: igp_sync_down_reason_not_applicable = 0

    	Not Applicable

    .. data:: no_hello_adjacency = 1

    	No hello adjacency

    .. data:: no_peer_session = 2

    	No peer session

    .. data:: initial_update_to_peer_not_done = 3

    	Initial update to peer not done yet

    .. data:: initial_update_from_peer_not_received = 4

    	Initial update from peer not received yet

    .. data:: internal_reason = 5

    	Internal reason

    """

    igp_sync_down_reason_not_applicable = Enum.YLeaf(0, "igp-sync-down-reason-not-applicable")

    no_hello_adjacency = Enum.YLeaf(1, "no-hello-adjacency")

    no_peer_session = Enum.YLeaf(2, "no-peer-session")

    initial_update_to_peer_not_done = Enum.YLeaf(3, "initial-update-to-peer-not-done")

    initial_update_from_peer_not_received = Enum.YLeaf(4, "initial-update-from-peer-not-received")

    internal_reason = Enum.YLeaf(5, "internal-reason")


class LdpIgpSyncState(Enum):
    """
    LdpIgpSyncState

    IGP Sync State

    .. data:: isync_ready = 0

    	Acheived

    .. data:: isync_not_ready = 1

    	Not acheived

    .. data:: isync_deferred = 2

    	Deferred due to interface delay or global

    	restart delay

    """

    isync_ready = Enum.YLeaf(0, "isync-ready")

    isync_not_ready = Enum.YLeaf(1, "isync-not-ready")

    isync_deferred = Enum.YLeaf(2, "isync-deferred")


class LdpRoutePathFlags(Enum):
    """
    LdpRoutePathFlags

    Route path flags

    .. data:: ip_path_no_flag = 0

    	A primary path with no special flag/attribute

    .. data:: ip_path_protected = 1

    	A primary path with LFA FRR protection

    .. data:: ip_path_backup = 2

    	A non-primary local LFA FRR (pure) backup path

    .. data:: ip_path_backup_remote = 3

    	A non-primary remote LFA FRR (pure) backup path

    .. data:: ip_path_bgp_backup = 4

    	A non-primary BGP backup path

    """

    ip_path_no_flag = Enum.YLeaf(0, "ip-path-no-flag")

    ip_path_protected = Enum.YLeaf(1, "ip-path-protected")

    ip_path_backup = Enum.YLeaf(2, "ip-path-backup")

    ip_path_backup_remote = Enum.YLeaf(3, "ip-path-backup-remote")

    ip_path_bgp_backup = Enum.YLeaf(4, "ip-path-bgp-backup")


class LdpRoutePathLblOwner(Enum):
    """
    LdpRoutePathLblOwner

    Route path label owner

    .. data:: ip_path_lbl_owner_none = 0

    	No label and no owner

    .. data:: ip_path_lbl_owner_ldp = 1

    	Path outgoing label owned by LDP

    .. data:: ip_path_lbl_owner_bgp = 2

    	Path outgoing label owned by BGP

    """

    ip_path_lbl_owner_none = Enum.YLeaf(0, "ip-path-lbl-owner-none")

    ip_path_lbl_owner_ldp = Enum.YLeaf(1, "ip-path-lbl-owner-ldp")

    ip_path_lbl_owner_bgp = Enum.YLeaf(2, "ip-path-lbl-owner-bgp")


class LocalLabelState(Enum):
    """
    LocalLabelState

    MPLS LDP Local Label State Type

    .. data:: local_label_state_none = 1

    	None

    .. data:: local_label_state_assigned = 2

    	Assigned

    .. data:: local_label_state_withdrawn = 3

    	Withdrawn

    """

    local_label_state_none = Enum.YLeaf(1, "local-label-state-none")

    local_label_state_assigned = Enum.YLeaf(2, "local-label-state-assigned")

    local_label_state_withdrawn = Enum.YLeaf(3, "local-label-state-withdrawn")


class MgmtLdpNbrBgpAdvtState(Enum):
    """
    MgmtLdpNbrBgpAdvtState

    MPLS LDP Neighbor BGP Label Advertisement State

    Type

    .. data:: not_applicable = 0

    	Not applicable

    .. data:: permit = 1

    	Advertisement permitted

    .. data:: deny = 2

    	Advertisement denied

    """

    not_applicable = Enum.YLeaf(0, "not-applicable")

    permit = Enum.YLeaf(1, "permit")

    deny = Enum.YLeaf(2, "deny")


class MgmtLdpNsrPeerLdpSyncNackRsn(Enum):
    """
    MgmtLdpNsrPeerLdpSyncNackRsn

    Mgmt ldp nsr peer ldp sync nack rsn

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_none = 0

    	mgmt ldp nsr peer ldp sync nack rsn none

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_tbl_id_mismatch = 1

    	mgmt ldp nsr peer ldp sync nack rsn tbl id

    	mismatch

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_pp_exists = 2

    	mgmt ldp nsr peer ldp sync nack rsn pp exists

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_missing_elem = 3

    	mgmt ldp nsr peer ldp sync nack rsn missing

    	elem

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_no_p_end_sock = 4

    	mgmt ldp nsr peer ldp sync nack rsn no p end

    	sock

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_p_end_sock_not_synced = 5

    	mgmt ldp nsr peer ldp sync nack rsn p end sock

    	not synced

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adj_add = 6

    	mgmt ldp nsr peer ldp sync nack rsn err adj add

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_dhcb_add = 7

    	mgmt ldp nsr peer ldp sync nack rsn err dhcb

    	add

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_enomem = 8

    	mgmt ldp nsr peer ldp sync nack rsn enomem

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_tp_create = 9

    	mgmt ldp nsr peer ldp sync nack rsn err tp

    	create

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_pp_create = 10

    	mgmt ldp nsr peer ldp sync nack rsn err pp

    	create

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_addr_bind = 11

    	mgmt ldp nsr peer ldp sync nack rsn err addr

    	bind

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_bad_pie = 12

    	mgmt ldp nsr peer ldp sync nack rsn err rx bad

    	pie

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_notif = 13

    	mgmt ldp nsr peer ldp sync nack rsn err rx

    	notif

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_unexp_open = 14

    	mgmt ldp nsr peer ldp sync nack rsn err rx

    	unexp open

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_unexp_peer_down = 15

    	mgmt ldp nsr peer ldp sync nack rsn err unexp

    	peer down

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_not_found = 16

    	mgmt ldp nsr peer ldp sync nack rsn err app not

    	found

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_invalid = 17

    	mgmt ldp nsr peer ldp sync nack rsn err app

    	invalid

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adj_grp_not_found = 18

    	mgmt ldp nsr peer ldp sync nack rsn err adj grp

    	not found

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_invalid_elem = 19

    	mgmt ldp nsr peer ldp sync nack rsn invalid

    	elem

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_data_invalid = 20

    	mgmt ldp nsr peer ldp sync nack rsn err app

    	data invalid

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_invalid_per_idx = 21

    	mgmt ldp nsr peer ldp sync nack rsn err invalid

    	per idx

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_pfx_not_found = 22

    	mgmt ldp nsr peer ldp sync nack rsn err pfx not

    	found

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_bm_size_invalid = 23

    	mgmt ldp nsr peer ldp sync nack rsn err bm size

    	invalid

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adv_bm_clear = 24

    	mgmt ldp nsr peer ldp sync nack rsn err adv bm

    	clear

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_tcp_struct_create = 25

    	mgmt ldp nsr peer ldp sync nack rsn err tcp

    	struct create

    .. data:: mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_no_ctx = 26

    	mgmt ldp nsr peer ldp sync nack rsn no ctx

    """

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_none = Enum.YLeaf(0, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-none")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_tbl_id_mismatch = Enum.YLeaf(1, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-tbl-id-mismatch")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_pp_exists = Enum.YLeaf(2, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-pp-exists")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_missing_elem = Enum.YLeaf(3, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-missing-elem")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_no_p_end_sock = Enum.YLeaf(4, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-no-p-end-sock")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_p_end_sock_not_synced = Enum.YLeaf(5, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-p-end-sock-not-synced")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adj_add = Enum.YLeaf(6, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-adj-add")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_dhcb_add = Enum.YLeaf(7, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-dhcb-add")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_enomem = Enum.YLeaf(8, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-enomem")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_tp_create = Enum.YLeaf(9, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-tp-create")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_pp_create = Enum.YLeaf(10, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-pp-create")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_addr_bind = Enum.YLeaf(11, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-addr-bind")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_bad_pie = Enum.YLeaf(12, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-rx-bad-pie")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_notif = Enum.YLeaf(13, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-rx-notif")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_rx_unexp_open = Enum.YLeaf(14, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-rx-unexp-open")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_unexp_peer_down = Enum.YLeaf(15, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-unexp-peer-down")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_not_found = Enum.YLeaf(16, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-app-not-found")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_invalid = Enum.YLeaf(17, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-app-invalid")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adj_grp_not_found = Enum.YLeaf(18, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-adj-grp-not-found")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_invalid_elem = Enum.YLeaf(19, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-invalid-elem")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_app_data_invalid = Enum.YLeaf(20, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-app-data-invalid")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_invalid_per_idx = Enum.YLeaf(21, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-invalid-per-idx")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_pfx_not_found = Enum.YLeaf(22, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-pfx-not-found")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_bm_size_invalid = Enum.YLeaf(23, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-bm-size-invalid")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_adv_bm_clear = Enum.YLeaf(24, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-adv-bm-clear")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_err_tcp_struct_create = Enum.YLeaf(25, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-err-tcp-struct-create")

    mgmt_ldp_nsr_peer_ldp_sync_nack_rsn_no_ctx = Enum.YLeaf(26, "mgmt-ldp-nsr-peer-ldp-sync-nack-rsn-no-ctx")


class MgmtLdpNsrPeerSyncErr(Enum):
    """
    MgmtLdpNsrPeerSyncErr

    Mgmt ldp nsr peer sync err

    .. data:: mgmt_ldp_nsr_peer_sync_err_none = 0

    	mgmt ldp nsr peer sync err none

    .. data:: mgmt_ldp_nsr_peer_sync_err_ldp_sync_nack = 1

    	mgmt ldp nsr peer sync err ldp sync nack

    .. data:: mgmt_ldp_nsr_peer_sync_err_sync_prep = 2

    	mgmt ldp nsr peer sync err sync prep

    .. data:: mgmt_ldp_nsr_peer_sync_err_tcp_peer = 3

    	mgmt ldp nsr peer sync err tcp peer

    .. data:: mgmt_ldp_nsr_peer_sync_err_tcp_gbl = 4

    	mgmt ldp nsr peer sync err tcp gbl

    .. data:: mgmt_ldp_nsr_peer_sync_err_ldp_peer = 5

    	mgmt ldp nsr peer sync err ldp peer

    .. data:: mgmt_ldp_nsr_peer_sync_err_ldp_gbl = 6

    	mgmt ldp nsr peer sync err ldp gbl

    .. data:: mgmt_ldp_nsr_peer_sync_err_app_fail = 7

    	mgmt ldp nsr peer sync err app fail

    .. data:: mgmt_ldp_nsr_peer_sync_err_sync_tcp_phase1 = 8

    	mgmt ldp nsr peer sync err sync tcp phase1

    .. data:: mgmt_ldp_nsr_peer_sync_err_sync_tcp_phase2 = 9

    	mgmt ldp nsr peer sync err sync tcp phase2

    """

    mgmt_ldp_nsr_peer_sync_err_none = Enum.YLeaf(0, "mgmt-ldp-nsr-peer-sync-err-none")

    mgmt_ldp_nsr_peer_sync_err_ldp_sync_nack = Enum.YLeaf(1, "mgmt-ldp-nsr-peer-sync-err-ldp-sync-nack")

    mgmt_ldp_nsr_peer_sync_err_sync_prep = Enum.YLeaf(2, "mgmt-ldp-nsr-peer-sync-err-sync-prep")

    mgmt_ldp_nsr_peer_sync_err_tcp_peer = Enum.YLeaf(3, "mgmt-ldp-nsr-peer-sync-err-tcp-peer")

    mgmt_ldp_nsr_peer_sync_err_tcp_gbl = Enum.YLeaf(4, "mgmt-ldp-nsr-peer-sync-err-tcp-gbl")

    mgmt_ldp_nsr_peer_sync_err_ldp_peer = Enum.YLeaf(5, "mgmt-ldp-nsr-peer-sync-err-ldp-peer")

    mgmt_ldp_nsr_peer_sync_err_ldp_gbl = Enum.YLeaf(6, "mgmt-ldp-nsr-peer-sync-err-ldp-gbl")

    mgmt_ldp_nsr_peer_sync_err_app_fail = Enum.YLeaf(7, "mgmt-ldp-nsr-peer-sync-err-app-fail")

    mgmt_ldp_nsr_peer_sync_err_sync_tcp_phase1 = Enum.YLeaf(8, "mgmt-ldp-nsr-peer-sync-err-sync-tcp-phase1")

    mgmt_ldp_nsr_peer_sync_err_sync_tcp_phase2 = Enum.YLeaf(9, "mgmt-ldp-nsr-peer-sync-err-sync-tcp-phase2")


class MgmtLdpNsrPeerSyncState(Enum):
    """
    MgmtLdpNsrPeerSyncState

    Mgmt ldp nsr peer sync state

    .. data:: mgmt_ldp_nsr_peer_sync_st_none = 0

    	mgmt ldp nsr peer sync st none

    .. data:: mgmt_ldp_nsr_peer_sync_st_wait = 1

    	mgmt ldp nsr peer sync st wait

    .. data:: mgmt_ldp_nsr_peer_sync_st_ready = 2

    	mgmt ldp nsr peer sync st ready

    .. data:: mgmt_ldp_nsr_peer_sync_st_prep = 3

    	mgmt ldp nsr peer sync st prep

    .. data:: mgmt_ldp_nsr_peer_sync_st_app_wait = 4

    	mgmt ldp nsr peer sync st app wait

    .. data:: mgmt_ldp_nsr_peer_sync_st_oper = 5

    	mgmt ldp nsr peer sync st oper

    .. data:: mgmt_ldp_nsr_peer_sync_st_tcp_phase1 = 6

    	mgmt ldp nsr peer sync st tcp phase1

    .. data:: mgmt_ldp_nsr_peer_sync_st_tcp_phase2 = 7

    	mgmt ldp nsr peer sync st tcp phase2

    """

    mgmt_ldp_nsr_peer_sync_st_none = Enum.YLeaf(0, "mgmt-ldp-nsr-peer-sync-st-none")

    mgmt_ldp_nsr_peer_sync_st_wait = Enum.YLeaf(1, "mgmt-ldp-nsr-peer-sync-st-wait")

    mgmt_ldp_nsr_peer_sync_st_ready = Enum.YLeaf(2, "mgmt-ldp-nsr-peer-sync-st-ready")

    mgmt_ldp_nsr_peer_sync_st_prep = Enum.YLeaf(3, "mgmt-ldp-nsr-peer-sync-st-prep")

    mgmt_ldp_nsr_peer_sync_st_app_wait = Enum.YLeaf(4, "mgmt-ldp-nsr-peer-sync-st-app-wait")

    mgmt_ldp_nsr_peer_sync_st_oper = Enum.YLeaf(5, "mgmt-ldp-nsr-peer-sync-st-oper")

    mgmt_ldp_nsr_peer_sync_st_tcp_phase1 = Enum.YLeaf(6, "mgmt-ldp-nsr-peer-sync-st-tcp-phase1")

    mgmt_ldp_nsr_peer_sync_st_tcp_phase2 = Enum.YLeaf(7, "mgmt-ldp-nsr-peer-sync-st-tcp-phase2")


class MplsLdpOperAfName(Enum):
    """
    MplsLdpOperAfName

    Mpls ldp oper af name

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    """

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")


class ShowNsrState(Enum):
    """
    ShowNsrState

    NSR State Type

    .. data:: nsr_ready = 0

    	NSR ready

    .. data:: nsr_not_ready = 1

    	NSR not ready

    .. data:: nsr_na = 2

    	NSR not applicable

    """

    nsr_ready = Enum.YLeaf(0, "nsr-ready")

    nsr_not_ready = Enum.YLeaf(1, "nsr-not-ready")

    nsr_na = Enum.YLeaf(2, "nsr-na")



class MplsLdp(Entity):
    """
    MPLS LDP operational data
    
    .. attribute:: global_
    
    	Global MPLS LDP operational data
    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_>`
    
    .. attribute:: nodes
    
    	Location MPLS LDP operational data
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes>`
    
    

    """

    _prefix = 'mpls-ldp-oper'
    _revision = '2017-05-01'

    def __init__(self):
        super(MplsLdp, self).__init__()
        self._top_entity = None

        self.yang_name = "mpls-ldp"
        self.yang_parent_name = "Cisco-IOS-XR-mpls-ldp-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"global" : ("global_", MplsLdp.Global_), "nodes" : ("nodes", MplsLdp.Nodes)}
        self._child_list_classes = {}

        self.global_ = MplsLdp.Global_()
        self.global_.parent = self
        self._children_name_map["global_"] = "global"
        self._children_yang_names.add("global")

        self.nodes = MplsLdp.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._children_yang_names.add("nodes")
        self._segment_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp"


    class Global_(Entity):
        """
        Global MPLS LDP operational data
        
        .. attribute:: active
        
        	Active MPLS LDP operational data
        	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active>`
        
        .. attribute:: standby
        
        	Standby MPLS LDP operational data
        	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby>`
        
        

        """

        _prefix = 'mpls-ldp-oper'
        _revision = '2017-05-01'

        def __init__(self):
            super(MplsLdp.Global_, self).__init__()

            self.yang_name = "global"
            self.yang_parent_name = "mpls-ldp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"active" : ("active", MplsLdp.Global_.Active), "standby" : ("standby", MplsLdp.Global_.Standby)}
            self._child_list_classes = {}

            self.active = MplsLdp.Global_.Active()
            self.active.parent = self
            self._children_name_map["active"] = "active"
            self._children_yang_names.add("active")

            self.standby = MplsLdp.Global_.Standby()
            self.standby.parent = self
            self._children_name_map["standby"] = "standby"
            self._children_yang_names.add("standby")
            self._segment_path = lambda: "global"
            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/%s" % self._segment_path()


        class Active(Entity):
            """
            Active MPLS LDP operational data
            
            .. attribute:: ato_mdb_table_entries
            
            	AToM DB Table
            	**type**\:   :py:class:`AtoMdbTableEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries>`
            
            .. attribute:: bindings_summary_all
            
            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
            	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.BindingsSummaryAll>`
            
            .. attribute:: default_vrf
            
            	DefaultVRF specific operational data
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf>`
            
            .. attribute:: discovery_summary_all
            
            	Summary information regarding LDP discovery
            	**type**\:   :py:class:`DiscoverySummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DiscoverySummaryAll>`
            
            .. attribute:: forwarding_summary_all
            
            	Summary information regarding LDP forwarding setup
            	**type**\:   :py:class:`ForwardingSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.ForwardingSummaryAll>`
            
            .. attribute:: nsr_summary_all
            
            	Summary information regarding LDP NSR State
            	**type**\:   :py:class:`NsrSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.NsrSummaryAll>`
            
            .. attribute:: summary
            
            	LDP summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Summary>`
            
            .. attribute:: vrfs
            
            	VRF specific operational data
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs>`
            
            

            """

            _prefix = 'mpls-ldp-oper'
            _revision = '2017-05-01'

            def __init__(self):
                super(MplsLdp.Global_.Active, self).__init__()

                self.yang_name = "active"
                self.yang_parent_name = "global"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"ato-mdb-table-entries" : ("ato_mdb_table_entries", MplsLdp.Global_.Active.AtoMdbTableEntries), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Global_.Active.BindingsSummaryAll), "default-vrf" : ("default_vrf", MplsLdp.Global_.Active.DefaultVrf), "discovery-summary-all" : ("discovery_summary_all", MplsLdp.Global_.Active.DiscoverySummaryAll), "forwarding-summary-all" : ("forwarding_summary_all", MplsLdp.Global_.Active.ForwardingSummaryAll), "nsr-summary-all" : ("nsr_summary_all", MplsLdp.Global_.Active.NsrSummaryAll), "summary" : ("summary", MplsLdp.Global_.Active.Summary), "vrfs" : ("vrfs", MplsLdp.Global_.Active.Vrfs)}
                self._child_list_classes = {}

                self.ato_mdb_table_entries = MplsLdp.Global_.Active.AtoMdbTableEntries()
                self.ato_mdb_table_entries.parent = self
                self._children_name_map["ato_mdb_table_entries"] = "ato-mdb-table-entries"
                self._children_yang_names.add("ato-mdb-table-entries")

                self.bindings_summary_all = MplsLdp.Global_.Active.BindingsSummaryAll()
                self.bindings_summary_all.parent = self
                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                self._children_yang_names.add("bindings-summary-all")

                self.default_vrf = MplsLdp.Global_.Active.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._children_yang_names.add("default-vrf")

                self.discovery_summary_all = MplsLdp.Global_.Active.DiscoverySummaryAll()
                self.discovery_summary_all.parent = self
                self._children_name_map["discovery_summary_all"] = "discovery-summary-all"
                self._children_yang_names.add("discovery-summary-all")

                self.forwarding_summary_all = MplsLdp.Global_.Active.ForwardingSummaryAll()
                self.forwarding_summary_all.parent = self
                self._children_name_map["forwarding_summary_all"] = "forwarding-summary-all"
                self._children_yang_names.add("forwarding-summary-all")

                self.nsr_summary_all = MplsLdp.Global_.Active.NsrSummaryAll()
                self.nsr_summary_all.parent = self
                self._children_name_map["nsr_summary_all"] = "nsr-summary-all"
                self._children_yang_names.add("nsr-summary-all")

                self.summary = MplsLdp.Global_.Active.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.vrfs = MplsLdp.Global_.Active.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
                self._children_yang_names.add("vrfs")
                self._segment_path = lambda: "active"
                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/%s" % self._segment_path()


            class AtoMdbTableEntries(Entity):
                """
                AToM DB Table
                
                .. attribute:: ato_mdb_table_entry
                
                	Entries in AToM DB
                	**type**\: list of    :py:class:`AtoMdbTableEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Active.AtoMdbTableEntries, self).__init__()

                    self.yang_name = "ato-mdb-table-entries"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ato-mdb-table-entry" : ("ato_mdb_table_entry", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry)}

                    self.ato_mdb_table_entry = YList(self)
                    self._segment_path = lambda: "ato-mdb-table-entries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries, [], name, value)


                class AtoMdbTableEntry(Entity):
                    """
                    Entries in AToM DB
                    
                    .. attribute:: agi
                    
                    	AGI
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: agi_type
                    
                    	AGI Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: fe_ctype
                    
                    	FEC Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: fec_info
                    
                    	Pseudowire FEC information
                    	**type**\:   :py:class:`FecInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo>`
                    
                    .. attribute:: mapping_tlv_count
                    
                    	TLV Count from Label Mapping Message
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: notification_tlv_count
                    
                    	TLV Count from Notification Message
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: peer_id
                    
                    	Peer ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: peer_id_xr
                    
                    	Peer ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_ac_id
                    
                    	SAII AC ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_global_id
                    
                    	SAII Global ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_local_id
                    
                    	SAII Local ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: saii_prefix
                    
                    	SAII Prefix
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: saii_type
                    
                    	SAII Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_ac_id
                    
                    	TAII AC ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_global_id
                    
                    	TAII Global ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_local_id
                    
                    	TAII Local ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: taii_prefix
                    
                    	TAII Prefix
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: taii_type
                    
                    	TAII Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry, self).__init__()

                        self.yang_name = "ato-mdb-table-entry"
                        self.yang_parent_name = "ato-mdb-table-entries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"fec-info" : ("fec_info", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo)}
                        self._child_list_classes = {}

                        self.agi = YLeaf(YType.int32, "agi")

                        self.agi_type = YLeaf(YType.int32, "agi-type")

                        self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                        self.mapping_tlv_count = YLeaf(YType.uint32, "mapping-tlv-count")

                        self.notification_tlv_count = YLeaf(YType.uint32, "notification-tlv-count")

                        self.peer_id = YLeaf(YType.str, "peer-id")

                        self.peer_id_xr = YLeaf(YType.str, "peer-id-xr")

                        self.pw_id = YLeaf(YType.int32, "pw-id")

                        self.saii_ac_id = YLeaf(YType.int32, "saii-ac-id")

                        self.saii_global_id = YLeaf(YType.int32, "saii-global-id")

                        self.saii_local_id = YLeaf(YType.str, "saii-local-id")

                        self.saii_prefix = YLeaf(YType.str, "saii-prefix")

                        self.saii_type = YLeaf(YType.int32, "saii-type")

                        self.taii_ac_id = YLeaf(YType.int32, "taii-ac-id")

                        self.taii_global_id = YLeaf(YType.int32, "taii-global-id")

                        self.taii_local_id = YLeaf(YType.str, "taii-local-id")

                        self.taii_prefix = YLeaf(YType.str, "taii-prefix")

                        self.taii_type = YLeaf(YType.int32, "taii-type")

                        self.fec_info = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo()
                        self.fec_info.parent = self
                        self._children_name_map["fec_info"] = "fec-info"
                        self._children_yang_names.add("fec-info")
                        self._segment_path = lambda: "ato-mdb-table-entry"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry, ['agi', 'agi_type', 'fe_ctype', 'mapping_tlv_count', 'notification_tlv_count', 'peer_id', 'peer_id_xr', 'pw_id', 'saii_ac_id', 'saii_global_id', 'saii_local_id', 'saii_prefix', 'saii_type', 'taii_ac_id', 'taii_global_id', 'taii_local_id', 'taii_prefix', 'taii_type'], name, value)


                    class FecInfo(Entity):
                        """
                        Pseudowire FEC information
                        
                        .. attribute:: fe_ctype
                        
                        	FECType
                        	**type**\:   :py:class:`L2vpnLdpPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwFec>`
                        
                        .. attribute:: fec128
                        
                        	fec128
                        	**type**\:   :py:class:`Fec128 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128>`
                        
                        .. attribute:: fec129
                        
                        	fec129
                        	**type**\:   :py:class:`Fec129 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129>`
                        
                        .. attribute:: fec130
                        
                        	fec130
                        	**type**\:   :py:class:`Fec130 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, self).__init__()

                            self.yang_name = "fec-info"
                            self.yang_parent_name = "ato-mdb-table-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"fec128" : ("fec128", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128), "fec129" : ("fec129", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129), "fec130" : ("fec130", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130)}
                            self._child_list_classes = {}

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.fec128 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128()
                            self.fec128.parent = self
                            self._children_name_map["fec128"] = "fec128"
                            self._children_yang_names.add("fec128")

                            self.fec129 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129()
                            self.fec129.parent = self
                            self._children_name_map["fec129"] = "fec129"
                            self._children_yang_names.add("fec129")

                            self.fec130 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130()
                            self.fec130.parent = self
                            self._children_name_map["fec130"] = "fec130"
                            self._children_yang_names.add("fec130")
                            self._segment_path = lambda: "fec-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, ['fe_ctype'], name, value)


                        class Fec128(Entity):
                            """
                            fec128
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, self).__init__()

                                self.yang_name = "fec128"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")
                                self._segment_path = lambda: "fec128"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, ['pseudowire_id'], name, value)


                        class Fec129(Entity):
                            """
                            fec129
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:   :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:   :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii>`
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifier
                            	**type**\:   :py:class:`Taii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, self).__init__()

                                self.yang_name = "fec129"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"agi" : ("agi", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi), "saii" : ("saii", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii), "taii" : ("taii", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii)}
                                self._child_list_classes = {}

                                self.agi = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"
                                self._children_yang_names.add("agi")

                                self.saii = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._children_yang_names.add("saii")

                                self.taii = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii()
                                self.taii.parent = self
                                self._children_name_map["taii"] = "taii"
                                self._children_yang_names.add("taii")
                                self._segment_path = lambda: "fec129"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:   :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:   :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"agi1" : ("agi1", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1)}
                                    self._child_list_classes = {}

                                    self.agi_type = YLeaf(YType.enumeration, "agi-type")

                                    self.agi1 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._children_yang_names.add("agi1")
                                    self._segment_path = lambda: "agi"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.rd = YLeaf(YType.uint64, "rd")
                                        self._segment_path = lambda: "agi1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/agi/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1), "aii2" : ("aii2", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "saii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/saii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/saii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


                            class Taii(Entity):
                                """
                                Target Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, self).__init__()

                                    self.yang_name = "taii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1), "aii2" : ("aii2", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "taii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/taii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/taii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


                        class Fec130(Entity):
                            """
                            fec130
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:   :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:   :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, self).__init__()

                                self.yang_name = "fec130"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"agi" : ("agi", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi), "saii" : ("saii", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii)}
                                self._child_list_classes = {}

                                self.agi = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"
                                self._children_yang_names.add("agi")

                                self.saii = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._children_yang_names.add("saii")
                                self._segment_path = lambda: "fec130"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:   :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:   :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"agi1" : ("agi1", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1)}
                                    self._child_list_classes = {}

                                    self.agi_type = YLeaf(YType.enumeration, "agi-type")

                                    self.agi1 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._children_yang_names.add("agi1")
                                    self._segment_path = lambda: "agi"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.rd = YLeaf(YType.uint64, "rd")
                                        self._segment_path = lambda: "agi1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/agi/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1), "aii2" : ("aii2", MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "saii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/saii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/saii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


            class BindingsSummaryAll(Entity):
                """
                Aggregate VRF counters for the LDP Label
                Infomation Base (LIB)
                
                .. attribute:: address_family
                
                	Address Family
                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                
                .. attribute:: bind_af
                
                	bind af
                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.BindingsSummaryAll.BindAf>`
                
                .. attribute:: binding_local_explicit_null
                
                	Number of local explicit null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_implicit_null
                
                	Number of local implicit null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_no_route
                
                	Local bindings with no route
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_non_null
                
                	Number of local non\-null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_null
                
                	Number of local null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_oor
                
                	Number of local bindings        needing label \- OOR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_no_route
                
                	Bindings with no route
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: highest_allocated_label
                
                	Highest allocated label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lowest_allocated_label
                
                	Lowest allocated label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.BindingsSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Active.BindingsSummaryAll, self).__init__()

                    self.yang_name = "bindings-summary-all"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.BindingsSummaryAll.Vrf)}
                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Active.BindingsSummaryAll.BindAf)}

                    self.address_family = YLeaf(YType.enumeration, "address-family")

                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                    self.vrf = MplsLdp.Global_.Active.BindingsSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")

                    self.bind_af = YList(self)
                    self._segment_path = lambda: "bindings-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Active.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                class BindAf(Entity):
                    """
                    bind af
                    
                    .. attribute:: address_family
                    
                    	Binding Summary Address Family
                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: binding_local
                    
                    	Number of local bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_remote
                    
                    	Number of remote bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_total
                    
                    	Total bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_lib_update
                    
                    	Last update to LIB local binding
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lib_minimum_revision_sent_all
                    
                    	Last update sent to all peers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.BindingsSummaryAll.BindAf, self).__init__()

                        self.yang_name = "bind-af"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.address_family = YLeaf(YType.enumeration, "address-family")

                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                        self._segment_path = lambda: "bind-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/bindings-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.BindingsSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/bindings-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


            class DefaultVrf(Entity):
                """
                DefaultVRF specific operational data
                
                .. attribute:: afs
                
                	Address Family specific operational data
                	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs>`
                
                .. attribute:: backoff_parameters
                
                	The LDP Backoff Parameters
                	**type**\:   :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.BackoffParameters>`
                
                .. attribute:: backoffs
                
                	The LDP backoff
                	**type**\:   :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Backoffs>`
                
                .. attribute:: capabilities
                
                	LDP capability database information
                	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Capabilities>`
                
                .. attribute:: graceful_restart
                
                	LDP Graceful Restart info
                	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.GracefulRestart>`
                
                .. attribute:: issu
                
                	LDP ISSU related information
                	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu>`
                
                .. attribute:: ldp_id
                
                	Local LDP Id
                	**type**\:   :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.LdpId>`
                
                .. attribute:: neighbor_briefs
                
                	The LDP Neighbors (brief)
                	**type**\:   :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs>`
                
                .. attribute:: neighbor_capabilities
                
                	LDP Neighbors Capabilities
                	**type**\:   :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities>`
                
                .. attribute:: neighbors
                
                	The LDP Neighbors
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors>`
                
                .. attribute:: nsr
                
                	LDP NSR related information
                	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr>`
                
                .. attribute:: parameters
                
                	LDP parameters
                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Parameters>`
                
                .. attribute:: statistics
                
                	The LDP Statistics
                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Statistics>`
                
                .. attribute:: summary
                
                	LDP VRF summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Summary>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Active.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"afs" : ("afs", MplsLdp.Global_.Active.DefaultVrf.Afs), "backoff-parameters" : ("backoff_parameters", MplsLdp.Global_.Active.DefaultVrf.BackoffParameters), "backoffs" : ("backoffs", MplsLdp.Global_.Active.DefaultVrf.Backoffs), "capabilities" : ("capabilities", MplsLdp.Global_.Active.DefaultVrf.Capabilities), "graceful-restart" : ("graceful_restart", MplsLdp.Global_.Active.DefaultVrf.GracefulRestart), "issu" : ("issu", MplsLdp.Global_.Active.DefaultVrf.Issu), "ldp-id" : ("ldp_id", MplsLdp.Global_.Active.DefaultVrf.LdpId), "neighbor-briefs" : ("neighbor_briefs", MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs), "neighbor-capabilities" : ("neighbor_capabilities", MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities), "neighbors" : ("neighbors", MplsLdp.Global_.Active.DefaultVrf.Neighbors), "nsr" : ("nsr", MplsLdp.Global_.Active.DefaultVrf.Nsr), "parameters" : ("parameters", MplsLdp.Global_.Active.DefaultVrf.Parameters), "statistics" : ("statistics", MplsLdp.Global_.Active.DefaultVrf.Statistics), "summary" : ("summary", MplsLdp.Global_.Active.DefaultVrf.Summary)}
                    self._child_list_classes = {}

                    self.afs = MplsLdp.Global_.Active.DefaultVrf.Afs()
                    self.afs.parent = self
                    self._children_name_map["afs"] = "afs"
                    self._children_yang_names.add("afs")

                    self.backoff_parameters = MplsLdp.Global_.Active.DefaultVrf.BackoffParameters()
                    self.backoff_parameters.parent = self
                    self._children_name_map["backoff_parameters"] = "backoff-parameters"
                    self._children_yang_names.add("backoff-parameters")

                    self.backoffs = MplsLdp.Global_.Active.DefaultVrf.Backoffs()
                    self.backoffs.parent = self
                    self._children_name_map["backoffs"] = "backoffs"
                    self._children_yang_names.add("backoffs")

                    self.capabilities = MplsLdp.Global_.Active.DefaultVrf.Capabilities()
                    self.capabilities.parent = self
                    self._children_name_map["capabilities"] = "capabilities"
                    self._children_yang_names.add("capabilities")

                    self.graceful_restart = MplsLdp.Global_.Active.DefaultVrf.GracefulRestart()
                    self.graceful_restart.parent = self
                    self._children_name_map["graceful_restart"] = "graceful-restart"
                    self._children_yang_names.add("graceful-restart")

                    self.issu = MplsLdp.Global_.Active.DefaultVrf.Issu()
                    self.issu.parent = self
                    self._children_name_map["issu"] = "issu"
                    self._children_yang_names.add("issu")

                    self.ldp_id = MplsLdp.Global_.Active.DefaultVrf.LdpId()
                    self.ldp_id.parent = self
                    self._children_name_map["ldp_id"] = "ldp-id"
                    self._children_yang_names.add("ldp-id")

                    self.neighbor_briefs = MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs()
                    self.neighbor_briefs.parent = self
                    self._children_name_map["neighbor_briefs"] = "neighbor-briefs"
                    self._children_yang_names.add("neighbor-briefs")

                    self.neighbor_capabilities = MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities()
                    self.neighbor_capabilities.parent = self
                    self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"
                    self._children_yang_names.add("neighbor-capabilities")

                    self.neighbors = MplsLdp.Global_.Active.DefaultVrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.nsr = MplsLdp.Global_.Active.DefaultVrf.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"
                    self._children_yang_names.add("nsr")

                    self.parameters = MplsLdp.Global_.Active.DefaultVrf.Parameters()
                    self.parameters.parent = self
                    self._children_name_map["parameters"] = "parameters"
                    self._children_yang_names.add("parameters")

                    self.statistics = MplsLdp.Global_.Active.DefaultVrf.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._children_yang_names.add("statistics")

                    self.summary = MplsLdp.Global_.Active.DefaultVrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")
                    self._segment_path = lambda: "default-vrf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()


                class Afs(Entity):
                    """
                    Address Family specific operational data
                    
                    .. attribute:: af
                    
                    	Operational data for given Address Family
                    	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Afs, self).__init__()

                        self.yang_name = "afs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"af" : ("af", MplsLdp.Global_.Active.DefaultVrf.Afs.Af)}

                        self.af = YList(self)
                        self._segment_path = lambda: "afs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs, [], name, value)


                    class Af(Entity):
                        """
                        Operational data for given Address Family
                        
                        .. attribute:: af_name  <key>
                        
                        	Address Family name
                        	**type**\:   :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                        
                        .. attribute:: bindings
                        
                        	The LDP Bindings
                        	**type**\:   :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings>`
                        
                        .. attribute:: bindings_advertise_spec
                        
                        	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec>`
                        
                        .. attribute:: bindings_summary
                        
                        	Counters for the LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary>`
                        
                        .. attribute:: bindings_summary_all
                        
                        	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll>`
                        
                        .. attribute:: discovery
                        
                        	The LDP Discovery
                        	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery>`
                        
                        .. attribute:: forwarding_summary
                        
                        	Summary information regarding LDP forwarding setup
                        	**type**\:   :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary>`
                        
                        .. attribute:: forwardings
                        
                        	The LDP Forwarding rewrites
                        	**type**\:   :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings>`
                        
                        .. attribute:: igp
                        
                        	LDP IGP related information
                        	**type**\:   :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp>`
                        
                        .. attribute:: interface_summary
                        
                        	IPv4 interface summary information
                        	**type**\:   :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.InterfaceSummary>`
                        
                        .. attribute:: interfaces
                        
                        	LDP Interface related information
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af, self).__init__()

                            self.yang_name = "af"
                            self.yang_parent_name = "afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"bindings" : ("bindings", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings), "bindings-advertise-spec" : ("bindings_advertise_spec", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec), "bindings-summary" : ("bindings_summary", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll), "discovery" : ("discovery", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery), "forwarding-summary" : ("forwarding_summary", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary), "forwardings" : ("forwardings", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings), "igp" : ("igp", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp), "interface-summary" : ("interface_summary", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.InterfaceSummary), "interfaces" : ("interfaces", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces)}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.bindings = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings()
                            self.bindings.parent = self
                            self._children_name_map["bindings"] = "bindings"
                            self._children_yang_names.add("bindings")

                            self.bindings_advertise_spec = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec()
                            self.bindings_advertise_spec.parent = self
                            self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"
                            self._children_yang_names.add("bindings-advertise-spec")

                            self.bindings_summary = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary()
                            self.bindings_summary.parent = self
                            self._children_name_map["bindings_summary"] = "bindings-summary"
                            self._children_yang_names.add("bindings-summary")

                            self.bindings_summary_all = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll()
                            self.bindings_summary_all.parent = self
                            self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                            self._children_yang_names.add("bindings-summary-all")

                            self.discovery = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery()
                            self.discovery.parent = self
                            self._children_name_map["discovery"] = "discovery"
                            self._children_yang_names.add("discovery")

                            self.forwarding_summary = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary()
                            self.forwarding_summary.parent = self
                            self._children_name_map["forwarding_summary"] = "forwarding-summary"
                            self._children_yang_names.add("forwarding-summary")

                            self.forwardings = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings()
                            self.forwardings.parent = self
                            self._children_name_map["forwardings"] = "forwardings"
                            self._children_yang_names.add("forwardings")

                            self.igp = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp()
                            self.igp.parent = self
                            self._children_name_map["igp"] = "igp"
                            self._children_yang_names.add("igp")

                            self.interface_summary = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.InterfaceSummary()
                            self.interface_summary.parent = self
                            self._children_name_map["interface_summary"] = "interface-summary"
                            self._children_yang_names.add("interface-summary")

                            self.interfaces = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                            self._children_yang_names.add("interfaces")
                            self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/afs/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af, ['af_name'], name, value)


                        class Bindings(Entity):
                            """
                            The LDP Bindings
                            
                            .. attribute:: binding
                            
                            	Binding Information
                            	**type**\: list of    :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings, self).__init__()

                                self.yang_name = "bindings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"binding" : ("binding", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding)}

                                self.binding = YList(self)
                                self._segment_path = lambda: "bindings"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings, [], name, value)


                            class Binding(Entity):
                                """
                                Binding Information
                                
                                .. attribute:: prefix  <key>
                                
                                	The IP Prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: advertise_prefix_acl
                                
                                	Advertise Prerfix ACL
                                	**type**\:  str
                                
                                .. attribute:: advertise_tsr_acl
                                
                                	Advertise TSR ACL
                                	**type**\:  str
                                
                                .. attribute:: config_enforced_local_label_value
                                
                                	Config/User enforced local label value
                                	**type**\:  bool
                                
                                .. attribute:: is_elc
                                
                                	Is the entry entropy label capable
                                	**type**\:  bool
                                
                                .. attribute:: is_no_route
                                
                                	No route
                                	**type**\:  bool
                                
                                .. attribute:: label_oor
                                
                                	Label space depletion OOR
                                	**type**\:  bool
                                
                                .. attribute:: le_local_binding_revision
                                
                                	Local Binding revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_label_state
                                
                                	Local label state
                                	**type**\:   :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peers_acked
                                
                                	Peers that have ACKed this entry
                                	**type**\: list of    :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                
                                .. attribute:: peers_advertised_to
                                
                                	Peers this entry is advertised to
                                	**type**\: list of    :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                
                                .. attribute:: remote_binding
                                
                                	Remote binding
                                	**type**\: list of    :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding, self).__init__()

                                    self.yang_name = "binding"
                                    self.yang_parent_name = "bindings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr), "vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf)}
                                    self._child_list_classes = {"peers-acked" : ("peers_acked", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked), "peers-advertised-to" : ("peers_advertised_to", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo), "remote-binding" : ("remote_binding", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.advertise_prefix_acl = YLeaf(YType.str, "advertise-prefix-acl")

                                    self.advertise_tsr_acl = YLeaf(YType.str, "advertise-tsr-acl")

                                    self.config_enforced_local_label_value = YLeaf(YType.boolean, "config-enforced-local-label-value")

                                    self.is_elc = YLeaf(YType.boolean, "is-elc")

                                    self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                    self.le_local_binding_revision = YLeaf(YType.uint32, "le-local-binding-revision")

                                    self.le_local_label_state = YLeaf(YType.enumeration, "le-local-label-state")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                    self.prefix_xr = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"
                                    self._children_yang_names.add("prefix-xr")

                                    self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.peers_acked = YList(self)
                                    self.peers_advertised_to = YList(self)
                                    self.remote_binding = YList(self)
                                    self._segment_path = lambda: "binding" + "[prefix='" + self.prefix.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding, ['prefix', 'advertise_prefix_acl', 'advertise_tsr_acl', 'config_enforced_local_label_value', 'is_elc', 'is_no_route', 'label_oor', 'le_local_binding_revision', 'le_local_label_state', 'local_label', 'prefix_length'], name, value)


                                class PeersAcked(Entity):
                                    """
                                    Peers that have ACKed this entry
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                        self.yang_name = "peers-acked"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                        self._segment_path = lambda: "peers-acked"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class PeersAdvertisedTo(Entity):
                                    """
                                    Peers this entry is advertised to
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                        self.yang_name = "peers-advertised-to"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                        self._segment_path = lambda: "peers-advertised-to"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "prefix-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class RemoteBinding(Entity):
                                    """
                                    Remote binding
                                    
                                    .. attribute:: assigning_peer_ldp_ident
                                    
                                    	Assigning peer
                                    	**type**\:   :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_stale
                                    
                                    	Is the entry stale
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                        self.yang_name = "remote-binding"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"assigning-peer-ldp-ident" : ("assigning_peer_ldp_ident", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent)}
                                        self._child_list_classes = {}

                                        self.is_elc = YLeaf(YType.boolean, "is-elc")

                                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.assigning_peer_ldp_ident = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                        self.assigning_peer_ldp_ident.parent = self
                                        self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                        self._children_yang_names.add("assigning-peer-ldp-ident")
                                        self._segment_path = lambda: "remote-binding"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, ['is_elc', 'is_stale', 'remote_label'], name, value)


                                    class AssigningPeerLdpIdent(Entity):
                                        """
                                        Assigning peer
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                            self.yang_name = "assigning-peer-ldp-ident"
                                            self.yang_parent_name = "remote-binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "assigning-peer-ldp-ident"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, ['id', 'name'], name, value)


                        class BindingsAdvertiseSpec(Entity):
                            """
                            Advertisement Spec (ACL) for LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: advt_acl
                            
                            	Advertisement ACLs
                            	**type**\: list of    :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                            
                            .. attribute:: allocation_acl
                            
                            	Local label Allocation filter
                            	**type**\:   :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                self.yang_name = "bindings-advertise-spec"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"allocation-acl" : ("allocation_acl", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)}
                                self._child_list_classes = {"advt-acl" : ("advt_acl", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl)}

                                self.allocation_acl = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                self.allocation_acl.parent = self
                                self._children_name_map["allocation_acl"] = "allocation-acl"
                                self._children_yang_names.add("allocation-acl")

                                self.advt_acl = YList(self)
                                self._segment_path = lambda: "bindings-advertise-spec"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                            class AdvtAcl(Entity):
                                """
                                Advertisement ACLs
                                
                                .. attribute:: peer_acl
                                
                                	Peer ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                    self.yang_name = "advt-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.peer_acl = YLeaf(YType.str, "peer-acl")

                                    self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                    self._segment_path = lambda: "advt-acl"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, ['peer_acl', 'prefix_acl'], name, value)


                            class AllocationAcl(Entity):
                                """
                                Local label Allocation filter
                                
                                .. attribute:: has_acl
                                
                                	Has ACL filter?
                                	**type**\:  bool
                                
                                .. attribute:: is_host_route_only
                                
                                	Host\-routes only?
                                	**type**\:  bool
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                    self.yang_name = "allocation-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.has_acl = YLeaf(YType.boolean, "has-acl")

                                    self.is_host_route_only = YLeaf(YType.boolean, "is-host-route-only")

                                    self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                    self._segment_path = lambda: "allocation-acl"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, ['has_acl', 'is_host_route_only', 'prefix_acl'], name, value)


                        class BindingsSummary(Entity):
                            """
                            Counters for the LDP Label Infomation Base
                            (LIB)
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.BindAf>`
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary, self).__init__()

                                self.yang_name = "bindings-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf)}
                                self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.BindAf)}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local = YLeaf(YType.uint32, "binding-local")

                                    self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                    self.binding_total = YLeaf(YType.uint32, "binding-total")

                                    self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                    self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                    self._segment_path = lambda: "bind-af"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummary.Vrf, ['id', 'name'], name, value)


                        class BindingsSummaryAll(Entity):
                            """
                            Aggregate VRF counters for the LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf>`
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll, self).__init__()

                                self.yang_name = "bindings-summary-all"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf)}
                                self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf)}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary-all"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary-all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local = YLeaf(YType.uint32, "binding-local")

                                    self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                    self.binding_total = YLeaf(YType.uint32, "binding-total")

                                    self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                    self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                    self._segment_path = lambda: "bind-af"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary-all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


                        class Discovery(Entity):
                            """
                            The LDP Discovery
                            
                            .. attribute:: brief
                            
                            	Brief information on LDP discovery
                            	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief>`
                            
                            .. attribute:: link_hellos
                            
                            	The LDP Discovery link
                            	**type**\:   :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos>`
                            
                            .. attribute:: stats
                            
                            	The LDP Discovery Statistics
                            	**type**\:   :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats>`
                            
                            .. attribute:: summary
                            
                            	Summarized information on LDP discovery
                            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary>`
                            
                            .. attribute:: targeted_hellos
                            
                            	The LDP Discovery Targeted
                            	**type**\:   :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery, self).__init__()

                                self.yang_name = "discovery"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"brief" : ("brief", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief), "link-hellos" : ("link_hellos", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos), "stats" : ("stats", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats), "summary" : ("summary", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary), "targeted-hellos" : ("targeted_hellos", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos)}
                                self._child_list_classes = {}

                                self.brief = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief()
                                self.brief.parent = self
                                self._children_name_map["brief"] = "brief"
                                self._children_yang_names.add("brief")

                                self.link_hellos = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos()
                                self.link_hellos.parent = self
                                self._children_name_map["link_hellos"] = "link-hellos"
                                self._children_yang_names.add("link-hellos")

                                self.stats = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats()
                                self.stats.parent = self
                                self._children_name_map["stats"] = "stats"
                                self._children_yang_names.add("stats")

                                self.summary = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"
                                self._children_yang_names.add("summary")

                                self.targeted_hellos = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos()
                                self.targeted_hellos.parent = self
                                self._children_name_map["targeted_hellos"] = "targeted-hellos"
                                self._children_yang_names.add("targeted-hellos")
                                self._segment_path = lambda: "discovery"


                            class Brief(Entity):
                                """
                                Brief information on LDP discovery
                                
                                .. attribute:: link_hello_briefs
                                
                                	The LDP Discovery link brief information
                                	**type**\:   :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                
                                .. attribute:: targeted_hello_briefs
                                
                                	The LDP Discovery Targeted brief information
                                	**type**\:   :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief, self).__init__()

                                    self.yang_name = "brief"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"link-hello-briefs" : ("link_hello_briefs", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs), "targeted-hello-briefs" : ("targeted_hello_briefs", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs)}
                                    self._child_list_classes = {}

                                    self.link_hello_briefs = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                    self.link_hello_briefs.parent = self
                                    self._children_name_map["link_hello_briefs"] = "link-hello-briefs"
                                    self._children_yang_names.add("link-hello-briefs")

                                    self.targeted_hello_briefs = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                    self.targeted_hello_briefs.parent = self
                                    self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                    self._children_yang_names.add("targeted-hello-briefs")
                                    self._segment_path = lambda: "brief"


                                class LinkHelloBriefs(Entity):
                                    """
                                    The LDP Discovery link brief information
                                    
                                    .. attribute:: link_hello_brief
                                    
                                    	Brief information on LDP link discovery
                                    	**type**\: list of    :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                        self.yang_name = "link-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"link-hello-brief" : ("link_hello_brief", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief)}

                                        self.link_hello_brief = YList(self)
                                        self._segment_path = lambda: "link-hello-briefs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                    class LinkHelloBrief(Entity):
                                        """
                                        Brief information on LDP link discovery
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: address_family
                                        
                                        	Discovery Brief Address Family
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: address_family_set
                                        
                                        	Discovery Brief Address Family Set
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                            self.yang_name = "link-hello-brief"
                                            self.yang_parent_name = "link-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)}
                                            self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.address_family = YLeaf(YType.enumeration, "address-family")

                                            self.address_family_set = YLeaf(YType.enumeration, "address-family-set")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', 'address_family', 'address_family_set', 'interface', 'interface_name_xr'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_up = YLeaf(YType.boolean, "session-up")
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, ['id', 'name'], name, value)


                                class TargetedHelloBriefs(Entity):
                                    """
                                    The LDP Discovery Targeted brief information
                                    
                                    .. attribute:: targeted_hello_brief
                                    
                                    	Brief information on LDP targeted discovery
                                    	**type**\: list of    :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                        self.yang_name = "targeted-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"targeted-hello-brief" : ("targeted_hello_brief", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief)}

                                        self.targeted_hello_brief = YList(self)
                                        self._segment_path = lambda: "targeted-hello-briefs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                    class TargetedHelloBrief(Entity):
                                        """
                                        Brief information on LDP targeted discovery
                                        
                                        .. attribute:: address_family
                                        
                                        	Targeted Discovery Address Family
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                            self.yang_name = "targeted-hello-brief"
                                            self.yang_parent_name = "targeted-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"dhcb-target-address" : ("dhcb_target_address", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress), "vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)}
                                            self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation)}

                                            self.address_family = YLeaf(YType.enumeration, "address-family")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.target_address = YLeaf(YType.str, "target-address")

                                            self.dhcb_target_address = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                            self._children_yang_names.add("dhcb-target-address")

                                            self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "targeted-hello-brief"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['address_family', 'local_address', 'target_address'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_up = YLeaf(YType.boolean, "session-up")
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, ['id', 'name'], name, value)


                            class LinkHellos(Entity):
                                """
                                The LDP Discovery link
                                
                                .. attribute:: link_hello
                                
                                	Information on LDP link discovery
                                	**type**\: list of    :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                    self.yang_name = "link-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"link-hello" : ("link_hello", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello)}

                                    self.link_hello = YList(self)
                                    self._segment_path = lambda: "link-hellos"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                class LinkHello(Entity):
                                    """
                                    Information on LDP link discovery
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: discovery_link_af
                                    
                                    	LDP hello AF info
                                    	**type**\: list of    :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                    
                                    .. attribute:: hello_information
                                    
                                    	LDP hello info
                                    	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                        self.yang_name = "link-hello"
                                        self.yang_parent_name = "link-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)}
                                        self._child_list_classes = {"discovery-link-af" : ("discovery_link_af", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf), "hello-information" : ("hello_information", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.next_hello = YLeaf(YType.uint32, "next-hello")

                                        self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                        self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.discovery_link_af = YList(self)
                                        self.hello_information = YList(self)
                                        self._segment_path = lambda: "link-hello" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', 'interface', 'interface_name_xr', 'next_hello', 'quick_start_disabled'], name, value)


                                    class DiscoveryLinkAf(Entity):
                                        """
                                        LDP hello AF info
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_src_address
                                        
                                        	Local source address
                                        	**type**\:   :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                        
                                        .. attribute:: local_transport_address
                                        
                                        	Local transport address
                                        	**type**\:   :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                            self.yang_name = "discovery-link-af"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-src-address" : ("local_src_address", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress), "local-transport-address" : ("local_transport_address", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress)}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.local_src_address = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                            self.local_src_address.parent = self
                                            self._children_name_map["local_src_address"] = "local-src-address"
                                            self._children_yang_names.add("local-src-address")

                                            self.local_transport_address = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                            self.local_transport_address.parent = self
                                            self._children_name_map["local_transport_address"] = "local-transport-address"
                                            self._children_yang_names.add("local-transport-address")
                                            self._segment_path = lambda: "discovery-link-af"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, ['interval'], name, value)


                                        class LocalSrcAddress(Entity):
                                            """
                                            Local source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                self.yang_name = "local-src-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-src-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class LocalTransportAddress(Entity):
                                            """
                                            Local transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                self.yang_name = "local-transport-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-transport-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class HelloInformation(Entity):
                                        """
                                        LDP hello info
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: hold_time
                                        
                                        	Session hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: is_no_route
                                        
                                        	Is route valid
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_targeted
                                        
                                        	Is session a targeted session
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_ldp_identifier
                                        
                                        	Neighbor LDP Identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_src_address
                                        
                                        	Neighbor source address
                                        	**type**\:   :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                        
                                        .. attribute:: neighbor_transport_address
                                        
                                        	Neighbor transport address
                                        	**type**\:   :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\:  str
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\:  bool
                                        
                                        .. attribute:: target
                                        
                                        	Target address
                                        	**type**\:   :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                            self.yang_name = "hello-information"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-src-address" : ("neighbor_src_address", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress), "neighbor-transport-address" : ("neighbor_transport_address", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress), "target" : ("target", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)}
                                            self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo)}

                                            self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                            self.established_age = YLeaf(YType.uint64, "established-age")

                                            self.established_time = YLeaf(YType.uint64, "established-time")

                                            self.hold_time = YLeaf(YType.uint32, "hold-time")

                                            self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                            self.is_targeted = YLeaf(YType.boolean, "is-targeted")

                                            self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                            self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                            self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                            self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                            self.session_up = YLeaf(YType.boolean, "session-up")

                                            self.neighbor_src_address = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                            self.neighbor_src_address.parent = self
                                            self._children_name_map["neighbor_src_address"] = "neighbor-src-address"
                                            self._children_yang_names.add("neighbor-src-address")

                                            self.neighbor_transport_address = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                            self.neighbor_transport_address.parent = self
                                            self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"
                                            self._children_yang_names.add("neighbor-transport-address")

                                            self.target = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                            self.target.parent = self
                                            self._children_name_map["target"] = "target"
                                            self._children_yang_names.add("target")

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "hello-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, ['disc_expiry', 'established_age', 'established_time', 'hold_time', 'is_no_route', 'is_targeted', 'local_hold_time', 'neighbor_hold_time', 'neighbor_ldp_identifier', 'session_bringup_failure_reason', 'session_up'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\:  str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                self._segment_path = lambda: "last-session-down-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                                        class NeighborSrcAddress(Entity):
                                            """
                                            Neighbor source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                self.yang_name = "neighbor-src-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "neighbor-src-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class NeighborTransportAddress(Entity):
                                            """
                                            Neighbor transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                self.yang_name = "neighbor-transport-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "neighbor-transport-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class Target(Entity):
                                            """
                                            Target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                self.yang_name = "target"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, ['id', 'name'], name, value)


                            class Stats(Entity):
                                """
                                The LDP Discovery Statistics
                                
                                .. attribute:: stat
                                
                                	Information on LDP discovery statistics
                                	**type**\: list of    :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats.Stat>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats, self).__init__()

                                    self.yang_name = "stats"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"stat" : ("stat", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats.Stat)}

                                    self.stat = YList(self)
                                    self._segment_path = lambda: "stats"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats, [], name, value)


                                class Stat(Entity):
                                    """
                                    Information on LDP discovery statistics
                                    
                                    .. attribute:: adjacency_group_up_time
                                    
                                    	Adjacency group up time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tcp_arb_chg_count
                                    
                                    	Count of changes in TCP arbitration
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_open_count
                                    
                                    	Count of attempted TCP opens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_role
                                    
                                    	TCP Role
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                        self.yang_name = "stat"
                                        self.yang_parent_name = "stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.adjacency_group_up_time = YLeaf(YType.uint32, "adjacency-group-up-time")

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.tcp_arb_chg_count = YLeaf(YType.uint32, "tcp-arb-chg-count")

                                        self.tcp_open_count = YLeaf(YType.uint32, "tcp-open-count")

                                        self.tcp_role = YLeaf(YType.uint32, "tcp-role")
                                        self._segment_path = lambda: "stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Stats.Stat, ['adjacency_group_up_time', 'label_space_id', 'lsr_id', 'tcp_arb_chg_count', 'tcp_open_count', 'tcp_role'], name, value)


                            class Summary(Entity):
                                """
                                Summarized information on LDP discovery
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP identifier
                                	**type**\:  str
                                
                                .. attribute:: num_of_active_ldp_interfaces
                                
                                	Number of active LDP enabled interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_addr_recv
                                
                                	Number of hello discoveries received with bad source address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_hello_pdu
                                
                                	Number of hello discoveries received with bad hello PDU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_xport_addr
                                
                                	Number of hello discoveries received with bad export address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_same_router_id
                                
                                	Number of hello discoveries received with the same router id as this router
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_wrong_router_id
                                
                                	Number of hello discoveries received with the router id that is not destined for this router
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_ldp_interfaces
                                
                                	Total Number of LDP configured interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_recv
                                
                                	Number of link hello discoveries in recv state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_xmit
                                
                                	Number of link hello discoveries in xmit state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_recv
                                
                                	Number of targeted hello discoveries in recv state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_xmit
                                
                                	Number of targeted hello discoveries in xmit state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary, self).__init__()

                                    self.yang_name = "summary"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf)}
                                    self._child_list_classes = {}

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                                    self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                                    self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                                    self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                                    self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                                    self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                                    self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                                    self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                                    self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                                    self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                                    self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                                    self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, ['id', 'name'], name, value)


                            class TargetedHellos(Entity):
                                """
                                The LDP Discovery Targeted
                                
                                .. attribute:: targeted_hello
                                
                                	Information on LDP targeted discovery
                                	**type**\: list of    :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                    self.yang_name = "targeted-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"targeted-hello" : ("targeted_hello", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello)}

                                    self.targeted_hello = YList(self)
                                    self._segment_path = lambda: "targeted-hellos"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                class TargetedHello(Entity):
                                    """
                                    Information on LDP targeted discovery
                                    
                                    .. attribute:: adjacency_ldp_identifier
                                    
                                    	Adjacency LDP Identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcb_local_address
                                    
                                    	DHCB local address
                                    	**type**\:   :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                    
                                    .. attribute:: dhcb_target_address
                                    
                                    	DHCB target address
                                    	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                    
                                    .. attribute:: disc_expiry
                                    
                                    	Discovery expiry time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: established_age
                                    
                                    	Hello adjacency estabished age in nanosec
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: established_time
                                    
                                    	Hello adjacency estabished time in nanosec
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: hold_time
                                    
                                    	Targeted hello hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval in sec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_session_down_info
                                    
                                    	Last session down information
                                    	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: local_hold_time
                                    
                                    	Local hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_hold_time
                                    
                                    	Neighbor hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: session_bringup_failure_reason
                                    
                                    	session bringup failure reason
                                    	**type**\:  str
                                    
                                    .. attribute:: session_up
                                    
                                    	Is session up for this adj
                                    	**type**\:  bool
                                    
                                    .. attribute:: state
                                    
                                    	Targeted hello state
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	The target IP Address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                        self.yang_name = "targeted-hello"
                                        self.yang_parent_name = "targeted-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"dhcb-local-address" : ("dhcb_local_address", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress), "dhcb-target-address" : ("dhcb_target_address", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)}
                                        self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo)}

                                        self.adjacency_ldp_identifier = YLeaf(YType.str, "adjacency-ldp-identifier")

                                        self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                        self.established_age = YLeaf(YType.uint64, "established-age")

                                        self.established_time = YLeaf(YType.uint64, "established-time")

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                        self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                        self.next_hello = YLeaf(YType.uint32, "next-hello")

                                        self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                        self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                        self.session_up = YLeaf(YType.boolean, "session-up")

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.target_address = YLeaf(YType.str, "target-address")

                                        self.dhcb_local_address = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                        self.dhcb_local_address.parent = self
                                        self._children_name_map["dhcb_local_address"] = "dhcb-local-address"
                                        self._children_yang_names.add("dhcb-local-address")

                                        self.dhcb_target_address = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                        self.dhcb_target_address.parent = self
                                        self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                        self._children_yang_names.add("dhcb-target-address")

                                        self.last_session_down_info = YList(self)
                                        self._segment_path = lambda: "targeted-hello"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['adjacency_ldp_identifier', 'disc_expiry', 'established_age', 'established_time', 'hold_time', 'interval', 'local_address', 'local_hold_time', 'neighbor_hold_time', 'next_hello', 'quick_start_disabled', 'session_bringup_failure_reason', 'session_up', 'state', 'target_address'], name, value)


                                    class DhcbLocalAddress(Entity):
                                        """
                                        DHCB local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                            self.yang_name = "dhcb-local-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "dhcb-local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class DhcbTargetAddress(Entity):
                                        """
                                        DHCB target address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                            self.yang_name = "dhcb-target-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "dhcb-target-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class LastSessionDownInfo(Entity):
                                        """
                                        Last session down information
                                        
                                        .. attribute:: last_session_down_reason
                                        
                                        	The reason of last socket failure
                                        	**type**\:  str
                                        
                                        .. attribute:: last_session_down_time
                                        
                                        	Timestamp of when the last session went down
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_session_up_time
                                        
                                        	The time duration the last session was up
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                            self.yang_name = "last-session-down-info"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                            self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                            self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                            self._segment_path = lambda: "last-session-down-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                        class ForwardingSummary(Entity):
                            """
                            Summary information regarding LDP forwarding
                            setup
                            
                            .. attribute:: fsht
                            
                            	Forwarding state hold time registered with LSD
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: intfs
                            
                            	MPLS forwarding enabled interface count
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_lsd_bound
                            
                            	LDP is connected to LSD server
                            	**type**\:  bool
                            
                            .. attribute:: lbls
                            
                            	Local label allocated count
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: rws
                            
                            	Forwarding rewrites summary
                            	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary, self).__init__()

                                self.yang_name = "forwarding-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"rws" : ("rws", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws), "vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf)}
                                self._child_list_classes = {}

                                self.fsht = YLeaf(YType.uint16, "fsht")

                                self.intfs = YLeaf(YType.uint16, "intfs")

                                self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                                self.lbls = YLeaf(YType.uint16, "lbls")

                                self.rws = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws()
                                self.rws.parent = self
                                self._children_name_map["rws"] = "rws"
                                self._children_yang_names.add("rws")

                                self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "forwarding-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                            class Rws(Entity):
                                """
                                Forwarding rewrites summary
                                
                                .. attribute:: nhs
                                
                                	Forwarding rewrites nexthops (paths) summary
                                	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                
                                .. attribute:: pfxs
                                
                                	Forwarding rewrites prefix summary
                                	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                    self.yang_name = "rws"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs)}
                                    self._child_list_classes = {}

                                    self.nhs = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                    self.nhs.parent = self
                                    self._children_name_map["nhs"] = "nhs"
                                    self._children_yang_names.add("nhs")

                                    self.pfxs = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                    self.pfxs.parent = self
                                    self._children_name_map["pfxs"] = "pfxs"
                                    self._children_yang_names.add("pfxs")
                                    self._segment_path = lambda: "rws"


                                class Nhs(Entity):
                                    """
                                    Forwarding rewrites nexthops (paths) summary
                                    
                                    .. attribute:: backup_paths
                                    
                                    	Count of non\-primary backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_backup_paths
                                    
                                    	Count of labeled backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_paths
                                    
                                    	Count of all labeled paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: protected_paths
                                    
                                    	Count of FRR protected paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_backup_paths
                                    
                                    	Count of non\-primary remote backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_paths
                                    
                                    	Total path count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                        self.yang_name = "nhs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                                        self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                                        self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                                        self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                                        self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                                        self.total_paths = YLeaf(YType.uint32, "total-paths")
                                        self._segment_path = lambda: "nhs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                                class Pfxs(Entity):
                                    """
                                    Forwarding rewrites prefix summary
                                    
                                    .. attribute:: ecmp_pfxs
                                    
                                    	Count of prefixes with ECMP
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: labeled_pfxs_aggr
                                    
                                    	Labeled prefix count for all paths
                                    	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                    
                                    .. attribute:: labeled_pfxs_backup
                                    
                                    	Labeled prefix count related to backup paths only
                                    	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                    
                                    .. attribute:: labeled_pfxs_primary
                                    
                                    	Labeled prefix count related to primary paths only
                                    	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                    
                                    .. attribute:: protected_pfxs
                                    
                                    	Count of FRR protected prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: total_pfxs
                                    
                                    	Total Prefix count
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                        self.yang_name = "pfxs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)}
                                        self._child_list_classes = {}

                                        self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                                        self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                                        self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                                        self.labeled_pfxs_aggr = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                        self.labeled_pfxs_aggr.parent = self
                                        self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                                        self._children_yang_names.add("labeled-pfxs-aggr")

                                        self.labeled_pfxs_backup = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                        self.labeled_pfxs_backup.parent = self
                                        self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                        self._children_yang_names.add("labeled-pfxs-backup")

                                        self.labeled_pfxs_primary = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                        self.labeled_pfxs_primary.parent = self
                                        self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                                        self._children_yang_names.add("labeled-pfxs-primary")
                                        self._segment_path = lambda: "pfxs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                                    class LabeledPfxsAggr(Entity):
                                        """
                                        Labeled prefix count for all paths
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                            self.yang_name = "labeled-pfxs-aggr"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-aggr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsBackup(Entity):
                                        """
                                        Labeled prefix count related to backup paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                            self.yang_name = "labeled-pfxs-backup"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-backup"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsPrimary(Entity):
                                        """
                                        Labeled prefix count related to primary paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                            self.yang_name = "labeled-pfxs-primary"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-primary"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, ['id', 'name'], name, value)


                        class Forwardings(Entity):
                            """
                            The LDP Forwarding rewrites
                            
                            .. attribute:: forwarding
                            
                            	Information on a particular LDP forwarding rewrite
                            	**type**\: list of    :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings, self).__init__()

                                self.yang_name = "forwardings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"forwarding" : ("forwarding", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding)}

                                self.forwarding = YList(self)
                                self._segment_path = lambda: "forwardings"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings, [], name, value)


                            class Forwarding(Entity):
                                """
                                Information on a particular LDP forwarding
                                rewrite
                                
                                .. attribute:: prefix  <key>
                                
                                	The IP Prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: paths
                                
                                	Paths
                                	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                
                                .. attribute:: route
                                
                                	Route
                                	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route>`
                                
                                .. attribute:: table_id
                                
                                	Table ID associated with IP prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                    self.yang_name = "forwarding"
                                    self.yang_parent_name = "forwardings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr), "route" : ("route", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route), "vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf)}
                                    self._child_list_classes = {"paths" : ("paths", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                    self.table_id = YLeaf(YType.uint32, "table-id")

                                    self.prefix_xr = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"
                                    self._children_yang_names.add("prefix-xr")

                                    self.route = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route()
                                    self.route.parent = self
                                    self._children_name_map["route"] = "route"
                                    self._children_yang_names.add("route")

                                    self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.paths = YList(self)
                                    self._segment_path = lambda: "forwarding" + "[prefix='" + self.prefix.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding, ['prefix', 'prefix_length', 'table_id'], name, value)


                                class Paths(Entity):
                                    """
                                    Paths
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                        self.yang_name = "paths"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls), "routing" : ("routing", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)}
                                        self._child_list_classes = {}

                                        self.mpls = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._children_yang_names.add("mpls")

                                        self.routing = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"
                                        self._children_yang_names.add("routing")
                                        self._segment_path = lambda: "paths"


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: mpls_outgoing_info
                                        
                                        	MPLS nexthop info
                                        	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo), "remote-lfa" : ("remote_lfa", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa)}
                                            self._child_list_classes = {}

                                            self.mpls_outgoing_info = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                            self.mpls_outgoing_info.parent = self
                                            self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                            self._children_yang_names.add("mpls-outgoing-info")

                                            self.remote_lfa = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")
                                            self._segment_path = lambda: "mpls"


                                        class MplsOutgoingInfo(Entity):
                                            """
                                            MPLS nexthop info
                                            
                                            .. attribute:: is_from_graceful_restartable_neighbor
                                            
                                            	Is from a GR neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_stale
                                            
                                            	Is the entry stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_peer_ldp_ident
                                            
                                            	Nexthop LDP peer
                                            	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                            
                                            .. attribute:: out_label
                                            
                                            	Outgoing label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_label_owner
                                            
                                            	Outgoing label owner
                                            	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                            
                                            .. attribute:: out_label_rsn
                                            
                                            	Outgoing label reason
                                            	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                            
                                            .. attribute:: out_label_type
                                            
                                            	Outgoing Label Type
                                            	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                self.yang_name = "mpls-outgoing-info"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent)}
                                                self._child_list_classes = {}

                                                self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                self.out_label = YLeaf(YType.uint32, "out-label")

                                                self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                self.nexthop_peer_ldp_ident = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                self.nexthop_peer_ldp_ident.parent = self
                                                self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                self._segment_path = lambda: "mpls-outgoing-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                            class NexthopPeerLdpIdent(Entity):
                                                """
                                                Nexthop LDP peer
                                                
                                                .. attribute:: label_space_id
                                                
                                                	Label space identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ldp_id
                                                
                                                	LDP identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: lsr_id
                                                
                                                	LSR identifier
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                    self.yang_name = "nexthop-peer-ldp-ident"
                                                    self.yang_parent_name = "mpls-outgoing-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                    self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                    self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                    self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	Remote LFA MPLS nexthop(s\_ info
                                            	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo)}
                                                self._child_list_classes = {}

                                                self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                self.mpls_outgoing_info = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._children_yang_names.add("mpls-outgoing-info")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, ['has_remote_lfa_bkup'], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                Remote LFA MPLS nexthop(s\_ info
                                                
                                                .. attribute:: stack
                                                
                                                	Inner label stack info
                                                	**type**\: list of    :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"stack" : ("stack", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack)}

                                                    self.stack = YList(self)
                                                    self._segment_path = lambda: "mpls-outgoing-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                class Stack(Entity):
                                                    """
                                                    Inner label stack info
                                                    
                                                    .. attribute:: is_from_graceful_restartable_neighbor
                                                    
                                                    	Is from a GR neighbor
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_stale
                                                    
                                                    	Is the entry stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nexthop_peer_ldp_ident
                                                    
                                                    	Nexthop LDP peer
                                                    	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                    
                                                    .. attribute:: out_label
                                                    
                                                    	Outgoing label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: out_label_owner
                                                    
                                                    	Outgoing label owner
                                                    	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                    
                                                    .. attribute:: out_label_rsn
                                                    
                                                    	Outgoing label reason
                                                    	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                    
                                                    .. attribute:: out_label_type
                                                    
                                                    	Outgoing Label Type
                                                    	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                        self.yang_name = "stack"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent)}
                                                        self._child_list_classes = {}

                                                        self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                        self.out_label = YLeaf(YType.uint32, "out-label")

                                                        self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                        self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                        self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                        self.nexthop_peer_ldp_ident = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                        self.nexthop_peer_ldp_ident.parent = self
                                                        self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                        self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                        self._segment_path = lambda: "stack"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                    class NexthopPeerLdpIdent(Entity):
                                                        """
                                                        Nexthop LDP peer
                                                        
                                                        .. attribute:: label_space_id
                                                        
                                                        	Label space identifier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ldp_id
                                                        
                                                        	LDP identifier
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: lsr_id
                                                        
                                                        	LSR identifier
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                            self.yang_name = "nexthop-peer-ldp-ident"
                                                            self.yang_parent_name = "stack"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                            self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: bkup_path_id
                                        
                                        	Backup path Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: flags
                                        
                                        	Route path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface Name
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	Path's load metric for load balancing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next Hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                        
                                        .. attribute:: next_hop_table_id
                                        
                                        	Table ID for nexthop address
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	Nexthop Identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_is_overriden
                                        
                                        	Nexthop is overriden by LDP
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_flags
                                        
                                        	Routing path flags decoded
                                        	**type**\:   :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                        
                                        .. attribute:: path_id
                                        
                                        	path Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop" : ("next_hop", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop), "remote-lfa" : ("remote_lfa", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa)}
                                            self._child_list_classes = {}

                                            self.bkup_path_id = YLeaf(YType.uint8, "bkup-path-id")

                                            self.flags = YLeaf(YType.uint32, "flags")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                            self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                            self.nh_is_overriden = YLeaf(YType.boolean, "nh-is-overriden")

                                            self.path_flags = YLeaf(YType.enumeration, "path-flags")

                                            self.path_id = YLeaf(YType.uint8, "path-id")

                                            self.next_hop = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.remote_lfa = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")
                                            self._segment_path = lambda: "routing"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, ['bkup_path_id', 'flags', 'interface', 'interface_name', 'load_metric', 'next_hop_table_id', 'nexthop_id', 'nh_is_overriden', 'path_flags', 'path_id'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next Hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: has_q_node
                                            
                                            	Whether remote LFA path has a Q node associated
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: needs_tldp
                                            
                                            	Whether TLDP is needed with remote PQ node
                                            	**type**\:  bool
                                            
                                            .. attribute:: remote_p_node_id
                                            
                                            	Remote/P node address
                                            	**type**\:   :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                            
                                            .. attribute:: remote_q_node_id
                                            
                                            	Remote/Q node address
                                            	**type**\:   :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"remote-p-node-id" : ("remote_p_node_id", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId), "remote-q-node-id" : ("remote_q_node_id", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId)}
                                                self._child_list_classes = {}

                                                self.has_q_node = YLeaf(YType.boolean, "has-q-node")

                                                self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                self.needs_tldp = YLeaf(YType.boolean, "needs-tldp")

                                                self.remote_p_node_id = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                self.remote_p_node_id.parent = self
                                                self._children_name_map["remote_p_node_id"] = "remote-p-node-id"
                                                self._children_yang_names.add("remote-p-node-id")

                                                self.remote_q_node_id = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                self.remote_q_node_id.parent = self
                                                self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                self._children_yang_names.add("remote-q-node-id")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, ['has_q_node', 'has_remote_lfa_bkup', 'needs_tldp'], name, value)


                                            class RemotePNodeId(Entity):
                                                """
                                                Remote/P node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                    self.yang_name = "remote-p-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "remote-p-node-id"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class RemoteQNodeId(Entity):
                                                """
                                                Remote/Q node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                    self.yang_name = "remote-q-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "remote-q-node-id"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "prefix-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class Route(Entity):
                                    """
                                    Route
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                        self.yang_name = "route"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls), "routing" : ("routing", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing)}
                                        self._child_list_classes = {}

                                        self.mpls = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._children_yang_names.add("mpls")

                                        self.routing = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"
                                        self._children_yang_names.add("routing")
                                        self._segment_path = lambda: "route"


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: forwarding_update_age
                                        
                                        	Last Forwarding update nanosec age
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: forwarding_update_count
                                        
                                        	Number of forwarding updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_timestamp
                                        
                                        	Last Forwarding update nanosec timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.forwarding_update_age = YLeaf(YType.uint64, "forwarding-update-age")

                                            self.forwarding_update_count = YLeaf(YType.uint32, "forwarding-update-count")

                                            self.forwarding_update_timestamp = YLeaf(YType.uint64, "forwarding-update-timestamp")

                                            self.local_label = YLeaf(YType.uint32, "local-label")
                                            self._segment_path = lambda: "mpls"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, ['forwarding_update_age', 'forwarding_update_count', 'forwarding_update_timestamp', 'local_label'], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: flags
                                        
                                        	Route RIB flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_local_vrf_leaked
                                        
                                        	Is route leaked across local VRFs?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Route metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Route priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: routing_update_age
                                        
                                        	Last Routing update nanosec age
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: routing_update_count
                                        
                                        	Number of routing updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: routing_update_timestamp
                                        
                                        	Last Routing update nanosec timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: source
                                        
                                        	Route source protol Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sr_local_label
                                        
                                        	SR Local\-label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: type
                                        
                                        	Route type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: version
                                        
                                        	Route RIB ersion
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.flags = YLeaf(YType.uint32, "flags")

                                            self.is_local_vrf_leaked = YLeaf(YType.boolean, "is-local-vrf-leaked")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.priority = YLeaf(YType.uint8, "priority")

                                            self.routing_update_age = YLeaf(YType.uint64, "routing-update-age")

                                            self.routing_update_count = YLeaf(YType.uint32, "routing-update-count")

                                            self.routing_update_timestamp = YLeaf(YType.uint64, "routing-update-timestamp")

                                            self.source = YLeaf(YType.uint16, "source")

                                            self.sr_local_label = YLeaf(YType.uint32, "sr-local-label")

                                            self.type = YLeaf(YType.uint16, "type")

                                            self.version = YLeaf(YType.uint32, "version")
                                            self._segment_path = lambda: "routing"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, ['flags', 'is_local_vrf_leaked', 'metric', 'priority', 'routing_update_age', 'routing_update_count', 'routing_update_timestamp', 'source', 'sr_local_label', 'type', 'version'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, ['id', 'name'], name, value)


                        class Igp(Entity):
                            """
                            LDP IGP related information
                            
                            .. attribute:: sync_delay_restart
                            
                            	LDP\-IGP Synchronization Delay related information
                            	**type**\:   :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart>`
                            
                            .. attribute:: syncs
                            
                            	LDP IGP Sync related information
                            	**type**\:   :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp, self).__init__()

                                self.yang_name = "igp"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sync-delay-restart" : ("sync_delay_restart", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart), "syncs" : ("syncs", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs)}
                                self._child_list_classes = {}

                                self.sync_delay_restart = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart()
                                self.sync_delay_restart.parent = self
                                self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                self._children_yang_names.add("sync-delay-restart")

                                self.syncs = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs()
                                self.syncs.parent = self
                                self._children_name_map["syncs"] = "syncs"
                                self._children_yang_names.add("syncs")
                                self._segment_path = lambda: "igp"


                            class SyncDelayRestart(Entity):
                                """
                                LDP\-IGP Synchronization Delay related
                                information
                                
                                .. attribute:: configured
                                
                                	Is restart delay configured
                                	**type**\:  bool
                                
                                .. attribute:: delay_secs
                                
                                	Delay time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remaining_secs
                                
                                	Delay timer remaining time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: timer_running
                                
                                	Is restart delay timer running
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                    self.yang_name = "sync-delay-restart"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.configured = YLeaf(YType.boolean, "configured")

                                    self.delay_secs = YLeaf(YType.uint32, "delay-secs")

                                    self.remaining_secs = YLeaf(YType.uint32, "remaining-secs")

                                    self.timer_running = YLeaf(YType.boolean, "timer-running")
                                    self._segment_path = lambda: "sync-delay-restart"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, ['configured', 'delay_secs', 'remaining_secs', 'timer_running'], name, value)


                            class Syncs(Entity):
                                """
                                LDP IGP Sync related information
                                
                                .. attribute:: sync
                                
                                	LDP\-IGP Synchronization related information for an interface
                                	**type**\: list of    :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs, self).__init__()

                                    self.yang_name = "syncs"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sync" : ("sync", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync)}

                                    self.sync = YList(self)
                                    self._segment_path = lambda: "syncs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs, [], name, value)


                                class Sync(Entity):
                                    """
                                    LDP\-IGP Synchronization related information
                                    for an interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: delay_timer_remaining
                                    
                                    	Remaining timer (seconds) till expiry of sync delay timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_only_peer
                                    
                                    	Interface GR\-only reachable peers
                                    	**type**\: list of    :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                    
                                    .. attribute:: igp_sync_delay
                                    
                                    	IGP sync delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: igp_sync_down_reason
                                    
                                    	Reason IGP Sync Not Achieved
                                    	**type**\:   :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                    
                                    .. attribute:: igp_sync_state
                                    
                                    	IGP Sync state
                                    	**type**\:   :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_delay_timer_running
                                    
                                    	Is sync delay timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: peers
                                    
                                    	Interface Peers
                                    	**type**\: list of    :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                        self.yang_name = "sync"
                                        self.yang_parent_name = "syncs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf)}
                                        self._child_list_classes = {"gr-only-peer" : ("gr_only_peer", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer), "peers" : ("peers", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.delay_timer_remaining = YLeaf(YType.uint32, "delay-timer-remaining")

                                        self.igp_sync_delay = YLeaf(YType.uint32, "igp-sync-delay")

                                        self.igp_sync_down_reason = YLeaf(YType.enumeration, "igp-sync-down-reason")

                                        self.igp_sync_state = YLeaf(YType.enumeration, "igp-sync-state")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.is_delay_timer_running = YLeaf(YType.boolean, "is-delay-timer-running")

                                        self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.gr_only_peer = YList(self)
                                        self.peers = YList(self)
                                        self._segment_path = lambda: "sync" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', 'delay_timer_remaining', 'igp_sync_delay', 'igp_sync_down_reason', 'igp_sync_state', 'interface_name_xr', 'is_delay_timer_running'], name, value)


                                    class GrOnlyPeer(Entity):
                                        """
                                        Interface GR\-only reachable peers
                                        
                                        .. attribute:: is_chkpt_created
                                        
                                        	Is created due to checkpointing
                                        	**type**\:  bool
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                            self.yang_name = "gr-only-peer"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.is_chkpt_created = YLeaf(YType.boolean, "is-chkpt-created")

                                            self.peer_id = YLeaf(YType.str, "peer-id")
                                            self._segment_path = lambda: "gr-only-peer"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, ['is_chkpt_created', 'peer_id'], name, value)


                                    class Peers(Entity):
                                        """
                                        Interface Peers
                                        
                                        .. attribute:: is_gr_enabled
                                        
                                        	Is GR enabled session
                                        	**type**\:  bool
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                            self.yang_name = "peers"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                                            self.peer_id = YLeaf(YType.str, "peer-id")
                                            self._segment_path = lambda: "peers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, ['is_gr_enabled', 'peer_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, ['id', 'name'], name, value)


                        class InterfaceSummary(Entity):
                            """
                            IPv4 interface summary information
                            
                            .. attribute:: auto_config
                            
                            	Auto\-configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_disabled
                            
                            	Autoconfigure disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_forward_reference_interfaces
                            
                            	Auto\-configured forward references
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_references
                            
                            	Number of forward referenced interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_count
                            
                            	Number of known IP Interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_ldp_enabled
                            
                            	Number of known IP Interfaces with LDP Enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_attached_interface
                            
                            	Number of attached interfaces configured in LDP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_te_interface
                            
                            	Number of TE tunnel interfaces configured in LDP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.InterfaceSummary, self).__init__()

                                self.yang_name = "interface-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.auto_config = YLeaf(YType.uint32, "auto-config")

                                self.auto_config_disabled = YLeaf(YType.uint32, "auto-config-disabled")

                                self.auto_config_forward_reference_interfaces = YLeaf(YType.uint32, "auto-config-forward-reference-interfaces")

                                self.forward_references = YLeaf(YType.uint32, "forward-references")

                                self.known_ip_interface_count = YLeaf(YType.uint32, "known-ip-interface-count")

                                self.known_ip_interface_ldp_enabled = YLeaf(YType.uint32, "known-ip-interface-ldp-enabled")

                                self.ldp_configured_attached_interface = YLeaf(YType.uint32, "ldp-configured-attached-interface")

                                self.ldp_configured_te_interface = YLeaf(YType.uint32, "ldp-configured-te-interface")
                                self._segment_path = lambda: "interface-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.InterfaceSummary, ['auto_config', 'auto_config_disabled', 'auto_config_forward_reference_interfaces', 'forward_references', 'known_ip_interface_count', 'known_ip_interface_ldp_enabled', 'ldp_configured_attached_interface', 'ldp_configured_te_interface'], name, value)


                        class Interfaces(Entity):
                            """
                            LDP Interface related information
                            
                            .. attribute:: interface
                            
                            	IPv4 interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface" : ("interface", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface)}

                                self.interface = YList(self)
                                self._segment_path = lambda: "interfaces"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces, [], name, value)


                            class Interface(Entity):
                                """
                                IPv4 interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	The Interface Name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: auto_config
                                
                                	Auto config
                                	**type**\: list of    :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                
                                .. attribute:: interface
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\:  str
                                
                                .. attribute:: is_im_stale
                                
                                	Is IM information stale
                                	**type**\:  bool
                                
                                .. attribute:: ldp_autoconfig_disable
                                
                                	LDP autoconfig disable
                                	**type**\:  bool
                                
                                .. attribute:: ldp_config_mode
                                
                                	LDP config mode
                                	**type**\:  bool
                                
                                .. attribute:: ldp_enabled
                                
                                	LDP enabled
                                	**type**\:  bool
                                
                                .. attribute:: te_mesh_grp
                                
                                	TE tunnel mesh\-group
                                	**type**\: list of    :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf)}
                                    self._child_list_classes = {"auto-config" : ("auto_config", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig), "te-mesh-grp" : ("te_mesh_grp", MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface = YLeaf(YType.str, "interface")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.is_im_stale = YLeaf(YType.boolean, "is-im-stale")

                                    self.ldp_autoconfig_disable = YLeaf(YType.boolean, "ldp-autoconfig-disable")

                                    self.ldp_config_mode = YLeaf(YType.boolean, "ldp-config-mode")

                                    self.ldp_enabled = YLeaf(YType.boolean, "ldp-enabled")

                                    self.vrf = MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.auto_config = YList(self)
                                    self.te_mesh_grp = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface, ['interface_name', 'interface', 'interface_name_xr', 'is_im_stale', 'ldp_autoconfig_disable', 'ldp_config_mode', 'ldp_enabled'], name, value)


                                class AutoConfig(Entity):
                                    """
                                    Auto config
                                    
                                    .. attribute:: tuple
                                    
                                    	Tuple
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                        self.yang_name = "auto-config"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.tuple = YLeaf(YType.str, "tuple")
                                        self._segment_path = lambda: "auto-config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, ['tuple'], name, value)


                                class TeMeshGrp(Entity):
                                    """
                                    TE tunnel mesh\-group
                                    
                                    .. attribute:: ldp_mesh_group_enabled
                                    
                                    	LDP has enabled this TE mesh\-group
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_te_mesh_group_all_cfgd
                                    
                                    	LDP has enabled all TE mesh\-groups
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_mesh_group_id
                                    
                                    	TE tunnel Mesh Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                        self.yang_name = "te-mesh-grp"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ldp_mesh_group_enabled = YLeaf(YType.boolean, "ldp-mesh-group-enabled")

                                        self.ldp_te_mesh_group_all_cfgd = YLeaf(YType.boolean, "ldp-te-mesh-group-all-cfgd")

                                        self.te_mesh_group_id = YLeaf(YType.uint32, "te-mesh-group-id")
                                        self._segment_path = lambda: "te-mesh-grp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, ['ldp_mesh_group_enabled', 'ldp_te_mesh_group_all_cfgd', 'te_mesh_group_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, ['id', 'name'], name, value)


                class BackoffParameters(Entity):
                    """
                    The LDP Backoff Parameters
                    
                    .. attribute:: initial_seconds
                    
                    	Initial backoff value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: maximum_seconds
                    
                    	Maximum backoff value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.BackoffParameters, self).__init__()

                        self.yang_name = "backoff-parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.initial_seconds = YLeaf(YType.uint32, "initial-seconds")

                        self.maximum_seconds = YLeaf(YType.uint32, "maximum-seconds")
                        self._segment_path = lambda: "backoff-parameters"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.BackoffParameters, ['initial_seconds', 'maximum_seconds'], name, value)


                class Backoffs(Entity):
                    """
                    The LDP backoff
                    
                    .. attribute:: backoff
                    
                    	LDP Backoff Information
                    	**type**\: list of    :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Backoffs.Backoff>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Backoffs, self).__init__()

                        self.yang_name = "backoffs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"backoff" : ("backoff", MplsLdp.Global_.Active.DefaultVrf.Backoffs.Backoff)}

                        self.backoff = YList(self)
                        self._segment_path = lambda: "backoffs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Backoffs, [], name, value)


                    class Backoff(Entity):
                        """
                        LDP Backoff Information
                        
                        .. attribute:: backoff_seconds
                        
                        	Backoff seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: waiting_seconds
                        
                        	Backoff waiting seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Backoffs.Backoff, self).__init__()

                            self.yang_name = "backoff"
                            self.yang_parent_name = "backoffs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.backoff_seconds = YLeaf(YType.uint32, "backoff-seconds")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.waiting_seconds = YLeaf(YType.uint32, "waiting-seconds")
                            self._segment_path = lambda: "backoff"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/backoffs/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Backoffs.Backoff, ['backoff_seconds', 'label_space_id', 'lsr_id', 'waiting_seconds'], name, value)


                class Capabilities(Entity):
                    """
                    LDP capability database information
                    
                    .. attribute:: capability
                    
                    	Information on LDP capability
                    	**type**\: list of    :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Capabilities, self).__init__()

                        self.yang_name = "capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"capability" : ("capability", MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability)}

                        self.capability = YList(self)
                        self._segment_path = lambda: "capabilities"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Capabilities, [], name, value)


                    class Capability(Entity):
                        """
                        Information on LDP capability
                        
                        .. attribute:: capability_type  <key>
                        
                        	The capability type (IANA assigned)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: capability
                        
                        	Capability information
                        	**type**\:   :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability.Capability>`
                        
                        .. attribute:: capability_owner
                        
                        	Capability owner
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability, self).__init__()

                            self.yang_name = "capability"
                            self.yang_parent_name = "capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"capability" : ("capability", MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability.Capability)}
                            self._child_list_classes = {}

                            self.capability_type = YLeaf(YType.int32, "capability-type")

                            self.capability_owner = YLeaf(YType.str, "capability-owner")

                            self.capability = MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability.Capability()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"
                            self._children_yang_names.add("capability")
                            self._segment_path = lambda: "capability" + "[capability-type='" + self.capability_type.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/capabilities/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability, ['capability_type', 'capability_owner'], name, value)


                        class Capability(Entity):
                            """
                            Capability information
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "capability"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Capabilities.Capability.Capability, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                class GracefulRestart(Entity):
                    """
                    LDP Graceful Restart info
                    
                    .. attribute:: forwarding_state_hold_timer_remaining_seconds
                    
                    	Forwarding state hold timer remaining time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: graceful_restartable_neighbor
                    
                    	Vector of graceful restart neighbor information
                    	**type**\: list of    :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor>`
                    
                    .. attribute:: is_forwarding_state_hold_timer_running
                    
                    	Is graceful restart forwarding state hold timer running
                    	**type**\:  bool
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.Vrf>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.Vrf)}
                        self._child_list_classes = {"graceful-restartable-neighbor" : ("graceful_restartable_neighbor", MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor)}

                        self.forwarding_state_hold_timer_remaining_seconds = YLeaf(YType.uint32, "forwarding-state-hold-timer-remaining-seconds")

                        self.is_forwarding_state_hold_timer_running = YLeaf(YType.boolean, "is-forwarding-state-hold-timer-running")

                        self.vrf = MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._children_yang_names.add("vrf")

                        self.graceful_restartable_neighbor = YList(self)
                        self._segment_path = lambda: "graceful-restart"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart, ['forwarding_state_hold_timer_remaining_seconds', 'is_forwarding_state_hold_timer_running'], name, value)


                    class GracefulRestartableNeighbor(Entity):
                        """
                        Vector of graceful restart neighbor information
                        
                        .. attribute:: connect_count
                        
                        	ConnectCount
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_address
                        
                        	Addresses bound to GR down Nbr
                        	**type**\: list of    :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                        
                        .. attribute:: down_nbr_down_reason
                        
                        	Session down reason code
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flags
                        
                        	Flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flap_count
                        
                        	Count of back2back flaps
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: down_nbr_interface
                        
                        	Interfaces bound to GR down Nbr
                        	**type**\: list of    :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                        
                        .. attribute:: gr_peer
                        
                        	GR peer LDP Id
                        	**type**\:   :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                        
                        .. attribute:: is_liveness_timer_running
                        
                        	Is liveness timer running
                        	**type**\:  bool
                        
                        .. attribute:: is_neighbor_up
                        
                        	Is neighbor up
                        	**type**\:  bool
                        
                        .. attribute:: is_recovery_timer_running
                        
                        	Is recovery timer running
                        	**type**\:  bool
                        
                        .. attribute:: liveness_timer_remaining_seconds
                        
                        	Remaining time from liveness timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: recovery_timer_remaining_seconds
                        
                        	Recovery timer remining time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                            self.yang_name = "graceful-restartable-neighbor"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"gr-peer" : ("gr_peer", MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)}
                            self._child_list_classes = {"down-nbr-address" : ("down_nbr_address", MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress), "down-nbr-interface" : ("down_nbr_interface", MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)}

                            self.connect_count = YLeaf(YType.uint32, "connect-count")

                            self.down_nbr_down_reason = YLeaf(YType.uint32, "down-nbr-down-reason")

                            self.down_nbr_flags = YLeaf(YType.uint32, "down-nbr-flags")

                            self.down_nbr_flap_count = YLeaf(YType.uint8, "down-nbr-flap-count")

                            self.is_liveness_timer_running = YLeaf(YType.boolean, "is-liveness-timer-running")

                            self.is_neighbor_up = YLeaf(YType.boolean, "is-neighbor-up")

                            self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

                            self.liveness_timer_remaining_seconds = YLeaf(YType.uint32, "liveness-timer-remaining-seconds")

                            self.recovery_timer_remaining_seconds = YLeaf(YType.uint32, "recovery-timer-remaining-seconds")

                            self.gr_peer = MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                            self.gr_peer.parent = self
                            self._children_name_map["gr_peer"] = "gr-peer"
                            self._children_yang_names.add("gr-peer")

                            self.down_nbr_address = YList(self)
                            self.down_nbr_interface = YList(self)
                            self._segment_path = lambda: "graceful-restartable-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, ['connect_count', 'down_nbr_down_reason', 'down_nbr_flags', 'down_nbr_flap_count', 'is_liveness_timer_running', 'is_neighbor_up', 'is_recovery_timer_running', 'liveness_timer_remaining_seconds', 'recovery_timer_remaining_seconds'], name, value)


                        class DownNbrAddress(Entity):
                            """
                            Addresses bound to GR down Nbr
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                self.yang_name = "down-nbr-address"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.dummy = YLeaf(YType.uint8, "dummy")

                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                self._segment_path = lambda: "down-nbr-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class DownNbrInterface(Entity):
                            """
                            Interfaces bound to GR down Nbr
                            
                            .. attribute:: address_family
                            
                            	Interface adj Address Family
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: interface_handle
                            
                            	Interfaces handle
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                self.yang_name = "down-nbr-interface"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")
                                self._segment_path = lambda: "down-nbr-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, ['address_family', 'interface_handle'], name, value)


                        class GrPeer(Entity):
                            """
                            GR peer LDP Id
                            
                            .. attribute:: label_space_id
                            
                            	Label space identifier
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_id
                            
                            	LDP identifier
                            	**type**\:  str
                            
                            .. attribute:: lsr_id
                            
                            	LSR identifier
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                self.yang_name = "gr-peer"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                self._segment_path = lambda: "gr-peer"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.id = YLeaf(YType.uint32, "id")

                            self.name = YLeaf(YType.str, "name")
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/graceful-restart/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.GracefulRestart.Vrf, ['id', 'name'], name, value)


                class Issu(Entity):
                    """
                    LDP ISSU related information
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Issu, self).__init__()

                        self.yang_name = "issu"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary)}
                        self._child_list_classes = {}

                        self.ha_statistics = MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._children_yang_names.add("ha-statistics")

                        self.ha_summary = MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"
                        self._children_yang_names.add("ha-summary")
                        self._segment_path = lambda: "issu"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_global = MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"
                            self._children_yang_names.add("ha-global")

                            self.ha_neighbors = MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "ha-statistics"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/%s" % self._segment_path()


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync)}
                                self._child_list_classes = {}

                                self.init_sync = MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._children_yang_names.add("init-sync")
                                self._segment_path = lambda: "ha-global"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/%s" % self._segment_path()


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\:  bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\:  bool
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                    self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                    self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                    self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                    self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                    self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                    self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                    self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                    self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                    self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                    self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                    self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                    self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                    self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                    self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                    self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                    self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                    self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                    self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                    self.num_peers = YLeaf(YType.uint32, "num-peers")

                                    self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                    self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                    self._segment_path = lambda: "init-sync"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/ha-global/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/ha-neighbors/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Sessions>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Vrf)}
                            self._child_list_classes = {}

                            self.sessions = MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._children_yang_names.add("sessions")

                            self.vrf = MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "ha-summary"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/%s" % self._segment_path()


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                self.total = YLeaf(YType.uint32, "total")
                                self._segment_path = lambda: "sessions"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-summary/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/issu/ha-summary/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Issu.HaSummary.Vrf, ['id', 'name'], name, value)


                class LdpId(Entity):
                    """
                    Local LDP Id
                    
                    .. attribute:: label_space_id
                    
                    	Label space identifier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ldp_id
                    
                    	LDP identifier
                    	**type**\:  str
                    
                    .. attribute:: lsr_id
                    
                    	LSR identifier
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.LdpId, self).__init__()

                        self.yang_name = "ldp-id"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                        self._segment_path = lambda: "ldp-id"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.LdpId, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                class NeighborBriefs(Entity):
                    """
                    The LDP Neighbors (brief)
                    
                    .. attribute:: neighbor_brief
                    
                    	Brief information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs, self).__init__()

                        self.yang_name = "neighbor-briefs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-brief" : ("neighbor_brief", MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief)}

                        self.neighbor_brief = YList(self)
                        self._segment_path = lambda: "neighbor-briefs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs, [], name, value)


                    class NeighborBrief(Entity):
                        """
                        Brief information on a particular LDP neighbor
                        
                        .. attribute:: is_graceful_restartable
                        
                        	Is graceful restartable
                        	**type**\:  bool
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_br_af_info
                        
                        	Neighbor Brief AF Info
                        	**type**\: list of    :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                        
                        .. attribute:: nsr_state
                        
                        	NSR readiness state
                        	**type**\:   :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                        
                        .. attribute:: up_time_seconds
                        
                        	Up time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief, self).__init__()

                            self.yang_name = "neighbor-brief"
                            self.yang_parent_name = "neighbor-briefs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf)}
                            self._child_list_classes = {"nbr-br-af-info" : ("nbr_br_af_info", MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo)}

                            self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                            self.up_time_seconds = YLeaf(YType.uint32, "up-time-seconds")

                            self.vrf = MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")

                            self.nbr_br_af_info = YList(self)
                            self._segment_path = lambda: "neighbor-brief"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-briefs/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief, ['is_graceful_restartable', 'label_space_id', 'lsr_id', 'nsr_state', 'up_time_seconds'], name, value)


                        class NbrBrAfInfo(Entity):
                            """
                            Neighbor Brief AF Info
                            
                            .. attribute:: address_family
                            
                            	Neighbor Brief Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: num_of_nbr_addresses
                            
                            	Number of neighbor addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_discovery
                            
                            	Number of neighbor discovery sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_lbl
                            
                            	Number of neighbor labels
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                self.yang_name = "nbr-br-af-info"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.num_of_nbr_addresses = YLeaf(YType.uint32, "num-of-nbr-addresses")

                                self.num_of_nbr_discovery = YLeaf(YType.uint32, "num-of-nbr-discovery")

                                self.num_of_nbr_lbl = YLeaf(YType.uint32, "num-of-nbr-lbl")
                                self._segment_path = lambda: "nbr-br-af-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-briefs/neighbor-brief/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, ['address_family', 'num_of_nbr_addresses', 'num_of_nbr_discovery', 'num_of_nbr_lbl'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-briefs/neighbor-brief/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, ['id', 'name'], name, value)


                class NeighborCapabilities(Entity):
                    """
                    LDP Neighbors Capabilities
                    
                    .. attribute:: neighbor_capability
                    
                    	Information on capabilities of a particular LDP neighbor
                    	**type**\: list of    :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities, self).__init__()

                        self.yang_name = "neighbor-capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-capability" : ("neighbor_capability", MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability)}

                        self.neighbor_capability = YList(self)
                        self._segment_path = lambda: "neighbor-capabilities"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities, [], name, value)


                    class NeighborCapability(Entity):
                        """
                        Information on capabilities of a particular LDP
                        neighbor
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: received
                        
                        	List of received capabilities
                        	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Received>`
                        
                        .. attribute:: sent
                        
                        	List of sent capabilities
                        	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability, self).__init__()

                            self.yang_name = "neighbor-capability"
                            self.yang_parent_name = "neighbor-capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"received" : ("received", MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Received), "sent" : ("sent", MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent)}

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.received = YList(self)
                            self.sent = YList(self)
                            self._segment_path = lambda: "neighbor-capability"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-capabilities/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability, ['label_space_id', 'lsr_id'], name, value)


                        class Received(Entity):
                            """
                            List of received capabilities
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                self.yang_name = "received"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "received"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-capabilities/neighbor-capability/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                        class Sent(Entity):
                            """
                            List of sent capabilities
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                self.yang_name = "sent"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "sent"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbor-capabilities/neighbor-capability/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                class Neighbors(Entity):
                    """
                    The LDP Neighbors
                    
                    .. attribute:: neighbor
                    
                    	Information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor" : ("neighbor", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor)}

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        Information on a particular LDP neighbor
                        
                        .. attribute:: detailed_information
                        
                        	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                        	**type**\:   :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation>`
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_nbr_bound_ipv4_address_info
                        
                        	Neighbor IPv4 Address Info
                        	**type**\: list of    :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                        
                        .. attribute:: ldp_nbr_bound_ipv6_address_info
                        
                        	Neighbor IPv6 Address Info
                        	**type**\: list of    :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                        
                        .. attribute:: ldp_nbr_ipv4_adj_info
                        
                        	Neighbor's IPv4 Adjacency Information
                        	**type**\: list of    :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                        
                        .. attribute:: ldp_nbr_ipv6_adj_info
                        
                        	Neighbor's IPv6 Adjacency Information
                        	**type**\: list of    :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: protocol_information
                        
                        	Protocol Information
                        	**type**\:   :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation>`
                        
                        .. attribute:: tcp_information
                        
                        	TCP Information
                        	**type**\:   :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"detailed-information" : ("detailed_information", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation), "protocol-information" : ("protocol_information", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation), "tcp-information" : ("tcp_information", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation)}
                            self._child_list_classes = {"ldp-nbr-bound-ipv4-address-info" : ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo), "ldp-nbr-bound-ipv6-address-info" : ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo), "ldp-nbr-ipv4-adj-info" : ("ldp_nbr_ipv4_adj_info", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo), "ldp-nbr-ipv6-adj-info" : ("ldp_nbr_ipv6_adj_info", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo)}

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.detailed_information = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation()
                            self.detailed_information.parent = self
                            self._children_name_map["detailed_information"] = "detailed-information"
                            self._children_yang_names.add("detailed-information")

                            self.protocol_information = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation()
                            self.protocol_information.parent = self
                            self._children_name_map["protocol_information"] = "protocol-information"
                            self._children_yang_names.add("protocol-information")

                            self.tcp_information = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation()
                            self.tcp_information.parent = self
                            self._children_name_map["tcp_information"] = "tcp-information"
                            self._children_yang_names.add("tcp-information")

                            self.ldp_nbr_bound_ipv4_address_info = YList(self)
                            self.ldp_nbr_bound_ipv6_address_info = YList(self)
                            self.ldp_nbr_ipv4_adj_info = YList(self)
                            self.ldp_nbr_ipv6_adj_info = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor, ['label_space_id', 'lsr_id'], name, value)


                        class DetailedInformation(Entity):
                            """
                            Detailed information with regards to holdtime,
                            KA, inbound filtering, and Session protection
                            
                            .. attribute:: advertise_bgp_prefixes
                            
                            	Is BGP labelled prefixes advertised to the neighbor
                            	**type**\:  bool
                            
                            .. attribute:: bgp_advertisement_state
                            
                            	BGP labelled prefixes advertisement state
                            	**type**\:   :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                            
                            .. attribute:: capabilities
                            
                            	Capabilities sent to and received from neighbor
                            	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                            
                            .. attribute:: client
                            
                            	Targeted Session clients
                            	**type**\: list of    :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client>`
                            
                            .. attribute:: has_ipv4_inbound
                            
                            	IPv4 Inbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv4_outbound
                            
                            	IPv4 Outbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv6_inbound
                            
                            	IPv6 Inbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv6_outbound
                            
                            	IPv6 Outbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_sp
                            
                            	Session Protection enabled
                            	**type**\:  bool
                            
                            .. attribute:: inbound_ipv4acl
                            
                            	IPv4 Inbound accept ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: inbound_ipv6acl
                            
                            	IPv6 Inbound accept ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: ipv4_duplicate_address
                            
                            	Duplicate IPv4 address bound to this peer
                            	**type**\: list of    :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                            
                            .. attribute:: ipv6_duplicate_address
                            
                            	Duplicate IPv6 address bound to this peer
                            	**type**\: list of    :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                            
                            .. attribute:: keep_alive_interval
                            
                            	Session keepalive interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nsr_last_sync_error
                            
                            	Last NSR sync error
                            	**type**\:   :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                            
                            .. attribute:: nsr_last_sync_nack_reason
                            
                            	Last NSR sync NACK reaston
                            	**type**\:   :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                            
                            .. attribute:: nsr_sync_state
                            
                            	NSR Sync State
                            	**type**\:   :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                            
                            .. attribute:: outbound_ipv4acl
                            
                            	IPv4 Outbound advertise ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: outbound_ipv6acl
                            
                            	IPv6 Outbound advertise ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: peer_holdtime
                            
                            	Session holdtime value in seconds from the peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: peer_state
                            
                            	Peer state
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_duration
                            
                            	Session protection holdup time duration in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: sp_has_acl
                            
                            	Session protection ACL is present
                            	**type**\:  bool
                            
                            .. attribute:: sp_has_duration
                            
                            	Session Protection has non\-default duration
                            	**type**\:  bool
                            
                            .. attribute:: sp_state
                            
                            	Session Protection state
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: spacl
                            
                            	Session Protection ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: spht_remaining
                            
                            	Session Protection holdup time remaining value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: spht_running
                            
                            	Session Protection holdup timer is running
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                self.yang_name = "detailed-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"capabilities" : ("capabilities", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities)}
                                self._child_list_classes = {"client" : ("client", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client), "ipv4-duplicate-address" : ("ipv4_duplicate_address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress), "ipv6-duplicate-address" : ("ipv6_duplicate_address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress)}

                                self.advertise_bgp_prefixes = YLeaf(YType.boolean, "advertise-bgp-prefixes")

                                self.bgp_advertisement_state = YLeaf(YType.enumeration, "bgp-advertisement-state")

                                self.has_ipv4_inbound = YLeaf(YType.boolean, "has-ipv4-inbound")

                                self.has_ipv4_outbound = YLeaf(YType.boolean, "has-ipv4-outbound")

                                self.has_ipv6_inbound = YLeaf(YType.boolean, "has-ipv6-inbound")

                                self.has_ipv6_outbound = YLeaf(YType.boolean, "has-ipv6-outbound")

                                self.has_sp = YLeaf(YType.boolean, "has-sp")

                                self.inbound_ipv4acl = YLeaf(YType.str, "inbound-ipv4acl")

                                self.inbound_ipv6acl = YLeaf(YType.str, "inbound-ipv6acl")

                                self.keep_alive_interval = YLeaf(YType.uint32, "keep-alive-interval")

                                self.nsr_last_sync_error = YLeaf(YType.enumeration, "nsr-last-sync-error")

                                self.nsr_last_sync_nack_reason = YLeaf(YType.enumeration, "nsr-last-sync-nack-reason")

                                self.nsr_sync_state = YLeaf(YType.enumeration, "nsr-sync-state")

                                self.outbound_ipv4acl = YLeaf(YType.str, "outbound-ipv4acl")

                                self.outbound_ipv6acl = YLeaf(YType.str, "outbound-ipv6acl")

                                self.peer_holdtime = YLeaf(YType.uint32, "peer-holdtime")

                                self.peer_state = YLeaf(YType.str, "peer-state")

                                self.sp_duration = YLeaf(YType.uint32, "sp-duration")

                                self.sp_has_acl = YLeaf(YType.boolean, "sp-has-acl")

                                self.sp_has_duration = YLeaf(YType.boolean, "sp-has-duration")

                                self.sp_state = YLeaf(YType.str, "sp-state")

                                self.spacl = YLeaf(YType.str, "spacl")

                                self.spht_remaining = YLeaf(YType.uint32, "spht-remaining")

                                self.spht_running = YLeaf(YType.boolean, "spht-running")

                                self.capabilities = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                self.capabilities.parent = self
                                self._children_name_map["capabilities"] = "capabilities"
                                self._children_yang_names.add("capabilities")

                                self.client = YList(self)
                                self.ipv4_duplicate_address = YList(self)
                                self.ipv6_duplicate_address = YList(self)
                                self._segment_path = lambda: "detailed-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation, ['advertise_bgp_prefixes', 'bgp_advertisement_state', 'has_ipv4_inbound', 'has_ipv4_outbound', 'has_ipv6_inbound', 'has_ipv6_outbound', 'has_sp', 'inbound_ipv4acl', 'inbound_ipv6acl', 'keep_alive_interval', 'nsr_last_sync_error', 'nsr_last_sync_nack_reason', 'nsr_sync_state', 'outbound_ipv4acl', 'outbound_ipv6acl', 'peer_holdtime', 'peer_state', 'sp_duration', 'sp_has_acl', 'sp_has_duration', 'sp_state', 'spacl', 'spht_remaining', 'spht_running'], name, value)


                            class Capabilities(Entity):
                                """
                                Capabilities sent to and received from neighbor
                                
                                .. attribute:: received
                                
                                	List of received capabilities
                                	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                
                                .. attribute:: sent
                                
                                	List of sent capabilities
                                	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                    self.yang_name = "capabilities"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"received" : ("received", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received), "sent" : ("sent", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)}

                                    self.received = YList(self)
                                    self.sent = YList(self)
                                    self._segment_path = lambda: "capabilities"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                class Received(Entity):
                                    """
                                    List of received capabilities
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\:  str
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\:  str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                        self.yang_name = "received"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.capability_data = YLeaf(YType.str, "capability-data")

                                        self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                        self.description = YLeaf(YType.str, "description")

                                        self.type = YLeaf(YType.uint16, "type")
                                        self._segment_path = lambda: "received"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/capabilities/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                class Sent(Entity):
                                    """
                                    List of sent capabilities
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\:  str
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\:  str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                        self.yang_name = "sent"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.capability_data = YLeaf(YType.str, "capability-data")

                                        self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                        self.description = YLeaf(YType.str, "description")

                                        self.type = YLeaf(YType.uint16, "type")
                                        self._segment_path = lambda: "sent"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/capabilities/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                            class Client(Entity):
                                """
                                Targeted Session clients
                                
                                .. attribute:: name
                                
                                	Client's name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                    self.yang_name = "client"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "client"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, ['name'], name, value)


                            class Ipv4DuplicateAddress(Entity):
                                """
                                Duplicate IPv4 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv4-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ipv4-duplicate-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv4-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/ipv4-duplicate-address/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class Ipv6DuplicateAddress(Entity):
                                """
                                Duplicate IPv6 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv6-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ipv6-duplicate-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv6-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/detailed-information/ipv6-duplicate-address/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrBoundIpv4AddressInfo(Entity):
                            """
                            Neighbor IPv4 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address)}
                                self._child_list_classes = {}

                                self.address = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")
                                self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-bound-ipv4-address-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrBoundIpv6AddressInfo(Entity):
                            """
                            Neighbor IPv6 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address)}
                                self._child_list_classes = {}

                                self.address = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")
                                self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-bound-ipv6-address-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrIpv4AdjInfo(Entity):
                            """
                            Neighbor's IPv4 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv4-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup)}
                                self._child_list_classes = {}

                                self.adjacency_group = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._children_yang_names.add("adjacency-group")
                                self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData)}
                                    self._child_list_classes = {}

                                    self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                    self.link_hello_data = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"
                                    self._children_yang_names.add("link-hello-data")

                                    self.target_hello_data = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._children_yang_names.add("target-hello-data")
                                    self._segment_path = lambda: "adjacency-group"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "link-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                        self._child_list_classes = {}

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.local_address = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"
                                        self._children_yang_names.add("local-address")

                                        self.target_address = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._children_yang_names.add("target-address")
                                        self._segment_path = lambda: "target-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "local-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "target-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrIpv6AdjInfo(Entity):
                            """
                            Neighbor's IPv6 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv6-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup)}
                                self._child_list_classes = {}

                                self.adjacency_group = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._children_yang_names.add("adjacency-group")
                                self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData)}
                                    self._child_list_classes = {}

                                    self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                    self.link_hello_data = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"
                                    self._children_yang_names.add("link-hello-data")

                                    self.target_hello_data = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._children_yang_names.add("target-hello-data")
                                    self._segment_path = lambda: "adjacency-group"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "link-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                        self._child_list_classes = {}

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.local_address = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"
                                        self._children_yang_names.add("local-address")

                                        self.target_address = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._children_yang_names.add("target-address")
                                        self._segment_path = lambda: "target-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "local-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "target-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class ProtocolInformation(Entity):
                            """
                            Protocol Information
                            
                            .. attribute:: downstream_on_demand
                            
                            	Is Label advertisment mode in Downstream On Demand mode or Not
                            	**type**\:  bool
                            
                            .. attribute:: ta_graceful_restart_adjacency
                            
                            	Graceful restart information
                            	**type**\:   :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                            
                            .. attribute:: ta_holdtime
                            
                            	Session holdtime in sec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_rcvd
                            
                            	Number of pies received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_sent
                            
                            	Number of pies sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_state
                            
                            	State
                            	**type**\:  str
                            
                            .. attribute:: ta_up_time_seconds
                            
                            	Up time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                self.yang_name = "protocol-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"ta-graceful-restart-adjacency" : ("ta_graceful_restart_adjacency", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency)}
                                self._child_list_classes = {}

                                self.downstream_on_demand = YLeaf(YType.boolean, "downstream-on-demand")

                                self.ta_holdtime = YLeaf(YType.uint32, "ta-holdtime")

                                self.ta_pies_rcvd = YLeaf(YType.uint32, "ta-pies-rcvd")

                                self.ta_pies_sent = YLeaf(YType.uint32, "ta-pies-sent")

                                self.ta_state = YLeaf(YType.str, "ta-state")

                                self.ta_up_time_seconds = YLeaf(YType.uint32, "ta-up-time-seconds")

                                self.ta_graceful_restart_adjacency = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                self.ta_graceful_restart_adjacency.parent = self
                                self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                self._children_yang_names.add("ta-graceful-restart-adjacency")
                                self._segment_path = lambda: "protocol-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, ['downstream_on_demand', 'ta_holdtime', 'ta_pies_rcvd', 'ta_pies_sent', 'ta_state', 'ta_up_time_seconds'], name, value)


                            class TaGracefulRestartAdjacency(Entity):
                                """
                                Graceful restart information
                                
                                .. attribute:: is_graceful_restartable
                                
                                	Is graceful restartable
                                	**type**\:  bool
                                
                                .. attribute:: reconnect_timeout
                                
                                	Reconnect timeout
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recovery_time
                                
                                	Recovery time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                    self.yang_name = "ta-graceful-restart-adjacency"
                                    self.yang_parent_name = "protocol-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                    self.reconnect_timeout = YLeaf(YType.uint32, "reconnect-timeout")

                                    self.recovery_time = YLeaf(YType.uint32, "recovery-time")
                                    self._segment_path = lambda: "ta-graceful-restart-adjacency"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/protocol-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, ['is_graceful_restartable', 'reconnect_timeout', 'recovery_time'], name, value)


                        class TcpInformation(Entity):
                            """
                            TCP Information
                            
                            .. attribute:: foreign_host
                            
                            	Foreign host address
                            	**type**\:   :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                            
                            .. attribute:: foreign_port
                            
                            	Foreign port number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_md5_on
                            
                            	Is MD5 Digest on
                            	**type**\:  bool
                            
                            .. attribute:: local_host
                            
                            	Local host address
                            	**type**\:   :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                            
                            .. attribute:: local_port
                            
                            	Local port number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                self.yang_name = "tcp-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"foreign-host" : ("foreign_host", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost), "local-host" : ("local_host", MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost)}
                                self._child_list_classes = {}

                                self.foreign_port = YLeaf(YType.uint16, "foreign-port")

                                self.is_md5_on = YLeaf(YType.boolean, "is-md5-on")

                                self.local_port = YLeaf(YType.uint16, "local-port")

                                self.foreign_host = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                self.foreign_host.parent = self
                                self._children_name_map["foreign_host"] = "foreign-host"
                                self._children_yang_names.add("foreign-host")

                                self.local_host = MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                self.local_host.parent = self
                                self._children_name_map["local_host"] = "local-host"
                                self._children_yang_names.add("local-host")
                                self._segment_path = lambda: "tcp-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation, ['foreign_port', 'is_md5_on', 'local_port'], name, value)


                            class ForeignHost(Entity):
                                """
                                Foreign host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                    self.yang_name = "foreign-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "foreign-host"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/tcp-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LocalHost(Entity):
                                """
                                Local host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                    self.yang_name = "local-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "local-host"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/neighbors/neighbor/tcp-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class Nsr(Entity):
                    """
                    LDP NSR related information
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary>`
                    
                    .. attribute:: nsr_pending
                    
                    	LDP NSR Pending related information
                    	**type**\:   :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Nsr, self).__init__()

                        self.yang_name = "nsr"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary), "nsr-pending" : ("nsr_pending", MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending)}
                        self._child_list_classes = {}

                        self.ha_statistics = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._children_yang_names.add("ha-statistics")

                        self.ha_summary = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"
                        self._children_yang_names.add("ha-summary")

                        self.nsr_pending = MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending()
                        self.nsr_pending.parent = self
                        self._children_name_map["nsr_pending"] = "nsr-pending"
                        self._children_yang_names.add("nsr-pending")
                        self._segment_path = lambda: "nsr"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_global = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"
                            self._children_yang_names.add("ha-global")

                            self.ha_neighbors = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "ha-statistics"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/%s" % self._segment_path()


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync)}
                                self._child_list_classes = {}

                                self.init_sync = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._children_yang_names.add("init-sync")
                                self._segment_path = lambda: "ha-global"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/%s" % self._segment_path()


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\:  bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\:  bool
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                    self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                    self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                    self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                    self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                    self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                    self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                    self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                    self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                    self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                    self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                    self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                    self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                    self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                    self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                    self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                    self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                    self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                    self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                    self.num_peers = YLeaf(YType.uint32, "num-peers")

                                    self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                    self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                    self._segment_path = lambda: "init-sync"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/ha-global/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/ha-neighbors/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Sessions>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Vrf)}
                            self._child_list_classes = {}

                            self.sessions = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._children_yang_names.add("sessions")

                            self.vrf = MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "ha-summary"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/%s" % self._segment_path()


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                self.total = YLeaf(YType.uint32, "total")
                                self._segment_path = lambda: "sessions"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-summary/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/ha-summary/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.HaSummary.Vrf, ['id', 'name'], name, value)


                    class NsrPending(Entity):
                        """
                        LDP NSR Pending related information
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending, self).__init__()

                            self.yang_name = "nsr-pending"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_neighbors = MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "nsr-pending"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/%s" % self._segment_path()


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "nsr-pending"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/nsr-pending/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/nsr-pending/ha-neighbors/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/nsr-pending/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/nsr/nsr-pending/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                class Parameters(Entity):
                    """
                    LDP parameters
                    
                    .. attribute:: address_family_parameter
                    
                    	Per AF parameters
                    	**type**\: list of    :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter>`
                    
                    .. attribute:: af_binding_withdraw_delay
                    
                    	Delay (sec) in Binding Withdrawal for an Address Family
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: discovery_quick_start_disabled_on_interfaces
                    
                    	Discovery quick\-start disabled on some LDP\-enabled interfaces
                    	**type**\:  bool
                    
                    .. attribute:: global_discovery_quick_start_disabled
                    
                    	Discovery quick\-start globally disabled
                    	**type**\:  bool
                    
                    .. attribute:: global_md5_password_enabled
                    
                    	Global MD5 password enabled
                    	**type**\:  bool
                    
                    .. attribute:: graceful_restart_information
                    
                    	Graceful restart information
                    	**type**\:   :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Parameters.GracefulRestartInformation>`
                    
                    .. attribute:: hello_hold_time
                    
                    	Hello hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_interval
                    
                    	Hello interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: housekeeping_timer_interval
                    
                    	Housekeeping periodic timer interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: igp_sync_delay_time_for_interface
                    
                    	Interface IGP sync delay time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: igp_sync_delay_time_on_restart
                    
                    	IGP sync delay time on process restart in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: keepalive_interval
                    
                    	Keepalive interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_out_of_mem_state
                    
                    	LDP Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_recovery_timeout
                    
                    	LDP recovery timeout with LSD
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: le_no_route_timeout
                    
                    	LIB entry no route timeout
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_attached
                    
                    	Maximum number of LDP enabled attached interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_te
                    
                    	Maximum number of LDP enabled TE interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_peer
                    
                    	Maximum number of LDP peers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_enabled
                    
                    	TRUE if NSR is enabled
                    	**type**\:  bool
                    
                    .. attribute:: nsr_synced
                    
                    	TRUE if LDP is standby and is NSR Sync\-ed with active
                    	**type**\:  bool
                    
                    .. attribute:: protocol_version
                    
                    	Protocol version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: role_is_active
                    
                    	Is process role active or standby
                    	**type**\:  bool
                    
                    .. attribute:: router_id
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: session_hold_time
                    
                    	Session hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_hold_time
                    
                    	Targeted hello hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_interval
                    
                    	Targeted hello interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Parameters, self).__init__()

                        self.yang_name = "parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"graceful-restart-information" : ("graceful_restart_information", MplsLdp.Global_.Active.DefaultVrf.Parameters.GracefulRestartInformation)}
                        self._child_list_classes = {"address-family-parameter" : ("address_family_parameter", MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter)}

                        self.af_binding_withdraw_delay = YLeaf(YType.uint32, "af-binding-withdraw-delay")

                        self.discovery_quick_start_disabled_on_interfaces = YLeaf(YType.boolean, "discovery-quick-start-disabled-on-interfaces")

                        self.global_discovery_quick_start_disabled = YLeaf(YType.boolean, "global-discovery-quick-start-disabled")

                        self.global_md5_password_enabled = YLeaf(YType.boolean, "global-md5-password-enabled")

                        self.hello_hold_time = YLeaf(YType.uint32, "hello-hold-time")

                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                        self.housekeeping_timer_interval = YLeaf(YType.uint32, "housekeeping-timer-interval")

                        self.igp_sync_delay_time_for_interface = YLeaf(YType.uint32, "igp-sync-delay-time-for-interface")

                        self.igp_sync_delay_time_on_restart = YLeaf(YType.uint32, "igp-sync-delay-time-on-restart")

                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                        self.ldp_out_of_mem_state = YLeaf(YType.uint32, "ldp-out-of-mem-state")

                        self.ldp_recovery_timeout = YLeaf(YType.uint32, "ldp-recovery-timeout")

                        self.le_no_route_timeout = YLeaf(YType.uint32, "le-no-route-timeout")

                        self.max_intf_attached = YLeaf(YType.uint32, "max-intf-attached")

                        self.max_intf_te = YLeaf(YType.uint32, "max-intf-te")

                        self.max_peer = YLeaf(YType.uint32, "max-peer")

                        self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                        self.protocol_version = YLeaf(YType.uint32, "protocol-version")

                        self.role_is_active = YLeaf(YType.boolean, "role-is-active")

                        self.router_id = YLeaf(YType.str, "router-id")

                        self.session_hold_time = YLeaf(YType.uint32, "session-hold-time")

                        self.targeted_hello_hold_time = YLeaf(YType.uint32, "targeted-hello-hold-time")

                        self.targeted_hello_interval = YLeaf(YType.uint32, "targeted-hello-interval")

                        self.graceful_restart_information = MplsLdp.Global_.Active.DefaultVrf.Parameters.GracefulRestartInformation()
                        self.graceful_restart_information.parent = self
                        self._children_name_map["graceful_restart_information"] = "graceful-restart-information"
                        self._children_yang_names.add("graceful-restart-information")

                        self.address_family_parameter = YList(self)
                        self._segment_path = lambda: "parameters"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Parameters, ['af_binding_withdraw_delay', 'discovery_quick_start_disabled_on_interfaces', 'global_discovery_quick_start_disabled', 'global_md5_password_enabled', 'hello_hold_time', 'hello_interval', 'housekeeping_timer_interval', 'igp_sync_delay_time_for_interface', 'igp_sync_delay_time_on_restart', 'keepalive_interval', 'ldp_out_of_mem_state', 'ldp_recovery_timeout', 'le_no_route_timeout', 'max_intf_attached', 'max_intf_te', 'max_peer', 'nsr_enabled', 'nsr_synced', 'protocol_version', 'role_is_active', 'router_id', 'session_hold_time', 'targeted_hello_hold_time', 'targeted_hello_interval'], name, value)


                    class AddressFamilyParameter(Entity):
                        """
                        Per AF parameters
                        
                        .. attribute:: address_family
                        
                        	Address Family
                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: discovery_transport_address
                        
                        	Discovery transport address
                        	**type**\:   :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                        
                        .. attribute:: is_accepting_targeted_hellos
                        
                        	Accepting targeted Hellos
                        	**type**\:  bool
                        
                        .. attribute:: label_imp_null_override_acl
                        
                        	ACL to override local label to use implicit\-null
                        	**type**\:  str
                        
                        .. attribute:: null_label
                        
                        	Null label
                        	**type**\:  str
                        
                        .. attribute:: targeted_hello_acl
                        
                        	Targeted Hello ACL
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter, self).__init__()

                            self.yang_name = "address-family-parameter"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"discovery-transport-address" : ("discovery_transport_address", MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress)}
                            self._child_list_classes = {}

                            self.address_family = YLeaf(YType.enumeration, "address-family")

                            self.is_accepting_targeted_hellos = YLeaf(YType.boolean, "is-accepting-targeted-hellos")

                            self.label_imp_null_override_acl = YLeaf(YType.str, "label-imp-null-override-acl")

                            self.null_label = YLeaf(YType.str, "null-label")

                            self.targeted_hello_acl = YLeaf(YType.str, "targeted-hello-acl")

                            self.discovery_transport_address = MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                            self.discovery_transport_address.parent = self
                            self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                            self._children_yang_names.add("discovery-transport-address")
                            self._segment_path = lambda: "address-family-parameter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/parameters/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter, ['address_family', 'is_accepting_targeted_hellos', 'label_imp_null_override_acl', 'null_label', 'targeted_hello_acl'], name, value)


                        class DiscoveryTransportAddress(Entity):
                            """
                            Discovery transport address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                self.yang_name = "discovery-transport-address"
                                self.yang_parent_name = "address-family-parameter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.dummy = YLeaf(YType.uint8, "dummy")

                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                self._segment_path = lambda: "discovery-transport-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/parameters/address-family-parameter/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                    class GracefulRestartInformation(Entity):
                        """
                        Graceful restart information
                        
                        .. attribute:: graceful_restart_forwarding_state_hold_time
                        
                        	Graceful restart forward state hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_restart_reconnect_timeout
                        
                        	Reconnect timeout value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_graceful_restart_configured
                        
                        	Is graceful restart configured
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Parameters.GracefulRestartInformation, self).__init__()

                            self.yang_name = "graceful-restart-information"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.graceful_restart_forwarding_state_hold_time = YLeaf(YType.uint32, "graceful-restart-forwarding-state-hold-time")

                            self.graceful_restart_reconnect_timeout = YLeaf(YType.uint32, "graceful-restart-reconnect-timeout")

                            self.is_graceful_restart_configured = YLeaf(YType.boolean, "is-graceful-restart-configured")
                            self._segment_path = lambda: "graceful-restart-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/parameters/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Parameters.GracefulRestartInformation, ['graceful_restart_forwarding_state_hold_time', 'graceful_restart_reconnect_timeout', 'is_graceful_restart_configured'], name, value)


                class Statistics(Entity):
                    """
                    The LDP Statistics
                    
                    .. attribute:: statistic
                    
                    	Statistical Information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"statistic" : ("statistic", MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic)}

                        self.statistic = YList(self)
                        self._segment_path = lambda: "statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Statistics, [], name, value)


                    class Statistic(Entity):
                        """
                        Statistical Information on a particular LDP
                        neighbor
                        
                        .. attribute:: iccp_enabled
                        
                        	Is session ICCP enabled?
                        	**type**\:  bool
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: message_in
                        
                        	Message in count
                        	**type**\:   :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageIn>`
                        
                        .. attribute:: message_out
                        
                        	Message out count
                        	**type**\:   :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageOut>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic, self).__init__()

                            self.yang_name = "statistic"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"message-in" : ("message_in", MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageIn), "message-out" : ("message_out", MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageOut)}
                            self._child_list_classes = {}

                            self.iccp_enabled = YLeaf(YType.boolean, "iccp-enabled")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.message_in = MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageIn()
                            self.message_in.parent = self
                            self._children_name_map["message_in"] = "message-in"
                            self._children_yang_names.add("message-in")

                            self.message_out = MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageOut()
                            self.message_out.parent = self
                            self._children_name_map["message_out"] = "message-out"
                            self._children_yang_names.add("message-out")
                            self._segment_path = lambda: "statistic"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/statistics/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic, ['iccp_enabled', 'label_space_id', 'lsr_id'], name, value)


                        class MessageIn(Entity):
                            """
                            Message in count
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageIn, self).__init__()

                                self.yang_name = "message-in"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_count = YLeaf(YType.uint32, "address-count")

                                self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                self.init_count = YLeaf(YType.uint32, "init-count")

                                self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                self.notification_count = YLeaf(YType.uint32, "notification-count")

                                self.total_count = YLeaf(YType.uint32, "total-count")
                                self._segment_path = lambda: "message-in"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/statistics/statistic/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageIn, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                        class MessageOut(Entity):
                            """
                            Message out count
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageOut, self).__init__()

                                self.yang_name = "message-out"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_count = YLeaf(YType.uint32, "address-count")

                                self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                self.init_count = YLeaf(YType.uint32, "init-count")

                                self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                self.notification_count = YLeaf(YType.uint32, "notification-count")

                                self.total_count = YLeaf(YType.uint32, "total-count")
                                self._segment_path = lambda: "message-out"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/statistics/statistic/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Statistics.Statistic.MessageOut, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                class Summary(Entity):
                    """
                    LDP VRF summary
                    
                    .. attribute:: common
                    
                    	Common Summary information
                    	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Summary.Common>`
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DefaultVrf.Summary.Vrf>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DefaultVrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"common" : ("common", MplsLdp.Global_.Active.DefaultVrf.Summary.Common), "vrf" : ("vrf", MplsLdp.Global_.Active.DefaultVrf.Summary.Vrf)}
                        self._child_list_classes = {}

                        self.common = MplsLdp.Global_.Active.DefaultVrf.Summary.Common()
                        self.common.parent = self
                        self._children_name_map["common"] = "common"
                        self._children_yang_names.add("common")

                        self.vrf = MplsLdp.Global_.Active.DefaultVrf.Summary.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._children_yang_names.add("vrf")
                        self._segment_path = lambda: "summary"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/%s" % self._segment_path()


                    class Common(Entity):
                        """
                        Common Summary information
                        
                        .. attribute:: address_families
                        
                        	Address Families enabled
                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: number_of_bindings_ipv4
                        
                        	Total number of ipv4 bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv6
                        
                        	Total number of ipv6 bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_downstream_on_demand_neighbors
                        
                        	Number of Downstream\-On\-Demand neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_graceful_restart_neighbors
                        
                        	Number of Graceful Restart neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_hello_adj
                        
                        	Number of LDP discovery IPv4 hello adjacencies
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_local_addresses
                        
                        	Number of IPv4 local addresses
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_routes
                        
                        	Number of resolved IPv4 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4af
                        
                        	Number of IPv4 address\-families enabled
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4ldp_interfaces
                        
                        	Number of LDP IPv4 configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_hello_adj
                        
                        	Number of LDP discovery IPv6 hello adjacencies
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_local_addresses
                        
                        	Number of IPv6 local addresses
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_routes
                        
                        	Number of resolved IPv6 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6af
                        
                        	Number of IPv6 address\-families enabled
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6ldp_interfaces
                        
                        	Number of LDP IPv6 configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ldp_interfaces
                        
                        	Number of LDP configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv4
                        
                        	Total number of ipv4 local label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv6
                        
                        	Total number of ipv6 local label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_nsr_synced_neighbors
                        
                        	Number of NSR\-synced/operational neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv4
                        
                        	Total number of ipv4 remote label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv6
                        
                        	Total number of ipv6 remote label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Summary.Common, self).__init__()

                            self.yang_name = "common"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.address_families = YLeaf(YType.enumeration, "address-families")

                            self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                            self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                            self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                            self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                            self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                            self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                            self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                            self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                            self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                            self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                            self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                            self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                            self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                            self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                            self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                            self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                            self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                            self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                            self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                            self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                            self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                            self._segment_path = lambda: "common"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/summary/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.DefaultVrf.Summary.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.id = YLeaf(YType.uint32, "id")

                            self.name = YLeaf(YType.str, "name")
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/default-vrf/summary/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.DefaultVrf.Summary.Vrf, ['id', 'name'], name, value)


            class DiscoverySummaryAll(Entity):
                """
                Summary information regarding LDP discovery
                
                .. attribute:: local_ldp_id
                
                	Local LDP identifier
                	**type**\:  str
                
                .. attribute:: num_of_active_ldp_interfaces
                
                	Number of active LDP enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_addr_recv
                
                	Number of hello discoveries received with bad source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_hello_pdu
                
                	Number of hello discoveries received with bad hello PDU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_xport_addr
                
                	Number of hello discoveries received with bad export address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_same_router_id
                
                	Number of hello discoveries received with the same router id as this router
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_wrong_router_id
                
                	Number of hello discoveries received with the router id that is not destined for this router
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_ldp_interfaces
                
                	Total Number of LDP configured interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_recv
                
                	Number of link hello discoveries in recv state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_xmit
                
                	Number of link hello discoveries in xmit state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_recv
                
                	Number of targeted hello discoveries in recv state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_xmit
                
                	Number of targeted hello discoveries in xmit state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.DiscoverySummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Active.DiscoverySummaryAll, self).__init__()

                    self.yang_name = "discovery-summary-all"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.DiscoverySummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                    self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                    self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                    self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                    self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                    self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                    self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                    self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                    self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                    self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                    self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                    self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                    self.vrf = MplsLdp.Global_.Active.DiscoverySummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "discovery-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Active.DiscoverySummaryAll, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.DiscoverySummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "discovery-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/discovery-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.DiscoverySummaryAll.Vrf, ['id', 'name'], name, value)


            class ForwardingSummaryAll(Entity):
                """
                Summary information regarding LDP forwarding
                setup
                
                .. attribute:: fsht
                
                	Forwarding state hold time registered with LSD
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: intfs
                
                	MPLS forwarding enabled interface count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: is_lsd_bound
                
                	LDP is connected to LSD server
                	**type**\:  bool
                
                .. attribute:: lbls
                
                	Local label allocated count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: rws
                
                	Forwarding rewrites summary
                	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.ForwardingSummaryAll.Rws>`
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.ForwardingSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Active.ForwardingSummaryAll, self).__init__()

                    self.yang_name = "forwarding-summary-all"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"rws" : ("rws", MplsLdp.Global_.Active.ForwardingSummaryAll.Rws), "vrf" : ("vrf", MplsLdp.Global_.Active.ForwardingSummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.fsht = YLeaf(YType.uint16, "fsht")

                    self.intfs = YLeaf(YType.uint16, "intfs")

                    self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                    self.lbls = YLeaf(YType.uint16, "lbls")

                    self.rws = MplsLdp.Global_.Active.ForwardingSummaryAll.Rws()
                    self.rws.parent = self
                    self._children_name_map["rws"] = "rws"
                    self._children_yang_names.add("rws")

                    self.vrf = MplsLdp.Global_.Active.ForwardingSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "forwarding-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Active.ForwardingSummaryAll, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                class Rws(Entity):
                    """
                    Forwarding rewrites summary
                    
                    .. attribute:: nhs
                    
                    	Forwarding rewrites nexthops (paths) summary
                    	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Nhs>`
                    
                    .. attribute:: pfxs
                    
                    	Forwarding rewrites prefix summary
                    	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws, self).__init__()

                        self.yang_name = "rws"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs)}
                        self._child_list_classes = {}

                        self.nhs = MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Nhs()
                        self.nhs.parent = self
                        self._children_name_map["nhs"] = "nhs"
                        self._children_yang_names.add("nhs")

                        self.pfxs = MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs()
                        self.pfxs.parent = self
                        self._children_name_map["pfxs"] = "pfxs"
                        self._children_yang_names.add("pfxs")
                        self._segment_path = lambda: "rws"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/%s" % self._segment_path()


                    class Nhs(Entity):
                        """
                        Forwarding rewrites nexthops (paths) summary
                        
                        .. attribute:: backup_paths
                        
                        	Count of non\-primary backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_backup_paths
                        
                        	Count of labeled backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_paths
                        
                        	Count of all labeled paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protected_paths
                        
                        	Count of FRR protected paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_backup_paths
                        
                        	Count of non\-primary remote backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_paths
                        
                        	Total path count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Nhs, self).__init__()

                            self.yang_name = "nhs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                            self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                            self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                            self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                            self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                            self.total_paths = YLeaf(YType.uint32, "total-paths")
                            self._segment_path = lambda: "nhs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                    class Pfxs(Entity):
                        """
                        Forwarding rewrites prefix summary
                        
                        .. attribute:: ecmp_pfxs
                        
                        	Count of prefixes with ECMP
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: labeled_pfxs_aggr
                        
                        	Labeled prefix count for all paths
                        	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr>`
                        
                        .. attribute:: labeled_pfxs_backup
                        
                        	Labeled prefix count related to backup paths only
                        	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup>`
                        
                        .. attribute:: labeled_pfxs_primary
                        
                        	Labeled prefix count related to primary paths only
                        	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary>`
                        
                        .. attribute:: protected_pfxs
                        
                        	Count of FRR protected prefixes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: total_pfxs
                        
                        	Total Prefix count
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs, self).__init__()

                            self.yang_name = "pfxs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary)}
                            self._child_list_classes = {}

                            self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                            self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                            self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                            self.labeled_pfxs_aggr = MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr()
                            self.labeled_pfxs_aggr.parent = self
                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                            self._children_yang_names.add("labeled-pfxs-aggr")

                            self.labeled_pfxs_backup = MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup()
                            self.labeled_pfxs_backup.parent = self
                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                            self._children_yang_names.add("labeled-pfxs-backup")

                            self.labeled_pfxs_primary = MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary()
                            self.labeled_pfxs_primary.parent = self
                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                            self._children_yang_names.add("labeled-pfxs-primary")
                            self._segment_path = lambda: "pfxs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                        class LabeledPfxsAggr(Entity):
                            """
                            Labeled prefix count for all paths
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                self.yang_name = "labeled-pfxs-aggr"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-aggr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                        class LabeledPfxsBackup(Entity):
                            """
                            Labeled prefix count related to backup paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                self.yang_name = "labeled-pfxs-backup"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-backup"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                        class LabeledPfxsPrimary(Entity):
                            """
                            Labeled prefix count related to primary paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                self.yang_name = "labeled-pfxs-primary"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-primary"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.ForwardingSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/forwarding-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.ForwardingSummaryAll.Vrf, ['id', 'name'], name, value)


            class NsrSummaryAll(Entity):
                """
                Summary information regarding LDP NSR State
                
                .. attribute:: sessions
                
                	Session summary
                	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.NsrSummaryAll.Sessions>`
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.NsrSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Active.NsrSummaryAll, self).__init__()

                    self.yang_name = "nsr-summary-all"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Active.NsrSummaryAll.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Active.NsrSummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.sessions = MplsLdp.Global_.Active.NsrSummaryAll.Sessions()
                    self.sessions.parent = self
                    self._children_name_map["sessions"] = "sessions"
                    self._children_yang_names.add("sessions")

                    self.vrf = MplsLdp.Global_.Active.NsrSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "nsr-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()


                class Sessions(Entity):
                    """
                    Session summary
                    
                    .. attribute:: nsr_eligible
                    
                    	NSR eligible sessions
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_app_wait
                    
                    	Number of sessions in NSR app\-wait state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_none
                    
                    	Number of sessions in NSR none state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_operational
                    
                    	Number of sessions in NSR operational state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_prepare
                    
                    	Number of sessions in NSR prepare state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_ready
                    
                    	Number of sessions in NSR ready state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase1
                    
                    	Number of sessions in NSR TCP phase 1 state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase2
                    
                    	Number of sessions in NSR TCP phase 2 state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_wait
                    
                    	Number of sessions in NSR wait state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total
                    
                    	Total sessions
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.NsrSummaryAll.Sessions, self).__init__()

                        self.yang_name = "sessions"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                        self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                        self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                        self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                        self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                        self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                        self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                        self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                        self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                        self.total = YLeaf(YType.uint32, "total")
                        self._segment_path = lambda: "sessions"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/nsr-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.NsrSummaryAll.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.NsrSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/nsr-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.NsrSummaryAll.Vrf, ['id', 'name'], name, value)


            class Summary(Entity):
                """
                LDP summary
                
                .. attribute:: common
                
                	Common Summary information
                	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Summary.Common>`
                
                .. attribute:: is_bound_with_atom
                
                	Bound status with L2VPN ATOM
                	**type**\:  bool
                
                .. attribute:: is_bound_with_interface_manager
                
                	Bound status with Interface Manager
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ip_arm
                
                	Bound status with IP Arm
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ipv4_rib
                
                	Bound status with IPv4 RIB
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ipv6_rib
                
                	Bound status with IPv6 RIB
                	**type**\:  bool
                
                .. attribute:: is_bound_with_lsd
                
                	Bound status with LSD
                	**type**\:  bool
                
                .. attribute:: is_bound_with_nsr_mate
                
                	Bound status with NSR Mate
                	**type**\:  bool
                
                .. attribute:: is_bound_with_rsi
                
                	Bound status with rsi
                	**type**\:  bool
                
                .. attribute:: is_bound_with_sysdb
                
                	Bound status with sysdb
                	**type**\:  bool
                
                .. attribute:: is_mldp_registered
                
                	mLDP registration status
                	**type**\:  bool
                
                .. attribute:: is_nsr_configured
                
                	NSR configured
                	**type**\:  bool
                
                .. attribute:: is_registered_with_interface_manager
                
                	Registration status with Interface Manager
                	**type**\:  bool
                
                .. attribute:: is_registered_with_ipv4_rib
                
                	Registration status with IPv4 RIB
                	**type**\:  bool
                
                .. attribute:: is_registered_with_ipv6_rib
                
                	Registration status with IPv6 RIB
                	**type**\:  bool
                
                .. attribute:: is_registered_with_lsd
                
                	Registration status with LSD
                	**type**\:  bool
                
                .. attribute:: is_registered_with_sysdb
                
                	Registration status with Sysdb
                	**type**\:  bool
                
                .. attribute:: number_of_autocfg_interfaces
                
                	Number of auto\-configured interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_fwd_ref_interfaces
                
                	Number of Forward Referenc interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of known interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_ipv4rib_tables
                
                	Total number of ipv4 RIB tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_ipv6rib_tables
                
                	Total number of ipv6 RIB tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv4rib_tables
                
                	Number of ipv4 RIB tables registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv6rib_tables
                
                	Number of ipv6 RIB tables registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf
                
                	Number of configured VRFs (including default)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf_oper
                
                	Number of configured operational VRFs (including default)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Active.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"common" : ("common", MplsLdp.Global_.Active.Summary.Common)}
                    self._child_list_classes = {}

                    self.is_bound_with_atom = YLeaf(YType.boolean, "is-bound-with-atom")

                    self.is_bound_with_interface_manager = YLeaf(YType.boolean, "is-bound-with-interface-manager")

                    self.is_bound_with_ip_arm = YLeaf(YType.boolean, "is-bound-with-ip-arm")

                    self.is_bound_with_ipv4_rib = YLeaf(YType.boolean, "is-bound-with-ipv4-rib")

                    self.is_bound_with_ipv6_rib = YLeaf(YType.boolean, "is-bound-with-ipv6-rib")

                    self.is_bound_with_lsd = YLeaf(YType.boolean, "is-bound-with-lsd")

                    self.is_bound_with_nsr_mate = YLeaf(YType.boolean, "is-bound-with-nsr-mate")

                    self.is_bound_with_rsi = YLeaf(YType.boolean, "is-bound-with-rsi")

                    self.is_bound_with_sysdb = YLeaf(YType.boolean, "is-bound-with-sysdb")

                    self.is_mldp_registered = YLeaf(YType.boolean, "is-mldp-registered")

                    self.is_nsr_configured = YLeaf(YType.boolean, "is-nsr-configured")

                    self.is_registered_with_interface_manager = YLeaf(YType.boolean, "is-registered-with-interface-manager")

                    self.is_registered_with_ipv4_rib = YLeaf(YType.boolean, "is-registered-with-ipv4-rib")

                    self.is_registered_with_ipv6_rib = YLeaf(YType.boolean, "is-registered-with-ipv6-rib")

                    self.is_registered_with_lsd = YLeaf(YType.boolean, "is-registered-with-lsd")

                    self.is_registered_with_sysdb = YLeaf(YType.boolean, "is-registered-with-sysdb")

                    self.number_of_autocfg_interfaces = YLeaf(YType.uint32, "number-of-autocfg-interfaces")

                    self.number_of_fwd_ref_interfaces = YLeaf(YType.uint32, "number-of-fwd-ref-interfaces")

                    self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                    self.number_of_ipv4rib_tables = YLeaf(YType.uint32, "number-of-ipv4rib-tables")

                    self.number_of_ipv6rib_tables = YLeaf(YType.uint32, "number-of-ipv6rib-tables")

                    self.number_of_registered_ipv4rib_tables = YLeaf(YType.uint32, "number-of-registered-ipv4rib-tables")

                    self.number_of_registered_ipv6rib_tables = YLeaf(YType.uint32, "number-of-registered-ipv6rib-tables")

                    self.number_of_vrf = YLeaf(YType.uint32, "number-of-vrf")

                    self.number_of_vrf_oper = YLeaf(YType.uint32, "number-of-vrf-oper")

                    self.common = MplsLdp.Global_.Active.Summary.Common()
                    self.common.parent = self
                    self._children_name_map["common"] = "common"
                    self._children_yang_names.add("common")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Active.Summary, ['is_bound_with_atom', 'is_bound_with_interface_manager', 'is_bound_with_ip_arm', 'is_bound_with_ipv4_rib', 'is_bound_with_ipv6_rib', 'is_bound_with_lsd', 'is_bound_with_nsr_mate', 'is_bound_with_rsi', 'is_bound_with_sysdb', 'is_mldp_registered', 'is_nsr_configured', 'is_registered_with_interface_manager', 'is_registered_with_ipv4_rib', 'is_registered_with_ipv6_rib', 'is_registered_with_lsd', 'is_registered_with_sysdb', 'number_of_autocfg_interfaces', 'number_of_fwd_ref_interfaces', 'number_of_interfaces', 'number_of_ipv4rib_tables', 'number_of_ipv6rib_tables', 'number_of_registered_ipv4rib_tables', 'number_of_registered_ipv6rib_tables', 'number_of_vrf', 'number_of_vrf_oper'], name, value)


                class Common(Entity):
                    """
                    Common Summary information
                    
                    .. attribute:: address_families
                    
                    	Address Families enabled
                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: number_of_bindings_ipv4
                    
                    	Total number of ipv4 bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv6
                    
                    	Total number of ipv6 bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_downstream_on_demand_neighbors
                    
                    	Number of Downstream\-On\-Demand neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_graceful_restart_neighbors
                    
                    	Number of Graceful Restart neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_hello_adj
                    
                    	Number of LDP discovery IPv4 hello adjacencies
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_local_addresses
                    
                    	Number of IPv4 local addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_routes
                    
                    	Number of resolved IPv4 routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4af
                    
                    	Number of IPv4 address\-families enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4ldp_interfaces
                    
                    	Number of LDP IPv4 configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_hello_adj
                    
                    	Number of LDP discovery IPv6 hello adjacencies
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_local_addresses
                    
                    	Number of IPv6 local addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_routes
                    
                    	Number of resolved IPv6 routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6af
                    
                    	Number of IPv6 address\-families enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6ldp_interfaces
                    
                    	Number of LDP IPv6 configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ldp_interfaces
                    
                    	Number of LDP configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv4
                    
                    	Total number of ipv4 local label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv6
                    
                    	Total number of ipv6 local label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_nsr_synced_neighbors
                    
                    	Number of NSR\-synced/operational neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv4
                    
                    	Total number of ipv4 remote label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv6
                    
                    	Total number of ipv6 remote label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.Summary.Common, self).__init__()

                        self.yang_name = "common"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.address_families = YLeaf(YType.enumeration, "address-families")

                        self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                        self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                        self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                        self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                        self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                        self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                        self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                        self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                        self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                        self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                        self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                        self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                        self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                        self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                        self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                        self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                        self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                        self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                        self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                        self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                        self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                        self._segment_path = lambda: "common"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


            class Vrfs(Entity):
                """
                VRF specific operational data
                
                .. attribute:: vrf
                
                	Operational data for given VRF
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Active.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf)}

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for given VRF
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: afs
                    
                    	Address Family specific operational data
                    	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs>`
                    
                    .. attribute:: backoff_parameters
                    
                    	The LDP Backoff Parameters
                    	**type**\:   :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.BackoffParameters>`
                    
                    .. attribute:: backoffs
                    
                    	The LDP backoff
                    	**type**\:   :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs>`
                    
                    .. attribute:: capabilities
                    
                    	LDP capability database information
                    	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities>`
                    
                    .. attribute:: graceful_restart
                    
                    	LDP Graceful Restart info
                    	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart>`
                    
                    .. attribute:: issu
                    
                    	LDP ISSU related information
                    	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu>`
                    
                    .. attribute:: ldp_id
                    
                    	Local LDP Id
                    	**type**\:   :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.LdpId>`
                    
                    .. attribute:: neighbor_briefs
                    
                    	The LDP Neighbors (brief)
                    	**type**\:   :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs>`
                    
                    .. attribute:: neighbor_capabilities
                    
                    	LDP Neighbors Capabilities
                    	**type**\:   :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities>`
                    
                    .. attribute:: neighbors
                    
                    	The LDP Neighbors
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors>`
                    
                    .. attribute:: nsr
                    
                    	LDP NSR related information
                    	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr>`
                    
                    .. attribute:: parameters
                    
                    	LDP parameters
                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Parameters>`
                    
                    .. attribute:: statistics
                    
                    	The LDP Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Statistics>`
                    
                    .. attribute:: summary
                    
                    	LDP VRF summary
                    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Summary>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Active.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"afs" : ("afs", MplsLdp.Global_.Active.Vrfs.Vrf.Afs), "backoff-parameters" : ("backoff_parameters", MplsLdp.Global_.Active.Vrfs.Vrf.BackoffParameters), "backoffs" : ("backoffs", MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs), "capabilities" : ("capabilities", MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities), "graceful-restart" : ("graceful_restart", MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart), "issu" : ("issu", MplsLdp.Global_.Active.Vrfs.Vrf.Issu), "ldp-id" : ("ldp_id", MplsLdp.Global_.Active.Vrfs.Vrf.LdpId), "neighbor-briefs" : ("neighbor_briefs", MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs), "neighbor-capabilities" : ("neighbor_capabilities", MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities), "neighbors" : ("neighbors", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors), "nsr" : ("nsr", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr), "parameters" : ("parameters", MplsLdp.Global_.Active.Vrfs.Vrf.Parameters), "statistics" : ("statistics", MplsLdp.Global_.Active.Vrfs.Vrf.Statistics), "summary" : ("summary", MplsLdp.Global_.Active.Vrfs.Vrf.Summary)}
                        self._child_list_classes = {}

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.afs = MplsLdp.Global_.Active.Vrfs.Vrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"
                        self._children_yang_names.add("afs")

                        self.backoff_parameters = MplsLdp.Global_.Active.Vrfs.Vrf.BackoffParameters()
                        self.backoff_parameters.parent = self
                        self._children_name_map["backoff_parameters"] = "backoff-parameters"
                        self._children_yang_names.add("backoff-parameters")

                        self.backoffs = MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs()
                        self.backoffs.parent = self
                        self._children_name_map["backoffs"] = "backoffs"
                        self._children_yang_names.add("backoffs")

                        self.capabilities = MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities()
                        self.capabilities.parent = self
                        self._children_name_map["capabilities"] = "capabilities"
                        self._children_yang_names.add("capabilities")

                        self.graceful_restart = MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart()
                        self.graceful_restart.parent = self
                        self._children_name_map["graceful_restart"] = "graceful-restart"
                        self._children_yang_names.add("graceful-restart")

                        self.issu = MplsLdp.Global_.Active.Vrfs.Vrf.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"
                        self._children_yang_names.add("issu")

                        self.ldp_id = MplsLdp.Global_.Active.Vrfs.Vrf.LdpId()
                        self.ldp_id.parent = self
                        self._children_name_map["ldp_id"] = "ldp-id"
                        self._children_yang_names.add("ldp-id")

                        self.neighbor_briefs = MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs()
                        self.neighbor_briefs.parent = self
                        self._children_name_map["neighbor_briefs"] = "neighbor-briefs"
                        self._children_yang_names.add("neighbor-briefs")

                        self.neighbor_capabilities = MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities()
                        self.neighbor_capabilities.parent = self
                        self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"
                        self._children_yang_names.add("neighbor-capabilities")

                        self.neighbors = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                        self._children_yang_names.add("neighbors")

                        self.nsr = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                        self._children_yang_names.add("nsr")

                        self.parameters = MplsLdp.Global_.Active.Vrfs.Vrf.Parameters()
                        self.parameters.parent = self
                        self._children_name_map["parameters"] = "parameters"
                        self._children_yang_names.add("parameters")

                        self.statistics = MplsLdp.Global_.Active.Vrfs.Vrf.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                        self.summary = MplsLdp.Global_.Active.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                        self._children_yang_names.add("summary")
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/active/vrfs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf, ['vrf_name'], name, value)


                    class Afs(Entity):
                        """
                        Address Family specific operational data
                        
                        .. attribute:: af
                        
                        	Operational data for given Address Family
                        	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"af" : ("af", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af)}

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            Operational data for given Address Family
                            
                            .. attribute:: af_name  <key>
                            
                            	Address Family name
                            	**type**\:   :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                            
                            .. attribute:: bindings
                            
                            	The LDP Bindings
                            	**type**\:   :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings>`
                            
                            .. attribute:: bindings_advertise_spec
                            
                            	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec>`
                            
                            .. attribute:: bindings_summary
                            
                            	Counters for the LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary>`
                            
                            .. attribute:: bindings_summary_all
                            
                            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll>`
                            
                            .. attribute:: discovery
                            
                            	The LDP Discovery
                            	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery>`
                            
                            .. attribute:: forwarding_summary
                            
                            	Summary information regarding LDP forwarding setup
                            	**type**\:   :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary>`
                            
                            .. attribute:: forwardings
                            
                            	The LDP Forwarding rewrites
                            	**type**\:   :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings>`
                            
                            .. attribute:: igp
                            
                            	LDP IGP related information
                            	**type**\:   :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp>`
                            
                            .. attribute:: interface_summary
                            
                            	IPv4 interface summary information
                            	**type**\:   :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary>`
                            
                            .. attribute:: interfaces
                            
                            	LDP Interface related information
                            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"bindings" : ("bindings", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings), "bindings-advertise-spec" : ("bindings_advertise_spec", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec), "bindings-summary" : ("bindings_summary", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll), "discovery" : ("discovery", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery), "forwarding-summary" : ("forwarding_summary", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary), "forwardings" : ("forwardings", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings), "igp" : ("igp", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp), "interface-summary" : ("interface_summary", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary), "interfaces" : ("interfaces", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces)}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.bindings = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings()
                                self.bindings.parent = self
                                self._children_name_map["bindings"] = "bindings"
                                self._children_yang_names.add("bindings")

                                self.bindings_advertise_spec = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec()
                                self.bindings_advertise_spec.parent = self
                                self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"
                                self._children_yang_names.add("bindings-advertise-spec")

                                self.bindings_summary = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary()
                                self.bindings_summary.parent = self
                                self._children_name_map["bindings_summary"] = "bindings-summary"
                                self._children_yang_names.add("bindings-summary")

                                self.bindings_summary_all = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll()
                                self.bindings_summary_all.parent = self
                                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                                self._children_yang_names.add("bindings-summary-all")

                                self.discovery = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery()
                                self.discovery.parent = self
                                self._children_name_map["discovery"] = "discovery"
                                self._children_yang_names.add("discovery")

                                self.forwarding_summary = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary()
                                self.forwarding_summary.parent = self
                                self._children_name_map["forwarding_summary"] = "forwarding-summary"
                                self._children_yang_names.add("forwarding-summary")

                                self.forwardings = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings()
                                self.forwardings.parent = self
                                self._children_name_map["forwardings"] = "forwardings"
                                self._children_yang_names.add("forwardings")

                                self.igp = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp()
                                self.igp.parent = self
                                self._children_name_map["igp"] = "igp"
                                self._children_yang_names.add("igp")

                                self.interface_summary = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary()
                                self.interface_summary.parent = self
                                self._children_name_map["interface_summary"] = "interface-summary"
                                self._children_yang_names.add("interface-summary")

                                self.interfaces = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"
                                self._children_yang_names.add("interfaces")
                                self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                            class Bindings(Entity):
                                """
                                The LDP Bindings
                                
                                .. attribute:: binding
                                
                                	Binding Information
                                	**type**\: list of    :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings, self).__init__()

                                    self.yang_name = "bindings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"binding" : ("binding", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding)}

                                    self.binding = YList(self)
                                    self._segment_path = lambda: "bindings"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings, [], name, value)


                                class Binding(Entity):
                                    """
                                    Binding Information
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	The IP Prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: advertise_prefix_acl
                                    
                                    	Advertise Prerfix ACL
                                    	**type**\:  str
                                    
                                    .. attribute:: advertise_tsr_acl
                                    
                                    	Advertise TSR ACL
                                    	**type**\:  str
                                    
                                    .. attribute:: config_enforced_local_label_value
                                    
                                    	Config/User enforced local label value
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_no_route
                                    
                                    	No route
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_oor
                                    
                                    	Label space depletion OOR
                                    	**type**\:  bool
                                    
                                    .. attribute:: le_local_binding_revision
                                    
                                    	Local Binding revision
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_label_state
                                    
                                    	Local label state
                                    	**type**\:   :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peers_acked
                                    
                                    	Peers that have ACKed this entry
                                    	**type**\: list of    :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                    
                                    .. attribute:: peers_advertised_to
                                    
                                    	Peers this entry is advertised to
                                    	**type**\: list of    :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                    
                                    .. attribute:: remote_binding
                                    
                                    	Remote binding
                                    	**type**\: list of    :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding, self).__init__()

                                        self.yang_name = "binding"
                                        self.yang_parent_name = "bindings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr), "vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf)}
                                        self._child_list_classes = {"peers-acked" : ("peers_acked", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked), "peers-advertised-to" : ("peers_advertised_to", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo), "remote-binding" : ("remote_binding", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.advertise_prefix_acl = YLeaf(YType.str, "advertise-prefix-acl")

                                        self.advertise_tsr_acl = YLeaf(YType.str, "advertise-tsr-acl")

                                        self.config_enforced_local_label_value = YLeaf(YType.boolean, "config-enforced-local-label-value")

                                        self.is_elc = YLeaf(YType.boolean, "is-elc")

                                        self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.le_local_binding_revision = YLeaf(YType.uint32, "le-local-binding-revision")

                                        self.le_local_label_state = YLeaf(YType.enumeration, "le-local-label-state")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.prefix_xr = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"
                                        self._children_yang_names.add("prefix-xr")

                                        self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.peers_acked = YList(self)
                                        self.peers_advertised_to = YList(self)
                                        self.remote_binding = YList(self)
                                        self._segment_path = lambda: "binding" + "[prefix='" + self.prefix.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding, ['prefix', 'advertise_prefix_acl', 'advertise_tsr_acl', 'config_enforced_local_label_value', 'is_elc', 'is_no_route', 'label_oor', 'le_local_binding_revision', 'le_local_label_state', 'local_label', 'prefix_length'], name, value)


                                    class PeersAcked(Entity):
                                        """
                                        Peers that have ACKed this entry
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                            self.yang_name = "peers-acked"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "peers-acked"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class PeersAdvertisedTo(Entity):
                                        """
                                        Peers this entry is advertised to
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                            self.yang_name = "peers-advertised-to"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "prefix-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class RemoteBinding(Entity):
                                        """
                                        Remote binding
                                        
                                        .. attribute:: assigning_peer_ldp_ident
                                        
                                        	Assigning peer
                                        	**type**\:   :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                        
                                        .. attribute:: is_elc
                                        
                                        	Is the entry entropy label capable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_stale
                                        
                                        	Is the entry stale
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                            self.yang_name = "remote-binding"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"assigning-peer-ldp-ident" : ("assigning_peer_ldp_ident", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent)}
                                            self._child_list_classes = {}

                                            self.is_elc = YLeaf(YType.boolean, "is-elc")

                                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.assigning_peer_ldp_ident = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                            self.assigning_peer_ldp_ident.parent = self
                                            self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                            self._children_yang_names.add("assigning-peer-ldp-ident")
                                            self._segment_path = lambda: "remote-binding"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, ['is_elc', 'is_stale', 'remote_label'], name, value)


                                        class AssigningPeerLdpIdent(Entity):
                                            """
                                            Assigning peer
                                            
                                            .. attribute:: label_space_id
                                            
                                            	Label space identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ldp_id
                                            
                                            	LDP identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: lsr_id
                                            
                                            	LSR identifier
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                                self.yang_name = "assigning-peer-ldp-ident"
                                                self.yang_parent_name = "remote-binding"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                self._segment_path = lambda: "assigning-peer-ldp-ident"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf, ['id', 'name'], name, value)


                            class BindingsAdvertiseSpec(Entity):
                                """
                                Advertisement Spec (ACL) for LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: advt_acl
                                
                                	Advertisement ACLs
                                	**type**\: list of    :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                                
                                .. attribute:: allocation_acl
                                
                                	Local label Allocation filter
                                	**type**\:   :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                    self.yang_name = "bindings-advertise-spec"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"allocation-acl" : ("allocation_acl", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)}
                                    self._child_list_classes = {"advt-acl" : ("advt_acl", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl)}

                                    self.allocation_acl = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                    self.allocation_acl.parent = self
                                    self._children_name_map["allocation_acl"] = "allocation-acl"
                                    self._children_yang_names.add("allocation-acl")

                                    self.advt_acl = YList(self)
                                    self._segment_path = lambda: "bindings-advertise-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                                class AdvtAcl(Entity):
                                    """
                                    Advertisement ACLs
                                    
                                    .. attribute:: peer_acl
                                    
                                    	Peer ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                        self.yang_name = "advt-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.peer_acl = YLeaf(YType.str, "peer-acl")

                                        self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                        self._segment_path = lambda: "advt-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, ['peer_acl', 'prefix_acl'], name, value)


                                class AllocationAcl(Entity):
                                    """
                                    Local label Allocation filter
                                    
                                    .. attribute:: has_acl
                                    
                                    	Has ACL filter?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_host_route_only
                                    
                                    	Host\-routes only?
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                        self.yang_name = "allocation-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.has_acl = YLeaf(YType.boolean, "has-acl")

                                        self.is_host_route_only = YLeaf(YType.boolean, "is-host-route-only")

                                        self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                        self._segment_path = lambda: "allocation-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, ['has_acl', 'is_host_route_only', 'prefix_acl'], name, value)


                            class BindingsSummary(Entity):
                                """
                                Counters for the LDP Label Infomation Base
                                (LIB)
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf>`
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary, self).__init__()

                                    self.yang_name = "bindings-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf)}
                                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf)}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                    self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.address_family = YLeaf(YType.enumeration, "address-family")

                                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                        self._segment_path = lambda: "bind-af"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf, ['id', 'name'], name, value)


                            class BindingsSummaryAll(Entity):
                                """
                                Aggregate VRF counters for the LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf>`
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll, self).__init__()

                                    self.yang_name = "bindings-summary-all"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf)}
                                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf)}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                    self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary-all"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary-all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.address_family = YLeaf(YType.enumeration, "address-family")

                                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                        self._segment_path = lambda: "bind-af"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary-all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


                            class Discovery(Entity):
                                """
                                The LDP Discovery
                                
                                .. attribute:: brief
                                
                                	Brief information on LDP discovery
                                	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief>`
                                
                                .. attribute:: link_hellos
                                
                                	The LDP Discovery link
                                	**type**\:   :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos>`
                                
                                .. attribute:: stats
                                
                                	The LDP Discovery Statistics
                                	**type**\:   :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats>`
                                
                                .. attribute:: summary
                                
                                	Summarized information on LDP discovery
                                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary>`
                                
                                .. attribute:: targeted_hellos
                                
                                	The LDP Discovery Targeted
                                	**type**\:   :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery, self).__init__()

                                    self.yang_name = "discovery"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"brief" : ("brief", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief), "link-hellos" : ("link_hellos", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos), "stats" : ("stats", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats), "summary" : ("summary", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary), "targeted-hellos" : ("targeted_hellos", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos)}
                                    self._child_list_classes = {}

                                    self.brief = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief()
                                    self.brief.parent = self
                                    self._children_name_map["brief"] = "brief"
                                    self._children_yang_names.add("brief")

                                    self.link_hellos = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos()
                                    self.link_hellos.parent = self
                                    self._children_name_map["link_hellos"] = "link-hellos"
                                    self._children_yang_names.add("link-hellos")

                                    self.stats = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats()
                                    self.stats.parent = self
                                    self._children_name_map["stats"] = "stats"
                                    self._children_yang_names.add("stats")

                                    self.summary = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary()
                                    self.summary.parent = self
                                    self._children_name_map["summary"] = "summary"
                                    self._children_yang_names.add("summary")

                                    self.targeted_hellos = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos()
                                    self.targeted_hellos.parent = self
                                    self._children_name_map["targeted_hellos"] = "targeted-hellos"
                                    self._children_yang_names.add("targeted-hellos")
                                    self._segment_path = lambda: "discovery"


                                class Brief(Entity):
                                    """
                                    Brief information on LDP discovery
                                    
                                    .. attribute:: link_hello_briefs
                                    
                                    	The LDP Discovery link brief information
                                    	**type**\:   :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                    
                                    .. attribute:: targeted_hello_briefs
                                    
                                    	The LDP Discovery Targeted brief information
                                    	**type**\:   :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief, self).__init__()

                                        self.yang_name = "brief"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-briefs" : ("link_hello_briefs", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs), "targeted-hello-briefs" : ("targeted_hello_briefs", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs)}
                                        self._child_list_classes = {}

                                        self.link_hello_briefs = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                        self.link_hello_briefs.parent = self
                                        self._children_name_map["link_hello_briefs"] = "link-hello-briefs"
                                        self._children_yang_names.add("link-hello-briefs")

                                        self.targeted_hello_briefs = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                        self.targeted_hello_briefs.parent = self
                                        self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                        self._children_yang_names.add("targeted-hello-briefs")
                                        self._segment_path = lambda: "brief"


                                    class LinkHelloBriefs(Entity):
                                        """
                                        The LDP Discovery link brief information
                                        
                                        .. attribute:: link_hello_brief
                                        
                                        	Brief information on LDP link discovery
                                        	**type**\: list of    :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                            self.yang_name = "link-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"link-hello-brief" : ("link_hello_brief", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief)}

                                            self.link_hello_brief = YList(self)
                                            self._segment_path = lambda: "link-hello-briefs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                        class LinkHelloBrief(Entity):
                                            """
                                            Brief information on LDP link discovery
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	The Interface Name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: address_family
                                            
                                            	Discovery Brief Address Family
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: address_family_set
                                            
                                            	Discovery Brief Address Family Set
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: interface_name_xr
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                                self.yang_name = "link-hello-brief"
                                                self.yang_parent_name = "link-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)}
                                                self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation)}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                                self.address_family_set = YLeaf(YType.enumeration, "address-family-set")

                                                self.interface = YLeaf(YType.str, "interface")

                                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                                self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"
                                                self._children_yang_names.add("vrf")

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', 'address_family', 'address_family_set', 'interface', 'interface_name_xr'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                    self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                    self.session_up = YLeaf(YType.boolean, "session-up")
                                                    self._segment_path = lambda: "hello-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                            class Vrf(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.id = YLeaf(YType.uint32, "id")

                                                    self.name = YLeaf(YType.str, "name")
                                                    self._segment_path = lambda: "vrf"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, ['id', 'name'], name, value)


                                    class TargetedHelloBriefs(Entity):
                                        """
                                        The LDP Discovery Targeted brief information
                                        
                                        .. attribute:: targeted_hello_brief
                                        
                                        	Brief information on LDP targeted discovery
                                        	**type**\: list of    :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                            self.yang_name = "targeted-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"targeted-hello-brief" : ("targeted_hello_brief", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief)}

                                            self.targeted_hello_brief = YList(self)
                                            self._segment_path = lambda: "targeted-hello-briefs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                        class TargetedHelloBrief(Entity):
                                            """
                                            Brief information on LDP targeted discovery
                                            
                                            .. attribute:: address_family
                                            
                                            	Targeted Discovery Address Family
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: dhcb_target_address
                                            
                                            	DHCB target address
                                            	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: target_address
                                            
                                            	The target IP Address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                                self.yang_name = "targeted-hello-brief"
                                                self.yang_parent_name = "targeted-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"dhcb-target-address" : ("dhcb_target_address", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress), "vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)}
                                                self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation)}

                                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.target_address = YLeaf(YType.str, "target-address")

                                                self.dhcb_target_address = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                                self.dhcb_target_address.parent = self
                                                self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                                self._children_yang_names.add("dhcb-target-address")

                                                self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"
                                                self._children_yang_names.add("vrf")

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "targeted-hello-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['address_family', 'local_address', 'target_address'], name, value)


                                            class DhcbTargetAddress(Entity):
                                                """
                                                DHCB target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                    self.yang_name = "dhcb-target-address"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "dhcb-target-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                    self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                    self.session_up = YLeaf(YType.boolean, "session-up")
                                                    self._segment_path = lambda: "hello-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                            class Vrf(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.id = YLeaf(YType.uint32, "id")

                                                    self.name = YLeaf(YType.str, "name")
                                                    self._segment_path = lambda: "vrf"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, ['id', 'name'], name, value)


                                class LinkHellos(Entity):
                                    """
                                    The LDP Discovery link
                                    
                                    .. attribute:: link_hello
                                    
                                    	Information on LDP link discovery
                                    	**type**\: list of    :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                        self.yang_name = "link-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"link-hello" : ("link_hello", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello)}

                                        self.link_hello = YList(self)
                                        self._segment_path = lambda: "link-hellos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                    class LinkHello(Entity):
                                        """
                                        Information on LDP link discovery
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: discovery_link_af
                                        
                                        	LDP hello AF info
                                        	**type**\: list of    :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                            self.yang_name = "link-hello"
                                            self.yang_parent_name = "link-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)}
                                            self._child_list_classes = {"discovery-link-af" : ("discovery_link_af", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf), "hello-information" : ("hello_information", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.next_hello = YLeaf(YType.uint32, "next-hello")

                                            self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                            self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.discovery_link_af = YList(self)
                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', 'interface', 'interface_name_xr', 'next_hello', 'quick_start_disabled'], name, value)


                                        class DiscoveryLinkAf(Entity):
                                            """
                                            LDP hello AF info
                                            
                                            .. attribute:: interval
                                            
                                            	Hello interval in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_src_address
                                            
                                            	Local source address
                                            	**type**\:   :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                            
                                            .. attribute:: local_transport_address
                                            
                                            	Local transport address
                                            	**type**\:   :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                                self.yang_name = "discovery-link-af"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"local-src-address" : ("local_src_address", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress), "local-transport-address" : ("local_transport_address", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress)}
                                                self._child_list_classes = {}

                                                self.interval = YLeaf(YType.uint32, "interval")

                                                self.local_src_address = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                                self.local_src_address.parent = self
                                                self._children_name_map["local_src_address"] = "local-src-address"
                                                self._children_yang_names.add("local-src-address")

                                                self.local_transport_address = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                                self.local_transport_address.parent = self
                                                self._children_name_map["local_transport_address"] = "local-transport-address"
                                                self._children_yang_names.add("local-transport-address")
                                                self._segment_path = lambda: "discovery-link-af"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, ['interval'], name, value)


                                            class LocalSrcAddress(Entity):
                                                """
                                                Local source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                    self.yang_name = "local-src-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "local-src-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class LocalTransportAddress(Entity):
                                                """
                                                Local transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                    self.yang_name = "local-transport-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "local-transport-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: disc_expiry
                                            
                                            	Discovery expiry time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: established_age
                                            
                                            	Hello adjacency estabished age in nanosec
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: established_time
                                            
                                            	Hello adjacency estabished time in nanosec
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: is_no_route
                                            
                                            	Is route valid
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_targeted
                                            
                                            	Is session a targeted session
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_session_down_info
                                            
                                            	Last session down information
                                            	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                            
                                            .. attribute:: local_hold_time
                                            
                                            	Local hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_hold_time
                                            
                                            	Neighbor hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_src_address
                                            
                                            	Neighbor source address
                                            	**type**\:   :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                            
                                            .. attribute:: neighbor_transport_address
                                            
                                            	Neighbor transport address
                                            	**type**\:   :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                            
                                            .. attribute:: session_bringup_failure_reason
                                            
                                            	session bringup failure reason
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            .. attribute:: target
                                            
                                            	Target address
                                            	**type**\:   :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-src-address" : ("neighbor_src_address", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress), "neighbor-transport-address" : ("neighbor_transport_address", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress), "target" : ("target", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)}
                                                self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo)}

                                                self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                                self.established_age = YLeaf(YType.uint64, "established-age")

                                                self.established_time = YLeaf(YType.uint64, "established-time")

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                                self.is_targeted = YLeaf(YType.boolean, "is-targeted")

                                                self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                                self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                                self.session_up = YLeaf(YType.boolean, "session-up")

                                                self.neighbor_src_address = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                                self.neighbor_src_address.parent = self
                                                self._children_name_map["neighbor_src_address"] = "neighbor-src-address"
                                                self._children_yang_names.add("neighbor-src-address")

                                                self.neighbor_transport_address = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                                self.neighbor_transport_address.parent = self
                                                self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"
                                                self._children_yang_names.add("neighbor-transport-address")

                                                self.target = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                                self.target.parent = self
                                                self._children_name_map["target"] = "target"
                                                self._children_yang_names.add("target")

                                                self.last_session_down_info = YList(self)
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, ['disc_expiry', 'established_age', 'established_time', 'hold_time', 'is_no_route', 'is_targeted', 'local_hold_time', 'neighbor_hold_time', 'neighbor_ldp_identifier', 'session_bringup_failure_reason', 'session_up'], name, value)


                                            class LastSessionDownInfo(Entity):
                                                """
                                                Last session down information
                                                
                                                .. attribute:: last_session_down_reason
                                                
                                                	The reason of last socket failure
                                                	**type**\:  str
                                                
                                                .. attribute:: last_session_down_time
                                                
                                                	Timestamp of when the last session went down
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: last_session_up_time
                                                
                                                	The time duration the last session was up
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                    self.yang_name = "last-session-down-info"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                    self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                    self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                    self._segment_path = lambda: "last-session-down-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                                            class NeighborSrcAddress(Entity):
                                                """
                                                Neighbor source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                    self.yang_name = "neighbor-src-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "neighbor-src-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class NeighborTransportAddress(Entity):
                                                """
                                                Neighbor transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                    self.yang_name = "neighbor-transport-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "neighbor-transport-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class Target(Entity):
                                                """
                                                Target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                    self.yang_name = "target"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "target"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, ['id', 'name'], name, value)


                                class Stats(Entity):
                                    """
                                    The LDP Discovery Statistics
                                    
                                    .. attribute:: stat
                                    
                                    	Information on LDP discovery statistics
                                    	**type**\: list of    :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats, self).__init__()

                                        self.yang_name = "stats"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"stat" : ("stat", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat)}

                                        self.stat = YList(self)
                                        self._segment_path = lambda: "stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats, [], name, value)


                                    class Stat(Entity):
                                        """
                                        Information on LDP discovery statistics
                                        
                                        .. attribute:: adjacency_group_up_time
                                        
                                        	Adjacency group up time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space ID of neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR ID of neighbor
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: tcp_arb_chg_count
                                        
                                        	Count of changes in TCP arbitration
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_open_count
                                        
                                        	Count of attempted TCP opens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_role
                                        
                                        	TCP Role
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                            self.yang_name = "stat"
                                            self.yang_parent_name = "stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.adjacency_group_up_time = YLeaf(YType.uint32, "adjacency-group-up-time")

                                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                                            self.tcp_arb_chg_count = YLeaf(YType.uint32, "tcp-arb-chg-count")

                                            self.tcp_open_count = YLeaf(YType.uint32, "tcp-open-count")

                                            self.tcp_role = YLeaf(YType.uint32, "tcp-role")
                                            self._segment_path = lambda: "stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, ['adjacency_group_up_time', 'label_space_id', 'lsr_id', 'tcp_arb_chg_count', 'tcp_open_count', 'tcp_role'], name, value)


                                class Summary(Entity):
                                    """
                                    Summarized information on LDP discovery
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: num_of_active_ldp_interfaces
                                    
                                    	Number of active LDP enabled interfaces
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_addr_recv
                                    
                                    	Number of hello discoveries received with bad source address
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_hello_pdu
                                    
                                    	Number of hello discoveries received with bad hello PDU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_xport_addr
                                    
                                    	Number of hello discoveries received with bad export address
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_same_router_id
                                    
                                    	Number of hello discoveries received with the same router id as this router
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_wrong_router_id
                                    
                                    	Number of hello discoveries received with the router id that is not destined for this router
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_ldp_interfaces
                                    
                                    	Total Number of LDP configured interfaces
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_recv
                                    
                                    	Number of link hello discoveries in recv state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_xmit
                                    
                                    	Number of link hello discoveries in xmit state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_recv
                                    
                                    	Number of targeted hello discoveries in recv state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_xmit
                                    
                                    	Number of targeted hello discoveries in xmit state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary, self).__init__()

                                        self.yang_name = "summary"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf)}
                                        self._child_list_classes = {}

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                                        self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                                        self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                                        self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                                        self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                                        self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                                        self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                                        self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                                        self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                                        self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                                        self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                                        self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf, ['id', 'name'], name, value)


                                class TargetedHellos(Entity):
                                    """
                                    The LDP Discovery Targeted
                                    
                                    .. attribute:: targeted_hello
                                    
                                    	Information on LDP targeted discovery
                                    	**type**\: list of    :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                        self.yang_name = "targeted-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"targeted-hello" : ("targeted_hello", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello)}

                                        self.targeted_hello = YList(self)
                                        self._segment_path = lambda: "targeted-hellos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                    class TargetedHello(Entity):
                                        """
                                        Information on LDP targeted discovery
                                        
                                        .. attribute:: adjacency_ldp_identifier
                                        
                                        	Adjacency LDP Identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcb_local_address
                                        
                                        	DHCB local address
                                        	**type**\:   :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: hold_time
                                        
                                        	Targeted hello hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\:  str
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\:  bool
                                        
                                        .. attribute:: state
                                        
                                        	Targeted hello state
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                            self.yang_name = "targeted-hello"
                                            self.yang_parent_name = "targeted-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"dhcb-local-address" : ("dhcb_local_address", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress), "dhcb-target-address" : ("dhcb_target_address", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)}
                                            self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo)}

                                            self.adjacency_ldp_identifier = YLeaf(YType.str, "adjacency-ldp-identifier")

                                            self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                            self.established_age = YLeaf(YType.uint64, "established-age")

                                            self.established_time = YLeaf(YType.uint64, "established-time")

                                            self.hold_time = YLeaf(YType.uint32, "hold-time")

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                            self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                            self.next_hello = YLeaf(YType.uint32, "next-hello")

                                            self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                            self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                            self.session_up = YLeaf(YType.boolean, "session-up")

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.target_address = YLeaf(YType.str, "target-address")

                                            self.dhcb_local_address = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                            self.dhcb_local_address.parent = self
                                            self._children_name_map["dhcb_local_address"] = "dhcb-local-address"
                                            self._children_yang_names.add("dhcb-local-address")

                                            self.dhcb_target_address = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                            self._children_yang_names.add("dhcb-target-address")

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "targeted-hello"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['adjacency_ldp_identifier', 'disc_expiry', 'established_age', 'established_time', 'hold_time', 'interval', 'local_address', 'local_hold_time', 'neighbor_hold_time', 'next_hello', 'quick_start_disabled', 'session_bringup_failure_reason', 'session_up', 'state', 'target_address'], name, value)


                                        class DhcbLocalAddress(Entity):
                                            """
                                            DHCB local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                                self.yang_name = "dhcb-local-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\:  str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                self._segment_path = lambda: "last-session-down-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                            class ForwardingSummary(Entity):
                                """
                                Summary information regarding LDP forwarding
                                setup
                                
                                .. attribute:: fsht
                                
                                	Forwarding state hold time registered with LSD
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: intfs
                                
                                	MPLS forwarding enabled interface count
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_lsd_bound
                                
                                	LDP is connected to LSD server
                                	**type**\:  bool
                                
                                .. attribute:: lbls
                                
                                	Local label allocated count
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rws
                                
                                	Forwarding rewrites summary
                                	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary, self).__init__()

                                    self.yang_name = "forwarding-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rws" : ("rws", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws), "vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf)}
                                    self._child_list_classes = {}

                                    self.fsht = YLeaf(YType.uint16, "fsht")

                                    self.intfs = YLeaf(YType.uint16, "intfs")

                                    self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                                    self.lbls = YLeaf(YType.uint16, "lbls")

                                    self.rws = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws()
                                    self.rws.parent = self
                                    self._children_name_map["rws"] = "rws"
                                    self._children_yang_names.add("rws")

                                    self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "forwarding-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                                class Rws(Entity):
                                    """
                                    Forwarding rewrites summary
                                    
                                    .. attribute:: nhs
                                    
                                    	Forwarding rewrites nexthops (paths) summary
                                    	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                    
                                    .. attribute:: pfxs
                                    
                                    	Forwarding rewrites prefix summary
                                    	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                        self.yang_name = "rws"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs)}
                                        self._child_list_classes = {}

                                        self.nhs = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                        self.nhs.parent = self
                                        self._children_name_map["nhs"] = "nhs"
                                        self._children_yang_names.add("nhs")

                                        self.pfxs = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                        self.pfxs.parent = self
                                        self._children_name_map["pfxs"] = "pfxs"
                                        self._children_yang_names.add("pfxs")
                                        self._segment_path = lambda: "rws"


                                    class Nhs(Entity):
                                        """
                                        Forwarding rewrites nexthops (paths) summary
                                        
                                        .. attribute:: backup_paths
                                        
                                        	Count of non\-primary backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_backup_paths
                                        
                                        	Count of labeled backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_paths
                                        
                                        	Count of all labeled paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: protected_paths
                                        
                                        	Count of FRR protected paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_backup_paths
                                        
                                        	Count of non\-primary remote backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_paths
                                        
                                        	Total path count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                            self.yang_name = "nhs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                                            self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                                            self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                                            self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                                            self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                                            self.total_paths = YLeaf(YType.uint32, "total-paths")
                                            self._segment_path = lambda: "nhs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                                    class Pfxs(Entity):
                                        """
                                        Forwarding rewrites prefix summary
                                        
                                        .. attribute:: ecmp_pfxs
                                        
                                        	Count of prefixes with ECMP
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_aggr
                                        
                                        	Labeled prefix count for all paths
                                        	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                        
                                        .. attribute:: labeled_pfxs_backup
                                        
                                        	Labeled prefix count related to backup paths only
                                        	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                        
                                        .. attribute:: labeled_pfxs_primary
                                        
                                        	Labeled prefix count related to primary paths only
                                        	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                        
                                        .. attribute:: protected_pfxs
                                        
                                        	Count of FRR protected prefixes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: total_pfxs
                                        
                                        	Total Prefix count
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                            self.yang_name = "pfxs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)}
                                            self._child_list_classes = {}

                                            self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                                            self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                                            self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                                            self.labeled_pfxs_aggr = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                            self.labeled_pfxs_aggr.parent = self
                                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                                            self._children_yang_names.add("labeled-pfxs-aggr")

                                            self.labeled_pfxs_backup = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                            self.labeled_pfxs_backup.parent = self
                                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                            self._children_yang_names.add("labeled-pfxs-backup")

                                            self.labeled_pfxs_primary = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                            self.labeled_pfxs_primary.parent = self
                                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                                            self._children_yang_names.add("labeled-pfxs-primary")
                                            self._segment_path = lambda: "pfxs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                                        class LabeledPfxsAggr(Entity):
                                            """
                                            Labeled prefix count for all paths
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                                self.yang_name = "labeled-pfxs-aggr"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-aggr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsBackup(Entity):
                                            """
                                            Labeled prefix count related to backup paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                                self.yang_name = "labeled-pfxs-backup"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-backup"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsPrimary(Entity):
                                            """
                                            Labeled prefix count related to primary paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                                self.yang_name = "labeled-pfxs-primary"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-primary"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf, ['id', 'name'], name, value)


                            class Forwardings(Entity):
                                """
                                The LDP Forwarding rewrites
                                
                                .. attribute:: forwarding
                                
                                	Information on a particular LDP forwarding rewrite
                                	**type**\: list of    :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings, self).__init__()

                                    self.yang_name = "forwardings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"forwarding" : ("forwarding", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding)}

                                    self.forwarding = YList(self)
                                    self._segment_path = lambda: "forwardings"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings, [], name, value)


                                class Forwarding(Entity):
                                    """
                                    Information on a particular LDP forwarding
                                    rewrite
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	The IP Prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: paths
                                    
                                    	Paths
                                    	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                    
                                    .. attribute:: route
                                    
                                    	Route
                                    	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route>`
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID associated with IP prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                        self.yang_name = "forwarding"
                                        self.yang_parent_name = "forwardings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr), "route" : ("route", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route), "vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf)}
                                        self._child_list_classes = {"paths" : ("paths", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.table_id = YLeaf(YType.uint32, "table-id")

                                        self.prefix_xr = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"
                                        self._children_yang_names.add("prefix-xr")

                                        self.route = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route()
                                        self.route.parent = self
                                        self._children_name_map["route"] = "route"
                                        self._children_yang_names.add("route")

                                        self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.paths = YList(self)
                                        self._segment_path = lambda: "forwarding" + "[prefix='" + self.prefix.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, ['prefix', 'prefix_length', 'table_id'], name, value)


                                    class Paths(Entity):
                                        """
                                        Paths
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls), "routing" : ("routing", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)}
                                            self._child_list_classes = {}

                                            self.mpls = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._children_yang_names.add("mpls")

                                            self.routing = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"
                                            self._children_yang_names.add("routing")
                                            self._segment_path = lambda: "paths"


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	MPLS nexthop info
                                            	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo), "remote-lfa" : ("remote_lfa", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa)}
                                                self._child_list_classes = {}

                                                self.mpls_outgoing_info = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._children_yang_names.add("mpls-outgoing-info")

                                                self.remote_lfa = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")
                                                self._segment_path = lambda: "mpls"


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                MPLS nexthop info
                                                
                                                .. attribute:: is_from_graceful_restartable_neighbor
                                                
                                                	Is from a GR neighbor
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_stale
                                                
                                                	Is the entry stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_peer_ldp_ident
                                                
                                                	Nexthop LDP peer
                                                	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                                
                                                .. attribute:: out_label
                                                
                                                	Outgoing label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: out_label_owner
                                                
                                                	Outgoing label owner
                                                	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                
                                                .. attribute:: out_label_rsn
                                                
                                                	Outgoing label reason
                                                	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                
                                                .. attribute:: out_label_type
                                                
                                                	Outgoing Label Type
                                                	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent)}
                                                    self._child_list_classes = {}

                                                    self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                    self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                    self.out_label = YLeaf(YType.uint32, "out-label")

                                                    self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                    self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                    self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                    self.nexthop_peer_ldp_ident = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                    self.nexthop_peer_ldp_ident.parent = self
                                                    self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                    self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                    self._segment_path = lambda: "mpls-outgoing-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                class NexthopPeerLdpIdent(Entity):
                                                    """
                                                    Nexthop LDP peer
                                                    
                                                    .. attribute:: label_space_id
                                                    
                                                    	Label space identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ldp_id
                                                    
                                                    	LDP identifier
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: lsr_id
                                                    
                                                    	LSR identifier
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                        self.yang_name = "nexthop-peer-ldp-ident"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                        self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_outgoing_info
                                                
                                                	Remote LFA MPLS nexthop(s\_ info
                                                	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo)}
                                                    self._child_list_classes = {}

                                                    self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                    self.mpls_outgoing_info = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                    self.mpls_outgoing_info.parent = self
                                                    self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                    self._children_yang_names.add("mpls-outgoing-info")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, ['has_remote_lfa_bkup'], name, value)


                                                class MplsOutgoingInfo(Entity):
                                                    """
                                                    Remote LFA MPLS nexthop(s\_ info
                                                    
                                                    .. attribute:: stack
                                                    
                                                    	Inner label stack info
                                                    	**type**\: list of    :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                        self.yang_name = "mpls-outgoing-info"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"stack" : ("stack", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack)}

                                                        self.stack = YList(self)
                                                        self._segment_path = lambda: "mpls-outgoing-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                    class Stack(Entity):
                                                        """
                                                        Inner label stack info
                                                        
                                                        .. attribute:: is_from_graceful_restartable_neighbor
                                                        
                                                        	Is from a GR neighbor
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_stale
                                                        
                                                        	Is the entry stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: nexthop_peer_ldp_ident
                                                        
                                                        	Nexthop LDP peer
                                                        	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                        
                                                        .. attribute:: out_label
                                                        
                                                        	Outgoing label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: out_label_owner
                                                        
                                                        	Outgoing label owner
                                                        	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                        
                                                        .. attribute:: out_label_rsn
                                                        
                                                        	Outgoing label reason
                                                        	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                        
                                                        .. attribute:: out_label_type
                                                        
                                                        	Outgoing Label Type
                                                        	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                            self.yang_name = "stack"
                                                            self.yang_parent_name = "mpls-outgoing-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent)}
                                                            self._child_list_classes = {}

                                                            self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                            self.out_label = YLeaf(YType.uint32, "out-label")

                                                            self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                            self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                            self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                            self.nexthop_peer_ldp_ident = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                            self.nexthop_peer_ldp_ident.parent = self
                                                            self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                            self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                            self._segment_path = lambda: "stack"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                        class NexthopPeerLdpIdent(Entity):
                                                            """
                                                            Nexthop LDP peer
                                                            
                                                            .. attribute:: label_space_id
                                                            
                                                            	Label space identifier
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ldp_id
                                                            
                                                            	LDP identifier
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: lsr_id
                                                            
                                                            	LSR identifier
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'mpls-ldp-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                                self.yang_name = "nexthop-peer-ldp-ident"
                                                                self.yang_parent_name = "stack"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                                self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: bkup_path_id
                                            
                                            	Backup path Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface Name
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	Path's load metric for load balancing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next Hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                            
                                            .. attribute:: next_hop_table_id
                                            
                                            	Table ID for nexthop address
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_id
                                            
                                            	Nexthop Identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_is_overriden
                                            
                                            	Nexthop is overriden by LDP
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_flags
                                            
                                            	Routing path flags decoded
                                            	**type**\:   :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                            
                                            .. attribute:: path_id
                                            
                                            	path Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop" : ("next_hop", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop), "remote-lfa" : ("remote_lfa", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa)}
                                                self._child_list_classes = {}

                                                self.bkup_path_id = YLeaf(YType.uint8, "bkup-path-id")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.interface = YLeaf(YType.str, "interface")

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                                self.nh_is_overriden = YLeaf(YType.boolean, "nh-is-overriden")

                                                self.path_flags = YLeaf(YType.enumeration, "path-flags")

                                                self.path_id = YLeaf(YType.uint8, "path-id")

                                                self.next_hop = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.remote_lfa = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")
                                                self._segment_path = lambda: "routing"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, ['bkup_path_id', 'flags', 'interface', 'interface_name', 'load_metric', 'next_hop_table_id', 'nexthop_id', 'nh_is_overriden', 'path_flags', 'path_id'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next Hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: has_q_node
                                                
                                                	Whether remote LFA path has a Q node associated
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: needs_tldp
                                                
                                                	Whether TLDP is needed with remote PQ node
                                                	**type**\:  bool
                                                
                                                .. attribute:: remote_p_node_id
                                                
                                                	Remote/P node address
                                                	**type**\:   :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                                
                                                .. attribute:: remote_q_node_id
                                                
                                                	Remote/Q node address
                                                	**type**\:   :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"remote-p-node-id" : ("remote_p_node_id", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId), "remote-q-node-id" : ("remote_q_node_id", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId)}
                                                    self._child_list_classes = {}

                                                    self.has_q_node = YLeaf(YType.boolean, "has-q-node")

                                                    self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                    self.needs_tldp = YLeaf(YType.boolean, "needs-tldp")

                                                    self.remote_p_node_id = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                    self.remote_p_node_id.parent = self
                                                    self._children_name_map["remote_p_node_id"] = "remote-p-node-id"
                                                    self._children_yang_names.add("remote-p-node-id")

                                                    self.remote_q_node_id = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                    self.remote_q_node_id.parent = self
                                                    self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                    self._children_yang_names.add("remote-q-node-id")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, ['has_q_node', 'has_remote_lfa_bkup', 'needs_tldp'], name, value)


                                                class RemotePNodeId(Entity):
                                                    """
                                                    Remote/P node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                        self.yang_name = "remote-p-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                                        self._segment_path = lambda: "remote-p-node-id"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                                class RemoteQNodeId(Entity):
                                                    """
                                                    Remote/Q node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                        self.yang_name = "remote-q-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                                        self._segment_path = lambda: "remote-q-node-id"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "prefix-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class Route(Entity):
                                        """
                                        Route
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                            self.yang_name = "route"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls), "routing" : ("routing", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing)}
                                            self._child_list_classes = {}

                                            self.mpls = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._children_yang_names.add("mpls")

                                            self.routing = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"
                                            self._children_yang_names.add("routing")
                                            self._segment_path = lambda: "route"


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: forwarding_update_age
                                            
                                            	Last Forwarding update nanosec age
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: forwarding_update_count
                                            
                                            	Number of forwarding updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_timestamp
                                            
                                            	Last Forwarding update nanosec timestamp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.forwarding_update_age = YLeaf(YType.uint64, "forwarding-update-age")

                                                self.forwarding_update_count = YLeaf(YType.uint32, "forwarding-update-count")

                                                self.forwarding_update_timestamp = YLeaf(YType.uint64, "forwarding-update-timestamp")

                                                self.local_label = YLeaf(YType.uint32, "local-label")
                                                self._segment_path = lambda: "mpls"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, ['forwarding_update_age', 'forwarding_update_count', 'forwarding_update_timestamp', 'local_label'], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: flags
                                            
                                            	Route RIB flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_local_vrf_leaked
                                            
                                            	Is route leaked across local VRFs?
                                            	**type**\:  bool
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: routing_update_age
                                            
                                            	Last Routing update nanosec age
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: routing_update_count
                                            
                                            	Number of routing updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: routing_update_timestamp
                                            
                                            	Last Routing update nanosec timestamp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: source
                                            
                                            	Route source protol Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sr_local_label
                                            
                                            	SR Local\-label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: version
                                            
                                            	Route RIB ersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.is_local_vrf_leaked = YLeaf(YType.boolean, "is-local-vrf-leaked")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.routing_update_age = YLeaf(YType.uint64, "routing-update-age")

                                                self.routing_update_count = YLeaf(YType.uint32, "routing-update-count")

                                                self.routing_update_timestamp = YLeaf(YType.uint64, "routing-update-timestamp")

                                                self.source = YLeaf(YType.uint16, "source")

                                                self.sr_local_label = YLeaf(YType.uint32, "sr-local-label")

                                                self.type = YLeaf(YType.uint16, "type")

                                                self.version = YLeaf(YType.uint32, "version")
                                                self._segment_path = lambda: "routing"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, ['flags', 'is_local_vrf_leaked', 'metric', 'priority', 'routing_update_age', 'routing_update_count', 'routing_update_timestamp', 'source', 'sr_local_label', 'type', 'version'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf, ['id', 'name'], name, value)


                            class Igp(Entity):
                                """
                                LDP IGP related information
                                
                                .. attribute:: sync_delay_restart
                                
                                	LDP\-IGP Synchronization Delay related information
                                	**type**\:   :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart>`
                                
                                .. attribute:: syncs
                                
                                	LDP IGP Sync related information
                                	**type**\:   :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp, self).__init__()

                                    self.yang_name = "igp"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sync-delay-restart" : ("sync_delay_restart", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart), "syncs" : ("syncs", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs)}
                                    self._child_list_classes = {}

                                    self.sync_delay_restart = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart()
                                    self.sync_delay_restart.parent = self
                                    self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                    self._children_yang_names.add("sync-delay-restart")

                                    self.syncs = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs()
                                    self.syncs.parent = self
                                    self._children_name_map["syncs"] = "syncs"
                                    self._children_yang_names.add("syncs")
                                    self._segment_path = lambda: "igp"


                                class SyncDelayRestart(Entity):
                                    """
                                    LDP\-IGP Synchronization Delay related
                                    information
                                    
                                    .. attribute:: configured
                                    
                                    	Is restart delay configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: delay_secs
                                    
                                    	Delay time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remaining_secs
                                    
                                    	Delay timer remaining time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timer_running
                                    
                                    	Is restart delay timer running
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                        self.yang_name = "sync-delay-restart"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.configured = YLeaf(YType.boolean, "configured")

                                        self.delay_secs = YLeaf(YType.uint32, "delay-secs")

                                        self.remaining_secs = YLeaf(YType.uint32, "remaining-secs")

                                        self.timer_running = YLeaf(YType.boolean, "timer-running")
                                        self._segment_path = lambda: "sync-delay-restart"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, ['configured', 'delay_secs', 'remaining_secs', 'timer_running'], name, value)


                                class Syncs(Entity):
                                    """
                                    LDP IGP Sync related information
                                    
                                    .. attribute:: sync
                                    
                                    	LDP\-IGP Synchronization related information for an interface
                                    	**type**\: list of    :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs, self).__init__()

                                        self.yang_name = "syncs"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"sync" : ("sync", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync)}

                                        self.sync = YList(self)
                                        self._segment_path = lambda: "syncs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs, [], name, value)


                                    class Sync(Entity):
                                        """
                                        LDP\-IGP Synchronization related information
                                        for an interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: delay_timer_remaining
                                        
                                        	Remaining timer (seconds) till expiry of sync delay timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_only_peer
                                        
                                        	Interface GR\-only reachable peers
                                        	**type**\: list of    :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                        
                                        .. attribute:: igp_sync_delay
                                        
                                        	IGP sync delay in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: igp_sync_down_reason
                                        
                                        	Reason IGP Sync Not Achieved
                                        	**type**\:   :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                        
                                        .. attribute:: igp_sync_state
                                        
                                        	IGP Sync state
                                        	**type**\:   :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_delay_timer_running
                                        
                                        	Is sync delay timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: peers
                                        
                                        	Interface Peers
                                        	**type**\: list of    :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                            self.yang_name = "sync"
                                            self.yang_parent_name = "syncs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf)}
                                            self._child_list_classes = {"gr-only-peer" : ("gr_only_peer", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer), "peers" : ("peers", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.delay_timer_remaining = YLeaf(YType.uint32, "delay-timer-remaining")

                                            self.igp_sync_delay = YLeaf(YType.uint32, "igp-sync-delay")

                                            self.igp_sync_down_reason = YLeaf(YType.enumeration, "igp-sync-down-reason")

                                            self.igp_sync_state = YLeaf(YType.enumeration, "igp-sync-state")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.is_delay_timer_running = YLeaf(YType.boolean, "is-delay-timer-running")

                                            self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.gr_only_peer = YList(self)
                                            self.peers = YList(self)
                                            self._segment_path = lambda: "sync" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', 'delay_timer_remaining', 'igp_sync_delay', 'igp_sync_down_reason', 'igp_sync_state', 'interface_name_xr', 'is_delay_timer_running'], name, value)


                                        class GrOnlyPeer(Entity):
                                            """
                                            Interface GR\-only reachable peers
                                            
                                            .. attribute:: is_chkpt_created
                                            
                                            	Is created due to checkpointing
                                            	**type**\:  bool
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                                self.yang_name = "gr-only-peer"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.is_chkpt_created = YLeaf(YType.boolean, "is-chkpt-created")

                                                self.peer_id = YLeaf(YType.str, "peer-id")
                                                self._segment_path = lambda: "gr-only-peer"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, ['is_chkpt_created', 'peer_id'], name, value)


                                        class Peers(Entity):
                                            """
                                            Interface Peers
                                            
                                            .. attribute:: is_gr_enabled
                                            
                                            	Is GR enabled session
                                            	**type**\:  bool
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                                self.yang_name = "peers"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                                                self.peer_id = YLeaf(YType.str, "peer-id")
                                                self._segment_path = lambda: "peers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, ['is_gr_enabled', 'peer_id'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf, ['id', 'name'], name, value)


                            class InterfaceSummary(Entity):
                                """
                                IPv4 interface summary information
                                
                                .. attribute:: auto_config
                                
                                	Auto\-configured interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_disabled
                                
                                	Autoconfigure disabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_forward_reference_interfaces
                                
                                	Auto\-configured forward references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_references
                                
                                	Number of forward referenced interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_count
                                
                                	Number of known IP Interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_ldp_enabled
                                
                                	Number of known IP Interfaces with LDP Enabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_attached_interface
                                
                                	Number of attached interfaces configured in LDP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_te_interface
                                
                                	Number of TE tunnel interfaces configured in LDP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary, self).__init__()

                                    self.yang_name = "interface-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.auto_config = YLeaf(YType.uint32, "auto-config")

                                    self.auto_config_disabled = YLeaf(YType.uint32, "auto-config-disabled")

                                    self.auto_config_forward_reference_interfaces = YLeaf(YType.uint32, "auto-config-forward-reference-interfaces")

                                    self.forward_references = YLeaf(YType.uint32, "forward-references")

                                    self.known_ip_interface_count = YLeaf(YType.uint32, "known-ip-interface-count")

                                    self.known_ip_interface_ldp_enabled = YLeaf(YType.uint32, "known-ip-interface-ldp-enabled")

                                    self.ldp_configured_attached_interface = YLeaf(YType.uint32, "ldp-configured-attached-interface")

                                    self.ldp_configured_te_interface = YLeaf(YType.uint32, "ldp-configured-te-interface")
                                    self._segment_path = lambda: "interface-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.InterfaceSummary, ['auto_config', 'auto_config_disabled', 'auto_config_forward_reference_interfaces', 'forward_references', 'known_ip_interface_count', 'known_ip_interface_ldp_enabled', 'ldp_configured_attached_interface', 'ldp_configured_te_interface'], name, value)


                            class Interfaces(Entity):
                                """
                                LDP Interface related information
                                
                                .. attribute:: interface
                                
                                	IPv4 interface information
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces, self).__init__()

                                    self.yang_name = "interfaces"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface" : ("interface", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface)}

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces, [], name, value)


                                class Interface(Entity):
                                    """
                                    IPv4 interface information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: auto_config
                                    
                                    	Auto config
                                    	**type**\: list of    :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_im_stale
                                    
                                    	Is IM information stale
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_autoconfig_disable
                                    
                                    	LDP autoconfig disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_config_mode
                                    
                                    	LDP config mode
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_enabled
                                    
                                    	LDP enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_mesh_grp
                                    
                                    	TE tunnel mesh\-group
                                    	**type**\: list of    :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf)}
                                        self._child_list_classes = {"auto-config" : ("auto_config", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig), "te-mesh-grp" : ("te_mesh_grp", MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.is_im_stale = YLeaf(YType.boolean, "is-im-stale")

                                        self.ldp_autoconfig_disable = YLeaf(YType.boolean, "ldp-autoconfig-disable")

                                        self.ldp_config_mode = YLeaf(YType.boolean, "ldp-config-mode")

                                        self.ldp_enabled = YLeaf(YType.boolean, "ldp-enabled")

                                        self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.auto_config = YList(self)
                                        self.te_mesh_grp = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface, ['interface_name', 'interface', 'interface_name_xr', 'is_im_stale', 'ldp_autoconfig_disable', 'ldp_config_mode', 'ldp_enabled'], name, value)


                                    class AutoConfig(Entity):
                                        """
                                        Auto config
                                        
                                        .. attribute:: tuple
                                        
                                        	Tuple
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                            self.yang_name = "auto-config"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.tuple = YLeaf(YType.str, "tuple")
                                            self._segment_path = lambda: "auto-config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, ['tuple'], name, value)


                                    class TeMeshGrp(Entity):
                                        """
                                        TE tunnel mesh\-group
                                        
                                        .. attribute:: ldp_mesh_group_enabled
                                        
                                        	LDP has enabled this TE mesh\-group
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_te_mesh_group_all_cfgd
                                        
                                        	LDP has enabled all TE mesh\-groups
                                        	**type**\:  bool
                                        
                                        .. attribute:: te_mesh_group_id
                                        
                                        	TE tunnel Mesh Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                            self.yang_name = "te-mesh-grp"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ldp_mesh_group_enabled = YLeaf(YType.boolean, "ldp-mesh-group-enabled")

                                            self.ldp_te_mesh_group_all_cfgd = YLeaf(YType.boolean, "ldp-te-mesh-group-all-cfgd")

                                            self.te_mesh_group_id = YLeaf(YType.uint32, "te-mesh-group-id")
                                            self._segment_path = lambda: "te-mesh-grp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, ['ldp_mesh_group_enabled', 'ldp_te_mesh_group_all_cfgd', 'te_mesh_group_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf, ['id', 'name'], name, value)


                    class BackoffParameters(Entity):
                        """
                        The LDP Backoff Parameters
                        
                        .. attribute:: initial_seconds
                        
                        	Initial backoff value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: maximum_seconds
                        
                        	Maximum backoff value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.BackoffParameters, self).__init__()

                            self.yang_name = "backoff-parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.initial_seconds = YLeaf(YType.uint32, "initial-seconds")

                            self.maximum_seconds = YLeaf(YType.uint32, "maximum-seconds")
                            self._segment_path = lambda: "backoff-parameters"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.BackoffParameters, ['initial_seconds', 'maximum_seconds'], name, value)


                    class Backoffs(Entity):
                        """
                        The LDP backoff
                        
                        .. attribute:: backoff
                        
                        	LDP Backoff Information
                        	**type**\: list of    :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs.Backoff>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs, self).__init__()

                            self.yang_name = "backoffs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"backoff" : ("backoff", MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs.Backoff)}

                            self.backoff = YList(self)
                            self._segment_path = lambda: "backoffs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs, [], name, value)


                        class Backoff(Entity):
                            """
                            LDP Backoff Information
                            
                            .. attribute:: backoff_seconds
                            
                            	Backoff seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: waiting_seconds
                            
                            	Backoff waiting seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs.Backoff, self).__init__()

                                self.yang_name = "backoff"
                                self.yang_parent_name = "backoffs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.backoff_seconds = YLeaf(YType.uint32, "backoff-seconds")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.waiting_seconds = YLeaf(YType.uint32, "waiting-seconds")
                                self._segment_path = lambda: "backoff"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Backoffs.Backoff, ['backoff_seconds', 'label_space_id', 'lsr_id', 'waiting_seconds'], name, value)


                    class Capabilities(Entity):
                        """
                        LDP capability database information
                        
                        .. attribute:: capability
                        
                        	Information on LDP capability
                        	**type**\: list of    :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities, self).__init__()

                            self.yang_name = "capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"capability" : ("capability", MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability)}

                            self.capability = YList(self)
                            self._segment_path = lambda: "capabilities"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities, [], name, value)


                        class Capability(Entity):
                            """
                            Information on LDP capability
                            
                            .. attribute:: capability_type  <key>
                            
                            	The capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: capability
                            
                            	Capability information
                            	**type**\:   :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability.Capability>`
                            
                            .. attribute:: capability_owner
                            
                            	Capability owner
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"capability" : ("capability", MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability.Capability)}
                                self._child_list_classes = {}

                                self.capability_type = YLeaf(YType.int32, "capability-type")

                                self.capability_owner = YLeaf(YType.str, "capability-owner")

                                self.capability = MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability.Capability()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"
                                self._children_yang_names.add("capability")
                                self._segment_path = lambda: "capability" + "[capability-type='" + self.capability_type.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability, ['capability_type', 'capability_owner'], name, value)


                            class Capability(Entity):
                                """
                                Capability information
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability.Capability, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "capability"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Capabilities.Capability.Capability, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                    class GracefulRestart(Entity):
                        """
                        LDP Graceful Restart info
                        
                        .. attribute:: forwarding_state_hold_timer_remaining_seconds
                        
                        	Forwarding state hold timer remaining time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: graceful_restartable_neighbor
                        
                        	Vector of graceful restart neighbor information
                        	**type**\: list of    :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor>`
                        
                        .. attribute:: is_forwarding_state_hold_timer_running
                        
                        	Is graceful restart forwarding state hold timer running
                        	**type**\:  bool
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart, self).__init__()

                            self.yang_name = "graceful-restart"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.Vrf)}
                            self._child_list_classes = {"graceful-restartable-neighbor" : ("graceful_restartable_neighbor", MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor)}

                            self.forwarding_state_hold_timer_remaining_seconds = YLeaf(YType.uint32, "forwarding-state-hold-timer-remaining-seconds")

                            self.is_forwarding_state_hold_timer_running = YLeaf(YType.boolean, "is-forwarding-state-hold-timer-running")

                            self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")

                            self.graceful_restartable_neighbor = YList(self)
                            self._segment_path = lambda: "graceful-restart"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart, ['forwarding_state_hold_timer_remaining_seconds', 'is_forwarding_state_hold_timer_running'], name, value)


                        class GracefulRestartableNeighbor(Entity):
                            """
                            Vector of graceful restart neighbor information
                            
                            .. attribute:: connect_count
                            
                            	ConnectCount
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_address
                            
                            	Addresses bound to GR down Nbr
                            	**type**\: list of    :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                            
                            .. attribute:: down_nbr_down_reason
                            
                            	Session down reason code
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flags
                            
                            	Flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flap_count
                            
                            	Count of back2back flaps
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: down_nbr_interface
                            
                            	Interfaces bound to GR down Nbr
                            	**type**\: list of    :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                            
                            .. attribute:: gr_peer
                            
                            	GR peer LDP Id
                            	**type**\:   :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                            
                            .. attribute:: is_liveness_timer_running
                            
                            	Is liveness timer running
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_up
                            
                            	Is neighbor up
                            	**type**\:  bool
                            
                            .. attribute:: is_recovery_timer_running
                            
                            	Is recovery timer running
                            	**type**\:  bool
                            
                            .. attribute:: liveness_timer_remaining_seconds
                            
                            	Remaining time from liveness timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: recovery_timer_remaining_seconds
                            
                            	Recovery timer remining time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                                self.yang_name = "graceful-restartable-neighbor"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"gr-peer" : ("gr_peer", MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)}
                                self._child_list_classes = {"down-nbr-address" : ("down_nbr_address", MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress), "down-nbr-interface" : ("down_nbr_interface", MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)}

                                self.connect_count = YLeaf(YType.uint32, "connect-count")

                                self.down_nbr_down_reason = YLeaf(YType.uint32, "down-nbr-down-reason")

                                self.down_nbr_flags = YLeaf(YType.uint32, "down-nbr-flags")

                                self.down_nbr_flap_count = YLeaf(YType.uint8, "down-nbr-flap-count")

                                self.is_liveness_timer_running = YLeaf(YType.boolean, "is-liveness-timer-running")

                                self.is_neighbor_up = YLeaf(YType.boolean, "is-neighbor-up")

                                self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

                                self.liveness_timer_remaining_seconds = YLeaf(YType.uint32, "liveness-timer-remaining-seconds")

                                self.recovery_timer_remaining_seconds = YLeaf(YType.uint32, "recovery-timer-remaining-seconds")

                                self.gr_peer = MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                                self.gr_peer.parent = self
                                self._children_name_map["gr_peer"] = "gr-peer"
                                self._children_yang_names.add("gr-peer")

                                self.down_nbr_address = YList(self)
                                self.down_nbr_interface = YList(self)
                                self._segment_path = lambda: "graceful-restartable-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, ['connect_count', 'down_nbr_down_reason', 'down_nbr_flags', 'down_nbr_flap_count', 'is_liveness_timer_running', 'is_neighbor_up', 'is_recovery_timer_running', 'liveness_timer_remaining_seconds', 'recovery_timer_remaining_seconds'], name, value)


                            class DownNbrAddress(Entity):
                                """
                                Addresses bound to GR down Nbr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                    self.yang_name = "down-nbr-address"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "down-nbr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class DownNbrInterface(Entity):
                                """
                                Interfaces bound to GR down Nbr
                                
                                .. attribute:: address_family
                                
                                	Interface adj Address Family
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: interface_handle
                                
                                	Interfaces handle
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                    self.yang_name = "down-nbr-interface"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")
                                    self._segment_path = lambda: "down-nbr-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, ['address_family', 'interface_handle'], name, value)


                            class GrPeer(Entity):
                                """
                                GR peer LDP Id
                                
                                .. attribute:: label_space_id
                                
                                	Label space identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ldp_id
                                
                                	LDP identifier
                                	**type**\:  str
                                
                                .. attribute:: lsr_id
                                
                                	LSR identifier
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                    self.yang_name = "gr-peer"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                    self.ldp_id = YLeaf(YType.str, "ldp-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")
                                    self._segment_path = lambda: "gr-peer"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.GracefulRestart.Vrf, ['id', 'name'], name, value)


                    class Issu(Entity):
                        """
                        LDP ISSU related information
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu, self).__init__()

                            self.yang_name = "issu"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary)}
                            self._child_list_classes = {}

                            self.ha_statistics = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._children_yang_names.add("ha-statistics")

                            self.ha_summary = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"
                            self._children_yang_names.add("ha-summary")
                            self._segment_path = lambda: "issu"


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_global = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"
                                self._children_yang_names.add("ha-global")

                                self.ha_neighbors = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "ha-statistics"


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync)}
                                    self._child_list_classes = {}

                                    self.init_sync = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._children_yang_names.add("init-sync")
                                    self._segment_path = lambda: "ha-global"


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                        self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                        self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                        self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                        self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                        self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                        self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                        self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                        self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                        self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                        self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                        self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                        self.num_peers = YLeaf(YType.uint32, "num-peers")

                                        self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                        self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                        self._segment_path = lambda: "init-sync"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Sessions>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Vrf)}
                                self._child_list_classes = {}

                                self.sessions = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._children_yang_names.add("sessions")

                                self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "ha-summary"


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                    self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                    self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                    self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                    self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                    self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                    self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                    self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                    self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                    self.total = YLeaf(YType.uint32, "total")
                                    self._segment_path = lambda: "sessions"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Issu.HaSummary.Vrf, ['id', 'name'], name, value)


                    class LdpId(Entity):
                        """
                        Local LDP Id
                        
                        .. attribute:: label_space_id
                        
                        	Label space identifier
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_id
                        
                        	LDP identifier
                        	**type**\:  str
                        
                        .. attribute:: lsr_id
                        
                        	LSR identifier
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.LdpId, self).__init__()

                            self.yang_name = "ldp-id"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                            self._segment_path = lambda: "ldp-id"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.LdpId, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                    class NeighborBriefs(Entity):
                        """
                        The LDP Neighbors (brief)
                        
                        .. attribute:: neighbor_brief
                        
                        	Brief information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs, self).__init__()

                            self.yang_name = "neighbor-briefs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-brief" : ("neighbor_brief", MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief)}

                            self.neighbor_brief = YList(self)
                            self._segment_path = lambda: "neighbor-briefs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs, [], name, value)


                        class NeighborBrief(Entity):
                            """
                            Brief information on a particular LDP neighbor
                            
                            .. attribute:: is_graceful_restartable
                            
                            	Is graceful restartable
                            	**type**\:  bool
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nbr_br_af_info
                            
                            	Neighbor Brief AF Info
                            	**type**\: list of    :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                            
                            .. attribute:: nsr_state
                            
                            	NSR readiness state
                            	**type**\:   :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                            
                            .. attribute:: up_time_seconds
                            
                            	Up time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief, self).__init__()

                                self.yang_name = "neighbor-brief"
                                self.yang_parent_name = "neighbor-briefs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf)}
                                self._child_list_classes = {"nbr-br-af-info" : ("nbr_br_af_info", MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo)}

                                self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.up_time_seconds = YLeaf(YType.uint32, "up-time-seconds")

                                self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.nbr_br_af_info = YList(self)
                                self._segment_path = lambda: "neighbor-brief"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief, ['is_graceful_restartable', 'label_space_id', 'lsr_id', 'nsr_state', 'up_time_seconds'], name, value)


                            class NbrBrAfInfo(Entity):
                                """
                                Neighbor Brief AF Info
                                
                                .. attribute:: address_family
                                
                                	Neighbor Brief Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: num_of_nbr_addresses
                                
                                	Number of neighbor addresses
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_discovery
                                
                                	Number of neighbor discovery sources
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_lbl
                                
                                	Number of neighbor labels
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                    self.yang_name = "nbr-br-af-info"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.num_of_nbr_addresses = YLeaf(YType.uint32, "num-of-nbr-addresses")

                                    self.num_of_nbr_discovery = YLeaf(YType.uint32, "num-of-nbr-discovery")

                                    self.num_of_nbr_lbl = YLeaf(YType.uint32, "num-of-nbr-lbl")
                                    self._segment_path = lambda: "nbr-br-af-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, ['address_family', 'num_of_nbr_addresses', 'num_of_nbr_discovery', 'num_of_nbr_lbl'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf, ['id', 'name'], name, value)


                    class NeighborCapabilities(Entity):
                        """
                        LDP Neighbors Capabilities
                        
                        .. attribute:: neighbor_capability
                        
                        	Information on capabilities of a particular LDP neighbor
                        	**type**\: list of    :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities, self).__init__()

                            self.yang_name = "neighbor-capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-capability" : ("neighbor_capability", MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability)}

                            self.neighbor_capability = YList(self)
                            self._segment_path = lambda: "neighbor-capabilities"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities, [], name, value)


                        class NeighborCapability(Entity):
                            """
                            Information on capabilities of a particular LDP
                            neighbor
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: received
                            
                            	List of received capabilities
                            	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received>`
                            
                            .. attribute:: sent
                            
                            	List of sent capabilities
                            	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, self).__init__()

                                self.yang_name = "neighbor-capability"
                                self.yang_parent_name = "neighbor-capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"received" : ("received", MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received), "sent" : ("sent", MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent)}

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.received = YList(self)
                                self.sent = YList(self)
                                self._segment_path = lambda: "neighbor-capability"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, ['label_space_id', 'lsr_id'], name, value)


                            class Received(Entity):
                                """
                                List of received capabilities
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                    self.yang_name = "received"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "received"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                            class Sent(Entity):
                                """
                                List of sent capabilities
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                    self.yang_name = "sent"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "sent"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                    class Neighbors(Entity):
                        """
                        The LDP Neighbors
                        
                        .. attribute:: neighbor
                        
                        	Information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor" : ("neighbor", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor)}

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            Information on a particular LDP neighbor
                            
                            .. attribute:: detailed_information
                            
                            	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                            	**type**\:   :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation>`
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_nbr_bound_ipv4_address_info
                            
                            	Neighbor IPv4 Address Info
                            	**type**\: list of    :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                            
                            .. attribute:: ldp_nbr_bound_ipv6_address_info
                            
                            	Neighbor IPv6 Address Info
                            	**type**\: list of    :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                            
                            .. attribute:: ldp_nbr_ipv4_adj_info
                            
                            	Neighbor's IPv4 Adjacency Information
                            	**type**\: list of    :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                            
                            .. attribute:: ldp_nbr_ipv6_adj_info
                            
                            	Neighbor's IPv6 Adjacency Information
                            	**type**\: list of    :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: protocol_information
                            
                            	Protocol Information
                            	**type**\:   :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation>`
                            
                            .. attribute:: tcp_information
                            
                            	TCP Information
                            	**type**\:   :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"detailed-information" : ("detailed_information", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation), "protocol-information" : ("protocol_information", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation), "tcp-information" : ("tcp_information", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation)}
                                self._child_list_classes = {"ldp-nbr-bound-ipv4-address-info" : ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo), "ldp-nbr-bound-ipv6-address-info" : ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo), "ldp-nbr-ipv4-adj-info" : ("ldp_nbr_ipv4_adj_info", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo), "ldp-nbr-ipv6-adj-info" : ("ldp_nbr_ipv6_adj_info", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo)}

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.detailed_information = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation()
                                self.detailed_information.parent = self
                                self._children_name_map["detailed_information"] = "detailed-information"
                                self._children_yang_names.add("detailed-information")

                                self.protocol_information = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation()
                                self.protocol_information.parent = self
                                self._children_name_map["protocol_information"] = "protocol-information"
                                self._children_yang_names.add("protocol-information")

                                self.tcp_information = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation()
                                self.tcp_information.parent = self
                                self._children_name_map["tcp_information"] = "tcp-information"
                                self._children_yang_names.add("tcp-information")

                                self.ldp_nbr_bound_ipv4_address_info = YList(self)
                                self.ldp_nbr_bound_ipv6_address_info = YList(self)
                                self.ldp_nbr_ipv4_adj_info = YList(self)
                                self.ldp_nbr_ipv6_adj_info = YList(self)
                                self._segment_path = lambda: "neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor, ['label_space_id', 'lsr_id'], name, value)


                            class DetailedInformation(Entity):
                                """
                                Detailed information with regards to holdtime,
                                KA, inbound filtering, and Session protection
                                
                                .. attribute:: advertise_bgp_prefixes
                                
                                	Is BGP labelled prefixes advertised to the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: bgp_advertisement_state
                                
                                	BGP labelled prefixes advertisement state
                                	**type**\:   :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                                
                                .. attribute:: capabilities
                                
                                	Capabilities sent to and received from neighbor
                                	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                                
                                .. attribute:: client
                                
                                	Targeted Session clients
                                	**type**\: list of    :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client>`
                                
                                .. attribute:: has_ipv4_inbound
                                
                                	IPv4 Inbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv4_outbound
                                
                                	IPv4 Outbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv6_inbound
                                
                                	IPv6 Inbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv6_outbound
                                
                                	IPv6 Outbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_sp
                                
                                	Session Protection enabled
                                	**type**\:  bool
                                
                                .. attribute:: inbound_ipv4acl
                                
                                	IPv4 Inbound accept ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: inbound_ipv6acl
                                
                                	IPv6 Inbound accept ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: ipv4_duplicate_address
                                
                                	Duplicate IPv4 address bound to this peer
                                	**type**\: list of    :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                                
                                .. attribute:: ipv6_duplicate_address
                                
                                	Duplicate IPv6 address bound to this peer
                                	**type**\: list of    :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                                
                                .. attribute:: keep_alive_interval
                                
                                	Session keepalive interval in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsr_last_sync_error
                                
                                	Last NSR sync error
                                	**type**\:   :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                                
                                .. attribute:: nsr_last_sync_nack_reason
                                
                                	Last NSR sync NACK reaston
                                	**type**\:   :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                                
                                .. attribute:: nsr_sync_state
                                
                                	NSR Sync State
                                	**type**\:   :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                                
                                .. attribute:: outbound_ipv4acl
                                
                                	IPv4 Outbound advertise ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: outbound_ipv6acl
                                
                                	IPv6 Outbound advertise ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: peer_holdtime
                                
                                	Session holdtime value in seconds from the peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: peer_state
                                
                                	Peer state
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_duration
                                
                                	Session protection holdup time duration in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: sp_has_acl
                                
                                	Session protection ACL is present
                                	**type**\:  bool
                                
                                .. attribute:: sp_has_duration
                                
                                	Session Protection has non\-default duration
                                	**type**\:  bool
                                
                                .. attribute:: sp_state
                                
                                	Session Protection state
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: spacl
                                
                                	Session Protection ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: spht_remaining
                                
                                	Session Protection holdup time remaining value in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: spht_running
                                
                                	Session Protection holdup timer is running
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                    self.yang_name = "detailed-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"capabilities" : ("capabilities", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities)}
                                    self._child_list_classes = {"client" : ("client", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client), "ipv4-duplicate-address" : ("ipv4_duplicate_address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress), "ipv6-duplicate-address" : ("ipv6_duplicate_address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress)}

                                    self.advertise_bgp_prefixes = YLeaf(YType.boolean, "advertise-bgp-prefixes")

                                    self.bgp_advertisement_state = YLeaf(YType.enumeration, "bgp-advertisement-state")

                                    self.has_ipv4_inbound = YLeaf(YType.boolean, "has-ipv4-inbound")

                                    self.has_ipv4_outbound = YLeaf(YType.boolean, "has-ipv4-outbound")

                                    self.has_ipv6_inbound = YLeaf(YType.boolean, "has-ipv6-inbound")

                                    self.has_ipv6_outbound = YLeaf(YType.boolean, "has-ipv6-outbound")

                                    self.has_sp = YLeaf(YType.boolean, "has-sp")

                                    self.inbound_ipv4acl = YLeaf(YType.str, "inbound-ipv4acl")

                                    self.inbound_ipv6acl = YLeaf(YType.str, "inbound-ipv6acl")

                                    self.keep_alive_interval = YLeaf(YType.uint32, "keep-alive-interval")

                                    self.nsr_last_sync_error = YLeaf(YType.enumeration, "nsr-last-sync-error")

                                    self.nsr_last_sync_nack_reason = YLeaf(YType.enumeration, "nsr-last-sync-nack-reason")

                                    self.nsr_sync_state = YLeaf(YType.enumeration, "nsr-sync-state")

                                    self.outbound_ipv4acl = YLeaf(YType.str, "outbound-ipv4acl")

                                    self.outbound_ipv6acl = YLeaf(YType.str, "outbound-ipv6acl")

                                    self.peer_holdtime = YLeaf(YType.uint32, "peer-holdtime")

                                    self.peer_state = YLeaf(YType.str, "peer-state")

                                    self.sp_duration = YLeaf(YType.uint32, "sp-duration")

                                    self.sp_has_acl = YLeaf(YType.boolean, "sp-has-acl")

                                    self.sp_has_duration = YLeaf(YType.boolean, "sp-has-duration")

                                    self.sp_state = YLeaf(YType.str, "sp-state")

                                    self.spacl = YLeaf(YType.str, "spacl")

                                    self.spht_remaining = YLeaf(YType.uint32, "spht-remaining")

                                    self.spht_running = YLeaf(YType.boolean, "spht-running")

                                    self.capabilities = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                    self.capabilities.parent = self
                                    self._children_name_map["capabilities"] = "capabilities"
                                    self._children_yang_names.add("capabilities")

                                    self.client = YList(self)
                                    self.ipv4_duplicate_address = YList(self)
                                    self.ipv6_duplicate_address = YList(self)
                                    self._segment_path = lambda: "detailed-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, ['advertise_bgp_prefixes', 'bgp_advertisement_state', 'has_ipv4_inbound', 'has_ipv4_outbound', 'has_ipv6_inbound', 'has_ipv6_outbound', 'has_sp', 'inbound_ipv4acl', 'inbound_ipv6acl', 'keep_alive_interval', 'nsr_last_sync_error', 'nsr_last_sync_nack_reason', 'nsr_sync_state', 'outbound_ipv4acl', 'outbound_ipv6acl', 'peer_holdtime', 'peer_state', 'sp_duration', 'sp_has_acl', 'sp_has_duration', 'sp_state', 'spacl', 'spht_remaining', 'spht_running'], name, value)


                                class Capabilities(Entity):
                                    """
                                    Capabilities sent to and received from neighbor
                                    
                                    .. attribute:: received
                                    
                                    	List of received capabilities
                                    	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                    
                                    .. attribute:: sent
                                    
                                    	List of sent capabilities
                                    	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                        self.yang_name = "capabilities"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"received" : ("received", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received), "sent" : ("sent", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)}

                                        self.received = YList(self)
                                        self.sent = YList(self)
                                        self._segment_path = lambda: "capabilities"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                    class Received(Entity):
                                        """
                                        List of received capabilities
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\:  str
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\:  str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                            self.yang_name = "received"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.capability_data = YLeaf(YType.str, "capability-data")

                                            self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                            self.description = YLeaf(YType.str, "description")

                                            self.type = YLeaf(YType.uint16, "type")
                                            self._segment_path = lambda: "received"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                    class Sent(Entity):
                                        """
                                        List of sent capabilities
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\:  str
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\:  str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                            self.yang_name = "sent"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.capability_data = YLeaf(YType.str, "capability-data")

                                            self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                            self.description = YLeaf(YType.str, "description")

                                            self.type = YLeaf(YType.uint16, "type")
                                            self._segment_path = lambda: "sent"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                class Client(Entity):
                                    """
                                    Targeted Session clients
                                    
                                    .. attribute:: name
                                    
                                    	Client's name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                        self.yang_name = "client"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "client"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, ['name'], name, value)


                                class Ipv4DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv4 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv4-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address)}
                                        self._child_list_classes = {}

                                        self.address = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._children_yang_names.add("address")
                                        self._segment_path = lambda: "ipv4-duplicate-address"


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv4-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class Ipv6DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv6 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv6-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address)}
                                        self._child_list_classes = {}

                                        self.address = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._children_yang_names.add("address")
                                        self._segment_path = lambda: "ipv6-duplicate-address"


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv6-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrBoundIpv4AddressInfo(Entity):
                                """
                                Neighbor IPv4 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrBoundIpv6AddressInfo(Entity):
                                """
                                Neighbor IPv6 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrIpv4AdjInfo(Entity):
                                """
                                Neighbor's IPv4 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv4-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup)}
                                    self._child_list_classes = {}

                                    self.adjacency_group = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._children_yang_names.add("adjacency-group")
                                    self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData)}
                                        self._child_list_classes = {}

                                        self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                        self.link_hello_data = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"
                                        self._children_yang_names.add("link-hello-data")

                                        self.target_hello_data = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._children_yang_names.add("target-hello-data")
                                        self._segment_path = lambda: "adjacency-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "link-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                            self._child_list_classes = {}

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.local_address = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                            self._children_yang_names.add("local-address")

                                            self.target_address = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._children_yang_names.add("target-address")
                                            self._segment_path = lambda: "target-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrIpv6AdjInfo(Entity):
                                """
                                Neighbor's IPv6 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv6-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup)}
                                    self._child_list_classes = {}

                                    self.adjacency_group = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._children_yang_names.add("adjacency-group")
                                    self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData)}
                                        self._child_list_classes = {}

                                        self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                        self.link_hello_data = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"
                                        self._children_yang_names.add("link-hello-data")

                                        self.target_hello_data = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._children_yang_names.add("target-hello-data")
                                        self._segment_path = lambda: "adjacency-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "link-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                            self._child_list_classes = {}

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.local_address = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                            self._children_yang_names.add("local-address")

                                            self.target_address = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._children_yang_names.add("target-address")
                                            self._segment_path = lambda: "target-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class ProtocolInformation(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: downstream_on_demand
                                
                                	Is Label advertisment mode in Downstream On Demand mode or Not
                                	**type**\:  bool
                                
                                .. attribute:: ta_graceful_restart_adjacency
                                
                                	Graceful restart information
                                	**type**\:   :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                                
                                .. attribute:: ta_holdtime
                                
                                	Session holdtime in sec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_rcvd
                                
                                	Number of pies received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_sent
                                
                                	Number of pies sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_state
                                
                                	State
                                	**type**\:  str
                                
                                .. attribute:: ta_up_time_seconds
                                
                                	Up time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                    self.yang_name = "protocol-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ta-graceful-restart-adjacency" : ("ta_graceful_restart_adjacency", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency)}
                                    self._child_list_classes = {}

                                    self.downstream_on_demand = YLeaf(YType.boolean, "downstream-on-demand")

                                    self.ta_holdtime = YLeaf(YType.uint32, "ta-holdtime")

                                    self.ta_pies_rcvd = YLeaf(YType.uint32, "ta-pies-rcvd")

                                    self.ta_pies_sent = YLeaf(YType.uint32, "ta-pies-sent")

                                    self.ta_state = YLeaf(YType.str, "ta-state")

                                    self.ta_up_time_seconds = YLeaf(YType.uint32, "ta-up-time-seconds")

                                    self.ta_graceful_restart_adjacency = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                    self.ta_graceful_restart_adjacency.parent = self
                                    self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                    self._children_yang_names.add("ta-graceful-restart-adjacency")
                                    self._segment_path = lambda: "protocol-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, ['downstream_on_demand', 'ta_holdtime', 'ta_pies_rcvd', 'ta_pies_sent', 'ta_state', 'ta_up_time_seconds'], name, value)


                                class TaGracefulRestartAdjacency(Entity):
                                    """
                                    Graceful restart information
                                    
                                    .. attribute:: is_graceful_restartable
                                    
                                    	Is graceful restartable
                                    	**type**\:  bool
                                    
                                    .. attribute:: reconnect_timeout
                                    
                                    	Reconnect timeout
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recovery_time
                                    
                                    	Recovery time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                        self.yang_name = "ta-graceful-restart-adjacency"
                                        self.yang_parent_name = "protocol-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                        self.reconnect_timeout = YLeaf(YType.uint32, "reconnect-timeout")

                                        self.recovery_time = YLeaf(YType.uint32, "recovery-time")
                                        self._segment_path = lambda: "ta-graceful-restart-adjacency"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, ['is_graceful_restartable', 'reconnect_timeout', 'recovery_time'], name, value)


                            class TcpInformation(Entity):
                                """
                                TCP Information
                                
                                .. attribute:: foreign_host
                                
                                	Foreign host address
                                	**type**\:   :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                                
                                .. attribute:: foreign_port
                                
                                	Foreign port number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_md5_on
                                
                                	Is MD5 Digest on
                                	**type**\:  bool
                                
                                .. attribute:: local_host
                                
                                	Local host address
                                	**type**\:   :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                                
                                .. attribute:: local_port
                                
                                	Local port number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                    self.yang_name = "tcp-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"foreign-host" : ("foreign_host", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost), "local-host" : ("local_host", MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost)}
                                    self._child_list_classes = {}

                                    self.foreign_port = YLeaf(YType.uint16, "foreign-port")

                                    self.is_md5_on = YLeaf(YType.boolean, "is-md5-on")

                                    self.local_port = YLeaf(YType.uint16, "local-port")

                                    self.foreign_host = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                    self.foreign_host.parent = self
                                    self._children_name_map["foreign_host"] = "foreign-host"
                                    self._children_yang_names.add("foreign-host")

                                    self.local_host = MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                    self.local_host.parent = self
                                    self._children_name_map["local_host"] = "local-host"
                                    self._children_yang_names.add("local-host")
                                    self._segment_path = lambda: "tcp-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, ['foreign_port', 'is_md5_on', 'local_port'], name, value)


                                class ForeignHost(Entity):
                                    """
                                    Foreign host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                        self.yang_name = "foreign-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "foreign-host"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class LocalHost(Entity):
                                    """
                                    Local host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                        self.yang_name = "local-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "local-host"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                    class Nsr(Entity):
                        """
                        LDP NSR related information
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary>`
                        
                        .. attribute:: nsr_pending
                        
                        	LDP NSR Pending related information
                        	**type**\:   :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr, self).__init__()

                            self.yang_name = "nsr"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary), "nsr-pending" : ("nsr_pending", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending)}
                            self._child_list_classes = {}

                            self.ha_statistics = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._children_yang_names.add("ha-statistics")

                            self.ha_summary = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"
                            self._children_yang_names.add("ha-summary")

                            self.nsr_pending = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending()
                            self.nsr_pending.parent = self
                            self._children_name_map["nsr_pending"] = "nsr-pending"
                            self._children_yang_names.add("nsr-pending")
                            self._segment_path = lambda: "nsr"


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_global = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"
                                self._children_yang_names.add("ha-global")

                                self.ha_neighbors = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "ha-statistics"


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync)}
                                    self._child_list_classes = {}

                                    self.init_sync = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._children_yang_names.add("init-sync")
                                    self._segment_path = lambda: "ha-global"


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                        self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                        self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                        self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                        self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                        self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                        self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                        self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                        self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                        self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                        self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                        self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                        self.num_peers = YLeaf(YType.uint32, "num-peers")

                                        self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                        self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                        self._segment_path = lambda: "init-sync"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf)}
                                self._child_list_classes = {}

                                self.sessions = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._children_yang_names.add("sessions")

                                self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "ha-summary"


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                    self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                    self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                    self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                    self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                    self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                    self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                    self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                    self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                    self.total = YLeaf(YType.uint32, "total")
                                    self._segment_path = lambda: "sessions"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.HaSummary.Vrf, ['id', 'name'], name, value)


                        class NsrPending(Entity):
                            """
                            LDP NSR Pending related information
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending, self).__init__()

                                self.yang_name = "nsr-pending"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_neighbors = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "nsr-pending"


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "nsr-pending"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class Parameters(Entity):
                        """
                        LDP parameters
                        
                        .. attribute:: address_family_parameter
                        
                        	Per AF parameters
                        	**type**\: list of    :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter>`
                        
                        .. attribute:: af_binding_withdraw_delay
                        
                        	Delay (sec) in Binding Withdrawal for an Address Family
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: discovery_quick_start_disabled_on_interfaces
                        
                        	Discovery quick\-start disabled on some LDP\-enabled interfaces
                        	**type**\:  bool
                        
                        .. attribute:: global_discovery_quick_start_disabled
                        
                        	Discovery quick\-start globally disabled
                        	**type**\:  bool
                        
                        .. attribute:: global_md5_password_enabled
                        
                        	Global MD5 password enabled
                        	**type**\:  bool
                        
                        .. attribute:: graceful_restart_information
                        
                        	Graceful restart information
                        	**type**\:   :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation>`
                        
                        .. attribute:: hello_hold_time
                        
                        	Hello hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_interval
                        
                        	Hello interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: housekeeping_timer_interval
                        
                        	Housekeeping periodic timer interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: igp_sync_delay_time_for_interface
                        
                        	Interface IGP sync delay time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: igp_sync_delay_time_on_restart
                        
                        	IGP sync delay time on process restart in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: keepalive_interval
                        
                        	Keepalive interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_out_of_mem_state
                        
                        	LDP Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_recovery_timeout
                        
                        	LDP recovery timeout with LSD
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: le_no_route_timeout
                        
                        	LIB entry no route timeout
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_attached
                        
                        	Maximum number of LDP enabled attached interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_te
                        
                        	Maximum number of LDP enabled TE interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_peer
                        
                        	Maximum number of LDP peers
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	TRUE if NSR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: nsr_synced
                        
                        	TRUE if LDP is standby and is NSR Sync\-ed with active
                        	**type**\:  bool
                        
                        .. attribute:: protocol_version
                        
                        	Protocol version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role_is_active
                        
                        	Is process role active or standby
                        	**type**\:  bool
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_hold_time
                        
                        	Session hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_hold_time
                        
                        	Targeted hello hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_interval
                        
                        	Targeted hello interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Parameters, self).__init__()

                            self.yang_name = "parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"graceful-restart-information" : ("graceful_restart_information", MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation)}
                            self._child_list_classes = {"address-family-parameter" : ("address_family_parameter", MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter)}

                            self.af_binding_withdraw_delay = YLeaf(YType.uint32, "af-binding-withdraw-delay")

                            self.discovery_quick_start_disabled_on_interfaces = YLeaf(YType.boolean, "discovery-quick-start-disabled-on-interfaces")

                            self.global_discovery_quick_start_disabled = YLeaf(YType.boolean, "global-discovery-quick-start-disabled")

                            self.global_md5_password_enabled = YLeaf(YType.boolean, "global-md5-password-enabled")

                            self.hello_hold_time = YLeaf(YType.uint32, "hello-hold-time")

                            self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                            self.housekeeping_timer_interval = YLeaf(YType.uint32, "housekeeping-timer-interval")

                            self.igp_sync_delay_time_for_interface = YLeaf(YType.uint32, "igp-sync-delay-time-for-interface")

                            self.igp_sync_delay_time_on_restart = YLeaf(YType.uint32, "igp-sync-delay-time-on-restart")

                            self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                            self.ldp_out_of_mem_state = YLeaf(YType.uint32, "ldp-out-of-mem-state")

                            self.ldp_recovery_timeout = YLeaf(YType.uint32, "ldp-recovery-timeout")

                            self.le_no_route_timeout = YLeaf(YType.uint32, "le-no-route-timeout")

                            self.max_intf_attached = YLeaf(YType.uint32, "max-intf-attached")

                            self.max_intf_te = YLeaf(YType.uint32, "max-intf-te")

                            self.max_peer = YLeaf(YType.uint32, "max-peer")

                            self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                            self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                            self.protocol_version = YLeaf(YType.uint32, "protocol-version")

                            self.role_is_active = YLeaf(YType.boolean, "role-is-active")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.session_hold_time = YLeaf(YType.uint32, "session-hold-time")

                            self.targeted_hello_hold_time = YLeaf(YType.uint32, "targeted-hello-hold-time")

                            self.targeted_hello_interval = YLeaf(YType.uint32, "targeted-hello-interval")

                            self.graceful_restart_information = MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation()
                            self.graceful_restart_information.parent = self
                            self._children_name_map["graceful_restart_information"] = "graceful-restart-information"
                            self._children_yang_names.add("graceful-restart-information")

                            self.address_family_parameter = YList(self)
                            self._segment_path = lambda: "parameters"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Parameters, ['af_binding_withdraw_delay', 'discovery_quick_start_disabled_on_interfaces', 'global_discovery_quick_start_disabled', 'global_md5_password_enabled', 'hello_hold_time', 'hello_interval', 'housekeeping_timer_interval', 'igp_sync_delay_time_for_interface', 'igp_sync_delay_time_on_restart', 'keepalive_interval', 'ldp_out_of_mem_state', 'ldp_recovery_timeout', 'le_no_route_timeout', 'max_intf_attached', 'max_intf_te', 'max_peer', 'nsr_enabled', 'nsr_synced', 'protocol_version', 'role_is_active', 'router_id', 'session_hold_time', 'targeted_hello_hold_time', 'targeted_hello_interval'], name, value)


                        class AddressFamilyParameter(Entity):
                            """
                            Per AF parameters
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: discovery_transport_address
                            
                            	Discovery transport address
                            	**type**\:   :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                            
                            .. attribute:: is_accepting_targeted_hellos
                            
                            	Accepting targeted Hellos
                            	**type**\:  bool
                            
                            .. attribute:: label_imp_null_override_acl
                            
                            	ACL to override local label to use implicit\-null
                            	**type**\:  str
                            
                            .. attribute:: null_label
                            
                            	Null label
                            	**type**\:  str
                            
                            .. attribute:: targeted_hello_acl
                            
                            	Targeted Hello ACL
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter, self).__init__()

                                self.yang_name = "address-family-parameter"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"discovery-transport-address" : ("discovery_transport_address", MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress)}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.is_accepting_targeted_hellos = YLeaf(YType.boolean, "is-accepting-targeted-hellos")

                                self.label_imp_null_override_acl = YLeaf(YType.str, "label-imp-null-override-acl")

                                self.null_label = YLeaf(YType.str, "null-label")

                                self.targeted_hello_acl = YLeaf(YType.str, "targeted-hello-acl")

                                self.discovery_transport_address = MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                                self.discovery_transport_address.parent = self
                                self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                                self._children_yang_names.add("discovery-transport-address")
                                self._segment_path = lambda: "address-family-parameter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter, ['address_family', 'is_accepting_targeted_hellos', 'label_imp_null_override_acl', 'null_label', 'targeted_hello_acl'], name, value)


                            class DiscoveryTransportAddress(Entity):
                                """
                                Discovery transport address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                    self.yang_name = "discovery-transport-address"
                                    self.yang_parent_name = "address-family-parameter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "discovery-transport-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class GracefulRestartInformation(Entity):
                            """
                            Graceful restart information
                            
                            .. attribute:: graceful_restart_forwarding_state_hold_time
                            
                            	Graceful restart forward state hold time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_reconnect_timeout
                            
                            	Reconnect timeout value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_graceful_restart_configured
                            
                            	Is graceful restart configured
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation, self).__init__()

                                self.yang_name = "graceful-restart-information"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.graceful_restart_forwarding_state_hold_time = YLeaf(YType.uint32, "graceful-restart-forwarding-state-hold-time")

                                self.graceful_restart_reconnect_timeout = YLeaf(YType.uint32, "graceful-restart-reconnect-timeout")

                                self.is_graceful_restart_configured = YLeaf(YType.boolean, "is-graceful-restart-configured")
                                self._segment_path = lambda: "graceful-restart-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Parameters.GracefulRestartInformation, ['graceful_restart_forwarding_state_hold_time', 'graceful_restart_reconnect_timeout', 'is_graceful_restart_configured'], name, value)


                    class Statistics(Entity):
                        """
                        The LDP Statistics
                        
                        .. attribute:: statistic
                        
                        	Statistical Information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"statistic" : ("statistic", MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic)}

                            self.statistic = YList(self)
                            self._segment_path = lambda: "statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Statistics, [], name, value)


                        class Statistic(Entity):
                            """
                            Statistical Information on a particular LDP
                            neighbor
                            
                            .. attribute:: iccp_enabled
                            
                            	Is session ICCP enabled?
                            	**type**\:  bool
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: message_in
                            
                            	Message in count
                            	**type**\:   :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn>`
                            
                            .. attribute:: message_out
                            
                            	Message out count
                            	**type**\:   :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic, self).__init__()

                                self.yang_name = "statistic"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"message-in" : ("message_in", MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn), "message-out" : ("message_out", MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut)}
                                self._child_list_classes = {}

                                self.iccp_enabled = YLeaf(YType.boolean, "iccp-enabled")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.message_in = MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn()
                                self.message_in.parent = self
                                self._children_name_map["message_in"] = "message-in"
                                self._children_yang_names.add("message-in")

                                self.message_out = MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut()
                                self.message_out.parent = self
                                self._children_name_map["message_out"] = "message-out"
                                self._children_yang_names.add("message-out")
                                self._segment_path = lambda: "statistic"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic, ['iccp_enabled', 'label_space_id', 'lsr_id'], name, value)


                            class MessageIn(Entity):
                                """
                                Message in count
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn, self).__init__()

                                    self.yang_name = "message-in"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_count = YLeaf(YType.uint32, "address-count")

                                    self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                    self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                    self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                    self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                    self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                    self.init_count = YLeaf(YType.uint32, "init-count")

                                    self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                    self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                    self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                    self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                    self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                    self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                    self.notification_count = YLeaf(YType.uint32, "notification-count")

                                    self.total_count = YLeaf(YType.uint32, "total-count")
                                    self._segment_path = lambda: "message-in"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageIn, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                            class MessageOut(Entity):
                                """
                                Message out count
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut, self).__init__()

                                    self.yang_name = "message-out"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_count = YLeaf(YType.uint32, "address-count")

                                    self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                    self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                    self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                    self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                    self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                    self.init_count = YLeaf(YType.uint32, "init-count")

                                    self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                    self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                    self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                    self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                    self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                    self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                    self.notification_count = YLeaf(YType.uint32, "notification-count")

                                    self.total_count = YLeaf(YType.uint32, "total-count")
                                    self._segment_path = lambda: "message-out"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Statistics.Statistic.MessageOut, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                    class Summary(Entity):
                        """
                        LDP VRF summary
                        
                        .. attribute:: common
                        
                        	Common Summary information
                        	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Common>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Active.Vrfs.Vrf.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"common" : ("common", MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Common), "vrf" : ("vrf", MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Vrf)}
                            self._child_list_classes = {}

                            self.common = MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Common()
                            self.common.parent = self
                            self._children_name_map["common"] = "common"
                            self._children_yang_names.add("common")

                            self.vrf = MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "summary"


                        class Common(Entity):
                            """
                            Common Summary information
                            
                            .. attribute:: address_families
                            
                            	Address Families enabled
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: number_of_bindings_ipv4
                            
                            	Total number of ipv4 bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv6
                            
                            	Total number of ipv6 bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_downstream_on_demand_neighbors
                            
                            	Number of Downstream\-On\-Demand neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_graceful_restart_neighbors
                            
                            	Number of Graceful Restart neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_hello_adj
                            
                            	Number of LDP discovery IPv4 hello adjacencies
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_local_addresses
                            
                            	Number of IPv4 local addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_routes
                            
                            	Number of resolved IPv4 routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4af
                            
                            	Number of IPv4 address\-families enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4ldp_interfaces
                            
                            	Number of LDP IPv4 configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_hello_adj
                            
                            	Number of LDP discovery IPv6 hello adjacencies
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_local_addresses
                            
                            	Number of IPv6 local addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_routes
                            
                            	Number of resolved IPv6 routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6af
                            
                            	Number of IPv6 address\-families enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6ldp_interfaces
                            
                            	Number of LDP IPv6 configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ldp_interfaces
                            
                            	Number of LDP configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv4
                            
                            	Total number of ipv4 local label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv6
                            
                            	Total number of ipv6 local label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_neighbors
                            
                            	Number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_nsr_synced_neighbors
                            
                            	Number of NSR\-synced/operational neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv4
                            
                            	Total number of ipv4 remote label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv6
                            
                            	Total number of ipv6 remote label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Common, self).__init__()

                                self.yang_name = "common"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_families = YLeaf(YType.enumeration, "address-families")

                                self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                                self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                                self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                                self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                                self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                                self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                                self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                                self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                                self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                                self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                                self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                                self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                                self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                                self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                                self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                                self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                                self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                                self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                                self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                                self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                                self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                                self._segment_path = lambda: "common"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Active.Vrfs.Vrf.Summary.Vrf, ['id', 'name'], name, value)


        class Standby(Entity):
            """
            Standby MPLS LDP operational data
            
            .. attribute:: ato_mdb_table_entries
            
            	AToM DB Table
            	**type**\:   :py:class:`AtoMdbTableEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries>`
            
            .. attribute:: bindings_summary_all
            
            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
            	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.BindingsSummaryAll>`
            
            .. attribute:: default_vrf
            
            	DefaultVRF specific operational data
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf>`
            
            .. attribute:: discovery_summary_all
            
            	Summary information regarding LDP discovery
            	**type**\:   :py:class:`DiscoverySummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DiscoverySummaryAll>`
            
            .. attribute:: forwarding_summary_all
            
            	Summary information regarding LDP forwarding setup
            	**type**\:   :py:class:`ForwardingSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.ForwardingSummaryAll>`
            
            .. attribute:: nsr_summary_all
            
            	Summary information regarding LDP NSR State
            	**type**\:   :py:class:`NsrSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.NsrSummaryAll>`
            
            .. attribute:: summary
            
            	LDP summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Summary>`
            
            .. attribute:: vrfs
            
            	VRF specific operational data
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs>`
            
            

            """

            _prefix = 'mpls-ldp-oper'
            _revision = '2017-05-01'

            def __init__(self):
                super(MplsLdp.Global_.Standby, self).__init__()

                self.yang_name = "standby"
                self.yang_parent_name = "global"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"ato-mdb-table-entries" : ("ato_mdb_table_entries", MplsLdp.Global_.Standby.AtoMdbTableEntries), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Global_.Standby.BindingsSummaryAll), "default-vrf" : ("default_vrf", MplsLdp.Global_.Standby.DefaultVrf), "discovery-summary-all" : ("discovery_summary_all", MplsLdp.Global_.Standby.DiscoverySummaryAll), "forwarding-summary-all" : ("forwarding_summary_all", MplsLdp.Global_.Standby.ForwardingSummaryAll), "nsr-summary-all" : ("nsr_summary_all", MplsLdp.Global_.Standby.NsrSummaryAll), "summary" : ("summary", MplsLdp.Global_.Standby.Summary), "vrfs" : ("vrfs", MplsLdp.Global_.Standby.Vrfs)}
                self._child_list_classes = {}

                self.ato_mdb_table_entries = MplsLdp.Global_.Standby.AtoMdbTableEntries()
                self.ato_mdb_table_entries.parent = self
                self._children_name_map["ato_mdb_table_entries"] = "ato-mdb-table-entries"
                self._children_yang_names.add("ato-mdb-table-entries")

                self.bindings_summary_all = MplsLdp.Global_.Standby.BindingsSummaryAll()
                self.bindings_summary_all.parent = self
                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                self._children_yang_names.add("bindings-summary-all")

                self.default_vrf = MplsLdp.Global_.Standby.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._children_yang_names.add("default-vrf")

                self.discovery_summary_all = MplsLdp.Global_.Standby.DiscoverySummaryAll()
                self.discovery_summary_all.parent = self
                self._children_name_map["discovery_summary_all"] = "discovery-summary-all"
                self._children_yang_names.add("discovery-summary-all")

                self.forwarding_summary_all = MplsLdp.Global_.Standby.ForwardingSummaryAll()
                self.forwarding_summary_all.parent = self
                self._children_name_map["forwarding_summary_all"] = "forwarding-summary-all"
                self._children_yang_names.add("forwarding-summary-all")

                self.nsr_summary_all = MplsLdp.Global_.Standby.NsrSummaryAll()
                self.nsr_summary_all.parent = self
                self._children_name_map["nsr_summary_all"] = "nsr-summary-all"
                self._children_yang_names.add("nsr-summary-all")

                self.summary = MplsLdp.Global_.Standby.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.vrfs = MplsLdp.Global_.Standby.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
                self._children_yang_names.add("vrfs")
                self._segment_path = lambda: "standby"
                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/%s" % self._segment_path()


            class AtoMdbTableEntries(Entity):
                """
                AToM DB Table
                
                .. attribute:: ato_mdb_table_entry
                
                	Entries in AToM DB
                	**type**\: list of    :py:class:`AtoMdbTableEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Standby.AtoMdbTableEntries, self).__init__()

                    self.yang_name = "ato-mdb-table-entries"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ato-mdb-table-entry" : ("ato_mdb_table_entry", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry)}

                    self.ato_mdb_table_entry = YList(self)
                    self._segment_path = lambda: "ato-mdb-table-entries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries, [], name, value)


                class AtoMdbTableEntry(Entity):
                    """
                    Entries in AToM DB
                    
                    .. attribute:: agi
                    
                    	AGI
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: agi_type
                    
                    	AGI Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: fe_ctype
                    
                    	FEC Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: fec_info
                    
                    	Pseudowire FEC information
                    	**type**\:   :py:class:`FecInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo>`
                    
                    .. attribute:: mapping_tlv_count
                    
                    	TLV Count from Label Mapping Message
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: notification_tlv_count
                    
                    	TLV Count from Notification Message
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: peer_id
                    
                    	Peer ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: peer_id_xr
                    
                    	Peer ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_ac_id
                    
                    	SAII AC ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_global_id
                    
                    	SAII Global ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_local_id
                    
                    	SAII Local ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: saii_prefix
                    
                    	SAII Prefix
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: saii_type
                    
                    	SAII Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_ac_id
                    
                    	TAII AC ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_global_id
                    
                    	TAII Global ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_local_id
                    
                    	TAII Local ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: taii_prefix
                    
                    	TAII Prefix
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: taii_type
                    
                    	TAII Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry, self).__init__()

                        self.yang_name = "ato-mdb-table-entry"
                        self.yang_parent_name = "ato-mdb-table-entries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"fec-info" : ("fec_info", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo)}
                        self._child_list_classes = {}

                        self.agi = YLeaf(YType.int32, "agi")

                        self.agi_type = YLeaf(YType.int32, "agi-type")

                        self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                        self.mapping_tlv_count = YLeaf(YType.uint32, "mapping-tlv-count")

                        self.notification_tlv_count = YLeaf(YType.uint32, "notification-tlv-count")

                        self.peer_id = YLeaf(YType.str, "peer-id")

                        self.peer_id_xr = YLeaf(YType.str, "peer-id-xr")

                        self.pw_id = YLeaf(YType.int32, "pw-id")

                        self.saii_ac_id = YLeaf(YType.int32, "saii-ac-id")

                        self.saii_global_id = YLeaf(YType.int32, "saii-global-id")

                        self.saii_local_id = YLeaf(YType.str, "saii-local-id")

                        self.saii_prefix = YLeaf(YType.str, "saii-prefix")

                        self.saii_type = YLeaf(YType.int32, "saii-type")

                        self.taii_ac_id = YLeaf(YType.int32, "taii-ac-id")

                        self.taii_global_id = YLeaf(YType.int32, "taii-global-id")

                        self.taii_local_id = YLeaf(YType.str, "taii-local-id")

                        self.taii_prefix = YLeaf(YType.str, "taii-prefix")

                        self.taii_type = YLeaf(YType.int32, "taii-type")

                        self.fec_info = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo()
                        self.fec_info.parent = self
                        self._children_name_map["fec_info"] = "fec-info"
                        self._children_yang_names.add("fec-info")
                        self._segment_path = lambda: "ato-mdb-table-entry"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry, ['agi', 'agi_type', 'fe_ctype', 'mapping_tlv_count', 'notification_tlv_count', 'peer_id', 'peer_id_xr', 'pw_id', 'saii_ac_id', 'saii_global_id', 'saii_local_id', 'saii_prefix', 'saii_type', 'taii_ac_id', 'taii_global_id', 'taii_local_id', 'taii_prefix', 'taii_type'], name, value)


                    class FecInfo(Entity):
                        """
                        Pseudowire FEC information
                        
                        .. attribute:: fe_ctype
                        
                        	FECType
                        	**type**\:   :py:class:`L2vpnLdpPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwFec>`
                        
                        .. attribute:: fec128
                        
                        	fec128
                        	**type**\:   :py:class:`Fec128 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128>`
                        
                        .. attribute:: fec129
                        
                        	fec129
                        	**type**\:   :py:class:`Fec129 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129>`
                        
                        .. attribute:: fec130
                        
                        	fec130
                        	**type**\:   :py:class:`Fec130 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, self).__init__()

                            self.yang_name = "fec-info"
                            self.yang_parent_name = "ato-mdb-table-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"fec128" : ("fec128", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128), "fec129" : ("fec129", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129), "fec130" : ("fec130", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130)}
                            self._child_list_classes = {}

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.fec128 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128()
                            self.fec128.parent = self
                            self._children_name_map["fec128"] = "fec128"
                            self._children_yang_names.add("fec128")

                            self.fec129 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129()
                            self.fec129.parent = self
                            self._children_name_map["fec129"] = "fec129"
                            self._children_yang_names.add("fec129")

                            self.fec130 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130()
                            self.fec130.parent = self
                            self._children_name_map["fec130"] = "fec130"
                            self._children_yang_names.add("fec130")
                            self._segment_path = lambda: "fec-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, ['fe_ctype'], name, value)


                        class Fec128(Entity):
                            """
                            fec128
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, self).__init__()

                                self.yang_name = "fec128"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")
                                self._segment_path = lambda: "fec128"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, ['pseudowire_id'], name, value)


                        class Fec129(Entity):
                            """
                            fec129
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:   :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:   :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii>`
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifier
                            	**type**\:   :py:class:`Taii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, self).__init__()

                                self.yang_name = "fec129"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"agi" : ("agi", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi), "saii" : ("saii", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii), "taii" : ("taii", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii)}
                                self._child_list_classes = {}

                                self.agi = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"
                                self._children_yang_names.add("agi")

                                self.saii = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._children_yang_names.add("saii")

                                self.taii = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii()
                                self.taii.parent = self
                                self._children_name_map["taii"] = "taii"
                                self._children_yang_names.add("taii")
                                self._segment_path = lambda: "fec129"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:   :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:   :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"agi1" : ("agi1", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1)}
                                    self._child_list_classes = {}

                                    self.agi_type = YLeaf(YType.enumeration, "agi-type")

                                    self.agi1 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._children_yang_names.add("agi1")
                                    self._segment_path = lambda: "agi"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.rd = YLeaf(YType.uint64, "rd")
                                        self._segment_path = lambda: "agi1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/agi/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1), "aii2" : ("aii2", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "saii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/saii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/saii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


                            class Taii(Entity):
                                """
                                Target Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, self).__init__()

                                    self.yang_name = "taii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1), "aii2" : ("aii2", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "taii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/taii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec129/taii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


                        class Fec130(Entity):
                            """
                            fec130
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:   :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:   :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, self).__init__()

                                self.yang_name = "fec130"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"agi" : ("agi", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi), "saii" : ("saii", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii)}
                                self._child_list_classes = {}

                                self.agi = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"
                                self._children_yang_names.add("agi")

                                self.saii = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._children_yang_names.add("saii")
                                self._segment_path = lambda: "fec130"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/%s" % self._segment_path()


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:   :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:   :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"agi1" : ("agi1", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1)}
                                    self._child_list_classes = {}

                                    self.agi_type = YLeaf(YType.enumeration, "agi-type")

                                    self.agi1 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._children_yang_names.add("agi1")
                                    self._segment_path = lambda: "agi"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.rd = YLeaf(YType.uint64, "rd")
                                        self._segment_path = lambda: "agi1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/agi/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1), "aii2" : ("aii2", MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "saii"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/saii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/ato-mdb-table-entries/ato-mdb-table-entry/fec-info/fec130/saii/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


            class BindingsSummaryAll(Entity):
                """
                Aggregate VRF counters for the LDP Label
                Infomation Base (LIB)
                
                .. attribute:: address_family
                
                	Address Family
                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                
                .. attribute:: bind_af
                
                	bind af
                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.BindingsSummaryAll.BindAf>`
                
                .. attribute:: binding_local_explicit_null
                
                	Number of local explicit null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_implicit_null
                
                	Number of local implicit null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_no_route
                
                	Local bindings with no route
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_non_null
                
                	Number of local non\-null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_null
                
                	Number of local null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_oor
                
                	Number of local bindings        needing label \- OOR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_no_route
                
                	Bindings with no route
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: highest_allocated_label
                
                	Highest allocated label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lowest_allocated_label
                
                	Lowest allocated label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.BindingsSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Standby.BindingsSummaryAll, self).__init__()

                    self.yang_name = "bindings-summary-all"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.BindingsSummaryAll.Vrf)}
                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Standby.BindingsSummaryAll.BindAf)}

                    self.address_family = YLeaf(YType.enumeration, "address-family")

                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                    self.vrf = MplsLdp.Global_.Standby.BindingsSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")

                    self.bind_af = YList(self)
                    self._segment_path = lambda: "bindings-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Standby.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                class BindAf(Entity):
                    """
                    bind af
                    
                    .. attribute:: address_family
                    
                    	Binding Summary Address Family
                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: binding_local
                    
                    	Number of local bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_remote
                    
                    	Number of remote bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_total
                    
                    	Total bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_lib_update
                    
                    	Last update to LIB local binding
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lib_minimum_revision_sent_all
                    
                    	Last update sent to all peers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.BindingsSummaryAll.BindAf, self).__init__()

                        self.yang_name = "bind-af"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.address_family = YLeaf(YType.enumeration, "address-family")

                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                        self._segment_path = lambda: "bind-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/bindings-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.BindingsSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/bindings-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


            class DefaultVrf(Entity):
                """
                DefaultVRF specific operational data
                
                .. attribute:: afs
                
                	Address Family specific operational data
                	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs>`
                
                .. attribute:: backoff_parameters
                
                	The LDP Backoff Parameters
                	**type**\:   :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.BackoffParameters>`
                
                .. attribute:: backoffs
                
                	The LDP backoff
                	**type**\:   :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Backoffs>`
                
                .. attribute:: capabilities
                
                	LDP capability database information
                	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Capabilities>`
                
                .. attribute:: graceful_restart
                
                	LDP Graceful Restart info
                	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart>`
                
                .. attribute:: issu
                
                	LDP ISSU related information
                	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu>`
                
                .. attribute:: ldp_id
                
                	Local LDP Id
                	**type**\:   :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.LdpId>`
                
                .. attribute:: neighbor_briefs
                
                	The LDP Neighbors (brief)
                	**type**\:   :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs>`
                
                .. attribute:: neighbor_capabilities
                
                	LDP Neighbors Capabilities
                	**type**\:   :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities>`
                
                .. attribute:: neighbors
                
                	The LDP Neighbors
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors>`
                
                .. attribute:: nsr
                
                	LDP NSR related information
                	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr>`
                
                .. attribute:: parameters
                
                	LDP parameters
                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Parameters>`
                
                .. attribute:: statistics
                
                	The LDP Statistics
                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Statistics>`
                
                .. attribute:: summary
                
                	LDP VRF summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Summary>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Standby.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"afs" : ("afs", MplsLdp.Global_.Standby.DefaultVrf.Afs), "backoff-parameters" : ("backoff_parameters", MplsLdp.Global_.Standby.DefaultVrf.BackoffParameters), "backoffs" : ("backoffs", MplsLdp.Global_.Standby.DefaultVrf.Backoffs), "capabilities" : ("capabilities", MplsLdp.Global_.Standby.DefaultVrf.Capabilities), "graceful-restart" : ("graceful_restart", MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart), "issu" : ("issu", MplsLdp.Global_.Standby.DefaultVrf.Issu), "ldp-id" : ("ldp_id", MplsLdp.Global_.Standby.DefaultVrf.LdpId), "neighbor-briefs" : ("neighbor_briefs", MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs), "neighbor-capabilities" : ("neighbor_capabilities", MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities), "neighbors" : ("neighbors", MplsLdp.Global_.Standby.DefaultVrf.Neighbors), "nsr" : ("nsr", MplsLdp.Global_.Standby.DefaultVrf.Nsr), "parameters" : ("parameters", MplsLdp.Global_.Standby.DefaultVrf.Parameters), "statistics" : ("statistics", MplsLdp.Global_.Standby.DefaultVrf.Statistics), "summary" : ("summary", MplsLdp.Global_.Standby.DefaultVrf.Summary)}
                    self._child_list_classes = {}

                    self.afs = MplsLdp.Global_.Standby.DefaultVrf.Afs()
                    self.afs.parent = self
                    self._children_name_map["afs"] = "afs"
                    self._children_yang_names.add("afs")

                    self.backoff_parameters = MplsLdp.Global_.Standby.DefaultVrf.BackoffParameters()
                    self.backoff_parameters.parent = self
                    self._children_name_map["backoff_parameters"] = "backoff-parameters"
                    self._children_yang_names.add("backoff-parameters")

                    self.backoffs = MplsLdp.Global_.Standby.DefaultVrf.Backoffs()
                    self.backoffs.parent = self
                    self._children_name_map["backoffs"] = "backoffs"
                    self._children_yang_names.add("backoffs")

                    self.capabilities = MplsLdp.Global_.Standby.DefaultVrf.Capabilities()
                    self.capabilities.parent = self
                    self._children_name_map["capabilities"] = "capabilities"
                    self._children_yang_names.add("capabilities")

                    self.graceful_restart = MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart()
                    self.graceful_restart.parent = self
                    self._children_name_map["graceful_restart"] = "graceful-restart"
                    self._children_yang_names.add("graceful-restart")

                    self.issu = MplsLdp.Global_.Standby.DefaultVrf.Issu()
                    self.issu.parent = self
                    self._children_name_map["issu"] = "issu"
                    self._children_yang_names.add("issu")

                    self.ldp_id = MplsLdp.Global_.Standby.DefaultVrf.LdpId()
                    self.ldp_id.parent = self
                    self._children_name_map["ldp_id"] = "ldp-id"
                    self._children_yang_names.add("ldp-id")

                    self.neighbor_briefs = MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs()
                    self.neighbor_briefs.parent = self
                    self._children_name_map["neighbor_briefs"] = "neighbor-briefs"
                    self._children_yang_names.add("neighbor-briefs")

                    self.neighbor_capabilities = MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities()
                    self.neighbor_capabilities.parent = self
                    self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"
                    self._children_yang_names.add("neighbor-capabilities")

                    self.neighbors = MplsLdp.Global_.Standby.DefaultVrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.nsr = MplsLdp.Global_.Standby.DefaultVrf.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"
                    self._children_yang_names.add("nsr")

                    self.parameters = MplsLdp.Global_.Standby.DefaultVrf.Parameters()
                    self.parameters.parent = self
                    self._children_name_map["parameters"] = "parameters"
                    self._children_yang_names.add("parameters")

                    self.statistics = MplsLdp.Global_.Standby.DefaultVrf.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._children_yang_names.add("statistics")

                    self.summary = MplsLdp.Global_.Standby.DefaultVrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")
                    self._segment_path = lambda: "default-vrf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()


                class Afs(Entity):
                    """
                    Address Family specific operational data
                    
                    .. attribute:: af
                    
                    	Operational data for given Address Family
                    	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs, self).__init__()

                        self.yang_name = "afs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"af" : ("af", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af)}

                        self.af = YList(self)
                        self._segment_path = lambda: "afs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs, [], name, value)


                    class Af(Entity):
                        """
                        Operational data for given Address Family
                        
                        .. attribute:: af_name  <key>
                        
                        	Address Family name
                        	**type**\:   :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                        
                        .. attribute:: bindings
                        
                        	The LDP Bindings
                        	**type**\:   :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings>`
                        
                        .. attribute:: bindings_advertise_spec
                        
                        	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec>`
                        
                        .. attribute:: bindings_summary
                        
                        	Counters for the LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary>`
                        
                        .. attribute:: bindings_summary_all
                        
                        	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll>`
                        
                        .. attribute:: discovery
                        
                        	The LDP Discovery
                        	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery>`
                        
                        .. attribute:: forwarding_summary
                        
                        	Summary information regarding LDP forwarding setup
                        	**type**\:   :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary>`
                        
                        .. attribute:: forwardings
                        
                        	The LDP Forwarding rewrites
                        	**type**\:   :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings>`
                        
                        .. attribute:: igp
                        
                        	LDP IGP related information
                        	**type**\:   :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp>`
                        
                        .. attribute:: interface_summary
                        
                        	IPv4 interface summary information
                        	**type**\:   :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.InterfaceSummary>`
                        
                        .. attribute:: interfaces
                        
                        	LDP Interface related information
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af, self).__init__()

                            self.yang_name = "af"
                            self.yang_parent_name = "afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"bindings" : ("bindings", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings), "bindings-advertise-spec" : ("bindings_advertise_spec", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec), "bindings-summary" : ("bindings_summary", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll), "discovery" : ("discovery", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery), "forwarding-summary" : ("forwarding_summary", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary), "forwardings" : ("forwardings", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings), "igp" : ("igp", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp), "interface-summary" : ("interface_summary", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.InterfaceSummary), "interfaces" : ("interfaces", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces)}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.bindings = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings()
                            self.bindings.parent = self
                            self._children_name_map["bindings"] = "bindings"
                            self._children_yang_names.add("bindings")

                            self.bindings_advertise_spec = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec()
                            self.bindings_advertise_spec.parent = self
                            self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"
                            self._children_yang_names.add("bindings-advertise-spec")

                            self.bindings_summary = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary()
                            self.bindings_summary.parent = self
                            self._children_name_map["bindings_summary"] = "bindings-summary"
                            self._children_yang_names.add("bindings-summary")

                            self.bindings_summary_all = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll()
                            self.bindings_summary_all.parent = self
                            self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                            self._children_yang_names.add("bindings-summary-all")

                            self.discovery = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery()
                            self.discovery.parent = self
                            self._children_name_map["discovery"] = "discovery"
                            self._children_yang_names.add("discovery")

                            self.forwarding_summary = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary()
                            self.forwarding_summary.parent = self
                            self._children_name_map["forwarding_summary"] = "forwarding-summary"
                            self._children_yang_names.add("forwarding-summary")

                            self.forwardings = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings()
                            self.forwardings.parent = self
                            self._children_name_map["forwardings"] = "forwardings"
                            self._children_yang_names.add("forwardings")

                            self.igp = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp()
                            self.igp.parent = self
                            self._children_name_map["igp"] = "igp"
                            self._children_yang_names.add("igp")

                            self.interface_summary = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.InterfaceSummary()
                            self.interface_summary.parent = self
                            self._children_name_map["interface_summary"] = "interface-summary"
                            self._children_yang_names.add("interface-summary")

                            self.interfaces = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                            self._children_yang_names.add("interfaces")
                            self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/afs/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af, ['af_name'], name, value)


                        class Bindings(Entity):
                            """
                            The LDP Bindings
                            
                            .. attribute:: binding
                            
                            	Binding Information
                            	**type**\: list of    :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings, self).__init__()

                                self.yang_name = "bindings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"binding" : ("binding", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding)}

                                self.binding = YList(self)
                                self._segment_path = lambda: "bindings"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings, [], name, value)


                            class Binding(Entity):
                                """
                                Binding Information
                                
                                .. attribute:: prefix  <key>
                                
                                	The IP Prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: advertise_prefix_acl
                                
                                	Advertise Prerfix ACL
                                	**type**\:  str
                                
                                .. attribute:: advertise_tsr_acl
                                
                                	Advertise TSR ACL
                                	**type**\:  str
                                
                                .. attribute:: config_enforced_local_label_value
                                
                                	Config/User enforced local label value
                                	**type**\:  bool
                                
                                .. attribute:: is_elc
                                
                                	Is the entry entropy label capable
                                	**type**\:  bool
                                
                                .. attribute:: is_no_route
                                
                                	No route
                                	**type**\:  bool
                                
                                .. attribute:: label_oor
                                
                                	Label space depletion OOR
                                	**type**\:  bool
                                
                                .. attribute:: le_local_binding_revision
                                
                                	Local Binding revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_label_state
                                
                                	Local label state
                                	**type**\:   :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peers_acked
                                
                                	Peers that have ACKed this entry
                                	**type**\: list of    :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                
                                .. attribute:: peers_advertised_to
                                
                                	Peers this entry is advertised to
                                	**type**\: list of    :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                
                                .. attribute:: remote_binding
                                
                                	Remote binding
                                	**type**\: list of    :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding, self).__init__()

                                    self.yang_name = "binding"
                                    self.yang_parent_name = "bindings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr), "vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf)}
                                    self._child_list_classes = {"peers-acked" : ("peers_acked", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked), "peers-advertised-to" : ("peers_advertised_to", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo), "remote-binding" : ("remote_binding", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.advertise_prefix_acl = YLeaf(YType.str, "advertise-prefix-acl")

                                    self.advertise_tsr_acl = YLeaf(YType.str, "advertise-tsr-acl")

                                    self.config_enforced_local_label_value = YLeaf(YType.boolean, "config-enforced-local-label-value")

                                    self.is_elc = YLeaf(YType.boolean, "is-elc")

                                    self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                    self.le_local_binding_revision = YLeaf(YType.uint32, "le-local-binding-revision")

                                    self.le_local_label_state = YLeaf(YType.enumeration, "le-local-label-state")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                    self.prefix_xr = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"
                                    self._children_yang_names.add("prefix-xr")

                                    self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.peers_acked = YList(self)
                                    self.peers_advertised_to = YList(self)
                                    self.remote_binding = YList(self)
                                    self._segment_path = lambda: "binding" + "[prefix='" + self.prefix.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding, ['prefix', 'advertise_prefix_acl', 'advertise_tsr_acl', 'config_enforced_local_label_value', 'is_elc', 'is_no_route', 'label_oor', 'le_local_binding_revision', 'le_local_label_state', 'local_label', 'prefix_length'], name, value)


                                class PeersAcked(Entity):
                                    """
                                    Peers that have ACKed this entry
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                        self.yang_name = "peers-acked"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                        self._segment_path = lambda: "peers-acked"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class PeersAdvertisedTo(Entity):
                                    """
                                    Peers this entry is advertised to
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                        self.yang_name = "peers-advertised-to"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                        self._segment_path = lambda: "peers-advertised-to"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "prefix-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class RemoteBinding(Entity):
                                    """
                                    Remote binding
                                    
                                    .. attribute:: assigning_peer_ldp_ident
                                    
                                    	Assigning peer
                                    	**type**\:   :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_stale
                                    
                                    	Is the entry stale
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                        self.yang_name = "remote-binding"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"assigning-peer-ldp-ident" : ("assigning_peer_ldp_ident", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent)}
                                        self._child_list_classes = {}

                                        self.is_elc = YLeaf(YType.boolean, "is-elc")

                                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.assigning_peer_ldp_ident = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                        self.assigning_peer_ldp_ident.parent = self
                                        self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                        self._children_yang_names.add("assigning-peer-ldp-ident")
                                        self._segment_path = lambda: "remote-binding"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, ['is_elc', 'is_stale', 'remote_label'], name, value)


                                    class AssigningPeerLdpIdent(Entity):
                                        """
                                        Assigning peer
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                            self.yang_name = "assigning-peer-ldp-ident"
                                            self.yang_parent_name = "remote-binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "assigning-peer-ldp-ident"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, ['id', 'name'], name, value)


                        class BindingsAdvertiseSpec(Entity):
                            """
                            Advertisement Spec (ACL) for LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: advt_acl
                            
                            	Advertisement ACLs
                            	**type**\: list of    :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                            
                            .. attribute:: allocation_acl
                            
                            	Local label Allocation filter
                            	**type**\:   :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                self.yang_name = "bindings-advertise-spec"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"allocation-acl" : ("allocation_acl", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)}
                                self._child_list_classes = {"advt-acl" : ("advt_acl", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl)}

                                self.allocation_acl = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                self.allocation_acl.parent = self
                                self._children_name_map["allocation_acl"] = "allocation-acl"
                                self._children_yang_names.add("allocation-acl")

                                self.advt_acl = YList(self)
                                self._segment_path = lambda: "bindings-advertise-spec"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                            class AdvtAcl(Entity):
                                """
                                Advertisement ACLs
                                
                                .. attribute:: peer_acl
                                
                                	Peer ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                    self.yang_name = "advt-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.peer_acl = YLeaf(YType.str, "peer-acl")

                                    self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                    self._segment_path = lambda: "advt-acl"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, ['peer_acl', 'prefix_acl'], name, value)


                            class AllocationAcl(Entity):
                                """
                                Local label Allocation filter
                                
                                .. attribute:: has_acl
                                
                                	Has ACL filter?
                                	**type**\:  bool
                                
                                .. attribute:: is_host_route_only
                                
                                	Host\-routes only?
                                	**type**\:  bool
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                    self.yang_name = "allocation-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.has_acl = YLeaf(YType.boolean, "has-acl")

                                    self.is_host_route_only = YLeaf(YType.boolean, "is-host-route-only")

                                    self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                    self._segment_path = lambda: "allocation-acl"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, ['has_acl', 'is_host_route_only', 'prefix_acl'], name, value)


                        class BindingsSummary(Entity):
                            """
                            Counters for the LDP Label Infomation Base
                            (LIB)
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.BindAf>`
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary, self).__init__()

                                self.yang_name = "bindings-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf)}
                                self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.BindAf)}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local = YLeaf(YType.uint32, "binding-local")

                                    self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                    self.binding_total = YLeaf(YType.uint32, "binding-total")

                                    self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                    self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                    self._segment_path = lambda: "bind-af"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummary.Vrf, ['id', 'name'], name, value)


                        class BindingsSummaryAll(Entity):
                            """
                            Aggregate VRF counters for the LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf>`
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll, self).__init__()

                                self.yang_name = "bindings-summary-all"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf)}
                                self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf)}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary-all"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary-all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local = YLeaf(YType.uint32, "binding-local")

                                    self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                    self.binding_total = YLeaf(YType.uint32, "binding-total")

                                    self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                    self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                    self._segment_path = lambda: "bind-af"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary-all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


                        class Discovery(Entity):
                            """
                            The LDP Discovery
                            
                            .. attribute:: brief
                            
                            	Brief information on LDP discovery
                            	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief>`
                            
                            .. attribute:: link_hellos
                            
                            	The LDP Discovery link
                            	**type**\:   :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos>`
                            
                            .. attribute:: stats
                            
                            	The LDP Discovery Statistics
                            	**type**\:   :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats>`
                            
                            .. attribute:: summary
                            
                            	Summarized information on LDP discovery
                            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary>`
                            
                            .. attribute:: targeted_hellos
                            
                            	The LDP Discovery Targeted
                            	**type**\:   :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery, self).__init__()

                                self.yang_name = "discovery"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"brief" : ("brief", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief), "link-hellos" : ("link_hellos", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos), "stats" : ("stats", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats), "summary" : ("summary", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary), "targeted-hellos" : ("targeted_hellos", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos)}
                                self._child_list_classes = {}

                                self.brief = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief()
                                self.brief.parent = self
                                self._children_name_map["brief"] = "brief"
                                self._children_yang_names.add("brief")

                                self.link_hellos = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos()
                                self.link_hellos.parent = self
                                self._children_name_map["link_hellos"] = "link-hellos"
                                self._children_yang_names.add("link-hellos")

                                self.stats = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats()
                                self.stats.parent = self
                                self._children_name_map["stats"] = "stats"
                                self._children_yang_names.add("stats")

                                self.summary = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"
                                self._children_yang_names.add("summary")

                                self.targeted_hellos = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos()
                                self.targeted_hellos.parent = self
                                self._children_name_map["targeted_hellos"] = "targeted-hellos"
                                self._children_yang_names.add("targeted-hellos")
                                self._segment_path = lambda: "discovery"


                            class Brief(Entity):
                                """
                                Brief information on LDP discovery
                                
                                .. attribute:: link_hello_briefs
                                
                                	The LDP Discovery link brief information
                                	**type**\:   :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                
                                .. attribute:: targeted_hello_briefs
                                
                                	The LDP Discovery Targeted brief information
                                	**type**\:   :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief, self).__init__()

                                    self.yang_name = "brief"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"link-hello-briefs" : ("link_hello_briefs", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs), "targeted-hello-briefs" : ("targeted_hello_briefs", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs)}
                                    self._child_list_classes = {}

                                    self.link_hello_briefs = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                    self.link_hello_briefs.parent = self
                                    self._children_name_map["link_hello_briefs"] = "link-hello-briefs"
                                    self._children_yang_names.add("link-hello-briefs")

                                    self.targeted_hello_briefs = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                    self.targeted_hello_briefs.parent = self
                                    self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                    self._children_yang_names.add("targeted-hello-briefs")
                                    self._segment_path = lambda: "brief"


                                class LinkHelloBriefs(Entity):
                                    """
                                    The LDP Discovery link brief information
                                    
                                    .. attribute:: link_hello_brief
                                    
                                    	Brief information on LDP link discovery
                                    	**type**\: list of    :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                        self.yang_name = "link-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"link-hello-brief" : ("link_hello_brief", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief)}

                                        self.link_hello_brief = YList(self)
                                        self._segment_path = lambda: "link-hello-briefs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                    class LinkHelloBrief(Entity):
                                        """
                                        Brief information on LDP link discovery
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: address_family
                                        
                                        	Discovery Brief Address Family
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: address_family_set
                                        
                                        	Discovery Brief Address Family Set
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                            self.yang_name = "link-hello-brief"
                                            self.yang_parent_name = "link-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)}
                                            self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.address_family = YLeaf(YType.enumeration, "address-family")

                                            self.address_family_set = YLeaf(YType.enumeration, "address-family-set")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', 'address_family', 'address_family_set', 'interface', 'interface_name_xr'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_up = YLeaf(YType.boolean, "session-up")
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, ['id', 'name'], name, value)


                                class TargetedHelloBriefs(Entity):
                                    """
                                    The LDP Discovery Targeted brief information
                                    
                                    .. attribute:: targeted_hello_brief
                                    
                                    	Brief information on LDP targeted discovery
                                    	**type**\: list of    :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                        self.yang_name = "targeted-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"targeted-hello-brief" : ("targeted_hello_brief", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief)}

                                        self.targeted_hello_brief = YList(self)
                                        self._segment_path = lambda: "targeted-hello-briefs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                    class TargetedHelloBrief(Entity):
                                        """
                                        Brief information on LDP targeted discovery
                                        
                                        .. attribute:: address_family
                                        
                                        	Targeted Discovery Address Family
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                            self.yang_name = "targeted-hello-brief"
                                            self.yang_parent_name = "targeted-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"dhcb-target-address" : ("dhcb_target_address", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress), "vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)}
                                            self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation)}

                                            self.address_family = YLeaf(YType.enumeration, "address-family")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.target_address = YLeaf(YType.str, "target-address")

                                            self.dhcb_target_address = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                            self._children_yang_names.add("dhcb-target-address")

                                            self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "targeted-hello-brief"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['address_family', 'local_address', 'target_address'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_up = YLeaf(YType.boolean, "session-up")
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, ['id', 'name'], name, value)


                            class LinkHellos(Entity):
                                """
                                The LDP Discovery link
                                
                                .. attribute:: link_hello
                                
                                	Information on LDP link discovery
                                	**type**\: list of    :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                    self.yang_name = "link-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"link-hello" : ("link_hello", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello)}

                                    self.link_hello = YList(self)
                                    self._segment_path = lambda: "link-hellos"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                class LinkHello(Entity):
                                    """
                                    Information on LDP link discovery
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: discovery_link_af
                                    
                                    	LDP hello AF info
                                    	**type**\: list of    :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                    
                                    .. attribute:: hello_information
                                    
                                    	LDP hello info
                                    	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                        self.yang_name = "link-hello"
                                        self.yang_parent_name = "link-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)}
                                        self._child_list_classes = {"discovery-link-af" : ("discovery_link_af", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf), "hello-information" : ("hello_information", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.next_hello = YLeaf(YType.uint32, "next-hello")

                                        self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                        self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.discovery_link_af = YList(self)
                                        self.hello_information = YList(self)
                                        self._segment_path = lambda: "link-hello" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', 'interface', 'interface_name_xr', 'next_hello', 'quick_start_disabled'], name, value)


                                    class DiscoveryLinkAf(Entity):
                                        """
                                        LDP hello AF info
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_src_address
                                        
                                        	Local source address
                                        	**type**\:   :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                        
                                        .. attribute:: local_transport_address
                                        
                                        	Local transport address
                                        	**type**\:   :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                            self.yang_name = "discovery-link-af"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-src-address" : ("local_src_address", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress), "local-transport-address" : ("local_transport_address", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress)}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.local_src_address = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                            self.local_src_address.parent = self
                                            self._children_name_map["local_src_address"] = "local-src-address"
                                            self._children_yang_names.add("local-src-address")

                                            self.local_transport_address = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                            self.local_transport_address.parent = self
                                            self._children_name_map["local_transport_address"] = "local-transport-address"
                                            self._children_yang_names.add("local-transport-address")
                                            self._segment_path = lambda: "discovery-link-af"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, ['interval'], name, value)


                                        class LocalSrcAddress(Entity):
                                            """
                                            Local source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                self.yang_name = "local-src-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-src-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class LocalTransportAddress(Entity):
                                            """
                                            Local transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                self.yang_name = "local-transport-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-transport-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class HelloInformation(Entity):
                                        """
                                        LDP hello info
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: hold_time
                                        
                                        	Session hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: is_no_route
                                        
                                        	Is route valid
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_targeted
                                        
                                        	Is session a targeted session
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_ldp_identifier
                                        
                                        	Neighbor LDP Identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_src_address
                                        
                                        	Neighbor source address
                                        	**type**\:   :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                        
                                        .. attribute:: neighbor_transport_address
                                        
                                        	Neighbor transport address
                                        	**type**\:   :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\:  str
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\:  bool
                                        
                                        .. attribute:: target
                                        
                                        	Target address
                                        	**type**\:   :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                            self.yang_name = "hello-information"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-src-address" : ("neighbor_src_address", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress), "neighbor-transport-address" : ("neighbor_transport_address", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress), "target" : ("target", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)}
                                            self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo)}

                                            self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                            self.established_age = YLeaf(YType.uint64, "established-age")

                                            self.established_time = YLeaf(YType.uint64, "established-time")

                                            self.hold_time = YLeaf(YType.uint32, "hold-time")

                                            self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                            self.is_targeted = YLeaf(YType.boolean, "is-targeted")

                                            self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                            self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                            self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                            self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                            self.session_up = YLeaf(YType.boolean, "session-up")

                                            self.neighbor_src_address = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                            self.neighbor_src_address.parent = self
                                            self._children_name_map["neighbor_src_address"] = "neighbor-src-address"
                                            self._children_yang_names.add("neighbor-src-address")

                                            self.neighbor_transport_address = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                            self.neighbor_transport_address.parent = self
                                            self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"
                                            self._children_yang_names.add("neighbor-transport-address")

                                            self.target = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                            self.target.parent = self
                                            self._children_name_map["target"] = "target"
                                            self._children_yang_names.add("target")

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "hello-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, ['disc_expiry', 'established_age', 'established_time', 'hold_time', 'is_no_route', 'is_targeted', 'local_hold_time', 'neighbor_hold_time', 'neighbor_ldp_identifier', 'session_bringup_failure_reason', 'session_up'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\:  str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                self._segment_path = lambda: "last-session-down-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                                        class NeighborSrcAddress(Entity):
                                            """
                                            Neighbor source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                self.yang_name = "neighbor-src-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "neighbor-src-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class NeighborTransportAddress(Entity):
                                            """
                                            Neighbor transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                self.yang_name = "neighbor-transport-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "neighbor-transport-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class Target(Entity):
                                            """
                                            Target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                self.yang_name = "target"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, ['id', 'name'], name, value)


                            class Stats(Entity):
                                """
                                The LDP Discovery Statistics
                                
                                .. attribute:: stat
                                
                                	Information on LDP discovery statistics
                                	**type**\: list of    :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats.Stat>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats, self).__init__()

                                    self.yang_name = "stats"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"stat" : ("stat", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats.Stat)}

                                    self.stat = YList(self)
                                    self._segment_path = lambda: "stats"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats, [], name, value)


                                class Stat(Entity):
                                    """
                                    Information on LDP discovery statistics
                                    
                                    .. attribute:: adjacency_group_up_time
                                    
                                    	Adjacency group up time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tcp_arb_chg_count
                                    
                                    	Count of changes in TCP arbitration
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_open_count
                                    
                                    	Count of attempted TCP opens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_role
                                    
                                    	TCP Role
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                        self.yang_name = "stat"
                                        self.yang_parent_name = "stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.adjacency_group_up_time = YLeaf(YType.uint32, "adjacency-group-up-time")

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.tcp_arb_chg_count = YLeaf(YType.uint32, "tcp-arb-chg-count")

                                        self.tcp_open_count = YLeaf(YType.uint32, "tcp-open-count")

                                        self.tcp_role = YLeaf(YType.uint32, "tcp-role")
                                        self._segment_path = lambda: "stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Stats.Stat, ['adjacency_group_up_time', 'label_space_id', 'lsr_id', 'tcp_arb_chg_count', 'tcp_open_count', 'tcp_role'], name, value)


                            class Summary(Entity):
                                """
                                Summarized information on LDP discovery
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP identifier
                                	**type**\:  str
                                
                                .. attribute:: num_of_active_ldp_interfaces
                                
                                	Number of active LDP enabled interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_addr_recv
                                
                                	Number of hello discoveries received with bad source address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_hello_pdu
                                
                                	Number of hello discoveries received with bad hello PDU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_xport_addr
                                
                                	Number of hello discoveries received with bad export address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_same_router_id
                                
                                	Number of hello discoveries received with the same router id as this router
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_wrong_router_id
                                
                                	Number of hello discoveries received with the router id that is not destined for this router
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_ldp_interfaces
                                
                                	Total Number of LDP configured interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_recv
                                
                                	Number of link hello discoveries in recv state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_xmit
                                
                                	Number of link hello discoveries in xmit state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_recv
                                
                                	Number of targeted hello discoveries in recv state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_xmit
                                
                                	Number of targeted hello discoveries in xmit state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary, self).__init__()

                                    self.yang_name = "summary"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf)}
                                    self._child_list_classes = {}

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                                    self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                                    self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                                    self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                                    self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                                    self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                                    self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                                    self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                                    self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                                    self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                                    self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                                    self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, ['id', 'name'], name, value)


                            class TargetedHellos(Entity):
                                """
                                The LDP Discovery Targeted
                                
                                .. attribute:: targeted_hello
                                
                                	Information on LDP targeted discovery
                                	**type**\: list of    :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                    self.yang_name = "targeted-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"targeted-hello" : ("targeted_hello", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello)}

                                    self.targeted_hello = YList(self)
                                    self._segment_path = lambda: "targeted-hellos"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                class TargetedHello(Entity):
                                    """
                                    Information on LDP targeted discovery
                                    
                                    .. attribute:: adjacency_ldp_identifier
                                    
                                    	Adjacency LDP Identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcb_local_address
                                    
                                    	DHCB local address
                                    	**type**\:   :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                    
                                    .. attribute:: dhcb_target_address
                                    
                                    	DHCB target address
                                    	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                    
                                    .. attribute:: disc_expiry
                                    
                                    	Discovery expiry time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: established_age
                                    
                                    	Hello adjacency estabished age in nanosec
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: established_time
                                    
                                    	Hello adjacency estabished time in nanosec
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: hold_time
                                    
                                    	Targeted hello hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval in sec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_session_down_info
                                    
                                    	Last session down information
                                    	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: local_hold_time
                                    
                                    	Local hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_hold_time
                                    
                                    	Neighbor hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: session_bringup_failure_reason
                                    
                                    	session bringup failure reason
                                    	**type**\:  str
                                    
                                    .. attribute:: session_up
                                    
                                    	Is session up for this adj
                                    	**type**\:  bool
                                    
                                    .. attribute:: state
                                    
                                    	Targeted hello state
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	The target IP Address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                        self.yang_name = "targeted-hello"
                                        self.yang_parent_name = "targeted-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"dhcb-local-address" : ("dhcb_local_address", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress), "dhcb-target-address" : ("dhcb_target_address", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)}
                                        self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo)}

                                        self.adjacency_ldp_identifier = YLeaf(YType.str, "adjacency-ldp-identifier")

                                        self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                        self.established_age = YLeaf(YType.uint64, "established-age")

                                        self.established_time = YLeaf(YType.uint64, "established-time")

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                        self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                        self.next_hello = YLeaf(YType.uint32, "next-hello")

                                        self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                        self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                        self.session_up = YLeaf(YType.boolean, "session-up")

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.target_address = YLeaf(YType.str, "target-address")

                                        self.dhcb_local_address = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                        self.dhcb_local_address.parent = self
                                        self._children_name_map["dhcb_local_address"] = "dhcb-local-address"
                                        self._children_yang_names.add("dhcb-local-address")

                                        self.dhcb_target_address = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                        self.dhcb_target_address.parent = self
                                        self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                        self._children_yang_names.add("dhcb-target-address")

                                        self.last_session_down_info = YList(self)
                                        self._segment_path = lambda: "targeted-hello"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['adjacency_ldp_identifier', 'disc_expiry', 'established_age', 'established_time', 'hold_time', 'interval', 'local_address', 'local_hold_time', 'neighbor_hold_time', 'next_hello', 'quick_start_disabled', 'session_bringup_failure_reason', 'session_up', 'state', 'target_address'], name, value)


                                    class DhcbLocalAddress(Entity):
                                        """
                                        DHCB local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                            self.yang_name = "dhcb-local-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "dhcb-local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class DhcbTargetAddress(Entity):
                                        """
                                        DHCB target address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                            self.yang_name = "dhcb-target-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "dhcb-target-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class LastSessionDownInfo(Entity):
                                        """
                                        Last session down information
                                        
                                        .. attribute:: last_session_down_reason
                                        
                                        	The reason of last socket failure
                                        	**type**\:  str
                                        
                                        .. attribute:: last_session_down_time
                                        
                                        	Timestamp of when the last session went down
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_session_up_time
                                        
                                        	The time duration the last session was up
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                            self.yang_name = "last-session-down-info"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                            self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                            self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                            self._segment_path = lambda: "last-session-down-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                        class ForwardingSummary(Entity):
                            """
                            Summary information regarding LDP forwarding
                            setup
                            
                            .. attribute:: fsht
                            
                            	Forwarding state hold time registered with LSD
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: intfs
                            
                            	MPLS forwarding enabled interface count
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_lsd_bound
                            
                            	LDP is connected to LSD server
                            	**type**\:  bool
                            
                            .. attribute:: lbls
                            
                            	Local label allocated count
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: rws
                            
                            	Forwarding rewrites summary
                            	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary, self).__init__()

                                self.yang_name = "forwarding-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"rws" : ("rws", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws), "vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf)}
                                self._child_list_classes = {}

                                self.fsht = YLeaf(YType.uint16, "fsht")

                                self.intfs = YLeaf(YType.uint16, "intfs")

                                self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                                self.lbls = YLeaf(YType.uint16, "lbls")

                                self.rws = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws()
                                self.rws.parent = self
                                self._children_name_map["rws"] = "rws"
                                self._children_yang_names.add("rws")

                                self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "forwarding-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                            class Rws(Entity):
                                """
                                Forwarding rewrites summary
                                
                                .. attribute:: nhs
                                
                                	Forwarding rewrites nexthops (paths) summary
                                	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                
                                .. attribute:: pfxs
                                
                                	Forwarding rewrites prefix summary
                                	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                    self.yang_name = "rws"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs)}
                                    self._child_list_classes = {}

                                    self.nhs = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                    self.nhs.parent = self
                                    self._children_name_map["nhs"] = "nhs"
                                    self._children_yang_names.add("nhs")

                                    self.pfxs = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                    self.pfxs.parent = self
                                    self._children_name_map["pfxs"] = "pfxs"
                                    self._children_yang_names.add("pfxs")
                                    self._segment_path = lambda: "rws"


                                class Nhs(Entity):
                                    """
                                    Forwarding rewrites nexthops (paths) summary
                                    
                                    .. attribute:: backup_paths
                                    
                                    	Count of non\-primary backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_backup_paths
                                    
                                    	Count of labeled backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_paths
                                    
                                    	Count of all labeled paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: protected_paths
                                    
                                    	Count of FRR protected paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_backup_paths
                                    
                                    	Count of non\-primary remote backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_paths
                                    
                                    	Total path count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                        self.yang_name = "nhs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                                        self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                                        self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                                        self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                                        self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                                        self.total_paths = YLeaf(YType.uint32, "total-paths")
                                        self._segment_path = lambda: "nhs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                                class Pfxs(Entity):
                                    """
                                    Forwarding rewrites prefix summary
                                    
                                    .. attribute:: ecmp_pfxs
                                    
                                    	Count of prefixes with ECMP
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: labeled_pfxs_aggr
                                    
                                    	Labeled prefix count for all paths
                                    	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                    
                                    .. attribute:: labeled_pfxs_backup
                                    
                                    	Labeled prefix count related to backup paths only
                                    	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                    
                                    .. attribute:: labeled_pfxs_primary
                                    
                                    	Labeled prefix count related to primary paths only
                                    	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                    
                                    .. attribute:: protected_pfxs
                                    
                                    	Count of FRR protected prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: total_pfxs
                                    
                                    	Total Prefix count
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                        self.yang_name = "pfxs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)}
                                        self._child_list_classes = {}

                                        self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                                        self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                                        self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                                        self.labeled_pfxs_aggr = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                        self.labeled_pfxs_aggr.parent = self
                                        self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                                        self._children_yang_names.add("labeled-pfxs-aggr")

                                        self.labeled_pfxs_backup = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                        self.labeled_pfxs_backup.parent = self
                                        self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                        self._children_yang_names.add("labeled-pfxs-backup")

                                        self.labeled_pfxs_primary = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                        self.labeled_pfxs_primary.parent = self
                                        self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                                        self._children_yang_names.add("labeled-pfxs-primary")
                                        self._segment_path = lambda: "pfxs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                                    class LabeledPfxsAggr(Entity):
                                        """
                                        Labeled prefix count for all paths
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                            self.yang_name = "labeled-pfxs-aggr"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-aggr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsBackup(Entity):
                                        """
                                        Labeled prefix count related to backup paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                            self.yang_name = "labeled-pfxs-backup"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-backup"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsPrimary(Entity):
                                        """
                                        Labeled prefix count related to primary paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                            self.yang_name = "labeled-pfxs-primary"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-primary"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, ['id', 'name'], name, value)


                        class Forwardings(Entity):
                            """
                            The LDP Forwarding rewrites
                            
                            .. attribute:: forwarding
                            
                            	Information on a particular LDP forwarding rewrite
                            	**type**\: list of    :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings, self).__init__()

                                self.yang_name = "forwardings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"forwarding" : ("forwarding", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding)}

                                self.forwarding = YList(self)
                                self._segment_path = lambda: "forwardings"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings, [], name, value)


                            class Forwarding(Entity):
                                """
                                Information on a particular LDP forwarding
                                rewrite
                                
                                .. attribute:: prefix  <key>
                                
                                	The IP Prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: paths
                                
                                	Paths
                                	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                
                                .. attribute:: route
                                
                                	Route
                                	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route>`
                                
                                .. attribute:: table_id
                                
                                	Table ID associated with IP prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                    self.yang_name = "forwarding"
                                    self.yang_parent_name = "forwardings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr), "route" : ("route", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route), "vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf)}
                                    self._child_list_classes = {"paths" : ("paths", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                    self.table_id = YLeaf(YType.uint32, "table-id")

                                    self.prefix_xr = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"
                                    self._children_yang_names.add("prefix-xr")

                                    self.route = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route()
                                    self.route.parent = self
                                    self._children_name_map["route"] = "route"
                                    self._children_yang_names.add("route")

                                    self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.paths = YList(self)
                                    self._segment_path = lambda: "forwarding" + "[prefix='" + self.prefix.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding, ['prefix', 'prefix_length', 'table_id'], name, value)


                                class Paths(Entity):
                                    """
                                    Paths
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                        self.yang_name = "paths"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls), "routing" : ("routing", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)}
                                        self._child_list_classes = {}

                                        self.mpls = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._children_yang_names.add("mpls")

                                        self.routing = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"
                                        self._children_yang_names.add("routing")
                                        self._segment_path = lambda: "paths"


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: mpls_outgoing_info
                                        
                                        	MPLS nexthop info
                                        	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo), "remote-lfa" : ("remote_lfa", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa)}
                                            self._child_list_classes = {}

                                            self.mpls_outgoing_info = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                            self.mpls_outgoing_info.parent = self
                                            self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                            self._children_yang_names.add("mpls-outgoing-info")

                                            self.remote_lfa = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")
                                            self._segment_path = lambda: "mpls"


                                        class MplsOutgoingInfo(Entity):
                                            """
                                            MPLS nexthop info
                                            
                                            .. attribute:: is_from_graceful_restartable_neighbor
                                            
                                            	Is from a GR neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_stale
                                            
                                            	Is the entry stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_peer_ldp_ident
                                            
                                            	Nexthop LDP peer
                                            	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                            
                                            .. attribute:: out_label
                                            
                                            	Outgoing label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_label_owner
                                            
                                            	Outgoing label owner
                                            	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                            
                                            .. attribute:: out_label_rsn
                                            
                                            	Outgoing label reason
                                            	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                            
                                            .. attribute:: out_label_type
                                            
                                            	Outgoing Label Type
                                            	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                self.yang_name = "mpls-outgoing-info"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent)}
                                                self._child_list_classes = {}

                                                self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                self.out_label = YLeaf(YType.uint32, "out-label")

                                                self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                self.nexthop_peer_ldp_ident = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                self.nexthop_peer_ldp_ident.parent = self
                                                self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                self._segment_path = lambda: "mpls-outgoing-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                            class NexthopPeerLdpIdent(Entity):
                                                """
                                                Nexthop LDP peer
                                                
                                                .. attribute:: label_space_id
                                                
                                                	Label space identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ldp_id
                                                
                                                	LDP identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: lsr_id
                                                
                                                	LSR identifier
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                    self.yang_name = "nexthop-peer-ldp-ident"
                                                    self.yang_parent_name = "mpls-outgoing-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                    self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                    self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                    self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	Remote LFA MPLS nexthop(s\_ info
                                            	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo)}
                                                self._child_list_classes = {}

                                                self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                self.mpls_outgoing_info = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._children_yang_names.add("mpls-outgoing-info")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, ['has_remote_lfa_bkup'], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                Remote LFA MPLS nexthop(s\_ info
                                                
                                                .. attribute:: stack
                                                
                                                	Inner label stack info
                                                	**type**\: list of    :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"stack" : ("stack", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack)}

                                                    self.stack = YList(self)
                                                    self._segment_path = lambda: "mpls-outgoing-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                class Stack(Entity):
                                                    """
                                                    Inner label stack info
                                                    
                                                    .. attribute:: is_from_graceful_restartable_neighbor
                                                    
                                                    	Is from a GR neighbor
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_stale
                                                    
                                                    	Is the entry stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nexthop_peer_ldp_ident
                                                    
                                                    	Nexthop LDP peer
                                                    	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                    
                                                    .. attribute:: out_label
                                                    
                                                    	Outgoing label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: out_label_owner
                                                    
                                                    	Outgoing label owner
                                                    	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                    
                                                    .. attribute:: out_label_rsn
                                                    
                                                    	Outgoing label reason
                                                    	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                    
                                                    .. attribute:: out_label_type
                                                    
                                                    	Outgoing Label Type
                                                    	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                        self.yang_name = "stack"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent)}
                                                        self._child_list_classes = {}

                                                        self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                        self.out_label = YLeaf(YType.uint32, "out-label")

                                                        self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                        self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                        self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                        self.nexthop_peer_ldp_ident = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                        self.nexthop_peer_ldp_ident.parent = self
                                                        self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                        self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                        self._segment_path = lambda: "stack"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                    class NexthopPeerLdpIdent(Entity):
                                                        """
                                                        Nexthop LDP peer
                                                        
                                                        .. attribute:: label_space_id
                                                        
                                                        	Label space identifier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ldp_id
                                                        
                                                        	LDP identifier
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: lsr_id
                                                        
                                                        	LSR identifier
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                            self.yang_name = "nexthop-peer-ldp-ident"
                                                            self.yang_parent_name = "stack"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                            self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: bkup_path_id
                                        
                                        	Backup path Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: flags
                                        
                                        	Route path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface Name
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	Path's load metric for load balancing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next Hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                        
                                        .. attribute:: next_hop_table_id
                                        
                                        	Table ID for nexthop address
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	Nexthop Identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_is_overriden
                                        
                                        	Nexthop is overriden by LDP
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_flags
                                        
                                        	Routing path flags decoded
                                        	**type**\:   :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                        
                                        .. attribute:: path_id
                                        
                                        	path Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop" : ("next_hop", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop), "remote-lfa" : ("remote_lfa", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa)}
                                            self._child_list_classes = {}

                                            self.bkup_path_id = YLeaf(YType.uint8, "bkup-path-id")

                                            self.flags = YLeaf(YType.uint32, "flags")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                            self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                            self.nh_is_overriden = YLeaf(YType.boolean, "nh-is-overriden")

                                            self.path_flags = YLeaf(YType.enumeration, "path-flags")

                                            self.path_id = YLeaf(YType.uint8, "path-id")

                                            self.next_hop = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.remote_lfa = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")
                                            self._segment_path = lambda: "routing"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, ['bkup_path_id', 'flags', 'interface', 'interface_name', 'load_metric', 'next_hop_table_id', 'nexthop_id', 'nh_is_overriden', 'path_flags', 'path_id'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next Hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: has_q_node
                                            
                                            	Whether remote LFA path has a Q node associated
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: needs_tldp
                                            
                                            	Whether TLDP is needed with remote PQ node
                                            	**type**\:  bool
                                            
                                            .. attribute:: remote_p_node_id
                                            
                                            	Remote/P node address
                                            	**type**\:   :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                            
                                            .. attribute:: remote_q_node_id
                                            
                                            	Remote/Q node address
                                            	**type**\:   :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"remote-p-node-id" : ("remote_p_node_id", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId), "remote-q-node-id" : ("remote_q_node_id", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId)}
                                                self._child_list_classes = {}

                                                self.has_q_node = YLeaf(YType.boolean, "has-q-node")

                                                self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                self.needs_tldp = YLeaf(YType.boolean, "needs-tldp")

                                                self.remote_p_node_id = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                self.remote_p_node_id.parent = self
                                                self._children_name_map["remote_p_node_id"] = "remote-p-node-id"
                                                self._children_yang_names.add("remote-p-node-id")

                                                self.remote_q_node_id = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                self.remote_q_node_id.parent = self
                                                self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                self._children_yang_names.add("remote-q-node-id")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, ['has_q_node', 'has_remote_lfa_bkup', 'needs_tldp'], name, value)


                                            class RemotePNodeId(Entity):
                                                """
                                                Remote/P node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                    self.yang_name = "remote-p-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "remote-p-node-id"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class RemoteQNodeId(Entity):
                                                """
                                                Remote/Q node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                    self.yang_name = "remote-q-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "remote-q-node-id"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "prefix-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class Route(Entity):
                                    """
                                    Route
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                        self.yang_name = "route"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls), "routing" : ("routing", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing)}
                                        self._child_list_classes = {}

                                        self.mpls = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._children_yang_names.add("mpls")

                                        self.routing = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"
                                        self._children_yang_names.add("routing")
                                        self._segment_path = lambda: "route"


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: forwarding_update_age
                                        
                                        	Last Forwarding update nanosec age
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: forwarding_update_count
                                        
                                        	Number of forwarding updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_timestamp
                                        
                                        	Last Forwarding update nanosec timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.forwarding_update_age = YLeaf(YType.uint64, "forwarding-update-age")

                                            self.forwarding_update_count = YLeaf(YType.uint32, "forwarding-update-count")

                                            self.forwarding_update_timestamp = YLeaf(YType.uint64, "forwarding-update-timestamp")

                                            self.local_label = YLeaf(YType.uint32, "local-label")
                                            self._segment_path = lambda: "mpls"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, ['forwarding_update_age', 'forwarding_update_count', 'forwarding_update_timestamp', 'local_label'], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: flags
                                        
                                        	Route RIB flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_local_vrf_leaked
                                        
                                        	Is route leaked across local VRFs?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Route metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Route priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: routing_update_age
                                        
                                        	Last Routing update nanosec age
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: routing_update_count
                                        
                                        	Number of routing updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: routing_update_timestamp
                                        
                                        	Last Routing update nanosec timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: source
                                        
                                        	Route source protol Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sr_local_label
                                        
                                        	SR Local\-label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: type
                                        
                                        	Route type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: version
                                        
                                        	Route RIB ersion
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.flags = YLeaf(YType.uint32, "flags")

                                            self.is_local_vrf_leaked = YLeaf(YType.boolean, "is-local-vrf-leaked")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.priority = YLeaf(YType.uint8, "priority")

                                            self.routing_update_age = YLeaf(YType.uint64, "routing-update-age")

                                            self.routing_update_count = YLeaf(YType.uint32, "routing-update-count")

                                            self.routing_update_timestamp = YLeaf(YType.uint64, "routing-update-timestamp")

                                            self.source = YLeaf(YType.uint16, "source")

                                            self.sr_local_label = YLeaf(YType.uint32, "sr-local-label")

                                            self.type = YLeaf(YType.uint16, "type")

                                            self.version = YLeaf(YType.uint32, "version")
                                            self._segment_path = lambda: "routing"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, ['flags', 'is_local_vrf_leaked', 'metric', 'priority', 'routing_update_age', 'routing_update_count', 'routing_update_timestamp', 'source', 'sr_local_label', 'type', 'version'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, ['id', 'name'], name, value)


                        class Igp(Entity):
                            """
                            LDP IGP related information
                            
                            .. attribute:: sync_delay_restart
                            
                            	LDP\-IGP Synchronization Delay related information
                            	**type**\:   :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart>`
                            
                            .. attribute:: syncs
                            
                            	LDP IGP Sync related information
                            	**type**\:   :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp, self).__init__()

                                self.yang_name = "igp"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sync-delay-restart" : ("sync_delay_restart", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart), "syncs" : ("syncs", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs)}
                                self._child_list_classes = {}

                                self.sync_delay_restart = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart()
                                self.sync_delay_restart.parent = self
                                self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                self._children_yang_names.add("sync-delay-restart")

                                self.syncs = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs()
                                self.syncs.parent = self
                                self._children_name_map["syncs"] = "syncs"
                                self._children_yang_names.add("syncs")
                                self._segment_path = lambda: "igp"


                            class SyncDelayRestart(Entity):
                                """
                                LDP\-IGP Synchronization Delay related
                                information
                                
                                .. attribute:: configured
                                
                                	Is restart delay configured
                                	**type**\:  bool
                                
                                .. attribute:: delay_secs
                                
                                	Delay time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remaining_secs
                                
                                	Delay timer remaining time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: timer_running
                                
                                	Is restart delay timer running
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                    self.yang_name = "sync-delay-restart"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.configured = YLeaf(YType.boolean, "configured")

                                    self.delay_secs = YLeaf(YType.uint32, "delay-secs")

                                    self.remaining_secs = YLeaf(YType.uint32, "remaining-secs")

                                    self.timer_running = YLeaf(YType.boolean, "timer-running")
                                    self._segment_path = lambda: "sync-delay-restart"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, ['configured', 'delay_secs', 'remaining_secs', 'timer_running'], name, value)


                            class Syncs(Entity):
                                """
                                LDP IGP Sync related information
                                
                                .. attribute:: sync
                                
                                	LDP\-IGP Synchronization related information for an interface
                                	**type**\: list of    :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs, self).__init__()

                                    self.yang_name = "syncs"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sync" : ("sync", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync)}

                                    self.sync = YList(self)
                                    self._segment_path = lambda: "syncs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs, [], name, value)


                                class Sync(Entity):
                                    """
                                    LDP\-IGP Synchronization related information
                                    for an interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: delay_timer_remaining
                                    
                                    	Remaining timer (seconds) till expiry of sync delay timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_only_peer
                                    
                                    	Interface GR\-only reachable peers
                                    	**type**\: list of    :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                    
                                    .. attribute:: igp_sync_delay
                                    
                                    	IGP sync delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: igp_sync_down_reason
                                    
                                    	Reason IGP Sync Not Achieved
                                    	**type**\:   :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                    
                                    .. attribute:: igp_sync_state
                                    
                                    	IGP Sync state
                                    	**type**\:   :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_delay_timer_running
                                    
                                    	Is sync delay timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: peers
                                    
                                    	Interface Peers
                                    	**type**\: list of    :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                        self.yang_name = "sync"
                                        self.yang_parent_name = "syncs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf)}
                                        self._child_list_classes = {"gr-only-peer" : ("gr_only_peer", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer), "peers" : ("peers", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.delay_timer_remaining = YLeaf(YType.uint32, "delay-timer-remaining")

                                        self.igp_sync_delay = YLeaf(YType.uint32, "igp-sync-delay")

                                        self.igp_sync_down_reason = YLeaf(YType.enumeration, "igp-sync-down-reason")

                                        self.igp_sync_state = YLeaf(YType.enumeration, "igp-sync-state")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.is_delay_timer_running = YLeaf(YType.boolean, "is-delay-timer-running")

                                        self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.gr_only_peer = YList(self)
                                        self.peers = YList(self)
                                        self._segment_path = lambda: "sync" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', 'delay_timer_remaining', 'igp_sync_delay', 'igp_sync_down_reason', 'igp_sync_state', 'interface_name_xr', 'is_delay_timer_running'], name, value)


                                    class GrOnlyPeer(Entity):
                                        """
                                        Interface GR\-only reachable peers
                                        
                                        .. attribute:: is_chkpt_created
                                        
                                        	Is created due to checkpointing
                                        	**type**\:  bool
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                            self.yang_name = "gr-only-peer"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.is_chkpt_created = YLeaf(YType.boolean, "is-chkpt-created")

                                            self.peer_id = YLeaf(YType.str, "peer-id")
                                            self._segment_path = lambda: "gr-only-peer"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, ['is_chkpt_created', 'peer_id'], name, value)


                                    class Peers(Entity):
                                        """
                                        Interface Peers
                                        
                                        .. attribute:: is_gr_enabled
                                        
                                        	Is GR enabled session
                                        	**type**\:  bool
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                            self.yang_name = "peers"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                                            self.peer_id = YLeaf(YType.str, "peer-id")
                                            self._segment_path = lambda: "peers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, ['is_gr_enabled', 'peer_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, ['id', 'name'], name, value)


                        class InterfaceSummary(Entity):
                            """
                            IPv4 interface summary information
                            
                            .. attribute:: auto_config
                            
                            	Auto\-configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_disabled
                            
                            	Autoconfigure disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_forward_reference_interfaces
                            
                            	Auto\-configured forward references
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_references
                            
                            	Number of forward referenced interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_count
                            
                            	Number of known IP Interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_ldp_enabled
                            
                            	Number of known IP Interfaces with LDP Enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_attached_interface
                            
                            	Number of attached interfaces configured in LDP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_te_interface
                            
                            	Number of TE tunnel interfaces configured in LDP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.InterfaceSummary, self).__init__()

                                self.yang_name = "interface-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.auto_config = YLeaf(YType.uint32, "auto-config")

                                self.auto_config_disabled = YLeaf(YType.uint32, "auto-config-disabled")

                                self.auto_config_forward_reference_interfaces = YLeaf(YType.uint32, "auto-config-forward-reference-interfaces")

                                self.forward_references = YLeaf(YType.uint32, "forward-references")

                                self.known_ip_interface_count = YLeaf(YType.uint32, "known-ip-interface-count")

                                self.known_ip_interface_ldp_enabled = YLeaf(YType.uint32, "known-ip-interface-ldp-enabled")

                                self.ldp_configured_attached_interface = YLeaf(YType.uint32, "ldp-configured-attached-interface")

                                self.ldp_configured_te_interface = YLeaf(YType.uint32, "ldp-configured-te-interface")
                                self._segment_path = lambda: "interface-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.InterfaceSummary, ['auto_config', 'auto_config_disabled', 'auto_config_forward_reference_interfaces', 'forward_references', 'known_ip_interface_count', 'known_ip_interface_ldp_enabled', 'ldp_configured_attached_interface', 'ldp_configured_te_interface'], name, value)


                        class Interfaces(Entity):
                            """
                            LDP Interface related information
                            
                            .. attribute:: interface
                            
                            	IPv4 interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface" : ("interface", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface)}

                                self.interface = YList(self)
                                self._segment_path = lambda: "interfaces"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces, [], name, value)


                            class Interface(Entity):
                                """
                                IPv4 interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	The Interface Name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: auto_config
                                
                                	Auto config
                                	**type**\: list of    :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                
                                .. attribute:: interface
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\:  str
                                
                                .. attribute:: is_im_stale
                                
                                	Is IM information stale
                                	**type**\:  bool
                                
                                .. attribute:: ldp_autoconfig_disable
                                
                                	LDP autoconfig disable
                                	**type**\:  bool
                                
                                .. attribute:: ldp_config_mode
                                
                                	LDP config mode
                                	**type**\:  bool
                                
                                .. attribute:: ldp_enabled
                                
                                	LDP enabled
                                	**type**\:  bool
                                
                                .. attribute:: te_mesh_grp
                                
                                	TE tunnel mesh\-group
                                	**type**\: list of    :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf)}
                                    self._child_list_classes = {"auto-config" : ("auto_config", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig), "te-mesh-grp" : ("te_mesh_grp", MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface = YLeaf(YType.str, "interface")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.is_im_stale = YLeaf(YType.boolean, "is-im-stale")

                                    self.ldp_autoconfig_disable = YLeaf(YType.boolean, "ldp-autoconfig-disable")

                                    self.ldp_config_mode = YLeaf(YType.boolean, "ldp-config-mode")

                                    self.ldp_enabled = YLeaf(YType.boolean, "ldp-enabled")

                                    self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.auto_config = YList(self)
                                    self.te_mesh_grp = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface, ['interface_name', 'interface', 'interface_name_xr', 'is_im_stale', 'ldp_autoconfig_disable', 'ldp_config_mode', 'ldp_enabled'], name, value)


                                class AutoConfig(Entity):
                                    """
                                    Auto config
                                    
                                    .. attribute:: tuple
                                    
                                    	Tuple
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                        self.yang_name = "auto-config"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.tuple = YLeaf(YType.str, "tuple")
                                        self._segment_path = lambda: "auto-config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, ['tuple'], name, value)


                                class TeMeshGrp(Entity):
                                    """
                                    TE tunnel mesh\-group
                                    
                                    .. attribute:: ldp_mesh_group_enabled
                                    
                                    	LDP has enabled this TE mesh\-group
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_te_mesh_group_all_cfgd
                                    
                                    	LDP has enabled all TE mesh\-groups
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_mesh_group_id
                                    
                                    	TE tunnel Mesh Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                        self.yang_name = "te-mesh-grp"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ldp_mesh_group_enabled = YLeaf(YType.boolean, "ldp-mesh-group-enabled")

                                        self.ldp_te_mesh_group_all_cfgd = YLeaf(YType.boolean, "ldp-te-mesh-group-all-cfgd")

                                        self.te_mesh_group_id = YLeaf(YType.uint32, "te-mesh-group-id")
                                        self._segment_path = lambda: "te-mesh-grp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, ['ldp_mesh_group_enabled', 'ldp_te_mesh_group_all_cfgd', 'te_mesh_group_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, ['id', 'name'], name, value)


                class BackoffParameters(Entity):
                    """
                    The LDP Backoff Parameters
                    
                    .. attribute:: initial_seconds
                    
                    	Initial backoff value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: maximum_seconds
                    
                    	Maximum backoff value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.BackoffParameters, self).__init__()

                        self.yang_name = "backoff-parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.initial_seconds = YLeaf(YType.uint32, "initial-seconds")

                        self.maximum_seconds = YLeaf(YType.uint32, "maximum-seconds")
                        self._segment_path = lambda: "backoff-parameters"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.BackoffParameters, ['initial_seconds', 'maximum_seconds'], name, value)


                class Backoffs(Entity):
                    """
                    The LDP backoff
                    
                    .. attribute:: backoff
                    
                    	LDP Backoff Information
                    	**type**\: list of    :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Backoffs.Backoff>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Backoffs, self).__init__()

                        self.yang_name = "backoffs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"backoff" : ("backoff", MplsLdp.Global_.Standby.DefaultVrf.Backoffs.Backoff)}

                        self.backoff = YList(self)
                        self._segment_path = lambda: "backoffs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Backoffs, [], name, value)


                    class Backoff(Entity):
                        """
                        LDP Backoff Information
                        
                        .. attribute:: backoff_seconds
                        
                        	Backoff seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: waiting_seconds
                        
                        	Backoff waiting seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Backoffs.Backoff, self).__init__()

                            self.yang_name = "backoff"
                            self.yang_parent_name = "backoffs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.backoff_seconds = YLeaf(YType.uint32, "backoff-seconds")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.waiting_seconds = YLeaf(YType.uint32, "waiting-seconds")
                            self._segment_path = lambda: "backoff"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/backoffs/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Backoffs.Backoff, ['backoff_seconds', 'label_space_id', 'lsr_id', 'waiting_seconds'], name, value)


                class Capabilities(Entity):
                    """
                    LDP capability database information
                    
                    .. attribute:: capability
                    
                    	Information on LDP capability
                    	**type**\: list of    :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Capabilities, self).__init__()

                        self.yang_name = "capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"capability" : ("capability", MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability)}

                        self.capability = YList(self)
                        self._segment_path = lambda: "capabilities"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Capabilities, [], name, value)


                    class Capability(Entity):
                        """
                        Information on LDP capability
                        
                        .. attribute:: capability_type  <key>
                        
                        	The capability type (IANA assigned)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: capability
                        
                        	Capability information
                        	**type**\:   :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability.Capability>`
                        
                        .. attribute:: capability_owner
                        
                        	Capability owner
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability, self).__init__()

                            self.yang_name = "capability"
                            self.yang_parent_name = "capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"capability" : ("capability", MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability.Capability)}
                            self._child_list_classes = {}

                            self.capability_type = YLeaf(YType.int32, "capability-type")

                            self.capability_owner = YLeaf(YType.str, "capability-owner")

                            self.capability = MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability.Capability()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"
                            self._children_yang_names.add("capability")
                            self._segment_path = lambda: "capability" + "[capability-type='" + self.capability_type.get() + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/capabilities/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability, ['capability_type', 'capability_owner'], name, value)


                        class Capability(Entity):
                            """
                            Capability information
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "capability"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Capabilities.Capability.Capability, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                class GracefulRestart(Entity):
                    """
                    LDP Graceful Restart info
                    
                    .. attribute:: forwarding_state_hold_timer_remaining_seconds
                    
                    	Forwarding state hold timer remaining time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: graceful_restartable_neighbor
                    
                    	Vector of graceful restart neighbor information
                    	**type**\: list of    :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor>`
                    
                    .. attribute:: is_forwarding_state_hold_timer_running
                    
                    	Is graceful restart forwarding state hold timer running
                    	**type**\:  bool
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.Vrf>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.Vrf)}
                        self._child_list_classes = {"graceful-restartable-neighbor" : ("graceful_restartable_neighbor", MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor)}

                        self.forwarding_state_hold_timer_remaining_seconds = YLeaf(YType.uint32, "forwarding-state-hold-timer-remaining-seconds")

                        self.is_forwarding_state_hold_timer_running = YLeaf(YType.boolean, "is-forwarding-state-hold-timer-running")

                        self.vrf = MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._children_yang_names.add("vrf")

                        self.graceful_restartable_neighbor = YList(self)
                        self._segment_path = lambda: "graceful-restart"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart, ['forwarding_state_hold_timer_remaining_seconds', 'is_forwarding_state_hold_timer_running'], name, value)


                    class GracefulRestartableNeighbor(Entity):
                        """
                        Vector of graceful restart neighbor information
                        
                        .. attribute:: connect_count
                        
                        	ConnectCount
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_address
                        
                        	Addresses bound to GR down Nbr
                        	**type**\: list of    :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                        
                        .. attribute:: down_nbr_down_reason
                        
                        	Session down reason code
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flags
                        
                        	Flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flap_count
                        
                        	Count of back2back flaps
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: down_nbr_interface
                        
                        	Interfaces bound to GR down Nbr
                        	**type**\: list of    :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                        
                        .. attribute:: gr_peer
                        
                        	GR peer LDP Id
                        	**type**\:   :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                        
                        .. attribute:: is_liveness_timer_running
                        
                        	Is liveness timer running
                        	**type**\:  bool
                        
                        .. attribute:: is_neighbor_up
                        
                        	Is neighbor up
                        	**type**\:  bool
                        
                        .. attribute:: is_recovery_timer_running
                        
                        	Is recovery timer running
                        	**type**\:  bool
                        
                        .. attribute:: liveness_timer_remaining_seconds
                        
                        	Remaining time from liveness timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: recovery_timer_remaining_seconds
                        
                        	Recovery timer remining time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                            self.yang_name = "graceful-restartable-neighbor"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"gr-peer" : ("gr_peer", MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)}
                            self._child_list_classes = {"down-nbr-address" : ("down_nbr_address", MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress), "down-nbr-interface" : ("down_nbr_interface", MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)}

                            self.connect_count = YLeaf(YType.uint32, "connect-count")

                            self.down_nbr_down_reason = YLeaf(YType.uint32, "down-nbr-down-reason")

                            self.down_nbr_flags = YLeaf(YType.uint32, "down-nbr-flags")

                            self.down_nbr_flap_count = YLeaf(YType.uint8, "down-nbr-flap-count")

                            self.is_liveness_timer_running = YLeaf(YType.boolean, "is-liveness-timer-running")

                            self.is_neighbor_up = YLeaf(YType.boolean, "is-neighbor-up")

                            self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

                            self.liveness_timer_remaining_seconds = YLeaf(YType.uint32, "liveness-timer-remaining-seconds")

                            self.recovery_timer_remaining_seconds = YLeaf(YType.uint32, "recovery-timer-remaining-seconds")

                            self.gr_peer = MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                            self.gr_peer.parent = self
                            self._children_name_map["gr_peer"] = "gr-peer"
                            self._children_yang_names.add("gr-peer")

                            self.down_nbr_address = YList(self)
                            self.down_nbr_interface = YList(self)
                            self._segment_path = lambda: "graceful-restartable-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, ['connect_count', 'down_nbr_down_reason', 'down_nbr_flags', 'down_nbr_flap_count', 'is_liveness_timer_running', 'is_neighbor_up', 'is_recovery_timer_running', 'liveness_timer_remaining_seconds', 'recovery_timer_remaining_seconds'], name, value)


                        class DownNbrAddress(Entity):
                            """
                            Addresses bound to GR down Nbr
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                self.yang_name = "down-nbr-address"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.dummy = YLeaf(YType.uint8, "dummy")

                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                self._segment_path = lambda: "down-nbr-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class DownNbrInterface(Entity):
                            """
                            Interfaces bound to GR down Nbr
                            
                            .. attribute:: address_family
                            
                            	Interface adj Address Family
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: interface_handle
                            
                            	Interfaces handle
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                self.yang_name = "down-nbr-interface"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")
                                self._segment_path = lambda: "down-nbr-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, ['address_family', 'interface_handle'], name, value)


                        class GrPeer(Entity):
                            """
                            GR peer LDP Id
                            
                            .. attribute:: label_space_id
                            
                            	Label space identifier
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_id
                            
                            	LDP identifier
                            	**type**\:  str
                            
                            .. attribute:: lsr_id
                            
                            	LSR identifier
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                self.yang_name = "gr-peer"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                self._segment_path = lambda: "gr-peer"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/graceful-restartable-neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.id = YLeaf(YType.uint32, "id")

                            self.name = YLeaf(YType.str, "name")
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/graceful-restart/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.GracefulRestart.Vrf, ['id', 'name'], name, value)


                class Issu(Entity):
                    """
                    LDP ISSU related information
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Issu, self).__init__()

                        self.yang_name = "issu"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary)}
                        self._child_list_classes = {}

                        self.ha_statistics = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._children_yang_names.add("ha-statistics")

                        self.ha_summary = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"
                        self._children_yang_names.add("ha-summary")
                        self._segment_path = lambda: "issu"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_global = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"
                            self._children_yang_names.add("ha-global")

                            self.ha_neighbors = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "ha-statistics"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/%s" % self._segment_path()


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync)}
                                self._child_list_classes = {}

                                self.init_sync = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._children_yang_names.add("init-sync")
                                self._segment_path = lambda: "ha-global"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/%s" % self._segment_path()


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\:  bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\:  bool
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                    self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                    self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                    self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                    self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                    self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                    self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                    self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                    self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                    self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                    self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                    self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                    self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                    self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                    self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                    self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                    self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                    self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                    self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                    self.num_peers = YLeaf(YType.uint32, "num-peers")

                                    self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                    self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                    self._segment_path = lambda: "init-sync"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/ha-global/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/ha-neighbors/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Sessions>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Vrf)}
                            self._child_list_classes = {}

                            self.sessions = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._children_yang_names.add("sessions")

                            self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "ha-summary"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/%s" % self._segment_path()


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                self.total = YLeaf(YType.uint32, "total")
                                self._segment_path = lambda: "sessions"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-summary/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/issu/ha-summary/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Issu.HaSummary.Vrf, ['id', 'name'], name, value)


                class LdpId(Entity):
                    """
                    Local LDP Id
                    
                    .. attribute:: label_space_id
                    
                    	Label space identifier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ldp_id
                    
                    	LDP identifier
                    	**type**\:  str
                    
                    .. attribute:: lsr_id
                    
                    	LSR identifier
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.LdpId, self).__init__()

                        self.yang_name = "ldp-id"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                        self._segment_path = lambda: "ldp-id"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.LdpId, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                class NeighborBriefs(Entity):
                    """
                    The LDP Neighbors (brief)
                    
                    .. attribute:: neighbor_brief
                    
                    	Brief information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs, self).__init__()

                        self.yang_name = "neighbor-briefs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-brief" : ("neighbor_brief", MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief)}

                        self.neighbor_brief = YList(self)
                        self._segment_path = lambda: "neighbor-briefs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs, [], name, value)


                    class NeighborBrief(Entity):
                        """
                        Brief information on a particular LDP neighbor
                        
                        .. attribute:: is_graceful_restartable
                        
                        	Is graceful restartable
                        	**type**\:  bool
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_br_af_info
                        
                        	Neighbor Brief AF Info
                        	**type**\: list of    :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                        
                        .. attribute:: nsr_state
                        
                        	NSR readiness state
                        	**type**\:   :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                        
                        .. attribute:: up_time_seconds
                        
                        	Up time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief, self).__init__()

                            self.yang_name = "neighbor-brief"
                            self.yang_parent_name = "neighbor-briefs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf)}
                            self._child_list_classes = {"nbr-br-af-info" : ("nbr_br_af_info", MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo)}

                            self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                            self.up_time_seconds = YLeaf(YType.uint32, "up-time-seconds")

                            self.vrf = MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")

                            self.nbr_br_af_info = YList(self)
                            self._segment_path = lambda: "neighbor-brief"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-briefs/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief, ['is_graceful_restartable', 'label_space_id', 'lsr_id', 'nsr_state', 'up_time_seconds'], name, value)


                        class NbrBrAfInfo(Entity):
                            """
                            Neighbor Brief AF Info
                            
                            .. attribute:: address_family
                            
                            	Neighbor Brief Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: num_of_nbr_addresses
                            
                            	Number of neighbor addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_discovery
                            
                            	Number of neighbor discovery sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_lbl
                            
                            	Number of neighbor labels
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                self.yang_name = "nbr-br-af-info"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.num_of_nbr_addresses = YLeaf(YType.uint32, "num-of-nbr-addresses")

                                self.num_of_nbr_discovery = YLeaf(YType.uint32, "num-of-nbr-discovery")

                                self.num_of_nbr_lbl = YLeaf(YType.uint32, "num-of-nbr-lbl")
                                self._segment_path = lambda: "nbr-br-af-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-briefs/neighbor-brief/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, ['address_family', 'num_of_nbr_addresses', 'num_of_nbr_discovery', 'num_of_nbr_lbl'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-briefs/neighbor-brief/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, ['id', 'name'], name, value)


                class NeighborCapabilities(Entity):
                    """
                    LDP Neighbors Capabilities
                    
                    .. attribute:: neighbor_capability
                    
                    	Information on capabilities of a particular LDP neighbor
                    	**type**\: list of    :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities, self).__init__()

                        self.yang_name = "neighbor-capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-capability" : ("neighbor_capability", MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability)}

                        self.neighbor_capability = YList(self)
                        self._segment_path = lambda: "neighbor-capabilities"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities, [], name, value)


                    class NeighborCapability(Entity):
                        """
                        Information on capabilities of a particular LDP
                        neighbor
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: received
                        
                        	List of received capabilities
                        	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Received>`
                        
                        .. attribute:: sent
                        
                        	List of sent capabilities
                        	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability, self).__init__()

                            self.yang_name = "neighbor-capability"
                            self.yang_parent_name = "neighbor-capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"received" : ("received", MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Received), "sent" : ("sent", MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent)}

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.received = YList(self)
                            self.sent = YList(self)
                            self._segment_path = lambda: "neighbor-capability"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-capabilities/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability, ['label_space_id', 'lsr_id'], name, value)


                        class Received(Entity):
                            """
                            List of received capabilities
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                self.yang_name = "received"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "received"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-capabilities/neighbor-capability/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                        class Sent(Entity):
                            """
                            List of sent capabilities
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                self.yang_name = "sent"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "sent"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbor-capabilities/neighbor-capability/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                class Neighbors(Entity):
                    """
                    The LDP Neighbors
                    
                    .. attribute:: neighbor
                    
                    	Information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor" : ("neighbor", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor)}

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        Information on a particular LDP neighbor
                        
                        .. attribute:: detailed_information
                        
                        	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                        	**type**\:   :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation>`
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_nbr_bound_ipv4_address_info
                        
                        	Neighbor IPv4 Address Info
                        	**type**\: list of    :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                        
                        .. attribute:: ldp_nbr_bound_ipv6_address_info
                        
                        	Neighbor IPv6 Address Info
                        	**type**\: list of    :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                        
                        .. attribute:: ldp_nbr_ipv4_adj_info
                        
                        	Neighbor's IPv4 Adjacency Information
                        	**type**\: list of    :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                        
                        .. attribute:: ldp_nbr_ipv6_adj_info
                        
                        	Neighbor's IPv6 Adjacency Information
                        	**type**\: list of    :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: protocol_information
                        
                        	Protocol Information
                        	**type**\:   :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation>`
                        
                        .. attribute:: tcp_information
                        
                        	TCP Information
                        	**type**\:   :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"detailed-information" : ("detailed_information", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation), "protocol-information" : ("protocol_information", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation), "tcp-information" : ("tcp_information", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation)}
                            self._child_list_classes = {"ldp-nbr-bound-ipv4-address-info" : ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo), "ldp-nbr-bound-ipv6-address-info" : ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo), "ldp-nbr-ipv4-adj-info" : ("ldp_nbr_ipv4_adj_info", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo), "ldp-nbr-ipv6-adj-info" : ("ldp_nbr_ipv6_adj_info", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo)}

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.detailed_information = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation()
                            self.detailed_information.parent = self
                            self._children_name_map["detailed_information"] = "detailed-information"
                            self._children_yang_names.add("detailed-information")

                            self.protocol_information = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation()
                            self.protocol_information.parent = self
                            self._children_name_map["protocol_information"] = "protocol-information"
                            self._children_yang_names.add("protocol-information")

                            self.tcp_information = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation()
                            self.tcp_information.parent = self
                            self._children_name_map["tcp_information"] = "tcp-information"
                            self._children_yang_names.add("tcp-information")

                            self.ldp_nbr_bound_ipv4_address_info = YList(self)
                            self.ldp_nbr_bound_ipv6_address_info = YList(self)
                            self.ldp_nbr_ipv4_adj_info = YList(self)
                            self.ldp_nbr_ipv6_adj_info = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor, ['label_space_id', 'lsr_id'], name, value)


                        class DetailedInformation(Entity):
                            """
                            Detailed information with regards to holdtime,
                            KA, inbound filtering, and Session protection
                            
                            .. attribute:: advertise_bgp_prefixes
                            
                            	Is BGP labelled prefixes advertised to the neighbor
                            	**type**\:  bool
                            
                            .. attribute:: bgp_advertisement_state
                            
                            	BGP labelled prefixes advertisement state
                            	**type**\:   :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                            
                            .. attribute:: capabilities
                            
                            	Capabilities sent to and received from neighbor
                            	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                            
                            .. attribute:: client
                            
                            	Targeted Session clients
                            	**type**\: list of    :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client>`
                            
                            .. attribute:: has_ipv4_inbound
                            
                            	IPv4 Inbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv4_outbound
                            
                            	IPv4 Outbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv6_inbound
                            
                            	IPv6 Inbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv6_outbound
                            
                            	IPv6 Outbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_sp
                            
                            	Session Protection enabled
                            	**type**\:  bool
                            
                            .. attribute:: inbound_ipv4acl
                            
                            	IPv4 Inbound accept ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: inbound_ipv6acl
                            
                            	IPv6 Inbound accept ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: ipv4_duplicate_address
                            
                            	Duplicate IPv4 address bound to this peer
                            	**type**\: list of    :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                            
                            .. attribute:: ipv6_duplicate_address
                            
                            	Duplicate IPv6 address bound to this peer
                            	**type**\: list of    :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                            
                            .. attribute:: keep_alive_interval
                            
                            	Session keepalive interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nsr_last_sync_error
                            
                            	Last NSR sync error
                            	**type**\:   :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                            
                            .. attribute:: nsr_last_sync_nack_reason
                            
                            	Last NSR sync NACK reaston
                            	**type**\:   :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                            
                            .. attribute:: nsr_sync_state
                            
                            	NSR Sync State
                            	**type**\:   :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                            
                            .. attribute:: outbound_ipv4acl
                            
                            	IPv4 Outbound advertise ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: outbound_ipv6acl
                            
                            	IPv6 Outbound advertise ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: peer_holdtime
                            
                            	Session holdtime value in seconds from the peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: peer_state
                            
                            	Peer state
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_duration
                            
                            	Session protection holdup time duration in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: sp_has_acl
                            
                            	Session protection ACL is present
                            	**type**\:  bool
                            
                            .. attribute:: sp_has_duration
                            
                            	Session Protection has non\-default duration
                            	**type**\:  bool
                            
                            .. attribute:: sp_state
                            
                            	Session Protection state
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: spacl
                            
                            	Session Protection ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: spht_remaining
                            
                            	Session Protection holdup time remaining value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: spht_running
                            
                            	Session Protection holdup timer is running
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                self.yang_name = "detailed-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"capabilities" : ("capabilities", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities)}
                                self._child_list_classes = {"client" : ("client", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client), "ipv4-duplicate-address" : ("ipv4_duplicate_address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress), "ipv6-duplicate-address" : ("ipv6_duplicate_address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress)}

                                self.advertise_bgp_prefixes = YLeaf(YType.boolean, "advertise-bgp-prefixes")

                                self.bgp_advertisement_state = YLeaf(YType.enumeration, "bgp-advertisement-state")

                                self.has_ipv4_inbound = YLeaf(YType.boolean, "has-ipv4-inbound")

                                self.has_ipv4_outbound = YLeaf(YType.boolean, "has-ipv4-outbound")

                                self.has_ipv6_inbound = YLeaf(YType.boolean, "has-ipv6-inbound")

                                self.has_ipv6_outbound = YLeaf(YType.boolean, "has-ipv6-outbound")

                                self.has_sp = YLeaf(YType.boolean, "has-sp")

                                self.inbound_ipv4acl = YLeaf(YType.str, "inbound-ipv4acl")

                                self.inbound_ipv6acl = YLeaf(YType.str, "inbound-ipv6acl")

                                self.keep_alive_interval = YLeaf(YType.uint32, "keep-alive-interval")

                                self.nsr_last_sync_error = YLeaf(YType.enumeration, "nsr-last-sync-error")

                                self.nsr_last_sync_nack_reason = YLeaf(YType.enumeration, "nsr-last-sync-nack-reason")

                                self.nsr_sync_state = YLeaf(YType.enumeration, "nsr-sync-state")

                                self.outbound_ipv4acl = YLeaf(YType.str, "outbound-ipv4acl")

                                self.outbound_ipv6acl = YLeaf(YType.str, "outbound-ipv6acl")

                                self.peer_holdtime = YLeaf(YType.uint32, "peer-holdtime")

                                self.peer_state = YLeaf(YType.str, "peer-state")

                                self.sp_duration = YLeaf(YType.uint32, "sp-duration")

                                self.sp_has_acl = YLeaf(YType.boolean, "sp-has-acl")

                                self.sp_has_duration = YLeaf(YType.boolean, "sp-has-duration")

                                self.sp_state = YLeaf(YType.str, "sp-state")

                                self.spacl = YLeaf(YType.str, "spacl")

                                self.spht_remaining = YLeaf(YType.uint32, "spht-remaining")

                                self.spht_running = YLeaf(YType.boolean, "spht-running")

                                self.capabilities = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                self.capabilities.parent = self
                                self._children_name_map["capabilities"] = "capabilities"
                                self._children_yang_names.add("capabilities")

                                self.client = YList(self)
                                self.ipv4_duplicate_address = YList(self)
                                self.ipv6_duplicate_address = YList(self)
                                self._segment_path = lambda: "detailed-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation, ['advertise_bgp_prefixes', 'bgp_advertisement_state', 'has_ipv4_inbound', 'has_ipv4_outbound', 'has_ipv6_inbound', 'has_ipv6_outbound', 'has_sp', 'inbound_ipv4acl', 'inbound_ipv6acl', 'keep_alive_interval', 'nsr_last_sync_error', 'nsr_last_sync_nack_reason', 'nsr_sync_state', 'outbound_ipv4acl', 'outbound_ipv6acl', 'peer_holdtime', 'peer_state', 'sp_duration', 'sp_has_acl', 'sp_has_duration', 'sp_state', 'spacl', 'spht_remaining', 'spht_running'], name, value)


                            class Capabilities(Entity):
                                """
                                Capabilities sent to and received from neighbor
                                
                                .. attribute:: received
                                
                                	List of received capabilities
                                	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                
                                .. attribute:: sent
                                
                                	List of sent capabilities
                                	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                    self.yang_name = "capabilities"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"received" : ("received", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received), "sent" : ("sent", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)}

                                    self.received = YList(self)
                                    self.sent = YList(self)
                                    self._segment_path = lambda: "capabilities"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                class Received(Entity):
                                    """
                                    List of received capabilities
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\:  str
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\:  str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                        self.yang_name = "received"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.capability_data = YLeaf(YType.str, "capability-data")

                                        self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                        self.description = YLeaf(YType.str, "description")

                                        self.type = YLeaf(YType.uint16, "type")
                                        self._segment_path = lambda: "received"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/capabilities/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                class Sent(Entity):
                                    """
                                    List of sent capabilities
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\:  str
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\:  str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                        self.yang_name = "sent"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.capability_data = YLeaf(YType.str, "capability-data")

                                        self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                        self.description = YLeaf(YType.str, "description")

                                        self.type = YLeaf(YType.uint16, "type")
                                        self._segment_path = lambda: "sent"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/capabilities/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                            class Client(Entity):
                                """
                                Targeted Session clients
                                
                                .. attribute:: name
                                
                                	Client's name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                    self.yang_name = "client"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "client"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, ['name'], name, value)


                            class Ipv4DuplicateAddress(Entity):
                                """
                                Duplicate IPv4 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv4-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ipv4-duplicate-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv4-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/ipv4-duplicate-address/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class Ipv6DuplicateAddress(Entity):
                                """
                                Duplicate IPv6 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv6-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ipv6-duplicate-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/%s" % self._segment_path()


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv6-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/detailed-information/ipv6-duplicate-address/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrBoundIpv4AddressInfo(Entity):
                            """
                            Neighbor IPv4 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address)}
                                self._child_list_classes = {}

                                self.address = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")
                                self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-bound-ipv4-address-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrBoundIpv6AddressInfo(Entity):
                            """
                            Neighbor IPv6 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address)}
                                self._child_list_classes = {}

                                self.address = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")
                                self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-bound-ipv6-address-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrIpv4AdjInfo(Entity):
                            """
                            Neighbor's IPv4 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv4-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup)}
                                self._child_list_classes = {}

                                self.adjacency_group = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._children_yang_names.add("adjacency-group")
                                self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData)}
                                    self._child_list_classes = {}

                                    self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                    self.link_hello_data = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"
                                    self._children_yang_names.add("link-hello-data")

                                    self.target_hello_data = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._children_yang_names.add("target-hello-data")
                                    self._segment_path = lambda: "adjacency-group"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "link-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                        self._child_list_classes = {}

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.local_address = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"
                                        self._children_yang_names.add("local-address")

                                        self.target_address = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._children_yang_names.add("target-address")
                                        self._segment_path = lambda: "target-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "local-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "target-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv4-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrIpv6AdjInfo(Entity):
                            """
                            Neighbor's IPv6 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv6-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup)}
                                self._child_list_classes = {}

                                self.adjacency_group = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._children_yang_names.add("adjacency-group")
                                self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData)}
                                    self._child_list_classes = {}

                                    self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                    self.link_hello_data = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"
                                    self._children_yang_names.add("link-hello-data")

                                    self.target_hello_data = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._children_yang_names.add("target-hello-data")
                                    self._segment_path = lambda: "adjacency-group"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "link-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                        self._child_list_classes = {}

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.local_address = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"
                                        self._children_yang_names.add("local-address")

                                        self.target_address = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._children_yang_names.add("target-address")
                                        self._segment_path = lambda: "target-hello-data"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "local-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "target-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/ldp-nbr-ipv6-adj-info/adjacency-group/target-hello-data/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class ProtocolInformation(Entity):
                            """
                            Protocol Information
                            
                            .. attribute:: downstream_on_demand
                            
                            	Is Label advertisment mode in Downstream On Demand mode or Not
                            	**type**\:  bool
                            
                            .. attribute:: ta_graceful_restart_adjacency
                            
                            	Graceful restart information
                            	**type**\:   :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                            
                            .. attribute:: ta_holdtime
                            
                            	Session holdtime in sec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_rcvd
                            
                            	Number of pies received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_sent
                            
                            	Number of pies sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_state
                            
                            	State
                            	**type**\:  str
                            
                            .. attribute:: ta_up_time_seconds
                            
                            	Up time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                self.yang_name = "protocol-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"ta-graceful-restart-adjacency" : ("ta_graceful_restart_adjacency", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency)}
                                self._child_list_classes = {}

                                self.downstream_on_demand = YLeaf(YType.boolean, "downstream-on-demand")

                                self.ta_holdtime = YLeaf(YType.uint32, "ta-holdtime")

                                self.ta_pies_rcvd = YLeaf(YType.uint32, "ta-pies-rcvd")

                                self.ta_pies_sent = YLeaf(YType.uint32, "ta-pies-sent")

                                self.ta_state = YLeaf(YType.str, "ta-state")

                                self.ta_up_time_seconds = YLeaf(YType.uint32, "ta-up-time-seconds")

                                self.ta_graceful_restart_adjacency = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                self.ta_graceful_restart_adjacency.parent = self
                                self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                self._children_yang_names.add("ta-graceful-restart-adjacency")
                                self._segment_path = lambda: "protocol-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, ['downstream_on_demand', 'ta_holdtime', 'ta_pies_rcvd', 'ta_pies_sent', 'ta_state', 'ta_up_time_seconds'], name, value)


                            class TaGracefulRestartAdjacency(Entity):
                                """
                                Graceful restart information
                                
                                .. attribute:: is_graceful_restartable
                                
                                	Is graceful restartable
                                	**type**\:  bool
                                
                                .. attribute:: reconnect_timeout
                                
                                	Reconnect timeout
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recovery_time
                                
                                	Recovery time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                    self.yang_name = "ta-graceful-restart-adjacency"
                                    self.yang_parent_name = "protocol-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                    self.reconnect_timeout = YLeaf(YType.uint32, "reconnect-timeout")

                                    self.recovery_time = YLeaf(YType.uint32, "recovery-time")
                                    self._segment_path = lambda: "ta-graceful-restart-adjacency"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/protocol-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, ['is_graceful_restartable', 'reconnect_timeout', 'recovery_time'], name, value)


                        class TcpInformation(Entity):
                            """
                            TCP Information
                            
                            .. attribute:: foreign_host
                            
                            	Foreign host address
                            	**type**\:   :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                            
                            .. attribute:: foreign_port
                            
                            	Foreign port number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_md5_on
                            
                            	Is MD5 Digest on
                            	**type**\:  bool
                            
                            .. attribute:: local_host
                            
                            	Local host address
                            	**type**\:   :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                            
                            .. attribute:: local_port
                            
                            	Local port number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                self.yang_name = "tcp-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"foreign-host" : ("foreign_host", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost), "local-host" : ("local_host", MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost)}
                                self._child_list_classes = {}

                                self.foreign_port = YLeaf(YType.uint16, "foreign-port")

                                self.is_md5_on = YLeaf(YType.boolean, "is-md5-on")

                                self.local_port = YLeaf(YType.uint16, "local-port")

                                self.foreign_host = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                self.foreign_host.parent = self
                                self._children_name_map["foreign_host"] = "foreign-host"
                                self._children_yang_names.add("foreign-host")

                                self.local_host = MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                self.local_host.parent = self
                                self._children_name_map["local_host"] = "local-host"
                                self._children_yang_names.add("local-host")
                                self._segment_path = lambda: "tcp-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation, ['foreign_port', 'is_md5_on', 'local_port'], name, value)


                            class ForeignHost(Entity):
                                """
                                Foreign host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                    self.yang_name = "foreign-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "foreign-host"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/tcp-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LocalHost(Entity):
                                """
                                Local host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                    self.yang_name = "local-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "local-host"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/neighbors/neighbor/tcp-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class Nsr(Entity):
                    """
                    LDP NSR related information
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary>`
                    
                    .. attribute:: nsr_pending
                    
                    	LDP NSR Pending related information
                    	**type**\:   :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Nsr, self).__init__()

                        self.yang_name = "nsr"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary), "nsr-pending" : ("nsr_pending", MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending)}
                        self._child_list_classes = {}

                        self.ha_statistics = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._children_yang_names.add("ha-statistics")

                        self.ha_summary = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"
                        self._children_yang_names.add("ha-summary")

                        self.nsr_pending = MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending()
                        self.nsr_pending.parent = self
                        self._children_name_map["nsr_pending"] = "nsr-pending"
                        self._children_yang_names.add("nsr-pending")
                        self._segment_path = lambda: "nsr"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_global = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"
                            self._children_yang_names.add("ha-global")

                            self.ha_neighbors = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "ha-statistics"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/%s" % self._segment_path()


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync)}
                                self._child_list_classes = {}

                                self.init_sync = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._children_yang_names.add("init-sync")
                                self._segment_path = lambda: "ha-global"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/%s" % self._segment_path()


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\:  bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\:  bool
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                    self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                    self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                    self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                    self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                    self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                    self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                    self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                    self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                    self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                    self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                    self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                    self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                    self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                    self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                    self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                    self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                    self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                    self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                    self.num_peers = YLeaf(YType.uint32, "num-peers")

                                    self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                    self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                    self._segment_path = lambda: "init-sync"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/ha-global/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/ha-neighbors/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-statistics/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Sessions>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Vrf)}
                            self._child_list_classes = {}

                            self.sessions = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._children_yang_names.add("sessions")

                            self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "ha-summary"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/%s" % self._segment_path()


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                self.total = YLeaf(YType.uint32, "total")
                                self._segment_path = lambda: "sessions"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-summary/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/ha-summary/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.HaSummary.Vrf, ['id', 'name'], name, value)


                    class NsrPending(Entity):
                        """
                        LDP NSR Pending related information
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending, self).__init__()

                            self.yang_name = "nsr-pending"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_neighbors = MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "nsr-pending"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/%s" % self._segment_path()


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "nsr-pending"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/nsr-pending/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/nsr-pending/ha-neighbors/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/nsr-pending/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/nsr/nsr-pending/ha-neighbors/ha-neighbor/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                class Parameters(Entity):
                    """
                    LDP parameters
                    
                    .. attribute:: address_family_parameter
                    
                    	Per AF parameters
                    	**type**\: list of    :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter>`
                    
                    .. attribute:: af_binding_withdraw_delay
                    
                    	Delay (sec) in Binding Withdrawal for an Address Family
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: discovery_quick_start_disabled_on_interfaces
                    
                    	Discovery quick\-start disabled on some LDP\-enabled interfaces
                    	**type**\:  bool
                    
                    .. attribute:: global_discovery_quick_start_disabled
                    
                    	Discovery quick\-start globally disabled
                    	**type**\:  bool
                    
                    .. attribute:: global_md5_password_enabled
                    
                    	Global MD5 password enabled
                    	**type**\:  bool
                    
                    .. attribute:: graceful_restart_information
                    
                    	Graceful restart information
                    	**type**\:   :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Parameters.GracefulRestartInformation>`
                    
                    .. attribute:: hello_hold_time
                    
                    	Hello hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_interval
                    
                    	Hello interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: housekeeping_timer_interval
                    
                    	Housekeeping periodic timer interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: igp_sync_delay_time_for_interface
                    
                    	Interface IGP sync delay time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: igp_sync_delay_time_on_restart
                    
                    	IGP sync delay time on process restart in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: keepalive_interval
                    
                    	Keepalive interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_out_of_mem_state
                    
                    	LDP Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_recovery_timeout
                    
                    	LDP recovery timeout with LSD
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: le_no_route_timeout
                    
                    	LIB entry no route timeout
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_attached
                    
                    	Maximum number of LDP enabled attached interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_te
                    
                    	Maximum number of LDP enabled TE interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_peer
                    
                    	Maximum number of LDP peers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_enabled
                    
                    	TRUE if NSR is enabled
                    	**type**\:  bool
                    
                    .. attribute:: nsr_synced
                    
                    	TRUE if LDP is standby and is NSR Sync\-ed with active
                    	**type**\:  bool
                    
                    .. attribute:: protocol_version
                    
                    	Protocol version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: role_is_active
                    
                    	Is process role active or standby
                    	**type**\:  bool
                    
                    .. attribute:: router_id
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: session_hold_time
                    
                    	Session hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_hold_time
                    
                    	Targeted hello hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_interval
                    
                    	Targeted hello interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Parameters, self).__init__()

                        self.yang_name = "parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"graceful-restart-information" : ("graceful_restart_information", MplsLdp.Global_.Standby.DefaultVrf.Parameters.GracefulRestartInformation)}
                        self._child_list_classes = {"address-family-parameter" : ("address_family_parameter", MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter)}

                        self.af_binding_withdraw_delay = YLeaf(YType.uint32, "af-binding-withdraw-delay")

                        self.discovery_quick_start_disabled_on_interfaces = YLeaf(YType.boolean, "discovery-quick-start-disabled-on-interfaces")

                        self.global_discovery_quick_start_disabled = YLeaf(YType.boolean, "global-discovery-quick-start-disabled")

                        self.global_md5_password_enabled = YLeaf(YType.boolean, "global-md5-password-enabled")

                        self.hello_hold_time = YLeaf(YType.uint32, "hello-hold-time")

                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                        self.housekeeping_timer_interval = YLeaf(YType.uint32, "housekeeping-timer-interval")

                        self.igp_sync_delay_time_for_interface = YLeaf(YType.uint32, "igp-sync-delay-time-for-interface")

                        self.igp_sync_delay_time_on_restart = YLeaf(YType.uint32, "igp-sync-delay-time-on-restart")

                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                        self.ldp_out_of_mem_state = YLeaf(YType.uint32, "ldp-out-of-mem-state")

                        self.ldp_recovery_timeout = YLeaf(YType.uint32, "ldp-recovery-timeout")

                        self.le_no_route_timeout = YLeaf(YType.uint32, "le-no-route-timeout")

                        self.max_intf_attached = YLeaf(YType.uint32, "max-intf-attached")

                        self.max_intf_te = YLeaf(YType.uint32, "max-intf-te")

                        self.max_peer = YLeaf(YType.uint32, "max-peer")

                        self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                        self.protocol_version = YLeaf(YType.uint32, "protocol-version")

                        self.role_is_active = YLeaf(YType.boolean, "role-is-active")

                        self.router_id = YLeaf(YType.str, "router-id")

                        self.session_hold_time = YLeaf(YType.uint32, "session-hold-time")

                        self.targeted_hello_hold_time = YLeaf(YType.uint32, "targeted-hello-hold-time")

                        self.targeted_hello_interval = YLeaf(YType.uint32, "targeted-hello-interval")

                        self.graceful_restart_information = MplsLdp.Global_.Standby.DefaultVrf.Parameters.GracefulRestartInformation()
                        self.graceful_restart_information.parent = self
                        self._children_name_map["graceful_restart_information"] = "graceful-restart-information"
                        self._children_yang_names.add("graceful-restart-information")

                        self.address_family_parameter = YList(self)
                        self._segment_path = lambda: "parameters"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Parameters, ['af_binding_withdraw_delay', 'discovery_quick_start_disabled_on_interfaces', 'global_discovery_quick_start_disabled', 'global_md5_password_enabled', 'hello_hold_time', 'hello_interval', 'housekeeping_timer_interval', 'igp_sync_delay_time_for_interface', 'igp_sync_delay_time_on_restart', 'keepalive_interval', 'ldp_out_of_mem_state', 'ldp_recovery_timeout', 'le_no_route_timeout', 'max_intf_attached', 'max_intf_te', 'max_peer', 'nsr_enabled', 'nsr_synced', 'protocol_version', 'role_is_active', 'router_id', 'session_hold_time', 'targeted_hello_hold_time', 'targeted_hello_interval'], name, value)


                    class AddressFamilyParameter(Entity):
                        """
                        Per AF parameters
                        
                        .. attribute:: address_family
                        
                        	Address Family
                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: discovery_transport_address
                        
                        	Discovery transport address
                        	**type**\:   :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                        
                        .. attribute:: is_accepting_targeted_hellos
                        
                        	Accepting targeted Hellos
                        	**type**\:  bool
                        
                        .. attribute:: label_imp_null_override_acl
                        
                        	ACL to override local label to use implicit\-null
                        	**type**\:  str
                        
                        .. attribute:: null_label
                        
                        	Null label
                        	**type**\:  str
                        
                        .. attribute:: targeted_hello_acl
                        
                        	Targeted Hello ACL
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter, self).__init__()

                            self.yang_name = "address-family-parameter"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"discovery-transport-address" : ("discovery_transport_address", MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress)}
                            self._child_list_classes = {}

                            self.address_family = YLeaf(YType.enumeration, "address-family")

                            self.is_accepting_targeted_hellos = YLeaf(YType.boolean, "is-accepting-targeted-hellos")

                            self.label_imp_null_override_acl = YLeaf(YType.str, "label-imp-null-override-acl")

                            self.null_label = YLeaf(YType.str, "null-label")

                            self.targeted_hello_acl = YLeaf(YType.str, "targeted-hello-acl")

                            self.discovery_transport_address = MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                            self.discovery_transport_address.parent = self
                            self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                            self._children_yang_names.add("discovery-transport-address")
                            self._segment_path = lambda: "address-family-parameter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/parameters/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter, ['address_family', 'is_accepting_targeted_hellos', 'label_imp_null_override_acl', 'null_label', 'targeted_hello_acl'], name, value)


                        class DiscoveryTransportAddress(Entity):
                            """
                            Discovery transport address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                self.yang_name = "discovery-transport-address"
                                self.yang_parent_name = "address-family-parameter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.dummy = YLeaf(YType.uint8, "dummy")

                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                self._segment_path = lambda: "discovery-transport-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/parameters/address-family-parameter/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                    class GracefulRestartInformation(Entity):
                        """
                        Graceful restart information
                        
                        .. attribute:: graceful_restart_forwarding_state_hold_time
                        
                        	Graceful restart forward state hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_restart_reconnect_timeout
                        
                        	Reconnect timeout value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_graceful_restart_configured
                        
                        	Is graceful restart configured
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Parameters.GracefulRestartInformation, self).__init__()

                            self.yang_name = "graceful-restart-information"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.graceful_restart_forwarding_state_hold_time = YLeaf(YType.uint32, "graceful-restart-forwarding-state-hold-time")

                            self.graceful_restart_reconnect_timeout = YLeaf(YType.uint32, "graceful-restart-reconnect-timeout")

                            self.is_graceful_restart_configured = YLeaf(YType.boolean, "is-graceful-restart-configured")
                            self._segment_path = lambda: "graceful-restart-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/parameters/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Parameters.GracefulRestartInformation, ['graceful_restart_forwarding_state_hold_time', 'graceful_restart_reconnect_timeout', 'is_graceful_restart_configured'], name, value)


                class Statistics(Entity):
                    """
                    The LDP Statistics
                    
                    .. attribute:: statistic
                    
                    	Statistical Information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"statistic" : ("statistic", MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic)}

                        self.statistic = YList(self)
                        self._segment_path = lambda: "statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Statistics, [], name, value)


                    class Statistic(Entity):
                        """
                        Statistical Information on a particular LDP
                        neighbor
                        
                        .. attribute:: iccp_enabled
                        
                        	Is session ICCP enabled?
                        	**type**\:  bool
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: message_in
                        
                        	Message in count
                        	**type**\:   :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageIn>`
                        
                        .. attribute:: message_out
                        
                        	Message out count
                        	**type**\:   :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageOut>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic, self).__init__()

                            self.yang_name = "statistic"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"message-in" : ("message_in", MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageIn), "message-out" : ("message_out", MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageOut)}
                            self._child_list_classes = {}

                            self.iccp_enabled = YLeaf(YType.boolean, "iccp-enabled")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.message_in = MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageIn()
                            self.message_in.parent = self
                            self._children_name_map["message_in"] = "message-in"
                            self._children_yang_names.add("message-in")

                            self.message_out = MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageOut()
                            self.message_out.parent = self
                            self._children_name_map["message_out"] = "message-out"
                            self._children_yang_names.add("message-out")
                            self._segment_path = lambda: "statistic"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/statistics/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic, ['iccp_enabled', 'label_space_id', 'lsr_id'], name, value)


                        class MessageIn(Entity):
                            """
                            Message in count
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageIn, self).__init__()

                                self.yang_name = "message-in"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_count = YLeaf(YType.uint32, "address-count")

                                self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                self.init_count = YLeaf(YType.uint32, "init-count")

                                self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                self.notification_count = YLeaf(YType.uint32, "notification-count")

                                self.total_count = YLeaf(YType.uint32, "total-count")
                                self._segment_path = lambda: "message-in"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/statistics/statistic/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageIn, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                        class MessageOut(Entity):
                            """
                            Message out count
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageOut, self).__init__()

                                self.yang_name = "message-out"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_count = YLeaf(YType.uint32, "address-count")

                                self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                self.init_count = YLeaf(YType.uint32, "init-count")

                                self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                self.notification_count = YLeaf(YType.uint32, "notification-count")

                                self.total_count = YLeaf(YType.uint32, "total-count")
                                self._segment_path = lambda: "message-out"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/statistics/statistic/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Statistics.Statistic.MessageOut, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                class Summary(Entity):
                    """
                    LDP VRF summary
                    
                    .. attribute:: common
                    
                    	Common Summary information
                    	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Summary.Common>`
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DefaultVrf.Summary.Vrf>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DefaultVrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"common" : ("common", MplsLdp.Global_.Standby.DefaultVrf.Summary.Common), "vrf" : ("vrf", MplsLdp.Global_.Standby.DefaultVrf.Summary.Vrf)}
                        self._child_list_classes = {}

                        self.common = MplsLdp.Global_.Standby.DefaultVrf.Summary.Common()
                        self.common.parent = self
                        self._children_name_map["common"] = "common"
                        self._children_yang_names.add("common")

                        self.vrf = MplsLdp.Global_.Standby.DefaultVrf.Summary.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._children_yang_names.add("vrf")
                        self._segment_path = lambda: "summary"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/%s" % self._segment_path()


                    class Common(Entity):
                        """
                        Common Summary information
                        
                        .. attribute:: address_families
                        
                        	Address Families enabled
                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: number_of_bindings_ipv4
                        
                        	Total number of ipv4 bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv6
                        
                        	Total number of ipv6 bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_downstream_on_demand_neighbors
                        
                        	Number of Downstream\-On\-Demand neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_graceful_restart_neighbors
                        
                        	Number of Graceful Restart neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_hello_adj
                        
                        	Number of LDP discovery IPv4 hello adjacencies
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_local_addresses
                        
                        	Number of IPv4 local addresses
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_routes
                        
                        	Number of resolved IPv4 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4af
                        
                        	Number of IPv4 address\-families enabled
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4ldp_interfaces
                        
                        	Number of LDP IPv4 configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_hello_adj
                        
                        	Number of LDP discovery IPv6 hello adjacencies
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_local_addresses
                        
                        	Number of IPv6 local addresses
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_routes
                        
                        	Number of resolved IPv6 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6af
                        
                        	Number of IPv6 address\-families enabled
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6ldp_interfaces
                        
                        	Number of LDP IPv6 configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ldp_interfaces
                        
                        	Number of LDP configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv4
                        
                        	Total number of ipv4 local label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv6
                        
                        	Total number of ipv6 local label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_nsr_synced_neighbors
                        
                        	Number of NSR\-synced/operational neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv4
                        
                        	Total number of ipv4 remote label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv6
                        
                        	Total number of ipv6 remote label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Summary.Common, self).__init__()

                            self.yang_name = "common"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.address_families = YLeaf(YType.enumeration, "address-families")

                            self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                            self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                            self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                            self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                            self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                            self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                            self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                            self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                            self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                            self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                            self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                            self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                            self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                            self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                            self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                            self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                            self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                            self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                            self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                            self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                            self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                            self._segment_path = lambda: "common"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/summary/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.DefaultVrf.Summary.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.id = YLeaf(YType.uint32, "id")

                            self.name = YLeaf(YType.str, "name")
                            self._segment_path = lambda: "vrf"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/default-vrf/summary/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.DefaultVrf.Summary.Vrf, ['id', 'name'], name, value)


            class DiscoverySummaryAll(Entity):
                """
                Summary information regarding LDP discovery
                
                .. attribute:: local_ldp_id
                
                	Local LDP identifier
                	**type**\:  str
                
                .. attribute:: num_of_active_ldp_interfaces
                
                	Number of active LDP enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_addr_recv
                
                	Number of hello discoveries received with bad source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_hello_pdu
                
                	Number of hello discoveries received with bad hello PDU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_xport_addr
                
                	Number of hello discoveries received with bad export address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_same_router_id
                
                	Number of hello discoveries received with the same router id as this router
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_wrong_router_id
                
                	Number of hello discoveries received with the router id that is not destined for this router
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_ldp_interfaces
                
                	Total Number of LDP configured interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_recv
                
                	Number of link hello discoveries in recv state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_xmit
                
                	Number of link hello discoveries in xmit state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_recv
                
                	Number of targeted hello discoveries in recv state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_xmit
                
                	Number of targeted hello discoveries in xmit state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.DiscoverySummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Standby.DiscoverySummaryAll, self).__init__()

                    self.yang_name = "discovery-summary-all"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.DiscoverySummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                    self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                    self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                    self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                    self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                    self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                    self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                    self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                    self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                    self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                    self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                    self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                    self.vrf = MplsLdp.Global_.Standby.DiscoverySummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "discovery-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Standby.DiscoverySummaryAll, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.DiscoverySummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "discovery-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/discovery-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.DiscoverySummaryAll.Vrf, ['id', 'name'], name, value)


            class ForwardingSummaryAll(Entity):
                """
                Summary information regarding LDP forwarding
                setup
                
                .. attribute:: fsht
                
                	Forwarding state hold time registered with LSD
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: intfs
                
                	MPLS forwarding enabled interface count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: is_lsd_bound
                
                	LDP is connected to LSD server
                	**type**\:  bool
                
                .. attribute:: lbls
                
                	Local label allocated count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: rws
                
                	Forwarding rewrites summary
                	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws>`
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.ForwardingSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Standby.ForwardingSummaryAll, self).__init__()

                    self.yang_name = "forwarding-summary-all"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"rws" : ("rws", MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws), "vrf" : ("vrf", MplsLdp.Global_.Standby.ForwardingSummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.fsht = YLeaf(YType.uint16, "fsht")

                    self.intfs = YLeaf(YType.uint16, "intfs")

                    self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                    self.lbls = YLeaf(YType.uint16, "lbls")

                    self.rws = MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws()
                    self.rws.parent = self
                    self._children_name_map["rws"] = "rws"
                    self._children_yang_names.add("rws")

                    self.vrf = MplsLdp.Global_.Standby.ForwardingSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "forwarding-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Standby.ForwardingSummaryAll, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                class Rws(Entity):
                    """
                    Forwarding rewrites summary
                    
                    .. attribute:: nhs
                    
                    	Forwarding rewrites nexthops (paths) summary
                    	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Nhs>`
                    
                    .. attribute:: pfxs
                    
                    	Forwarding rewrites prefix summary
                    	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws, self).__init__()

                        self.yang_name = "rws"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs)}
                        self._child_list_classes = {}

                        self.nhs = MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Nhs()
                        self.nhs.parent = self
                        self._children_name_map["nhs"] = "nhs"
                        self._children_yang_names.add("nhs")

                        self.pfxs = MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs()
                        self.pfxs.parent = self
                        self._children_name_map["pfxs"] = "pfxs"
                        self._children_yang_names.add("pfxs")
                        self._segment_path = lambda: "rws"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/%s" % self._segment_path()


                    class Nhs(Entity):
                        """
                        Forwarding rewrites nexthops (paths) summary
                        
                        .. attribute:: backup_paths
                        
                        	Count of non\-primary backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_backup_paths
                        
                        	Count of labeled backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_paths
                        
                        	Count of all labeled paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protected_paths
                        
                        	Count of FRR protected paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_backup_paths
                        
                        	Count of non\-primary remote backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_paths
                        
                        	Total path count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Nhs, self).__init__()

                            self.yang_name = "nhs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                            self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                            self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                            self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                            self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                            self.total_paths = YLeaf(YType.uint32, "total-paths")
                            self._segment_path = lambda: "nhs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                    class Pfxs(Entity):
                        """
                        Forwarding rewrites prefix summary
                        
                        .. attribute:: ecmp_pfxs
                        
                        	Count of prefixes with ECMP
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: labeled_pfxs_aggr
                        
                        	Labeled prefix count for all paths
                        	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr>`
                        
                        .. attribute:: labeled_pfxs_backup
                        
                        	Labeled prefix count related to backup paths only
                        	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup>`
                        
                        .. attribute:: labeled_pfxs_primary
                        
                        	Labeled prefix count related to primary paths only
                        	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary>`
                        
                        .. attribute:: protected_pfxs
                        
                        	Count of FRR protected prefixes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: total_pfxs
                        
                        	Total Prefix count
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs, self).__init__()

                            self.yang_name = "pfxs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary)}
                            self._child_list_classes = {}

                            self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                            self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                            self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                            self.labeled_pfxs_aggr = MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr()
                            self.labeled_pfxs_aggr.parent = self
                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                            self._children_yang_names.add("labeled-pfxs-aggr")

                            self.labeled_pfxs_backup = MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup()
                            self.labeled_pfxs_backup.parent = self
                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                            self._children_yang_names.add("labeled-pfxs-backup")

                            self.labeled_pfxs_primary = MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary()
                            self.labeled_pfxs_primary.parent = self
                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                            self._children_yang_names.add("labeled-pfxs-primary")
                            self._segment_path = lambda: "pfxs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                        class LabeledPfxsAggr(Entity):
                            """
                            Labeled prefix count for all paths
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                self.yang_name = "labeled-pfxs-aggr"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-aggr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                        class LabeledPfxsBackup(Entity):
                            """
                            Labeled prefix count related to backup paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                self.yang_name = "labeled-pfxs-backup"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-backup"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                        class LabeledPfxsPrimary(Entity):
                            """
                            Labeled prefix count related to primary paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                self.yang_name = "labeled-pfxs-primary"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-primary"
                                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/rws/pfxs/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.ForwardingSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/forwarding-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.ForwardingSummaryAll.Vrf, ['id', 'name'], name, value)


            class NsrSummaryAll(Entity):
                """
                Summary information regarding LDP NSR State
                
                .. attribute:: sessions
                
                	Session summary
                	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.NsrSummaryAll.Sessions>`
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.NsrSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Standby.NsrSummaryAll, self).__init__()

                    self.yang_name = "nsr-summary-all"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Standby.NsrSummaryAll.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Standby.NsrSummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.sessions = MplsLdp.Global_.Standby.NsrSummaryAll.Sessions()
                    self.sessions.parent = self
                    self._children_name_map["sessions"] = "sessions"
                    self._children_yang_names.add("sessions")

                    self.vrf = MplsLdp.Global_.Standby.NsrSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "nsr-summary-all"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()


                class Sessions(Entity):
                    """
                    Session summary
                    
                    .. attribute:: nsr_eligible
                    
                    	NSR eligible sessions
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_app_wait
                    
                    	Number of sessions in NSR app\-wait state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_none
                    
                    	Number of sessions in NSR none state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_operational
                    
                    	Number of sessions in NSR operational state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_prepare
                    
                    	Number of sessions in NSR prepare state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_ready
                    
                    	Number of sessions in NSR ready state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase1
                    
                    	Number of sessions in NSR TCP phase 1 state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase2
                    
                    	Number of sessions in NSR TCP phase 2 state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_wait
                    
                    	Number of sessions in NSR wait state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total
                    
                    	Total sessions
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.NsrSummaryAll.Sessions, self).__init__()

                        self.yang_name = "sessions"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                        self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                        self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                        self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                        self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                        self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                        self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                        self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                        self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                        self.total = YLeaf(YType.uint32, "total")
                        self._segment_path = lambda: "sessions"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/nsr-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.NsrSummaryAll.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.NsrSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/nsr-summary-all/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.NsrSummaryAll.Vrf, ['id', 'name'], name, value)


            class Summary(Entity):
                """
                LDP summary
                
                .. attribute:: common
                
                	Common Summary information
                	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Summary.Common>`
                
                .. attribute:: is_bound_with_atom
                
                	Bound status with L2VPN ATOM
                	**type**\:  bool
                
                .. attribute:: is_bound_with_interface_manager
                
                	Bound status with Interface Manager
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ip_arm
                
                	Bound status with IP Arm
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ipv4_rib
                
                	Bound status with IPv4 RIB
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ipv6_rib
                
                	Bound status with IPv6 RIB
                	**type**\:  bool
                
                .. attribute:: is_bound_with_lsd
                
                	Bound status with LSD
                	**type**\:  bool
                
                .. attribute:: is_bound_with_nsr_mate
                
                	Bound status with NSR Mate
                	**type**\:  bool
                
                .. attribute:: is_bound_with_rsi
                
                	Bound status with rsi
                	**type**\:  bool
                
                .. attribute:: is_bound_with_sysdb
                
                	Bound status with sysdb
                	**type**\:  bool
                
                .. attribute:: is_mldp_registered
                
                	mLDP registration status
                	**type**\:  bool
                
                .. attribute:: is_nsr_configured
                
                	NSR configured
                	**type**\:  bool
                
                .. attribute:: is_registered_with_interface_manager
                
                	Registration status with Interface Manager
                	**type**\:  bool
                
                .. attribute:: is_registered_with_ipv4_rib
                
                	Registration status with IPv4 RIB
                	**type**\:  bool
                
                .. attribute:: is_registered_with_ipv6_rib
                
                	Registration status with IPv6 RIB
                	**type**\:  bool
                
                .. attribute:: is_registered_with_lsd
                
                	Registration status with LSD
                	**type**\:  bool
                
                .. attribute:: is_registered_with_sysdb
                
                	Registration status with Sysdb
                	**type**\:  bool
                
                .. attribute:: number_of_autocfg_interfaces
                
                	Number of auto\-configured interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_fwd_ref_interfaces
                
                	Number of Forward Referenc interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of known interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_ipv4rib_tables
                
                	Total number of ipv4 RIB tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_ipv6rib_tables
                
                	Total number of ipv6 RIB tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv4rib_tables
                
                	Number of ipv4 RIB tables registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv6rib_tables
                
                	Number of ipv6 RIB tables registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf
                
                	Number of configured VRFs (including default)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf_oper
                
                	Number of configured operational VRFs (including default)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Standby.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"common" : ("common", MplsLdp.Global_.Standby.Summary.Common)}
                    self._child_list_classes = {}

                    self.is_bound_with_atom = YLeaf(YType.boolean, "is-bound-with-atom")

                    self.is_bound_with_interface_manager = YLeaf(YType.boolean, "is-bound-with-interface-manager")

                    self.is_bound_with_ip_arm = YLeaf(YType.boolean, "is-bound-with-ip-arm")

                    self.is_bound_with_ipv4_rib = YLeaf(YType.boolean, "is-bound-with-ipv4-rib")

                    self.is_bound_with_ipv6_rib = YLeaf(YType.boolean, "is-bound-with-ipv6-rib")

                    self.is_bound_with_lsd = YLeaf(YType.boolean, "is-bound-with-lsd")

                    self.is_bound_with_nsr_mate = YLeaf(YType.boolean, "is-bound-with-nsr-mate")

                    self.is_bound_with_rsi = YLeaf(YType.boolean, "is-bound-with-rsi")

                    self.is_bound_with_sysdb = YLeaf(YType.boolean, "is-bound-with-sysdb")

                    self.is_mldp_registered = YLeaf(YType.boolean, "is-mldp-registered")

                    self.is_nsr_configured = YLeaf(YType.boolean, "is-nsr-configured")

                    self.is_registered_with_interface_manager = YLeaf(YType.boolean, "is-registered-with-interface-manager")

                    self.is_registered_with_ipv4_rib = YLeaf(YType.boolean, "is-registered-with-ipv4-rib")

                    self.is_registered_with_ipv6_rib = YLeaf(YType.boolean, "is-registered-with-ipv6-rib")

                    self.is_registered_with_lsd = YLeaf(YType.boolean, "is-registered-with-lsd")

                    self.is_registered_with_sysdb = YLeaf(YType.boolean, "is-registered-with-sysdb")

                    self.number_of_autocfg_interfaces = YLeaf(YType.uint32, "number-of-autocfg-interfaces")

                    self.number_of_fwd_ref_interfaces = YLeaf(YType.uint32, "number-of-fwd-ref-interfaces")

                    self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                    self.number_of_ipv4rib_tables = YLeaf(YType.uint32, "number-of-ipv4rib-tables")

                    self.number_of_ipv6rib_tables = YLeaf(YType.uint32, "number-of-ipv6rib-tables")

                    self.number_of_registered_ipv4rib_tables = YLeaf(YType.uint32, "number-of-registered-ipv4rib-tables")

                    self.number_of_registered_ipv6rib_tables = YLeaf(YType.uint32, "number-of-registered-ipv6rib-tables")

                    self.number_of_vrf = YLeaf(YType.uint32, "number-of-vrf")

                    self.number_of_vrf_oper = YLeaf(YType.uint32, "number-of-vrf-oper")

                    self.common = MplsLdp.Global_.Standby.Summary.Common()
                    self.common.parent = self
                    self._children_name_map["common"] = "common"
                    self._children_yang_names.add("common")
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Standby.Summary, ['is_bound_with_atom', 'is_bound_with_interface_manager', 'is_bound_with_ip_arm', 'is_bound_with_ipv4_rib', 'is_bound_with_ipv6_rib', 'is_bound_with_lsd', 'is_bound_with_nsr_mate', 'is_bound_with_rsi', 'is_bound_with_sysdb', 'is_mldp_registered', 'is_nsr_configured', 'is_registered_with_interface_manager', 'is_registered_with_ipv4_rib', 'is_registered_with_ipv6_rib', 'is_registered_with_lsd', 'is_registered_with_sysdb', 'number_of_autocfg_interfaces', 'number_of_fwd_ref_interfaces', 'number_of_interfaces', 'number_of_ipv4rib_tables', 'number_of_ipv6rib_tables', 'number_of_registered_ipv4rib_tables', 'number_of_registered_ipv6rib_tables', 'number_of_vrf', 'number_of_vrf_oper'], name, value)


                class Common(Entity):
                    """
                    Common Summary information
                    
                    .. attribute:: address_families
                    
                    	Address Families enabled
                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: number_of_bindings_ipv4
                    
                    	Total number of ipv4 bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv6
                    
                    	Total number of ipv6 bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_downstream_on_demand_neighbors
                    
                    	Number of Downstream\-On\-Demand neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_graceful_restart_neighbors
                    
                    	Number of Graceful Restart neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_hello_adj
                    
                    	Number of LDP discovery IPv4 hello adjacencies
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_local_addresses
                    
                    	Number of IPv4 local addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_routes
                    
                    	Number of resolved IPv4 routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4af
                    
                    	Number of IPv4 address\-families enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4ldp_interfaces
                    
                    	Number of LDP IPv4 configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_hello_adj
                    
                    	Number of LDP discovery IPv6 hello adjacencies
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_local_addresses
                    
                    	Number of IPv6 local addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_routes
                    
                    	Number of resolved IPv6 routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6af
                    
                    	Number of IPv6 address\-families enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6ldp_interfaces
                    
                    	Number of LDP IPv6 configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ldp_interfaces
                    
                    	Number of LDP configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv4
                    
                    	Total number of ipv4 local label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv6
                    
                    	Total number of ipv6 local label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_nsr_synced_neighbors
                    
                    	Number of NSR\-synced/operational neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv4
                    
                    	Total number of ipv4 remote label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv6
                    
                    	Total number of ipv6 remote label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.Summary.Common, self).__init__()

                        self.yang_name = "common"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.address_families = YLeaf(YType.enumeration, "address-families")

                        self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                        self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                        self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                        self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                        self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                        self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                        self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                        self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                        self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                        self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                        self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                        self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                        self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                        self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                        self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                        self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                        self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                        self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                        self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                        self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                        self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                        self._segment_path = lambda: "common"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


            class Vrfs(Entity):
                """
                VRF specific operational data
                
                .. attribute:: vrf
                
                	Operational data for given VRF
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Global_.Standby.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "standby"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf)}

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for given VRF
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: afs
                    
                    	Address Family specific operational data
                    	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs>`
                    
                    .. attribute:: backoff_parameters
                    
                    	The LDP Backoff Parameters
                    	**type**\:   :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.BackoffParameters>`
                    
                    .. attribute:: backoffs
                    
                    	The LDP backoff
                    	**type**\:   :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs>`
                    
                    .. attribute:: capabilities
                    
                    	LDP capability database information
                    	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities>`
                    
                    .. attribute:: graceful_restart
                    
                    	LDP Graceful Restart info
                    	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart>`
                    
                    .. attribute:: issu
                    
                    	LDP ISSU related information
                    	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu>`
                    
                    .. attribute:: ldp_id
                    
                    	Local LDP Id
                    	**type**\:   :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.LdpId>`
                    
                    .. attribute:: neighbor_briefs
                    
                    	The LDP Neighbors (brief)
                    	**type**\:   :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs>`
                    
                    .. attribute:: neighbor_capabilities
                    
                    	LDP Neighbors Capabilities
                    	**type**\:   :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities>`
                    
                    .. attribute:: neighbors
                    
                    	The LDP Neighbors
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors>`
                    
                    .. attribute:: nsr
                    
                    	LDP NSR related information
                    	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr>`
                    
                    .. attribute:: parameters
                    
                    	LDP parameters
                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters>`
                    
                    .. attribute:: statistics
                    
                    	The LDP Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics>`
                    
                    .. attribute:: summary
                    
                    	LDP VRF summary
                    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Summary>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Global_.Standby.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"afs" : ("afs", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs), "backoff-parameters" : ("backoff_parameters", MplsLdp.Global_.Standby.Vrfs.Vrf.BackoffParameters), "backoffs" : ("backoffs", MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs), "capabilities" : ("capabilities", MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities), "graceful-restart" : ("graceful_restart", MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart), "issu" : ("issu", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu), "ldp-id" : ("ldp_id", MplsLdp.Global_.Standby.Vrfs.Vrf.LdpId), "neighbor-briefs" : ("neighbor_briefs", MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs), "neighbor-capabilities" : ("neighbor_capabilities", MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities), "neighbors" : ("neighbors", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors), "nsr" : ("nsr", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr), "parameters" : ("parameters", MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters), "statistics" : ("statistics", MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics), "summary" : ("summary", MplsLdp.Global_.Standby.Vrfs.Vrf.Summary)}
                        self._child_list_classes = {}

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.afs = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"
                        self._children_yang_names.add("afs")

                        self.backoff_parameters = MplsLdp.Global_.Standby.Vrfs.Vrf.BackoffParameters()
                        self.backoff_parameters.parent = self
                        self._children_name_map["backoff_parameters"] = "backoff-parameters"
                        self._children_yang_names.add("backoff-parameters")

                        self.backoffs = MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs()
                        self.backoffs.parent = self
                        self._children_name_map["backoffs"] = "backoffs"
                        self._children_yang_names.add("backoffs")

                        self.capabilities = MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities()
                        self.capabilities.parent = self
                        self._children_name_map["capabilities"] = "capabilities"
                        self._children_yang_names.add("capabilities")

                        self.graceful_restart = MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart()
                        self.graceful_restart.parent = self
                        self._children_name_map["graceful_restart"] = "graceful-restart"
                        self._children_yang_names.add("graceful-restart")

                        self.issu = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"
                        self._children_yang_names.add("issu")

                        self.ldp_id = MplsLdp.Global_.Standby.Vrfs.Vrf.LdpId()
                        self.ldp_id.parent = self
                        self._children_name_map["ldp_id"] = "ldp-id"
                        self._children_yang_names.add("ldp-id")

                        self.neighbor_briefs = MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs()
                        self.neighbor_briefs.parent = self
                        self._children_name_map["neighbor_briefs"] = "neighbor-briefs"
                        self._children_yang_names.add("neighbor-briefs")

                        self.neighbor_capabilities = MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities()
                        self.neighbor_capabilities.parent = self
                        self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"
                        self._children_yang_names.add("neighbor-capabilities")

                        self.neighbors = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                        self._children_yang_names.add("neighbors")

                        self.nsr = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                        self._children_yang_names.add("nsr")

                        self.parameters = MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters()
                        self.parameters.parent = self
                        self._children_name_map["parameters"] = "parameters"
                        self._children_yang_names.add("parameters")

                        self.statistics = MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                        self.summary = MplsLdp.Global_.Standby.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                        self._children_yang_names.add("summary")
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/global/standby/vrfs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf, ['vrf_name'], name, value)


                    class Afs(Entity):
                        """
                        Address Family specific operational data
                        
                        .. attribute:: af
                        
                        	Operational data for given Address Family
                        	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"af" : ("af", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af)}

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            Operational data for given Address Family
                            
                            .. attribute:: af_name  <key>
                            
                            	Address Family name
                            	**type**\:   :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                            
                            .. attribute:: bindings
                            
                            	The LDP Bindings
                            	**type**\:   :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings>`
                            
                            .. attribute:: bindings_advertise_spec
                            
                            	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec>`
                            
                            .. attribute:: bindings_summary
                            
                            	Counters for the LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary>`
                            
                            .. attribute:: bindings_summary_all
                            
                            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll>`
                            
                            .. attribute:: discovery
                            
                            	The LDP Discovery
                            	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery>`
                            
                            .. attribute:: forwarding_summary
                            
                            	Summary information regarding LDP forwarding setup
                            	**type**\:   :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary>`
                            
                            .. attribute:: forwardings
                            
                            	The LDP Forwarding rewrites
                            	**type**\:   :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings>`
                            
                            .. attribute:: igp
                            
                            	LDP IGP related information
                            	**type**\:   :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp>`
                            
                            .. attribute:: interface_summary
                            
                            	IPv4 interface summary information
                            	**type**\:   :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary>`
                            
                            .. attribute:: interfaces
                            
                            	LDP Interface related information
                            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"bindings" : ("bindings", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings), "bindings-advertise-spec" : ("bindings_advertise_spec", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec), "bindings-summary" : ("bindings_summary", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll), "discovery" : ("discovery", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery), "forwarding-summary" : ("forwarding_summary", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary), "forwardings" : ("forwardings", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings), "igp" : ("igp", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp), "interface-summary" : ("interface_summary", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary), "interfaces" : ("interfaces", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces)}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.bindings = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings()
                                self.bindings.parent = self
                                self._children_name_map["bindings"] = "bindings"
                                self._children_yang_names.add("bindings")

                                self.bindings_advertise_spec = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec()
                                self.bindings_advertise_spec.parent = self
                                self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"
                                self._children_yang_names.add("bindings-advertise-spec")

                                self.bindings_summary = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary()
                                self.bindings_summary.parent = self
                                self._children_name_map["bindings_summary"] = "bindings-summary"
                                self._children_yang_names.add("bindings-summary")

                                self.bindings_summary_all = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll()
                                self.bindings_summary_all.parent = self
                                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                                self._children_yang_names.add("bindings-summary-all")

                                self.discovery = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery()
                                self.discovery.parent = self
                                self._children_name_map["discovery"] = "discovery"
                                self._children_yang_names.add("discovery")

                                self.forwarding_summary = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary()
                                self.forwarding_summary.parent = self
                                self._children_name_map["forwarding_summary"] = "forwarding-summary"
                                self._children_yang_names.add("forwarding-summary")

                                self.forwardings = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings()
                                self.forwardings.parent = self
                                self._children_name_map["forwardings"] = "forwardings"
                                self._children_yang_names.add("forwardings")

                                self.igp = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp()
                                self.igp.parent = self
                                self._children_name_map["igp"] = "igp"
                                self._children_yang_names.add("igp")

                                self.interface_summary = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary()
                                self.interface_summary.parent = self
                                self._children_name_map["interface_summary"] = "interface-summary"
                                self._children_yang_names.add("interface-summary")

                                self.interfaces = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"
                                self._children_yang_names.add("interfaces")
                                self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                            class Bindings(Entity):
                                """
                                The LDP Bindings
                                
                                .. attribute:: binding
                                
                                	Binding Information
                                	**type**\: list of    :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings, self).__init__()

                                    self.yang_name = "bindings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"binding" : ("binding", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding)}

                                    self.binding = YList(self)
                                    self._segment_path = lambda: "bindings"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings, [], name, value)


                                class Binding(Entity):
                                    """
                                    Binding Information
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	The IP Prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: advertise_prefix_acl
                                    
                                    	Advertise Prerfix ACL
                                    	**type**\:  str
                                    
                                    .. attribute:: advertise_tsr_acl
                                    
                                    	Advertise TSR ACL
                                    	**type**\:  str
                                    
                                    .. attribute:: config_enforced_local_label_value
                                    
                                    	Config/User enforced local label value
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_no_route
                                    
                                    	No route
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_oor
                                    
                                    	Label space depletion OOR
                                    	**type**\:  bool
                                    
                                    .. attribute:: le_local_binding_revision
                                    
                                    	Local Binding revision
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_label_state
                                    
                                    	Local label state
                                    	**type**\:   :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peers_acked
                                    
                                    	Peers that have ACKed this entry
                                    	**type**\: list of    :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                    
                                    .. attribute:: peers_advertised_to
                                    
                                    	Peers this entry is advertised to
                                    	**type**\: list of    :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                    
                                    .. attribute:: remote_binding
                                    
                                    	Remote binding
                                    	**type**\: list of    :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding, self).__init__()

                                        self.yang_name = "binding"
                                        self.yang_parent_name = "bindings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr), "vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf)}
                                        self._child_list_classes = {"peers-acked" : ("peers_acked", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked), "peers-advertised-to" : ("peers_advertised_to", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo), "remote-binding" : ("remote_binding", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.advertise_prefix_acl = YLeaf(YType.str, "advertise-prefix-acl")

                                        self.advertise_tsr_acl = YLeaf(YType.str, "advertise-tsr-acl")

                                        self.config_enforced_local_label_value = YLeaf(YType.boolean, "config-enforced-local-label-value")

                                        self.is_elc = YLeaf(YType.boolean, "is-elc")

                                        self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.le_local_binding_revision = YLeaf(YType.uint32, "le-local-binding-revision")

                                        self.le_local_label_state = YLeaf(YType.enumeration, "le-local-label-state")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.prefix_xr = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"
                                        self._children_yang_names.add("prefix-xr")

                                        self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.peers_acked = YList(self)
                                        self.peers_advertised_to = YList(self)
                                        self.remote_binding = YList(self)
                                        self._segment_path = lambda: "binding" + "[prefix='" + self.prefix.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding, ['prefix', 'advertise_prefix_acl', 'advertise_tsr_acl', 'config_enforced_local_label_value', 'is_elc', 'is_no_route', 'label_oor', 'le_local_binding_revision', 'le_local_label_state', 'local_label', 'prefix_length'], name, value)


                                    class PeersAcked(Entity):
                                        """
                                        Peers that have ACKed this entry
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                            self.yang_name = "peers-acked"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "peers-acked"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class PeersAdvertisedTo(Entity):
                                        """
                                        Peers this entry is advertised to
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                            self.yang_name = "peers-advertised-to"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "prefix-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class RemoteBinding(Entity):
                                        """
                                        Remote binding
                                        
                                        .. attribute:: assigning_peer_ldp_ident
                                        
                                        	Assigning peer
                                        	**type**\:   :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                        
                                        .. attribute:: is_elc
                                        
                                        	Is the entry entropy label capable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_stale
                                        
                                        	Is the entry stale
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                            self.yang_name = "remote-binding"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"assigning-peer-ldp-ident" : ("assigning_peer_ldp_ident", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent)}
                                            self._child_list_classes = {}

                                            self.is_elc = YLeaf(YType.boolean, "is-elc")

                                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.assigning_peer_ldp_ident = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                            self.assigning_peer_ldp_ident.parent = self
                                            self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                            self._children_yang_names.add("assigning-peer-ldp-ident")
                                            self._segment_path = lambda: "remote-binding"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, ['is_elc', 'is_stale', 'remote_label'], name, value)


                                        class AssigningPeerLdpIdent(Entity):
                                            """
                                            Assigning peer
                                            
                                            .. attribute:: label_space_id
                                            
                                            	Label space identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ldp_id
                                            
                                            	LDP identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: lsr_id
                                            
                                            	LSR identifier
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                                self.yang_name = "assigning-peer-ldp-ident"
                                                self.yang_parent_name = "remote-binding"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                self._segment_path = lambda: "assigning-peer-ldp-ident"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf, ['id', 'name'], name, value)


                            class BindingsAdvertiseSpec(Entity):
                                """
                                Advertisement Spec (ACL) for LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: advt_acl
                                
                                	Advertisement ACLs
                                	**type**\: list of    :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                                
                                .. attribute:: allocation_acl
                                
                                	Local label Allocation filter
                                	**type**\:   :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                    self.yang_name = "bindings-advertise-spec"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"allocation-acl" : ("allocation_acl", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)}
                                    self._child_list_classes = {"advt-acl" : ("advt_acl", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl)}

                                    self.allocation_acl = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                    self.allocation_acl.parent = self
                                    self._children_name_map["allocation_acl"] = "allocation-acl"
                                    self._children_yang_names.add("allocation-acl")

                                    self.advt_acl = YList(self)
                                    self._segment_path = lambda: "bindings-advertise-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                                class AdvtAcl(Entity):
                                    """
                                    Advertisement ACLs
                                    
                                    .. attribute:: peer_acl
                                    
                                    	Peer ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                        self.yang_name = "advt-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.peer_acl = YLeaf(YType.str, "peer-acl")

                                        self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                        self._segment_path = lambda: "advt-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, ['peer_acl', 'prefix_acl'], name, value)


                                class AllocationAcl(Entity):
                                    """
                                    Local label Allocation filter
                                    
                                    .. attribute:: has_acl
                                    
                                    	Has ACL filter?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_host_route_only
                                    
                                    	Host\-routes only?
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                        self.yang_name = "allocation-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.has_acl = YLeaf(YType.boolean, "has-acl")

                                        self.is_host_route_only = YLeaf(YType.boolean, "is-host-route-only")

                                        self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                        self._segment_path = lambda: "allocation-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, ['has_acl', 'is_host_route_only', 'prefix_acl'], name, value)


                            class BindingsSummary(Entity):
                                """
                                Counters for the LDP Label Infomation Base
                                (LIB)
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf>`
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary, self).__init__()

                                    self.yang_name = "bindings-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf)}
                                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf)}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                    self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.address_family = YLeaf(YType.enumeration, "address-family")

                                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                        self._segment_path = lambda: "bind-af"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf, ['id', 'name'], name, value)


                            class BindingsSummaryAll(Entity):
                                """
                                Aggregate VRF counters for the LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf>`
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll, self).__init__()

                                    self.yang_name = "bindings-summary-all"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf)}
                                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf)}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                    self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary-all"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary-all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.address_family = YLeaf(YType.enumeration, "address-family")

                                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                        self._segment_path = lambda: "bind-af"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary-all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


                            class Discovery(Entity):
                                """
                                The LDP Discovery
                                
                                .. attribute:: brief
                                
                                	Brief information on LDP discovery
                                	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief>`
                                
                                .. attribute:: link_hellos
                                
                                	The LDP Discovery link
                                	**type**\:   :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos>`
                                
                                .. attribute:: stats
                                
                                	The LDP Discovery Statistics
                                	**type**\:   :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats>`
                                
                                .. attribute:: summary
                                
                                	Summarized information on LDP discovery
                                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary>`
                                
                                .. attribute:: targeted_hellos
                                
                                	The LDP Discovery Targeted
                                	**type**\:   :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery, self).__init__()

                                    self.yang_name = "discovery"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"brief" : ("brief", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief), "link-hellos" : ("link_hellos", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos), "stats" : ("stats", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats), "summary" : ("summary", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary), "targeted-hellos" : ("targeted_hellos", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos)}
                                    self._child_list_classes = {}

                                    self.brief = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief()
                                    self.brief.parent = self
                                    self._children_name_map["brief"] = "brief"
                                    self._children_yang_names.add("brief")

                                    self.link_hellos = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos()
                                    self.link_hellos.parent = self
                                    self._children_name_map["link_hellos"] = "link-hellos"
                                    self._children_yang_names.add("link-hellos")

                                    self.stats = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats()
                                    self.stats.parent = self
                                    self._children_name_map["stats"] = "stats"
                                    self._children_yang_names.add("stats")

                                    self.summary = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary()
                                    self.summary.parent = self
                                    self._children_name_map["summary"] = "summary"
                                    self._children_yang_names.add("summary")

                                    self.targeted_hellos = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos()
                                    self.targeted_hellos.parent = self
                                    self._children_name_map["targeted_hellos"] = "targeted-hellos"
                                    self._children_yang_names.add("targeted-hellos")
                                    self._segment_path = lambda: "discovery"


                                class Brief(Entity):
                                    """
                                    Brief information on LDP discovery
                                    
                                    .. attribute:: link_hello_briefs
                                    
                                    	The LDP Discovery link brief information
                                    	**type**\:   :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                    
                                    .. attribute:: targeted_hello_briefs
                                    
                                    	The LDP Discovery Targeted brief information
                                    	**type**\:   :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief, self).__init__()

                                        self.yang_name = "brief"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-briefs" : ("link_hello_briefs", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs), "targeted-hello-briefs" : ("targeted_hello_briefs", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs)}
                                        self._child_list_classes = {}

                                        self.link_hello_briefs = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                        self.link_hello_briefs.parent = self
                                        self._children_name_map["link_hello_briefs"] = "link-hello-briefs"
                                        self._children_yang_names.add("link-hello-briefs")

                                        self.targeted_hello_briefs = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                        self.targeted_hello_briefs.parent = self
                                        self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                        self._children_yang_names.add("targeted-hello-briefs")
                                        self._segment_path = lambda: "brief"


                                    class LinkHelloBriefs(Entity):
                                        """
                                        The LDP Discovery link brief information
                                        
                                        .. attribute:: link_hello_brief
                                        
                                        	Brief information on LDP link discovery
                                        	**type**\: list of    :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                            self.yang_name = "link-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"link-hello-brief" : ("link_hello_brief", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief)}

                                            self.link_hello_brief = YList(self)
                                            self._segment_path = lambda: "link-hello-briefs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                        class LinkHelloBrief(Entity):
                                            """
                                            Brief information on LDP link discovery
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	The Interface Name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: address_family
                                            
                                            	Discovery Brief Address Family
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: address_family_set
                                            
                                            	Discovery Brief Address Family Set
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: interface_name_xr
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                                self.yang_name = "link-hello-brief"
                                                self.yang_parent_name = "link-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)}
                                                self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation)}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                                self.address_family_set = YLeaf(YType.enumeration, "address-family-set")

                                                self.interface = YLeaf(YType.str, "interface")

                                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                                self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"
                                                self._children_yang_names.add("vrf")

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', 'address_family', 'address_family_set', 'interface', 'interface_name_xr'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                    self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                    self.session_up = YLeaf(YType.boolean, "session-up")
                                                    self._segment_path = lambda: "hello-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                            class Vrf(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.id = YLeaf(YType.uint32, "id")

                                                    self.name = YLeaf(YType.str, "name")
                                                    self._segment_path = lambda: "vrf"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, ['id', 'name'], name, value)


                                    class TargetedHelloBriefs(Entity):
                                        """
                                        The LDP Discovery Targeted brief information
                                        
                                        .. attribute:: targeted_hello_brief
                                        
                                        	Brief information on LDP targeted discovery
                                        	**type**\: list of    :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                            self.yang_name = "targeted-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"targeted-hello-brief" : ("targeted_hello_brief", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief)}

                                            self.targeted_hello_brief = YList(self)
                                            self._segment_path = lambda: "targeted-hello-briefs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                        class TargetedHelloBrief(Entity):
                                            """
                                            Brief information on LDP targeted discovery
                                            
                                            .. attribute:: address_family
                                            
                                            	Targeted Discovery Address Family
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: dhcb_target_address
                                            
                                            	DHCB target address
                                            	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: target_address
                                            
                                            	The target IP Address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                                self.yang_name = "targeted-hello-brief"
                                                self.yang_parent_name = "targeted-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"dhcb-target-address" : ("dhcb_target_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress), "vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)}
                                                self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation)}

                                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.target_address = YLeaf(YType.str, "target-address")

                                                self.dhcb_target_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                                self.dhcb_target_address.parent = self
                                                self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                                self._children_yang_names.add("dhcb-target-address")

                                                self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"
                                                self._children_yang_names.add("vrf")

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "targeted-hello-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['address_family', 'local_address', 'target_address'], name, value)


                                            class DhcbTargetAddress(Entity):
                                                """
                                                DHCB target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                    self.yang_name = "dhcb-target-address"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "dhcb-target-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                    self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                    self.session_up = YLeaf(YType.boolean, "session-up")
                                                    self._segment_path = lambda: "hello-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                            class Vrf(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.id = YLeaf(YType.uint32, "id")

                                                    self.name = YLeaf(YType.str, "name")
                                                    self._segment_path = lambda: "vrf"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, ['id', 'name'], name, value)


                                class LinkHellos(Entity):
                                    """
                                    The LDP Discovery link
                                    
                                    .. attribute:: link_hello
                                    
                                    	Information on LDP link discovery
                                    	**type**\: list of    :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                        self.yang_name = "link-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"link-hello" : ("link_hello", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello)}

                                        self.link_hello = YList(self)
                                        self._segment_path = lambda: "link-hellos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                    class LinkHello(Entity):
                                        """
                                        Information on LDP link discovery
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: discovery_link_af
                                        
                                        	LDP hello AF info
                                        	**type**\: list of    :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                            self.yang_name = "link-hello"
                                            self.yang_parent_name = "link-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)}
                                            self._child_list_classes = {"discovery-link-af" : ("discovery_link_af", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf), "hello-information" : ("hello_information", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.next_hello = YLeaf(YType.uint32, "next-hello")

                                            self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                            self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.discovery_link_af = YList(self)
                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', 'interface', 'interface_name_xr', 'next_hello', 'quick_start_disabled'], name, value)


                                        class DiscoveryLinkAf(Entity):
                                            """
                                            LDP hello AF info
                                            
                                            .. attribute:: interval
                                            
                                            	Hello interval in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_src_address
                                            
                                            	Local source address
                                            	**type**\:   :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                            
                                            .. attribute:: local_transport_address
                                            
                                            	Local transport address
                                            	**type**\:   :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                                self.yang_name = "discovery-link-af"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"local-src-address" : ("local_src_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress), "local-transport-address" : ("local_transport_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress)}
                                                self._child_list_classes = {}

                                                self.interval = YLeaf(YType.uint32, "interval")

                                                self.local_src_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                                self.local_src_address.parent = self
                                                self._children_name_map["local_src_address"] = "local-src-address"
                                                self._children_yang_names.add("local-src-address")

                                                self.local_transport_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                                self.local_transport_address.parent = self
                                                self._children_name_map["local_transport_address"] = "local-transport-address"
                                                self._children_yang_names.add("local-transport-address")
                                                self._segment_path = lambda: "discovery-link-af"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, ['interval'], name, value)


                                            class LocalSrcAddress(Entity):
                                                """
                                                Local source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                    self.yang_name = "local-src-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "local-src-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class LocalTransportAddress(Entity):
                                                """
                                                Local transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                    self.yang_name = "local-transport-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "local-transport-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: disc_expiry
                                            
                                            	Discovery expiry time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: established_age
                                            
                                            	Hello adjacency estabished age in nanosec
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: established_time
                                            
                                            	Hello adjacency estabished time in nanosec
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: is_no_route
                                            
                                            	Is route valid
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_targeted
                                            
                                            	Is session a targeted session
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_session_down_info
                                            
                                            	Last session down information
                                            	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                            
                                            .. attribute:: local_hold_time
                                            
                                            	Local hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_hold_time
                                            
                                            	Neighbor hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_src_address
                                            
                                            	Neighbor source address
                                            	**type**\:   :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                            
                                            .. attribute:: neighbor_transport_address
                                            
                                            	Neighbor transport address
                                            	**type**\:   :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                            
                                            .. attribute:: session_bringup_failure_reason
                                            
                                            	session bringup failure reason
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            .. attribute:: target
                                            
                                            	Target address
                                            	**type**\:   :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-src-address" : ("neighbor_src_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress), "neighbor-transport-address" : ("neighbor_transport_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress), "target" : ("target", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)}
                                                self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo)}

                                                self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                                self.established_age = YLeaf(YType.uint64, "established-age")

                                                self.established_time = YLeaf(YType.uint64, "established-time")

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                                self.is_targeted = YLeaf(YType.boolean, "is-targeted")

                                                self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                                self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                                self.session_up = YLeaf(YType.boolean, "session-up")

                                                self.neighbor_src_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                                self.neighbor_src_address.parent = self
                                                self._children_name_map["neighbor_src_address"] = "neighbor-src-address"
                                                self._children_yang_names.add("neighbor-src-address")

                                                self.neighbor_transport_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                                self.neighbor_transport_address.parent = self
                                                self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"
                                                self._children_yang_names.add("neighbor-transport-address")

                                                self.target = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                                self.target.parent = self
                                                self._children_name_map["target"] = "target"
                                                self._children_yang_names.add("target")

                                                self.last_session_down_info = YList(self)
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, ['disc_expiry', 'established_age', 'established_time', 'hold_time', 'is_no_route', 'is_targeted', 'local_hold_time', 'neighbor_hold_time', 'neighbor_ldp_identifier', 'session_bringup_failure_reason', 'session_up'], name, value)


                                            class LastSessionDownInfo(Entity):
                                                """
                                                Last session down information
                                                
                                                .. attribute:: last_session_down_reason
                                                
                                                	The reason of last socket failure
                                                	**type**\:  str
                                                
                                                .. attribute:: last_session_down_time
                                                
                                                	Timestamp of when the last session went down
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: last_session_up_time
                                                
                                                	The time duration the last session was up
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                    self.yang_name = "last-session-down-info"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                    self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                    self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                    self._segment_path = lambda: "last-session-down-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                                            class NeighborSrcAddress(Entity):
                                                """
                                                Neighbor source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                    self.yang_name = "neighbor-src-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "neighbor-src-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class NeighborTransportAddress(Entity):
                                                """
                                                Neighbor transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                    self.yang_name = "neighbor-transport-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "neighbor-transport-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class Target(Entity):
                                                """
                                                Target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                    self.yang_name = "target"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "target"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, ['id', 'name'], name, value)


                                class Stats(Entity):
                                    """
                                    The LDP Discovery Statistics
                                    
                                    .. attribute:: stat
                                    
                                    	Information on LDP discovery statistics
                                    	**type**\: list of    :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats, self).__init__()

                                        self.yang_name = "stats"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"stat" : ("stat", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat)}

                                        self.stat = YList(self)
                                        self._segment_path = lambda: "stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats, [], name, value)


                                    class Stat(Entity):
                                        """
                                        Information on LDP discovery statistics
                                        
                                        .. attribute:: adjacency_group_up_time
                                        
                                        	Adjacency group up time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space ID of neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR ID of neighbor
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: tcp_arb_chg_count
                                        
                                        	Count of changes in TCP arbitration
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_open_count
                                        
                                        	Count of attempted TCP opens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_role
                                        
                                        	TCP Role
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                            self.yang_name = "stat"
                                            self.yang_parent_name = "stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.adjacency_group_up_time = YLeaf(YType.uint32, "adjacency-group-up-time")

                                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                                            self.tcp_arb_chg_count = YLeaf(YType.uint32, "tcp-arb-chg-count")

                                            self.tcp_open_count = YLeaf(YType.uint32, "tcp-open-count")

                                            self.tcp_role = YLeaf(YType.uint32, "tcp-role")
                                            self._segment_path = lambda: "stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, ['adjacency_group_up_time', 'label_space_id', 'lsr_id', 'tcp_arb_chg_count', 'tcp_open_count', 'tcp_role'], name, value)


                                class Summary(Entity):
                                    """
                                    Summarized information on LDP discovery
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: num_of_active_ldp_interfaces
                                    
                                    	Number of active LDP enabled interfaces
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_addr_recv
                                    
                                    	Number of hello discoveries received with bad source address
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_hello_pdu
                                    
                                    	Number of hello discoveries received with bad hello PDU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_xport_addr
                                    
                                    	Number of hello discoveries received with bad export address
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_same_router_id
                                    
                                    	Number of hello discoveries received with the same router id as this router
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_wrong_router_id
                                    
                                    	Number of hello discoveries received with the router id that is not destined for this router
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_ldp_interfaces
                                    
                                    	Total Number of LDP configured interfaces
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_recv
                                    
                                    	Number of link hello discoveries in recv state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_xmit
                                    
                                    	Number of link hello discoveries in xmit state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_recv
                                    
                                    	Number of targeted hello discoveries in recv state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_xmit
                                    
                                    	Number of targeted hello discoveries in xmit state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary, self).__init__()

                                        self.yang_name = "summary"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf)}
                                        self._child_list_classes = {}

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                                        self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                                        self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                                        self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                                        self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                                        self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                                        self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                                        self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                                        self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                                        self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                                        self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                                        self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf, ['id', 'name'], name, value)


                                class TargetedHellos(Entity):
                                    """
                                    The LDP Discovery Targeted
                                    
                                    .. attribute:: targeted_hello
                                    
                                    	Information on LDP targeted discovery
                                    	**type**\: list of    :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                        self.yang_name = "targeted-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"targeted-hello" : ("targeted_hello", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello)}

                                        self.targeted_hello = YList(self)
                                        self._segment_path = lambda: "targeted-hellos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                    class TargetedHello(Entity):
                                        """
                                        Information on LDP targeted discovery
                                        
                                        .. attribute:: adjacency_ldp_identifier
                                        
                                        	Adjacency LDP Identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcb_local_address
                                        
                                        	DHCB local address
                                        	**type**\:   :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: hold_time
                                        
                                        	Targeted hello hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\:  str
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\:  bool
                                        
                                        .. attribute:: state
                                        
                                        	Targeted hello state
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                            self.yang_name = "targeted-hello"
                                            self.yang_parent_name = "targeted-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"dhcb-local-address" : ("dhcb_local_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress), "dhcb-target-address" : ("dhcb_target_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)}
                                            self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo)}

                                            self.adjacency_ldp_identifier = YLeaf(YType.str, "adjacency-ldp-identifier")

                                            self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                            self.established_age = YLeaf(YType.uint64, "established-age")

                                            self.established_time = YLeaf(YType.uint64, "established-time")

                                            self.hold_time = YLeaf(YType.uint32, "hold-time")

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                            self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                            self.next_hello = YLeaf(YType.uint32, "next-hello")

                                            self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                            self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                            self.session_up = YLeaf(YType.boolean, "session-up")

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.target_address = YLeaf(YType.str, "target-address")

                                            self.dhcb_local_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                            self.dhcb_local_address.parent = self
                                            self._children_name_map["dhcb_local_address"] = "dhcb-local-address"
                                            self._children_yang_names.add("dhcb-local-address")

                                            self.dhcb_target_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                            self._children_yang_names.add("dhcb-target-address")

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "targeted-hello"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['adjacency_ldp_identifier', 'disc_expiry', 'established_age', 'established_time', 'hold_time', 'interval', 'local_address', 'local_hold_time', 'neighbor_hold_time', 'next_hello', 'quick_start_disabled', 'session_bringup_failure_reason', 'session_up', 'state', 'target_address'], name, value)


                                        class DhcbLocalAddress(Entity):
                                            """
                                            DHCB local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                                self.yang_name = "dhcb-local-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\:  str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                self._segment_path = lambda: "last-session-down-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                            class ForwardingSummary(Entity):
                                """
                                Summary information regarding LDP forwarding
                                setup
                                
                                .. attribute:: fsht
                                
                                	Forwarding state hold time registered with LSD
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: intfs
                                
                                	MPLS forwarding enabled interface count
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_lsd_bound
                                
                                	LDP is connected to LSD server
                                	**type**\:  bool
                                
                                .. attribute:: lbls
                                
                                	Local label allocated count
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rws
                                
                                	Forwarding rewrites summary
                                	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary, self).__init__()

                                    self.yang_name = "forwarding-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rws" : ("rws", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws), "vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf)}
                                    self._child_list_classes = {}

                                    self.fsht = YLeaf(YType.uint16, "fsht")

                                    self.intfs = YLeaf(YType.uint16, "intfs")

                                    self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                                    self.lbls = YLeaf(YType.uint16, "lbls")

                                    self.rws = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws()
                                    self.rws.parent = self
                                    self._children_name_map["rws"] = "rws"
                                    self._children_yang_names.add("rws")

                                    self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "forwarding-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                                class Rws(Entity):
                                    """
                                    Forwarding rewrites summary
                                    
                                    .. attribute:: nhs
                                    
                                    	Forwarding rewrites nexthops (paths) summary
                                    	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                    
                                    .. attribute:: pfxs
                                    
                                    	Forwarding rewrites prefix summary
                                    	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                        self.yang_name = "rws"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs)}
                                        self._child_list_classes = {}

                                        self.nhs = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                        self.nhs.parent = self
                                        self._children_name_map["nhs"] = "nhs"
                                        self._children_yang_names.add("nhs")

                                        self.pfxs = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                        self.pfxs.parent = self
                                        self._children_name_map["pfxs"] = "pfxs"
                                        self._children_yang_names.add("pfxs")
                                        self._segment_path = lambda: "rws"


                                    class Nhs(Entity):
                                        """
                                        Forwarding rewrites nexthops (paths) summary
                                        
                                        .. attribute:: backup_paths
                                        
                                        	Count of non\-primary backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_backup_paths
                                        
                                        	Count of labeled backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_paths
                                        
                                        	Count of all labeled paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: protected_paths
                                        
                                        	Count of FRR protected paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_backup_paths
                                        
                                        	Count of non\-primary remote backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_paths
                                        
                                        	Total path count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                            self.yang_name = "nhs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                                            self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                                            self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                                            self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                                            self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                                            self.total_paths = YLeaf(YType.uint32, "total-paths")
                                            self._segment_path = lambda: "nhs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                                    class Pfxs(Entity):
                                        """
                                        Forwarding rewrites prefix summary
                                        
                                        .. attribute:: ecmp_pfxs
                                        
                                        	Count of prefixes with ECMP
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_aggr
                                        
                                        	Labeled prefix count for all paths
                                        	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                        
                                        .. attribute:: labeled_pfxs_backup
                                        
                                        	Labeled prefix count related to backup paths only
                                        	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                        
                                        .. attribute:: labeled_pfxs_primary
                                        
                                        	Labeled prefix count related to primary paths only
                                        	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                        
                                        .. attribute:: protected_pfxs
                                        
                                        	Count of FRR protected prefixes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: total_pfxs
                                        
                                        	Total Prefix count
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                            self.yang_name = "pfxs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)}
                                            self._child_list_classes = {}

                                            self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                                            self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                                            self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                                            self.labeled_pfxs_aggr = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                            self.labeled_pfxs_aggr.parent = self
                                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                                            self._children_yang_names.add("labeled-pfxs-aggr")

                                            self.labeled_pfxs_backup = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                            self.labeled_pfxs_backup.parent = self
                                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                            self._children_yang_names.add("labeled-pfxs-backup")

                                            self.labeled_pfxs_primary = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                            self.labeled_pfxs_primary.parent = self
                                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                                            self._children_yang_names.add("labeled-pfxs-primary")
                                            self._segment_path = lambda: "pfxs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                                        class LabeledPfxsAggr(Entity):
                                            """
                                            Labeled prefix count for all paths
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                                self.yang_name = "labeled-pfxs-aggr"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-aggr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsBackup(Entity):
                                            """
                                            Labeled prefix count related to backup paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                                self.yang_name = "labeled-pfxs-backup"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-backup"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsPrimary(Entity):
                                            """
                                            Labeled prefix count related to primary paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                                self.yang_name = "labeled-pfxs-primary"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-primary"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf, ['id', 'name'], name, value)


                            class Forwardings(Entity):
                                """
                                The LDP Forwarding rewrites
                                
                                .. attribute:: forwarding
                                
                                	Information on a particular LDP forwarding rewrite
                                	**type**\: list of    :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings, self).__init__()

                                    self.yang_name = "forwardings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"forwarding" : ("forwarding", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding)}

                                    self.forwarding = YList(self)
                                    self._segment_path = lambda: "forwardings"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings, [], name, value)


                                class Forwarding(Entity):
                                    """
                                    Information on a particular LDP forwarding
                                    rewrite
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	The IP Prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: paths
                                    
                                    	Paths
                                    	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                    
                                    .. attribute:: route
                                    
                                    	Route
                                    	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route>`
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID associated with IP prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                        self.yang_name = "forwarding"
                                        self.yang_parent_name = "forwardings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr), "route" : ("route", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route), "vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf)}
                                        self._child_list_classes = {"paths" : ("paths", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.table_id = YLeaf(YType.uint32, "table-id")

                                        self.prefix_xr = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"
                                        self._children_yang_names.add("prefix-xr")

                                        self.route = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route()
                                        self.route.parent = self
                                        self._children_name_map["route"] = "route"
                                        self._children_yang_names.add("route")

                                        self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.paths = YList(self)
                                        self._segment_path = lambda: "forwarding" + "[prefix='" + self.prefix.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, ['prefix', 'prefix_length', 'table_id'], name, value)


                                    class Paths(Entity):
                                        """
                                        Paths
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls), "routing" : ("routing", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)}
                                            self._child_list_classes = {}

                                            self.mpls = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._children_yang_names.add("mpls")

                                            self.routing = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"
                                            self._children_yang_names.add("routing")
                                            self._segment_path = lambda: "paths"


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	MPLS nexthop info
                                            	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo), "remote-lfa" : ("remote_lfa", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa)}
                                                self._child_list_classes = {}

                                                self.mpls_outgoing_info = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._children_yang_names.add("mpls-outgoing-info")

                                                self.remote_lfa = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")
                                                self._segment_path = lambda: "mpls"


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                MPLS nexthop info
                                                
                                                .. attribute:: is_from_graceful_restartable_neighbor
                                                
                                                	Is from a GR neighbor
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_stale
                                                
                                                	Is the entry stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_peer_ldp_ident
                                                
                                                	Nexthop LDP peer
                                                	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                                
                                                .. attribute:: out_label
                                                
                                                	Outgoing label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: out_label_owner
                                                
                                                	Outgoing label owner
                                                	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                
                                                .. attribute:: out_label_rsn
                                                
                                                	Outgoing label reason
                                                	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                
                                                .. attribute:: out_label_type
                                                
                                                	Outgoing Label Type
                                                	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent)}
                                                    self._child_list_classes = {}

                                                    self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                    self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                    self.out_label = YLeaf(YType.uint32, "out-label")

                                                    self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                    self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                    self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                    self.nexthop_peer_ldp_ident = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                    self.nexthop_peer_ldp_ident.parent = self
                                                    self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                    self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                    self._segment_path = lambda: "mpls-outgoing-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                class NexthopPeerLdpIdent(Entity):
                                                    """
                                                    Nexthop LDP peer
                                                    
                                                    .. attribute:: label_space_id
                                                    
                                                    	Label space identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ldp_id
                                                    
                                                    	LDP identifier
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: lsr_id
                                                    
                                                    	LSR identifier
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                        self.yang_name = "nexthop-peer-ldp-ident"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                        self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_outgoing_info
                                                
                                                	Remote LFA MPLS nexthop(s\_ info
                                                	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo)}
                                                    self._child_list_classes = {}

                                                    self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                    self.mpls_outgoing_info = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                    self.mpls_outgoing_info.parent = self
                                                    self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                    self._children_yang_names.add("mpls-outgoing-info")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, ['has_remote_lfa_bkup'], name, value)


                                                class MplsOutgoingInfo(Entity):
                                                    """
                                                    Remote LFA MPLS nexthop(s\_ info
                                                    
                                                    .. attribute:: stack
                                                    
                                                    	Inner label stack info
                                                    	**type**\: list of    :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                        self.yang_name = "mpls-outgoing-info"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"stack" : ("stack", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack)}

                                                        self.stack = YList(self)
                                                        self._segment_path = lambda: "mpls-outgoing-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                    class Stack(Entity):
                                                        """
                                                        Inner label stack info
                                                        
                                                        .. attribute:: is_from_graceful_restartable_neighbor
                                                        
                                                        	Is from a GR neighbor
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_stale
                                                        
                                                        	Is the entry stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: nexthop_peer_ldp_ident
                                                        
                                                        	Nexthop LDP peer
                                                        	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                        
                                                        .. attribute:: out_label
                                                        
                                                        	Outgoing label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: out_label_owner
                                                        
                                                        	Outgoing label owner
                                                        	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                        
                                                        .. attribute:: out_label_rsn
                                                        
                                                        	Outgoing label reason
                                                        	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                        
                                                        .. attribute:: out_label_type
                                                        
                                                        	Outgoing Label Type
                                                        	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                            self.yang_name = "stack"
                                                            self.yang_parent_name = "mpls-outgoing-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent)}
                                                            self._child_list_classes = {}

                                                            self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                            self.out_label = YLeaf(YType.uint32, "out-label")

                                                            self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                            self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                            self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                            self.nexthop_peer_ldp_ident = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                            self.nexthop_peer_ldp_ident.parent = self
                                                            self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                            self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                            self._segment_path = lambda: "stack"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                        class NexthopPeerLdpIdent(Entity):
                                                            """
                                                            Nexthop LDP peer
                                                            
                                                            .. attribute:: label_space_id
                                                            
                                                            	Label space identifier
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ldp_id
                                                            
                                                            	LDP identifier
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: lsr_id
                                                            
                                                            	LSR identifier
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'mpls-ldp-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                                self.yang_name = "nexthop-peer-ldp-ident"
                                                                self.yang_parent_name = "stack"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                                self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: bkup_path_id
                                            
                                            	Backup path Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface Name
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	Path's load metric for load balancing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next Hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                            
                                            .. attribute:: next_hop_table_id
                                            
                                            	Table ID for nexthop address
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_id
                                            
                                            	Nexthop Identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_is_overriden
                                            
                                            	Nexthop is overriden by LDP
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_flags
                                            
                                            	Routing path flags decoded
                                            	**type**\:   :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                            
                                            .. attribute:: path_id
                                            
                                            	path Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop" : ("next_hop", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop), "remote-lfa" : ("remote_lfa", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa)}
                                                self._child_list_classes = {}

                                                self.bkup_path_id = YLeaf(YType.uint8, "bkup-path-id")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.interface = YLeaf(YType.str, "interface")

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                                self.nh_is_overriden = YLeaf(YType.boolean, "nh-is-overriden")

                                                self.path_flags = YLeaf(YType.enumeration, "path-flags")

                                                self.path_id = YLeaf(YType.uint8, "path-id")

                                                self.next_hop = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.remote_lfa = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")
                                                self._segment_path = lambda: "routing"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, ['bkup_path_id', 'flags', 'interface', 'interface_name', 'load_metric', 'next_hop_table_id', 'nexthop_id', 'nh_is_overriden', 'path_flags', 'path_id'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next Hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: has_q_node
                                                
                                                	Whether remote LFA path has a Q node associated
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: needs_tldp
                                                
                                                	Whether TLDP is needed with remote PQ node
                                                	**type**\:  bool
                                                
                                                .. attribute:: remote_p_node_id
                                                
                                                	Remote/P node address
                                                	**type**\:   :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                                
                                                .. attribute:: remote_q_node_id
                                                
                                                	Remote/Q node address
                                                	**type**\:   :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"remote-p-node-id" : ("remote_p_node_id", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId), "remote-q-node-id" : ("remote_q_node_id", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId)}
                                                    self._child_list_classes = {}

                                                    self.has_q_node = YLeaf(YType.boolean, "has-q-node")

                                                    self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                    self.needs_tldp = YLeaf(YType.boolean, "needs-tldp")

                                                    self.remote_p_node_id = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                    self.remote_p_node_id.parent = self
                                                    self._children_name_map["remote_p_node_id"] = "remote-p-node-id"
                                                    self._children_yang_names.add("remote-p-node-id")

                                                    self.remote_q_node_id = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                    self.remote_q_node_id.parent = self
                                                    self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                    self._children_yang_names.add("remote-q-node-id")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, ['has_q_node', 'has_remote_lfa_bkup', 'needs_tldp'], name, value)


                                                class RemotePNodeId(Entity):
                                                    """
                                                    Remote/P node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                        self.yang_name = "remote-p-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                                        self._segment_path = lambda: "remote-p-node-id"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                                class RemoteQNodeId(Entity):
                                                    """
                                                    Remote/Q node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                        self.yang_name = "remote-q-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                                        self._segment_path = lambda: "remote-q-node-id"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "prefix-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class Route(Entity):
                                        """
                                        Route
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                            self.yang_name = "route"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls), "routing" : ("routing", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing)}
                                            self._child_list_classes = {}

                                            self.mpls = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._children_yang_names.add("mpls")

                                            self.routing = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"
                                            self._children_yang_names.add("routing")
                                            self._segment_path = lambda: "route"


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: forwarding_update_age
                                            
                                            	Last Forwarding update nanosec age
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: forwarding_update_count
                                            
                                            	Number of forwarding updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_timestamp
                                            
                                            	Last Forwarding update nanosec timestamp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.forwarding_update_age = YLeaf(YType.uint64, "forwarding-update-age")

                                                self.forwarding_update_count = YLeaf(YType.uint32, "forwarding-update-count")

                                                self.forwarding_update_timestamp = YLeaf(YType.uint64, "forwarding-update-timestamp")

                                                self.local_label = YLeaf(YType.uint32, "local-label")
                                                self._segment_path = lambda: "mpls"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, ['forwarding_update_age', 'forwarding_update_count', 'forwarding_update_timestamp', 'local_label'], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: flags
                                            
                                            	Route RIB flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_local_vrf_leaked
                                            
                                            	Is route leaked across local VRFs?
                                            	**type**\:  bool
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: routing_update_age
                                            
                                            	Last Routing update nanosec age
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: routing_update_count
                                            
                                            	Number of routing updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: routing_update_timestamp
                                            
                                            	Last Routing update nanosec timestamp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: source
                                            
                                            	Route source protol Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sr_local_label
                                            
                                            	SR Local\-label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: version
                                            
                                            	Route RIB ersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.is_local_vrf_leaked = YLeaf(YType.boolean, "is-local-vrf-leaked")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.routing_update_age = YLeaf(YType.uint64, "routing-update-age")

                                                self.routing_update_count = YLeaf(YType.uint32, "routing-update-count")

                                                self.routing_update_timestamp = YLeaf(YType.uint64, "routing-update-timestamp")

                                                self.source = YLeaf(YType.uint16, "source")

                                                self.sr_local_label = YLeaf(YType.uint32, "sr-local-label")

                                                self.type = YLeaf(YType.uint16, "type")

                                                self.version = YLeaf(YType.uint32, "version")
                                                self._segment_path = lambda: "routing"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, ['flags', 'is_local_vrf_leaked', 'metric', 'priority', 'routing_update_age', 'routing_update_count', 'routing_update_timestamp', 'source', 'sr_local_label', 'type', 'version'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf, ['id', 'name'], name, value)


                            class Igp(Entity):
                                """
                                LDP IGP related information
                                
                                .. attribute:: sync_delay_restart
                                
                                	LDP\-IGP Synchronization Delay related information
                                	**type**\:   :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart>`
                                
                                .. attribute:: syncs
                                
                                	LDP IGP Sync related information
                                	**type**\:   :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp, self).__init__()

                                    self.yang_name = "igp"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sync-delay-restart" : ("sync_delay_restart", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart), "syncs" : ("syncs", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs)}
                                    self._child_list_classes = {}

                                    self.sync_delay_restart = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart()
                                    self.sync_delay_restart.parent = self
                                    self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                    self._children_yang_names.add("sync-delay-restart")

                                    self.syncs = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs()
                                    self.syncs.parent = self
                                    self._children_name_map["syncs"] = "syncs"
                                    self._children_yang_names.add("syncs")
                                    self._segment_path = lambda: "igp"


                                class SyncDelayRestart(Entity):
                                    """
                                    LDP\-IGP Synchronization Delay related
                                    information
                                    
                                    .. attribute:: configured
                                    
                                    	Is restart delay configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: delay_secs
                                    
                                    	Delay time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remaining_secs
                                    
                                    	Delay timer remaining time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timer_running
                                    
                                    	Is restart delay timer running
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                        self.yang_name = "sync-delay-restart"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.configured = YLeaf(YType.boolean, "configured")

                                        self.delay_secs = YLeaf(YType.uint32, "delay-secs")

                                        self.remaining_secs = YLeaf(YType.uint32, "remaining-secs")

                                        self.timer_running = YLeaf(YType.boolean, "timer-running")
                                        self._segment_path = lambda: "sync-delay-restart"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, ['configured', 'delay_secs', 'remaining_secs', 'timer_running'], name, value)


                                class Syncs(Entity):
                                    """
                                    LDP IGP Sync related information
                                    
                                    .. attribute:: sync
                                    
                                    	LDP\-IGP Synchronization related information for an interface
                                    	**type**\: list of    :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs, self).__init__()

                                        self.yang_name = "syncs"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"sync" : ("sync", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync)}

                                        self.sync = YList(self)
                                        self._segment_path = lambda: "syncs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs, [], name, value)


                                    class Sync(Entity):
                                        """
                                        LDP\-IGP Synchronization related information
                                        for an interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: delay_timer_remaining
                                        
                                        	Remaining timer (seconds) till expiry of sync delay timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_only_peer
                                        
                                        	Interface GR\-only reachable peers
                                        	**type**\: list of    :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                        
                                        .. attribute:: igp_sync_delay
                                        
                                        	IGP sync delay in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: igp_sync_down_reason
                                        
                                        	Reason IGP Sync Not Achieved
                                        	**type**\:   :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                        
                                        .. attribute:: igp_sync_state
                                        
                                        	IGP Sync state
                                        	**type**\:   :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_delay_timer_running
                                        
                                        	Is sync delay timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: peers
                                        
                                        	Interface Peers
                                        	**type**\: list of    :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                            self.yang_name = "sync"
                                            self.yang_parent_name = "syncs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf)}
                                            self._child_list_classes = {"gr-only-peer" : ("gr_only_peer", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer), "peers" : ("peers", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.delay_timer_remaining = YLeaf(YType.uint32, "delay-timer-remaining")

                                            self.igp_sync_delay = YLeaf(YType.uint32, "igp-sync-delay")

                                            self.igp_sync_down_reason = YLeaf(YType.enumeration, "igp-sync-down-reason")

                                            self.igp_sync_state = YLeaf(YType.enumeration, "igp-sync-state")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.is_delay_timer_running = YLeaf(YType.boolean, "is-delay-timer-running")

                                            self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.gr_only_peer = YList(self)
                                            self.peers = YList(self)
                                            self._segment_path = lambda: "sync" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', 'delay_timer_remaining', 'igp_sync_delay', 'igp_sync_down_reason', 'igp_sync_state', 'interface_name_xr', 'is_delay_timer_running'], name, value)


                                        class GrOnlyPeer(Entity):
                                            """
                                            Interface GR\-only reachable peers
                                            
                                            .. attribute:: is_chkpt_created
                                            
                                            	Is created due to checkpointing
                                            	**type**\:  bool
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                                self.yang_name = "gr-only-peer"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.is_chkpt_created = YLeaf(YType.boolean, "is-chkpt-created")

                                                self.peer_id = YLeaf(YType.str, "peer-id")
                                                self._segment_path = lambda: "gr-only-peer"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, ['is_chkpt_created', 'peer_id'], name, value)


                                        class Peers(Entity):
                                            """
                                            Interface Peers
                                            
                                            .. attribute:: is_gr_enabled
                                            
                                            	Is GR enabled session
                                            	**type**\:  bool
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                                self.yang_name = "peers"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                                                self.peer_id = YLeaf(YType.str, "peer-id")
                                                self._segment_path = lambda: "peers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, ['is_gr_enabled', 'peer_id'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf, ['id', 'name'], name, value)


                            class InterfaceSummary(Entity):
                                """
                                IPv4 interface summary information
                                
                                .. attribute:: auto_config
                                
                                	Auto\-configured interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_disabled
                                
                                	Autoconfigure disabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_forward_reference_interfaces
                                
                                	Auto\-configured forward references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_references
                                
                                	Number of forward referenced interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_count
                                
                                	Number of known IP Interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_ldp_enabled
                                
                                	Number of known IP Interfaces with LDP Enabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_attached_interface
                                
                                	Number of attached interfaces configured in LDP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_te_interface
                                
                                	Number of TE tunnel interfaces configured in LDP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary, self).__init__()

                                    self.yang_name = "interface-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.auto_config = YLeaf(YType.uint32, "auto-config")

                                    self.auto_config_disabled = YLeaf(YType.uint32, "auto-config-disabled")

                                    self.auto_config_forward_reference_interfaces = YLeaf(YType.uint32, "auto-config-forward-reference-interfaces")

                                    self.forward_references = YLeaf(YType.uint32, "forward-references")

                                    self.known_ip_interface_count = YLeaf(YType.uint32, "known-ip-interface-count")

                                    self.known_ip_interface_ldp_enabled = YLeaf(YType.uint32, "known-ip-interface-ldp-enabled")

                                    self.ldp_configured_attached_interface = YLeaf(YType.uint32, "ldp-configured-attached-interface")

                                    self.ldp_configured_te_interface = YLeaf(YType.uint32, "ldp-configured-te-interface")
                                    self._segment_path = lambda: "interface-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.InterfaceSummary, ['auto_config', 'auto_config_disabled', 'auto_config_forward_reference_interfaces', 'forward_references', 'known_ip_interface_count', 'known_ip_interface_ldp_enabled', 'ldp_configured_attached_interface', 'ldp_configured_te_interface'], name, value)


                            class Interfaces(Entity):
                                """
                                LDP Interface related information
                                
                                .. attribute:: interface
                                
                                	IPv4 interface information
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces, self).__init__()

                                    self.yang_name = "interfaces"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface" : ("interface", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface)}

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces, [], name, value)


                                class Interface(Entity):
                                    """
                                    IPv4 interface information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: auto_config
                                    
                                    	Auto config
                                    	**type**\: list of    :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_im_stale
                                    
                                    	Is IM information stale
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_autoconfig_disable
                                    
                                    	LDP autoconfig disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_config_mode
                                    
                                    	LDP config mode
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_enabled
                                    
                                    	LDP enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_mesh_grp
                                    
                                    	TE tunnel mesh\-group
                                    	**type**\: list of    :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf)}
                                        self._child_list_classes = {"auto-config" : ("auto_config", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig), "te-mesh-grp" : ("te_mesh_grp", MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.is_im_stale = YLeaf(YType.boolean, "is-im-stale")

                                        self.ldp_autoconfig_disable = YLeaf(YType.boolean, "ldp-autoconfig-disable")

                                        self.ldp_config_mode = YLeaf(YType.boolean, "ldp-config-mode")

                                        self.ldp_enabled = YLeaf(YType.boolean, "ldp-enabled")

                                        self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.auto_config = YList(self)
                                        self.te_mesh_grp = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface, ['interface_name', 'interface', 'interface_name_xr', 'is_im_stale', 'ldp_autoconfig_disable', 'ldp_config_mode', 'ldp_enabled'], name, value)


                                    class AutoConfig(Entity):
                                        """
                                        Auto config
                                        
                                        .. attribute:: tuple
                                        
                                        	Tuple
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                            self.yang_name = "auto-config"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.tuple = YLeaf(YType.str, "tuple")
                                            self._segment_path = lambda: "auto-config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, ['tuple'], name, value)


                                    class TeMeshGrp(Entity):
                                        """
                                        TE tunnel mesh\-group
                                        
                                        .. attribute:: ldp_mesh_group_enabled
                                        
                                        	LDP has enabled this TE mesh\-group
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_te_mesh_group_all_cfgd
                                        
                                        	LDP has enabled all TE mesh\-groups
                                        	**type**\:  bool
                                        
                                        .. attribute:: te_mesh_group_id
                                        
                                        	TE tunnel Mesh Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                            self.yang_name = "te-mesh-grp"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ldp_mesh_group_enabled = YLeaf(YType.boolean, "ldp-mesh-group-enabled")

                                            self.ldp_te_mesh_group_all_cfgd = YLeaf(YType.boolean, "ldp-te-mesh-group-all-cfgd")

                                            self.te_mesh_group_id = YLeaf(YType.uint32, "te-mesh-group-id")
                                            self._segment_path = lambda: "te-mesh-grp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, ['ldp_mesh_group_enabled', 'ldp_te_mesh_group_all_cfgd', 'te_mesh_group_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf, ['id', 'name'], name, value)


                    class BackoffParameters(Entity):
                        """
                        The LDP Backoff Parameters
                        
                        .. attribute:: initial_seconds
                        
                        	Initial backoff value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: maximum_seconds
                        
                        	Maximum backoff value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.BackoffParameters, self).__init__()

                            self.yang_name = "backoff-parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.initial_seconds = YLeaf(YType.uint32, "initial-seconds")

                            self.maximum_seconds = YLeaf(YType.uint32, "maximum-seconds")
                            self._segment_path = lambda: "backoff-parameters"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.BackoffParameters, ['initial_seconds', 'maximum_seconds'], name, value)


                    class Backoffs(Entity):
                        """
                        The LDP backoff
                        
                        .. attribute:: backoff
                        
                        	LDP Backoff Information
                        	**type**\: list of    :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs.Backoff>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs, self).__init__()

                            self.yang_name = "backoffs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"backoff" : ("backoff", MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs.Backoff)}

                            self.backoff = YList(self)
                            self._segment_path = lambda: "backoffs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs, [], name, value)


                        class Backoff(Entity):
                            """
                            LDP Backoff Information
                            
                            .. attribute:: backoff_seconds
                            
                            	Backoff seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: waiting_seconds
                            
                            	Backoff waiting seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs.Backoff, self).__init__()

                                self.yang_name = "backoff"
                                self.yang_parent_name = "backoffs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.backoff_seconds = YLeaf(YType.uint32, "backoff-seconds")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.waiting_seconds = YLeaf(YType.uint32, "waiting-seconds")
                                self._segment_path = lambda: "backoff"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Backoffs.Backoff, ['backoff_seconds', 'label_space_id', 'lsr_id', 'waiting_seconds'], name, value)


                    class Capabilities(Entity):
                        """
                        LDP capability database information
                        
                        .. attribute:: capability
                        
                        	Information on LDP capability
                        	**type**\: list of    :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities, self).__init__()

                            self.yang_name = "capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"capability" : ("capability", MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability)}

                            self.capability = YList(self)
                            self._segment_path = lambda: "capabilities"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities, [], name, value)


                        class Capability(Entity):
                            """
                            Information on LDP capability
                            
                            .. attribute:: capability_type  <key>
                            
                            	The capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: capability
                            
                            	Capability information
                            	**type**\:   :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability.Capability>`
                            
                            .. attribute:: capability_owner
                            
                            	Capability owner
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"capability" : ("capability", MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability.Capability)}
                                self._child_list_classes = {}

                                self.capability_type = YLeaf(YType.int32, "capability-type")

                                self.capability_owner = YLeaf(YType.str, "capability-owner")

                                self.capability = MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability.Capability()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"
                                self._children_yang_names.add("capability")
                                self._segment_path = lambda: "capability" + "[capability-type='" + self.capability_type.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability, ['capability_type', 'capability_owner'], name, value)


                            class Capability(Entity):
                                """
                                Capability information
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability.Capability, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "capability"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Capabilities.Capability.Capability, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                    class GracefulRestart(Entity):
                        """
                        LDP Graceful Restart info
                        
                        .. attribute:: forwarding_state_hold_timer_remaining_seconds
                        
                        	Forwarding state hold timer remaining time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: graceful_restartable_neighbor
                        
                        	Vector of graceful restart neighbor information
                        	**type**\: list of    :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor>`
                        
                        .. attribute:: is_forwarding_state_hold_timer_running
                        
                        	Is graceful restart forwarding state hold timer running
                        	**type**\:  bool
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart, self).__init__()

                            self.yang_name = "graceful-restart"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.Vrf)}
                            self._child_list_classes = {"graceful-restartable-neighbor" : ("graceful_restartable_neighbor", MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor)}

                            self.forwarding_state_hold_timer_remaining_seconds = YLeaf(YType.uint32, "forwarding-state-hold-timer-remaining-seconds")

                            self.is_forwarding_state_hold_timer_running = YLeaf(YType.boolean, "is-forwarding-state-hold-timer-running")

                            self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")

                            self.graceful_restartable_neighbor = YList(self)
                            self._segment_path = lambda: "graceful-restart"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart, ['forwarding_state_hold_timer_remaining_seconds', 'is_forwarding_state_hold_timer_running'], name, value)


                        class GracefulRestartableNeighbor(Entity):
                            """
                            Vector of graceful restart neighbor information
                            
                            .. attribute:: connect_count
                            
                            	ConnectCount
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_address
                            
                            	Addresses bound to GR down Nbr
                            	**type**\: list of    :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                            
                            .. attribute:: down_nbr_down_reason
                            
                            	Session down reason code
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flags
                            
                            	Flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flap_count
                            
                            	Count of back2back flaps
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: down_nbr_interface
                            
                            	Interfaces bound to GR down Nbr
                            	**type**\: list of    :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                            
                            .. attribute:: gr_peer
                            
                            	GR peer LDP Id
                            	**type**\:   :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                            
                            .. attribute:: is_liveness_timer_running
                            
                            	Is liveness timer running
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_up
                            
                            	Is neighbor up
                            	**type**\:  bool
                            
                            .. attribute:: is_recovery_timer_running
                            
                            	Is recovery timer running
                            	**type**\:  bool
                            
                            .. attribute:: liveness_timer_remaining_seconds
                            
                            	Remaining time from liveness timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: recovery_timer_remaining_seconds
                            
                            	Recovery timer remining time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                                self.yang_name = "graceful-restartable-neighbor"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"gr-peer" : ("gr_peer", MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)}
                                self._child_list_classes = {"down-nbr-address" : ("down_nbr_address", MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress), "down-nbr-interface" : ("down_nbr_interface", MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)}

                                self.connect_count = YLeaf(YType.uint32, "connect-count")

                                self.down_nbr_down_reason = YLeaf(YType.uint32, "down-nbr-down-reason")

                                self.down_nbr_flags = YLeaf(YType.uint32, "down-nbr-flags")

                                self.down_nbr_flap_count = YLeaf(YType.uint8, "down-nbr-flap-count")

                                self.is_liveness_timer_running = YLeaf(YType.boolean, "is-liveness-timer-running")

                                self.is_neighbor_up = YLeaf(YType.boolean, "is-neighbor-up")

                                self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

                                self.liveness_timer_remaining_seconds = YLeaf(YType.uint32, "liveness-timer-remaining-seconds")

                                self.recovery_timer_remaining_seconds = YLeaf(YType.uint32, "recovery-timer-remaining-seconds")

                                self.gr_peer = MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                                self.gr_peer.parent = self
                                self._children_name_map["gr_peer"] = "gr-peer"
                                self._children_yang_names.add("gr-peer")

                                self.down_nbr_address = YList(self)
                                self.down_nbr_interface = YList(self)
                                self._segment_path = lambda: "graceful-restartable-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, ['connect_count', 'down_nbr_down_reason', 'down_nbr_flags', 'down_nbr_flap_count', 'is_liveness_timer_running', 'is_neighbor_up', 'is_recovery_timer_running', 'liveness_timer_remaining_seconds', 'recovery_timer_remaining_seconds'], name, value)


                            class DownNbrAddress(Entity):
                                """
                                Addresses bound to GR down Nbr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                    self.yang_name = "down-nbr-address"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "down-nbr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class DownNbrInterface(Entity):
                                """
                                Interfaces bound to GR down Nbr
                                
                                .. attribute:: address_family
                                
                                	Interface adj Address Family
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: interface_handle
                                
                                	Interfaces handle
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                    self.yang_name = "down-nbr-interface"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")
                                    self._segment_path = lambda: "down-nbr-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, ['address_family', 'interface_handle'], name, value)


                            class GrPeer(Entity):
                                """
                                GR peer LDP Id
                                
                                .. attribute:: label_space_id
                                
                                	Label space identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ldp_id
                                
                                	LDP identifier
                                	**type**\:  str
                                
                                .. attribute:: lsr_id
                                
                                	LSR identifier
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                    self.yang_name = "gr-peer"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                    self.ldp_id = YLeaf(YType.str, "ldp-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")
                                    self._segment_path = lambda: "gr-peer"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.GracefulRestart.Vrf, ['id', 'name'], name, value)


                    class Issu(Entity):
                        """
                        LDP ISSU related information
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu, self).__init__()

                            self.yang_name = "issu"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary)}
                            self._child_list_classes = {}

                            self.ha_statistics = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._children_yang_names.add("ha-statistics")

                            self.ha_summary = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"
                            self._children_yang_names.add("ha-summary")
                            self._segment_path = lambda: "issu"


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_global = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"
                                self._children_yang_names.add("ha-global")

                                self.ha_neighbors = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "ha-statistics"


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync)}
                                    self._child_list_classes = {}

                                    self.init_sync = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._children_yang_names.add("init-sync")
                                    self._segment_path = lambda: "ha-global"


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                        self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                        self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                        self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                        self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                        self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                        self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                        self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                        self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                        self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                        self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                        self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                        self.num_peers = YLeaf(YType.uint32, "num-peers")

                                        self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                        self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                        self._segment_path = lambda: "init-sync"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf)}
                                self._child_list_classes = {}

                                self.sessions = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._children_yang_names.add("sessions")

                                self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "ha-summary"


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                    self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                    self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                    self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                    self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                    self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                    self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                    self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                    self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                    self.total = YLeaf(YType.uint32, "total")
                                    self._segment_path = lambda: "sessions"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Issu.HaSummary.Vrf, ['id', 'name'], name, value)


                    class LdpId(Entity):
                        """
                        Local LDP Id
                        
                        .. attribute:: label_space_id
                        
                        	Label space identifier
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_id
                        
                        	LDP identifier
                        	**type**\:  str
                        
                        .. attribute:: lsr_id
                        
                        	LSR identifier
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.LdpId, self).__init__()

                            self.yang_name = "ldp-id"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                            self._segment_path = lambda: "ldp-id"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.LdpId, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                    class NeighborBriefs(Entity):
                        """
                        The LDP Neighbors (brief)
                        
                        .. attribute:: neighbor_brief
                        
                        	Brief information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs, self).__init__()

                            self.yang_name = "neighbor-briefs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-brief" : ("neighbor_brief", MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief)}

                            self.neighbor_brief = YList(self)
                            self._segment_path = lambda: "neighbor-briefs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs, [], name, value)


                        class NeighborBrief(Entity):
                            """
                            Brief information on a particular LDP neighbor
                            
                            .. attribute:: is_graceful_restartable
                            
                            	Is graceful restartable
                            	**type**\:  bool
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nbr_br_af_info
                            
                            	Neighbor Brief AF Info
                            	**type**\: list of    :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                            
                            .. attribute:: nsr_state
                            
                            	NSR readiness state
                            	**type**\:   :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                            
                            .. attribute:: up_time_seconds
                            
                            	Up time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief, self).__init__()

                                self.yang_name = "neighbor-brief"
                                self.yang_parent_name = "neighbor-briefs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf)}
                                self._child_list_classes = {"nbr-br-af-info" : ("nbr_br_af_info", MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo)}

                                self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.up_time_seconds = YLeaf(YType.uint32, "up-time-seconds")

                                self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.nbr_br_af_info = YList(self)
                                self._segment_path = lambda: "neighbor-brief"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief, ['is_graceful_restartable', 'label_space_id', 'lsr_id', 'nsr_state', 'up_time_seconds'], name, value)


                            class NbrBrAfInfo(Entity):
                                """
                                Neighbor Brief AF Info
                                
                                .. attribute:: address_family
                                
                                	Neighbor Brief Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: num_of_nbr_addresses
                                
                                	Number of neighbor addresses
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_discovery
                                
                                	Number of neighbor discovery sources
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_lbl
                                
                                	Number of neighbor labels
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                    self.yang_name = "nbr-br-af-info"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.num_of_nbr_addresses = YLeaf(YType.uint32, "num-of-nbr-addresses")

                                    self.num_of_nbr_discovery = YLeaf(YType.uint32, "num-of-nbr-discovery")

                                    self.num_of_nbr_lbl = YLeaf(YType.uint32, "num-of-nbr-lbl")
                                    self._segment_path = lambda: "nbr-br-af-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, ['address_family', 'num_of_nbr_addresses', 'num_of_nbr_discovery', 'num_of_nbr_lbl'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf, ['id', 'name'], name, value)


                    class NeighborCapabilities(Entity):
                        """
                        LDP Neighbors Capabilities
                        
                        .. attribute:: neighbor_capability
                        
                        	Information on capabilities of a particular LDP neighbor
                        	**type**\: list of    :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities, self).__init__()

                            self.yang_name = "neighbor-capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-capability" : ("neighbor_capability", MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability)}

                            self.neighbor_capability = YList(self)
                            self._segment_path = lambda: "neighbor-capabilities"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities, [], name, value)


                        class NeighborCapability(Entity):
                            """
                            Information on capabilities of a particular LDP
                            neighbor
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: received
                            
                            	List of received capabilities
                            	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received>`
                            
                            .. attribute:: sent
                            
                            	List of sent capabilities
                            	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, self).__init__()

                                self.yang_name = "neighbor-capability"
                                self.yang_parent_name = "neighbor-capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"received" : ("received", MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received), "sent" : ("sent", MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent)}

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.received = YList(self)
                                self.sent = YList(self)
                                self._segment_path = lambda: "neighbor-capability"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, ['label_space_id', 'lsr_id'], name, value)


                            class Received(Entity):
                                """
                                List of received capabilities
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                    self.yang_name = "received"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "received"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                            class Sent(Entity):
                                """
                                List of sent capabilities
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                    self.yang_name = "sent"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "sent"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                    class Neighbors(Entity):
                        """
                        The LDP Neighbors
                        
                        .. attribute:: neighbor
                        
                        	Information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor" : ("neighbor", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor)}

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            Information on a particular LDP neighbor
                            
                            .. attribute:: detailed_information
                            
                            	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                            	**type**\:   :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation>`
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_nbr_bound_ipv4_address_info
                            
                            	Neighbor IPv4 Address Info
                            	**type**\: list of    :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                            
                            .. attribute:: ldp_nbr_bound_ipv6_address_info
                            
                            	Neighbor IPv6 Address Info
                            	**type**\: list of    :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                            
                            .. attribute:: ldp_nbr_ipv4_adj_info
                            
                            	Neighbor's IPv4 Adjacency Information
                            	**type**\: list of    :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                            
                            .. attribute:: ldp_nbr_ipv6_adj_info
                            
                            	Neighbor's IPv6 Adjacency Information
                            	**type**\: list of    :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: protocol_information
                            
                            	Protocol Information
                            	**type**\:   :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation>`
                            
                            .. attribute:: tcp_information
                            
                            	TCP Information
                            	**type**\:   :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"detailed-information" : ("detailed_information", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation), "protocol-information" : ("protocol_information", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation), "tcp-information" : ("tcp_information", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation)}
                                self._child_list_classes = {"ldp-nbr-bound-ipv4-address-info" : ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo), "ldp-nbr-bound-ipv6-address-info" : ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo), "ldp-nbr-ipv4-adj-info" : ("ldp_nbr_ipv4_adj_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo), "ldp-nbr-ipv6-adj-info" : ("ldp_nbr_ipv6_adj_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo)}

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.detailed_information = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation()
                                self.detailed_information.parent = self
                                self._children_name_map["detailed_information"] = "detailed-information"
                                self._children_yang_names.add("detailed-information")

                                self.protocol_information = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation()
                                self.protocol_information.parent = self
                                self._children_name_map["protocol_information"] = "protocol-information"
                                self._children_yang_names.add("protocol-information")

                                self.tcp_information = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation()
                                self.tcp_information.parent = self
                                self._children_name_map["tcp_information"] = "tcp-information"
                                self._children_yang_names.add("tcp-information")

                                self.ldp_nbr_bound_ipv4_address_info = YList(self)
                                self.ldp_nbr_bound_ipv6_address_info = YList(self)
                                self.ldp_nbr_ipv4_adj_info = YList(self)
                                self.ldp_nbr_ipv6_adj_info = YList(self)
                                self._segment_path = lambda: "neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor, ['label_space_id', 'lsr_id'], name, value)


                            class DetailedInformation(Entity):
                                """
                                Detailed information with regards to holdtime,
                                KA, inbound filtering, and Session protection
                                
                                .. attribute:: advertise_bgp_prefixes
                                
                                	Is BGP labelled prefixes advertised to the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: bgp_advertisement_state
                                
                                	BGP labelled prefixes advertisement state
                                	**type**\:   :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                                
                                .. attribute:: capabilities
                                
                                	Capabilities sent to and received from neighbor
                                	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                                
                                .. attribute:: client
                                
                                	Targeted Session clients
                                	**type**\: list of    :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client>`
                                
                                .. attribute:: has_ipv4_inbound
                                
                                	IPv4 Inbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv4_outbound
                                
                                	IPv4 Outbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv6_inbound
                                
                                	IPv6 Inbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv6_outbound
                                
                                	IPv6 Outbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_sp
                                
                                	Session Protection enabled
                                	**type**\:  bool
                                
                                .. attribute:: inbound_ipv4acl
                                
                                	IPv4 Inbound accept ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: inbound_ipv6acl
                                
                                	IPv6 Inbound accept ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: ipv4_duplicate_address
                                
                                	Duplicate IPv4 address bound to this peer
                                	**type**\: list of    :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                                
                                .. attribute:: ipv6_duplicate_address
                                
                                	Duplicate IPv6 address bound to this peer
                                	**type**\: list of    :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                                
                                .. attribute:: keep_alive_interval
                                
                                	Session keepalive interval in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsr_last_sync_error
                                
                                	Last NSR sync error
                                	**type**\:   :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                                
                                .. attribute:: nsr_last_sync_nack_reason
                                
                                	Last NSR sync NACK reaston
                                	**type**\:   :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                                
                                .. attribute:: nsr_sync_state
                                
                                	NSR Sync State
                                	**type**\:   :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                                
                                .. attribute:: outbound_ipv4acl
                                
                                	IPv4 Outbound advertise ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: outbound_ipv6acl
                                
                                	IPv6 Outbound advertise ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: peer_holdtime
                                
                                	Session holdtime value in seconds from the peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: peer_state
                                
                                	Peer state
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_duration
                                
                                	Session protection holdup time duration in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: sp_has_acl
                                
                                	Session protection ACL is present
                                	**type**\:  bool
                                
                                .. attribute:: sp_has_duration
                                
                                	Session Protection has non\-default duration
                                	**type**\:  bool
                                
                                .. attribute:: sp_state
                                
                                	Session Protection state
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: spacl
                                
                                	Session Protection ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: spht_remaining
                                
                                	Session Protection holdup time remaining value in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: spht_running
                                
                                	Session Protection holdup timer is running
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                    self.yang_name = "detailed-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"capabilities" : ("capabilities", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities)}
                                    self._child_list_classes = {"client" : ("client", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client), "ipv4-duplicate-address" : ("ipv4_duplicate_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress), "ipv6-duplicate-address" : ("ipv6_duplicate_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress)}

                                    self.advertise_bgp_prefixes = YLeaf(YType.boolean, "advertise-bgp-prefixes")

                                    self.bgp_advertisement_state = YLeaf(YType.enumeration, "bgp-advertisement-state")

                                    self.has_ipv4_inbound = YLeaf(YType.boolean, "has-ipv4-inbound")

                                    self.has_ipv4_outbound = YLeaf(YType.boolean, "has-ipv4-outbound")

                                    self.has_ipv6_inbound = YLeaf(YType.boolean, "has-ipv6-inbound")

                                    self.has_ipv6_outbound = YLeaf(YType.boolean, "has-ipv6-outbound")

                                    self.has_sp = YLeaf(YType.boolean, "has-sp")

                                    self.inbound_ipv4acl = YLeaf(YType.str, "inbound-ipv4acl")

                                    self.inbound_ipv6acl = YLeaf(YType.str, "inbound-ipv6acl")

                                    self.keep_alive_interval = YLeaf(YType.uint32, "keep-alive-interval")

                                    self.nsr_last_sync_error = YLeaf(YType.enumeration, "nsr-last-sync-error")

                                    self.nsr_last_sync_nack_reason = YLeaf(YType.enumeration, "nsr-last-sync-nack-reason")

                                    self.nsr_sync_state = YLeaf(YType.enumeration, "nsr-sync-state")

                                    self.outbound_ipv4acl = YLeaf(YType.str, "outbound-ipv4acl")

                                    self.outbound_ipv6acl = YLeaf(YType.str, "outbound-ipv6acl")

                                    self.peer_holdtime = YLeaf(YType.uint32, "peer-holdtime")

                                    self.peer_state = YLeaf(YType.str, "peer-state")

                                    self.sp_duration = YLeaf(YType.uint32, "sp-duration")

                                    self.sp_has_acl = YLeaf(YType.boolean, "sp-has-acl")

                                    self.sp_has_duration = YLeaf(YType.boolean, "sp-has-duration")

                                    self.sp_state = YLeaf(YType.str, "sp-state")

                                    self.spacl = YLeaf(YType.str, "spacl")

                                    self.spht_remaining = YLeaf(YType.uint32, "spht-remaining")

                                    self.spht_running = YLeaf(YType.boolean, "spht-running")

                                    self.capabilities = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                    self.capabilities.parent = self
                                    self._children_name_map["capabilities"] = "capabilities"
                                    self._children_yang_names.add("capabilities")

                                    self.client = YList(self)
                                    self.ipv4_duplicate_address = YList(self)
                                    self.ipv6_duplicate_address = YList(self)
                                    self._segment_path = lambda: "detailed-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, ['advertise_bgp_prefixes', 'bgp_advertisement_state', 'has_ipv4_inbound', 'has_ipv4_outbound', 'has_ipv6_inbound', 'has_ipv6_outbound', 'has_sp', 'inbound_ipv4acl', 'inbound_ipv6acl', 'keep_alive_interval', 'nsr_last_sync_error', 'nsr_last_sync_nack_reason', 'nsr_sync_state', 'outbound_ipv4acl', 'outbound_ipv6acl', 'peer_holdtime', 'peer_state', 'sp_duration', 'sp_has_acl', 'sp_has_duration', 'sp_state', 'spacl', 'spht_remaining', 'spht_running'], name, value)


                                class Capabilities(Entity):
                                    """
                                    Capabilities sent to and received from neighbor
                                    
                                    .. attribute:: received
                                    
                                    	List of received capabilities
                                    	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                    
                                    .. attribute:: sent
                                    
                                    	List of sent capabilities
                                    	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                        self.yang_name = "capabilities"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"received" : ("received", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received), "sent" : ("sent", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)}

                                        self.received = YList(self)
                                        self.sent = YList(self)
                                        self._segment_path = lambda: "capabilities"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                    class Received(Entity):
                                        """
                                        List of received capabilities
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\:  str
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\:  str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                            self.yang_name = "received"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.capability_data = YLeaf(YType.str, "capability-data")

                                            self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                            self.description = YLeaf(YType.str, "description")

                                            self.type = YLeaf(YType.uint16, "type")
                                            self._segment_path = lambda: "received"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                    class Sent(Entity):
                                        """
                                        List of sent capabilities
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\:  str
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\:  str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                            self.yang_name = "sent"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.capability_data = YLeaf(YType.str, "capability-data")

                                            self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                            self.description = YLeaf(YType.str, "description")

                                            self.type = YLeaf(YType.uint16, "type")
                                            self._segment_path = lambda: "sent"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                class Client(Entity):
                                    """
                                    Targeted Session clients
                                    
                                    .. attribute:: name
                                    
                                    	Client's name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                        self.yang_name = "client"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "client"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, ['name'], name, value)


                                class Ipv4DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv4 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv4-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address)}
                                        self._child_list_classes = {}

                                        self.address = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._children_yang_names.add("address")
                                        self._segment_path = lambda: "ipv4-duplicate-address"


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv4-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class Ipv6DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv6 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv6-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address)}
                                        self._child_list_classes = {}

                                        self.address = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._children_yang_names.add("address")
                                        self._segment_path = lambda: "ipv6-duplicate-address"


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv6-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrBoundIpv4AddressInfo(Entity):
                                """
                                Neighbor IPv4 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrBoundIpv6AddressInfo(Entity):
                                """
                                Neighbor IPv6 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrIpv4AdjInfo(Entity):
                                """
                                Neighbor's IPv4 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv4-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup)}
                                    self._child_list_classes = {}

                                    self.adjacency_group = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._children_yang_names.add("adjacency-group")
                                    self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData)}
                                        self._child_list_classes = {}

                                        self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                        self.link_hello_data = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"
                                        self._children_yang_names.add("link-hello-data")

                                        self.target_hello_data = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._children_yang_names.add("target-hello-data")
                                        self._segment_path = lambda: "adjacency-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "link-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                            self._child_list_classes = {}

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.local_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                            self._children_yang_names.add("local-address")

                                            self.target_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._children_yang_names.add("target-address")
                                            self._segment_path = lambda: "target-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrIpv6AdjInfo(Entity):
                                """
                                Neighbor's IPv6 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv6-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup)}
                                    self._child_list_classes = {}

                                    self.adjacency_group = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._children_yang_names.add("adjacency-group")
                                    self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData)}
                                        self._child_list_classes = {}

                                        self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                        self.link_hello_data = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"
                                        self._children_yang_names.add("link-hello-data")

                                        self.target_hello_data = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._children_yang_names.add("target-hello-data")
                                        self._segment_path = lambda: "adjacency-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "link-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                            self._child_list_classes = {}

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.local_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                            self._children_yang_names.add("local-address")

                                            self.target_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._children_yang_names.add("target-address")
                                            self._segment_path = lambda: "target-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class ProtocolInformation(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: downstream_on_demand
                                
                                	Is Label advertisment mode in Downstream On Demand mode or Not
                                	**type**\:  bool
                                
                                .. attribute:: ta_graceful_restart_adjacency
                                
                                	Graceful restart information
                                	**type**\:   :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                                
                                .. attribute:: ta_holdtime
                                
                                	Session holdtime in sec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_rcvd
                                
                                	Number of pies received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_sent
                                
                                	Number of pies sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_state
                                
                                	State
                                	**type**\:  str
                                
                                .. attribute:: ta_up_time_seconds
                                
                                	Up time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                    self.yang_name = "protocol-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ta-graceful-restart-adjacency" : ("ta_graceful_restart_adjacency", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency)}
                                    self._child_list_classes = {}

                                    self.downstream_on_demand = YLeaf(YType.boolean, "downstream-on-demand")

                                    self.ta_holdtime = YLeaf(YType.uint32, "ta-holdtime")

                                    self.ta_pies_rcvd = YLeaf(YType.uint32, "ta-pies-rcvd")

                                    self.ta_pies_sent = YLeaf(YType.uint32, "ta-pies-sent")

                                    self.ta_state = YLeaf(YType.str, "ta-state")

                                    self.ta_up_time_seconds = YLeaf(YType.uint32, "ta-up-time-seconds")

                                    self.ta_graceful_restart_adjacency = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                    self.ta_graceful_restart_adjacency.parent = self
                                    self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                    self._children_yang_names.add("ta-graceful-restart-adjacency")
                                    self._segment_path = lambda: "protocol-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, ['downstream_on_demand', 'ta_holdtime', 'ta_pies_rcvd', 'ta_pies_sent', 'ta_state', 'ta_up_time_seconds'], name, value)


                                class TaGracefulRestartAdjacency(Entity):
                                    """
                                    Graceful restart information
                                    
                                    .. attribute:: is_graceful_restartable
                                    
                                    	Is graceful restartable
                                    	**type**\:  bool
                                    
                                    .. attribute:: reconnect_timeout
                                    
                                    	Reconnect timeout
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recovery_time
                                    
                                    	Recovery time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                        self.yang_name = "ta-graceful-restart-adjacency"
                                        self.yang_parent_name = "protocol-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                        self.reconnect_timeout = YLeaf(YType.uint32, "reconnect-timeout")

                                        self.recovery_time = YLeaf(YType.uint32, "recovery-time")
                                        self._segment_path = lambda: "ta-graceful-restart-adjacency"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, ['is_graceful_restartable', 'reconnect_timeout', 'recovery_time'], name, value)


                            class TcpInformation(Entity):
                                """
                                TCP Information
                                
                                .. attribute:: foreign_host
                                
                                	Foreign host address
                                	**type**\:   :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                                
                                .. attribute:: foreign_port
                                
                                	Foreign port number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_md5_on
                                
                                	Is MD5 Digest on
                                	**type**\:  bool
                                
                                .. attribute:: local_host
                                
                                	Local host address
                                	**type**\:   :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                                
                                .. attribute:: local_port
                                
                                	Local port number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                    self.yang_name = "tcp-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"foreign-host" : ("foreign_host", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost), "local-host" : ("local_host", MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost)}
                                    self._child_list_classes = {}

                                    self.foreign_port = YLeaf(YType.uint16, "foreign-port")

                                    self.is_md5_on = YLeaf(YType.boolean, "is-md5-on")

                                    self.local_port = YLeaf(YType.uint16, "local-port")

                                    self.foreign_host = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                    self.foreign_host.parent = self
                                    self._children_name_map["foreign_host"] = "foreign-host"
                                    self._children_yang_names.add("foreign-host")

                                    self.local_host = MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                    self.local_host.parent = self
                                    self._children_name_map["local_host"] = "local-host"
                                    self._children_yang_names.add("local-host")
                                    self._segment_path = lambda: "tcp-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, ['foreign_port', 'is_md5_on', 'local_port'], name, value)


                                class ForeignHost(Entity):
                                    """
                                    Foreign host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                        self.yang_name = "foreign-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "foreign-host"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class LocalHost(Entity):
                                    """
                                    Local host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                        self.yang_name = "local-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "local-host"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                    class Nsr(Entity):
                        """
                        LDP NSR related information
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary>`
                        
                        .. attribute:: nsr_pending
                        
                        	LDP NSR Pending related information
                        	**type**\:   :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr, self).__init__()

                            self.yang_name = "nsr"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary), "nsr-pending" : ("nsr_pending", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending)}
                            self._child_list_classes = {}

                            self.ha_statistics = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._children_yang_names.add("ha-statistics")

                            self.ha_summary = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"
                            self._children_yang_names.add("ha-summary")

                            self.nsr_pending = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending()
                            self.nsr_pending.parent = self
                            self._children_name_map["nsr_pending"] = "nsr-pending"
                            self._children_yang_names.add("nsr-pending")
                            self._segment_path = lambda: "nsr"


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_global = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"
                                self._children_yang_names.add("ha-global")

                                self.ha_neighbors = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "ha-statistics"


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync)}
                                    self._child_list_classes = {}

                                    self.init_sync = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._children_yang_names.add("init-sync")
                                    self._segment_path = lambda: "ha-global"


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                        self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                        self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                        self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                        self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                        self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                        self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                        self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                        self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                        self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                        self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                        self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                        self.num_peers = YLeaf(YType.uint32, "num-peers")

                                        self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                        self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                        self._segment_path = lambda: "init-sync"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf)}
                                self._child_list_classes = {}

                                self.sessions = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._children_yang_names.add("sessions")

                                self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "ha-summary"


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                    self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                    self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                    self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                    self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                    self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                    self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                    self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                    self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                    self.total = YLeaf(YType.uint32, "total")
                                    self._segment_path = lambda: "sessions"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.HaSummary.Vrf, ['id', 'name'], name, value)


                        class NsrPending(Entity):
                            """
                            LDP NSR Pending related information
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending, self).__init__()

                                self.yang_name = "nsr-pending"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-neighbors" : ("ha_neighbors", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_neighbors = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "nsr-pending"


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "nsr-pending"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class Parameters(Entity):
                        """
                        LDP parameters
                        
                        .. attribute:: address_family_parameter
                        
                        	Per AF parameters
                        	**type**\: list of    :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter>`
                        
                        .. attribute:: af_binding_withdraw_delay
                        
                        	Delay (sec) in Binding Withdrawal for an Address Family
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: discovery_quick_start_disabled_on_interfaces
                        
                        	Discovery quick\-start disabled on some LDP\-enabled interfaces
                        	**type**\:  bool
                        
                        .. attribute:: global_discovery_quick_start_disabled
                        
                        	Discovery quick\-start globally disabled
                        	**type**\:  bool
                        
                        .. attribute:: global_md5_password_enabled
                        
                        	Global MD5 password enabled
                        	**type**\:  bool
                        
                        .. attribute:: graceful_restart_information
                        
                        	Graceful restart information
                        	**type**\:   :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation>`
                        
                        .. attribute:: hello_hold_time
                        
                        	Hello hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_interval
                        
                        	Hello interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: housekeeping_timer_interval
                        
                        	Housekeeping periodic timer interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: igp_sync_delay_time_for_interface
                        
                        	Interface IGP sync delay time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: igp_sync_delay_time_on_restart
                        
                        	IGP sync delay time on process restart in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: keepalive_interval
                        
                        	Keepalive interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_out_of_mem_state
                        
                        	LDP Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_recovery_timeout
                        
                        	LDP recovery timeout with LSD
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: le_no_route_timeout
                        
                        	LIB entry no route timeout
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_attached
                        
                        	Maximum number of LDP enabled attached interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_te
                        
                        	Maximum number of LDP enabled TE interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_peer
                        
                        	Maximum number of LDP peers
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	TRUE if NSR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: nsr_synced
                        
                        	TRUE if LDP is standby and is NSR Sync\-ed with active
                        	**type**\:  bool
                        
                        .. attribute:: protocol_version
                        
                        	Protocol version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role_is_active
                        
                        	Is process role active or standby
                        	**type**\:  bool
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_hold_time
                        
                        	Session hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_hold_time
                        
                        	Targeted hello hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_interval
                        
                        	Targeted hello interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters, self).__init__()

                            self.yang_name = "parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"graceful-restart-information" : ("graceful_restart_information", MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation)}
                            self._child_list_classes = {"address-family-parameter" : ("address_family_parameter", MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter)}

                            self.af_binding_withdraw_delay = YLeaf(YType.uint32, "af-binding-withdraw-delay")

                            self.discovery_quick_start_disabled_on_interfaces = YLeaf(YType.boolean, "discovery-quick-start-disabled-on-interfaces")

                            self.global_discovery_quick_start_disabled = YLeaf(YType.boolean, "global-discovery-quick-start-disabled")

                            self.global_md5_password_enabled = YLeaf(YType.boolean, "global-md5-password-enabled")

                            self.hello_hold_time = YLeaf(YType.uint32, "hello-hold-time")

                            self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                            self.housekeeping_timer_interval = YLeaf(YType.uint32, "housekeeping-timer-interval")

                            self.igp_sync_delay_time_for_interface = YLeaf(YType.uint32, "igp-sync-delay-time-for-interface")

                            self.igp_sync_delay_time_on_restart = YLeaf(YType.uint32, "igp-sync-delay-time-on-restart")

                            self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                            self.ldp_out_of_mem_state = YLeaf(YType.uint32, "ldp-out-of-mem-state")

                            self.ldp_recovery_timeout = YLeaf(YType.uint32, "ldp-recovery-timeout")

                            self.le_no_route_timeout = YLeaf(YType.uint32, "le-no-route-timeout")

                            self.max_intf_attached = YLeaf(YType.uint32, "max-intf-attached")

                            self.max_intf_te = YLeaf(YType.uint32, "max-intf-te")

                            self.max_peer = YLeaf(YType.uint32, "max-peer")

                            self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                            self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                            self.protocol_version = YLeaf(YType.uint32, "protocol-version")

                            self.role_is_active = YLeaf(YType.boolean, "role-is-active")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.session_hold_time = YLeaf(YType.uint32, "session-hold-time")

                            self.targeted_hello_hold_time = YLeaf(YType.uint32, "targeted-hello-hold-time")

                            self.targeted_hello_interval = YLeaf(YType.uint32, "targeted-hello-interval")

                            self.graceful_restart_information = MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation()
                            self.graceful_restart_information.parent = self
                            self._children_name_map["graceful_restart_information"] = "graceful-restart-information"
                            self._children_yang_names.add("graceful-restart-information")

                            self.address_family_parameter = YList(self)
                            self._segment_path = lambda: "parameters"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters, ['af_binding_withdraw_delay', 'discovery_quick_start_disabled_on_interfaces', 'global_discovery_quick_start_disabled', 'global_md5_password_enabled', 'hello_hold_time', 'hello_interval', 'housekeeping_timer_interval', 'igp_sync_delay_time_for_interface', 'igp_sync_delay_time_on_restart', 'keepalive_interval', 'ldp_out_of_mem_state', 'ldp_recovery_timeout', 'le_no_route_timeout', 'max_intf_attached', 'max_intf_te', 'max_peer', 'nsr_enabled', 'nsr_synced', 'protocol_version', 'role_is_active', 'router_id', 'session_hold_time', 'targeted_hello_hold_time', 'targeted_hello_interval'], name, value)


                        class AddressFamilyParameter(Entity):
                            """
                            Per AF parameters
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: discovery_transport_address
                            
                            	Discovery transport address
                            	**type**\:   :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                            
                            .. attribute:: is_accepting_targeted_hellos
                            
                            	Accepting targeted Hellos
                            	**type**\:  bool
                            
                            .. attribute:: label_imp_null_override_acl
                            
                            	ACL to override local label to use implicit\-null
                            	**type**\:  str
                            
                            .. attribute:: null_label
                            
                            	Null label
                            	**type**\:  str
                            
                            .. attribute:: targeted_hello_acl
                            
                            	Targeted Hello ACL
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter, self).__init__()

                                self.yang_name = "address-family-parameter"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"discovery-transport-address" : ("discovery_transport_address", MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress)}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.is_accepting_targeted_hellos = YLeaf(YType.boolean, "is-accepting-targeted-hellos")

                                self.label_imp_null_override_acl = YLeaf(YType.str, "label-imp-null-override-acl")

                                self.null_label = YLeaf(YType.str, "null-label")

                                self.targeted_hello_acl = YLeaf(YType.str, "targeted-hello-acl")

                                self.discovery_transport_address = MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                                self.discovery_transport_address.parent = self
                                self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                                self._children_yang_names.add("discovery-transport-address")
                                self._segment_path = lambda: "address-family-parameter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter, ['address_family', 'is_accepting_targeted_hellos', 'label_imp_null_override_acl', 'null_label', 'targeted_hello_acl'], name, value)


                            class DiscoveryTransportAddress(Entity):
                                """
                                Discovery transport address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                    self.yang_name = "discovery-transport-address"
                                    self.yang_parent_name = "address-family-parameter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "discovery-transport-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class GracefulRestartInformation(Entity):
                            """
                            Graceful restart information
                            
                            .. attribute:: graceful_restart_forwarding_state_hold_time
                            
                            	Graceful restart forward state hold time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_reconnect_timeout
                            
                            	Reconnect timeout value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_graceful_restart_configured
                            
                            	Is graceful restart configured
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation, self).__init__()

                                self.yang_name = "graceful-restart-information"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.graceful_restart_forwarding_state_hold_time = YLeaf(YType.uint32, "graceful-restart-forwarding-state-hold-time")

                                self.graceful_restart_reconnect_timeout = YLeaf(YType.uint32, "graceful-restart-reconnect-timeout")

                                self.is_graceful_restart_configured = YLeaf(YType.boolean, "is-graceful-restart-configured")
                                self._segment_path = lambda: "graceful-restart-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Parameters.GracefulRestartInformation, ['graceful_restart_forwarding_state_hold_time', 'graceful_restart_reconnect_timeout', 'is_graceful_restart_configured'], name, value)


                    class Statistics(Entity):
                        """
                        The LDP Statistics
                        
                        .. attribute:: statistic
                        
                        	Statistical Information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"statistic" : ("statistic", MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic)}

                            self.statistic = YList(self)
                            self._segment_path = lambda: "statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics, [], name, value)


                        class Statistic(Entity):
                            """
                            Statistical Information on a particular LDP
                            neighbor
                            
                            .. attribute:: iccp_enabled
                            
                            	Is session ICCP enabled?
                            	**type**\:  bool
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: message_in
                            
                            	Message in count
                            	**type**\:   :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn>`
                            
                            .. attribute:: message_out
                            
                            	Message out count
                            	**type**\:   :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic, self).__init__()

                                self.yang_name = "statistic"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"message-in" : ("message_in", MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn), "message-out" : ("message_out", MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut)}
                                self._child_list_classes = {}

                                self.iccp_enabled = YLeaf(YType.boolean, "iccp-enabled")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.message_in = MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn()
                                self.message_in.parent = self
                                self._children_name_map["message_in"] = "message-in"
                                self._children_yang_names.add("message-in")

                                self.message_out = MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut()
                                self.message_out.parent = self
                                self._children_name_map["message_out"] = "message-out"
                                self._children_yang_names.add("message-out")
                                self._segment_path = lambda: "statistic"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic, ['iccp_enabled', 'label_space_id', 'lsr_id'], name, value)


                            class MessageIn(Entity):
                                """
                                Message in count
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn, self).__init__()

                                    self.yang_name = "message-in"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_count = YLeaf(YType.uint32, "address-count")

                                    self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                    self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                    self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                    self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                    self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                    self.init_count = YLeaf(YType.uint32, "init-count")

                                    self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                    self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                    self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                    self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                    self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                    self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                    self.notification_count = YLeaf(YType.uint32, "notification-count")

                                    self.total_count = YLeaf(YType.uint32, "total-count")
                                    self._segment_path = lambda: "message-in"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageIn, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                            class MessageOut(Entity):
                                """
                                Message out count
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut, self).__init__()

                                    self.yang_name = "message-out"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_count = YLeaf(YType.uint32, "address-count")

                                    self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                    self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                    self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                    self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                    self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                    self.init_count = YLeaf(YType.uint32, "init-count")

                                    self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                    self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                    self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                    self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                    self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                    self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                    self.notification_count = YLeaf(YType.uint32, "notification-count")

                                    self.total_count = YLeaf(YType.uint32, "total-count")
                                    self._segment_path = lambda: "message-out"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Statistics.Statistic.MessageOut, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                    class Summary(Entity):
                        """
                        LDP VRF summary
                        
                        .. attribute:: common
                        
                        	Common Summary information
                        	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Common>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Global_.Standby.Vrfs.Vrf.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"common" : ("common", MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Common), "vrf" : ("vrf", MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Vrf)}
                            self._child_list_classes = {}

                            self.common = MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Common()
                            self.common.parent = self
                            self._children_name_map["common"] = "common"
                            self._children_yang_names.add("common")

                            self.vrf = MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "summary"


                        class Common(Entity):
                            """
                            Common Summary information
                            
                            .. attribute:: address_families
                            
                            	Address Families enabled
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: number_of_bindings_ipv4
                            
                            	Total number of ipv4 bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv6
                            
                            	Total number of ipv6 bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_downstream_on_demand_neighbors
                            
                            	Number of Downstream\-On\-Demand neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_graceful_restart_neighbors
                            
                            	Number of Graceful Restart neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_hello_adj
                            
                            	Number of LDP discovery IPv4 hello adjacencies
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_local_addresses
                            
                            	Number of IPv4 local addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_routes
                            
                            	Number of resolved IPv4 routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4af
                            
                            	Number of IPv4 address\-families enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4ldp_interfaces
                            
                            	Number of LDP IPv4 configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_hello_adj
                            
                            	Number of LDP discovery IPv6 hello adjacencies
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_local_addresses
                            
                            	Number of IPv6 local addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_routes
                            
                            	Number of resolved IPv6 routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6af
                            
                            	Number of IPv6 address\-families enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6ldp_interfaces
                            
                            	Number of LDP IPv6 configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ldp_interfaces
                            
                            	Number of LDP configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv4
                            
                            	Total number of ipv4 local label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv6
                            
                            	Total number of ipv6 local label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_neighbors
                            
                            	Number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_nsr_synced_neighbors
                            
                            	Number of NSR\-synced/operational neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv4
                            
                            	Total number of ipv4 remote label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv6
                            
                            	Total number of ipv6 remote label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Common, self).__init__()

                                self.yang_name = "common"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_families = YLeaf(YType.enumeration, "address-families")

                                self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                                self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                                self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                                self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                                self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                                self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                                self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                                self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                                self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                                self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                                self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                                self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                                self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                                self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                                self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                                self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                                self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                                self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                                self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                                self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                                self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                                self._segment_path = lambda: "common"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Global_.Standby.Vrfs.Vrf.Summary.Vrf, ['id', 'name'], name, value)


    class Nodes(Entity):
        """
        Location MPLS LDP operational data
        
        .. attribute:: node
        
        	The MPLD LDP operational data for a particular node
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node>`
        
        

        """

        _prefix = 'mpls-ldp-oper'
        _revision = '2017-05-01'

        def __init__(self):
            super(MplsLdp.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "mpls-ldp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"node" : ("node", MplsLdp.Nodes.Node)}

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(MplsLdp.Nodes, [], name, value)


        class Node(Entity):
            """
            The MPLD LDP operational data for a particular
            node
            
            .. attribute:: node_name  <key>
            
            	The identifier for the node
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: ato_mdb_table_entries
            
            	AToM DB Table
            	**type**\:   :py:class:`AtoMdbTableEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries>`
            
            .. attribute:: bindings_summary_all
            
            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
            	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.BindingsSummaryAll>`
            
            .. attribute:: default_vrf
            
            	DefaultVRF specific operational data
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf>`
            
            .. attribute:: discovery_summary_all
            
            	Summary information regarding LDP discovery
            	**type**\:   :py:class:`DiscoverySummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DiscoverySummaryAll>`
            
            .. attribute:: forwarding_summary_all
            
            	Summary information regarding LDP forwarding setup
            	**type**\:   :py:class:`ForwardingSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll>`
            
            .. attribute:: nsr_summary_all
            
            	Summary information regarding LDP NSR State
            	**type**\:   :py:class:`NsrSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.NsrSummaryAll>`
            
            .. attribute:: summary
            
            	LDP summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Summary>`
            
            .. attribute:: vrfs
            
            	VRF specific operational data
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs>`
            
            

            """

            _prefix = 'mpls-ldp-oper'
            _revision = '2017-05-01'

            def __init__(self):
                super(MplsLdp.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"ato-mdb-table-entries" : ("ato_mdb_table_entries", MplsLdp.Nodes.Node.AtoMdbTableEntries), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Nodes.Node.BindingsSummaryAll), "default-vrf" : ("default_vrf", MplsLdp.Nodes.Node.DefaultVrf), "discovery-summary-all" : ("discovery_summary_all", MplsLdp.Nodes.Node.DiscoverySummaryAll), "forwarding-summary-all" : ("forwarding_summary_all", MplsLdp.Nodes.Node.ForwardingSummaryAll), "nsr-summary-all" : ("nsr_summary_all", MplsLdp.Nodes.Node.NsrSummaryAll), "summary" : ("summary", MplsLdp.Nodes.Node.Summary), "vrfs" : ("vrfs", MplsLdp.Nodes.Node.Vrfs)}
                self._child_list_classes = {}

                self.node_name = YLeaf(YType.str, "node-name")

                self.ato_mdb_table_entries = MplsLdp.Nodes.Node.AtoMdbTableEntries()
                self.ato_mdb_table_entries.parent = self
                self._children_name_map["ato_mdb_table_entries"] = "ato-mdb-table-entries"
                self._children_yang_names.add("ato-mdb-table-entries")

                self.bindings_summary_all = MplsLdp.Nodes.Node.BindingsSummaryAll()
                self.bindings_summary_all.parent = self
                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                self._children_yang_names.add("bindings-summary-all")

                self.default_vrf = MplsLdp.Nodes.Node.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._children_yang_names.add("default-vrf")

                self.discovery_summary_all = MplsLdp.Nodes.Node.DiscoverySummaryAll()
                self.discovery_summary_all.parent = self
                self._children_name_map["discovery_summary_all"] = "discovery-summary-all"
                self._children_yang_names.add("discovery-summary-all")

                self.forwarding_summary_all = MplsLdp.Nodes.Node.ForwardingSummaryAll()
                self.forwarding_summary_all.parent = self
                self._children_name_map["forwarding_summary_all"] = "forwarding-summary-all"
                self._children_yang_names.add("forwarding-summary-all")

                self.nsr_summary_all = MplsLdp.Nodes.Node.NsrSummaryAll()
                self.nsr_summary_all.parent = self
                self._children_name_map["nsr_summary_all"] = "nsr-summary-all"
                self._children_yang_names.add("nsr-summary-all")

                self.summary = MplsLdp.Nodes.Node.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.vrfs = MplsLdp.Nodes.Node.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
                self._children_yang_names.add("vrfs")
                self._segment_path = lambda: "node" + "[node-name='" + self.node_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-mpls-ldp-oper:mpls-ldp/nodes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(MplsLdp.Nodes.Node, ['node_name'], name, value)


            class AtoMdbTableEntries(Entity):
                """
                AToM DB Table
                
                .. attribute:: ato_mdb_table_entry
                
                	Entries in AToM DB
                	**type**\: list of    :py:class:`AtoMdbTableEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries, self).__init__()

                    self.yang_name = "ato-mdb-table-entries"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"ato-mdb-table-entry" : ("ato_mdb_table_entry", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry)}

                    self.ato_mdb_table_entry = YList(self)
                    self._segment_path = lambda: "ato-mdb-table-entries"

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries, [], name, value)


                class AtoMdbTableEntry(Entity):
                    """
                    Entries in AToM DB
                    
                    .. attribute:: agi
                    
                    	AGI
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: agi_type
                    
                    	AGI Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: fe_ctype
                    
                    	FEC Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: fec_info
                    
                    	Pseudowire FEC information
                    	**type**\:   :py:class:`FecInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo>`
                    
                    .. attribute:: mapping_tlv_count
                    
                    	TLV Count from Label Mapping Message
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: notification_tlv_count
                    
                    	TLV Count from Notification Message
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: peer_id
                    
                    	Peer ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: peer_id_xr
                    
                    	Peer ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_ac_id
                    
                    	SAII AC ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_global_id
                    
                    	SAII Global ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: saii_local_id
                    
                    	SAII Local ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: saii_prefix
                    
                    	SAII Prefix
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: saii_type
                    
                    	SAII Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_ac_id
                    
                    	TAII AC ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_global_id
                    
                    	TAII Global ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: taii_local_id
                    
                    	TAII Local ID
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: taii_prefix
                    
                    	TAII Prefix
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: taii_type
                    
                    	TAII Type
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry, self).__init__()

                        self.yang_name = "ato-mdb-table-entry"
                        self.yang_parent_name = "ato-mdb-table-entries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"fec-info" : ("fec_info", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo)}
                        self._child_list_classes = {}

                        self.agi = YLeaf(YType.int32, "agi")

                        self.agi_type = YLeaf(YType.int32, "agi-type")

                        self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                        self.mapping_tlv_count = YLeaf(YType.uint32, "mapping-tlv-count")

                        self.notification_tlv_count = YLeaf(YType.uint32, "notification-tlv-count")

                        self.peer_id = YLeaf(YType.str, "peer-id")

                        self.peer_id_xr = YLeaf(YType.str, "peer-id-xr")

                        self.pw_id = YLeaf(YType.int32, "pw-id")

                        self.saii_ac_id = YLeaf(YType.int32, "saii-ac-id")

                        self.saii_global_id = YLeaf(YType.int32, "saii-global-id")

                        self.saii_local_id = YLeaf(YType.str, "saii-local-id")

                        self.saii_prefix = YLeaf(YType.str, "saii-prefix")

                        self.saii_type = YLeaf(YType.int32, "saii-type")

                        self.taii_ac_id = YLeaf(YType.int32, "taii-ac-id")

                        self.taii_global_id = YLeaf(YType.int32, "taii-global-id")

                        self.taii_local_id = YLeaf(YType.str, "taii-local-id")

                        self.taii_prefix = YLeaf(YType.str, "taii-prefix")

                        self.taii_type = YLeaf(YType.int32, "taii-type")

                        self.fec_info = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo()
                        self.fec_info.parent = self
                        self._children_name_map["fec_info"] = "fec-info"
                        self._children_yang_names.add("fec-info")
                        self._segment_path = lambda: "ato-mdb-table-entry"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry, ['agi', 'agi_type', 'fe_ctype', 'mapping_tlv_count', 'notification_tlv_count', 'peer_id', 'peer_id_xr', 'pw_id', 'saii_ac_id', 'saii_global_id', 'saii_local_id', 'saii_prefix', 'saii_type', 'taii_ac_id', 'taii_global_id', 'taii_local_id', 'taii_prefix', 'taii_type'], name, value)


                    class FecInfo(Entity):
                        """
                        Pseudowire FEC information
                        
                        .. attribute:: fe_ctype
                        
                        	FECType
                        	**type**\:   :py:class:`L2vpnLdpPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwFec>`
                        
                        .. attribute:: fec128
                        
                        	fec128
                        	**type**\:   :py:class:`Fec128 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128>`
                        
                        .. attribute:: fec129
                        
                        	fec129
                        	**type**\:   :py:class:`Fec129 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129>`
                        
                        .. attribute:: fec130
                        
                        	fec130
                        	**type**\:   :py:class:`Fec130 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, self).__init__()

                            self.yang_name = "fec-info"
                            self.yang_parent_name = "ato-mdb-table-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"fec128" : ("fec128", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128), "fec129" : ("fec129", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129), "fec130" : ("fec130", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130)}
                            self._child_list_classes = {}

                            self.fe_ctype = YLeaf(YType.enumeration, "fe-ctype")

                            self.fec128 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128()
                            self.fec128.parent = self
                            self._children_name_map["fec128"] = "fec128"
                            self._children_yang_names.add("fec128")

                            self.fec129 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129()
                            self.fec129.parent = self
                            self._children_name_map["fec129"] = "fec129"
                            self._children_yang_names.add("fec129")

                            self.fec130 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130()
                            self.fec130.parent = self
                            self._children_name_map["fec130"] = "fec130"
                            self._children_yang_names.add("fec130")
                            self._segment_path = lambda: "fec-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo, ['fe_ctype'], name, value)


                        class Fec128(Entity):
                            """
                            fec128
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, self).__init__()

                                self.yang_name = "fec128"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.pseudowire_id = YLeaf(YType.uint32, "pseudowire-id")
                                self._segment_path = lambda: "fec128"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec128, ['pseudowire_id'], name, value)


                        class Fec129(Entity):
                            """
                            fec129
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:   :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:   :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii>`
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifier
                            	**type**\:   :py:class:`Taii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129, self).__init__()

                                self.yang_name = "fec129"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"agi" : ("agi", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi), "saii" : ("saii", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii), "taii" : ("taii", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii)}
                                self._child_list_classes = {}

                                self.agi = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"
                                self._children_yang_names.add("agi")

                                self.saii = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._children_yang_names.add("saii")

                                self.taii = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii()
                                self.taii.parent = self
                                self._children_name_map["taii"] = "taii"
                                self._children_yang_names.add("taii")
                                self._segment_path = lambda: "fec129"


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:   :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:   :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"agi1" : ("agi1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1)}
                                    self._child_list_classes = {}

                                    self.agi_type = YLeaf(YType.enumeration, "agi-type")

                                    self.agi1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._children_yang_names.add("agi1")
                                    self._segment_path = lambda: "agi"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.rd = YLeaf(YType.uint64, "rd")
                                        self._segment_path = lambda: "agi1"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1), "aii2" : ("aii2", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "saii"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Saii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


                            class Taii(Entity):
                                """
                                Target Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, self).__init__()

                                    self.yang_name = "taii"
                                    self.yang_parent_name = "fec129"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1), "aii2" : ("aii2", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "taii"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "taii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec129.Taii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


                        class Fec130(Entity):
                            """
                            fec130
                            
                            .. attribute:: agi
                            
                            	AGI
                            	**type**\:   :py:class:`Agi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi>`
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifier
                            	**type**\:   :py:class:`Saii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130, self).__init__()

                                self.yang_name = "fec130"
                                self.yang_parent_name = "fec-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"agi" : ("agi", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi), "saii" : ("saii", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii)}
                                self._child_list_classes = {}

                                self.agi = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi()
                                self.agi.parent = self
                                self._children_name_map["agi"] = "agi"
                                self._children_yang_names.add("agi")

                                self.saii = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii()
                                self.saii.parent = self
                                self._children_name_map["saii"] = "saii"
                                self._children_yang_names.add("saii")
                                self._segment_path = lambda: "fec130"


                            class Agi(Entity):
                                """
                                AGI
                                
                                .. attribute:: agi1
                                
                                	agi1
                                	**type**\:   :py:class:`Agi1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1>`
                                
                                .. attribute:: agi_type
                                
                                	AGIType
                                	**type**\:   :py:class:`L2vpnLdpPwAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAgi>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, self).__init__()

                                    self.yang_name = "agi"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"agi1" : ("agi1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1)}
                                    self._child_list_classes = {}

                                    self.agi_type = YLeaf(YType.enumeration, "agi-type")

                                    self.agi1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1()
                                    self.agi1.parent = self
                                    self._children_name_map["agi1"] = "agi1"
                                    self._children_yang_names.add("agi1")
                                    self._segment_path = lambda: "agi"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi, ['agi_type'], name, value)


                                class Agi1(Entity):
                                    """
                                    agi1
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, self).__init__()

                                        self.yang_name = "agi1"
                                        self.yang_parent_name = "agi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.rd = YLeaf(YType.uint64, "rd")
                                        self._segment_path = lambda: "agi1"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Agi.Agi1, ['rd'], name, value)


                            class Saii(Entity):
                                """
                                Source Attachment Individual Identifier
                                
                                .. attribute:: aii1
                                
                                	aii1
                                	**type**\:   :py:class:`Aii1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1>`
                                
                                .. attribute:: aii2
                                
                                	aii2
                                	**type**\:   :py:class:`Aii2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2>`
                                
                                .. attribute:: aii_type
                                
                                	AIIType
                                	**type**\:   :py:class:`L2vpnLdpPwAii <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.L2vpnLdpPwAii>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, self).__init__()

                                    self.yang_name = "saii"
                                    self.yang_parent_name = "fec130"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"aii1" : ("aii1", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1), "aii2" : ("aii2", MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2)}
                                    self._child_list_classes = {}

                                    self.aii_type = YLeaf(YType.enumeration, "aii-type")

                                    self.aii1 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1()
                                    self.aii1.parent = self
                                    self._children_name_map["aii1"] = "aii1"
                                    self._children_yang_names.add("aii1")

                                    self.aii2 = MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2()
                                    self.aii2.parent = self
                                    self._children_name_map["aii2"] = "aii2"
                                    self._children_yang_names.add("aii2")
                                    self._segment_path = lambda: "saii"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii, ['aii_type'], name, value)


                                class Aii1(Entity):
                                    """
                                    aii1
                                    
                                    .. attribute:: local_id
                                    
                                    	Local Identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, self).__init__()

                                        self.yang_name = "aii1"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_id = YLeaf(YType.str, "local-id")
                                        self._segment_path = lambda: "aii1"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii1, ['local_id'], name, value)


                                class Aii2(Entity):
                                    """
                                    aii2
                                    
                                    .. attribute:: ac_id
                                    
                                    	AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gobal_id
                                    
                                    	Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, self).__init__()

                                        self.yang_name = "aii2"
                                        self.yang_parent_name = "saii"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ac_id = YLeaf(YType.uint32, "ac-id")

                                        self.gobal_id = YLeaf(YType.uint32, "gobal-id")

                                        self.prefix = YLeaf(YType.uint32, "prefix")
                                        self._segment_path = lambda: "aii2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.AtoMdbTableEntries.AtoMdbTableEntry.FecInfo.Fec130.Saii.Aii2, ['ac_id', 'gobal_id', 'prefix'], name, value)


            class BindingsSummaryAll(Entity):
                """
                Aggregate VRF counters for the LDP Label
                Infomation Base (LIB)
                
                .. attribute:: address_family
                
                	Address Family
                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                
                .. attribute:: bind_af
                
                	bind af
                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.BindingsSummaryAll.BindAf>`
                
                .. attribute:: binding_local_explicit_null
                
                	Number of local explicit null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_implicit_null
                
                	Number of local implicit null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_no_route
                
                	Local bindings with no route
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_non_null
                
                	Number of local non\-null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_null
                
                	Number of local null bindings
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_local_oor
                
                	Number of local bindings        needing label \- OOR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: binding_no_route
                
                	Bindings with no route
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: highest_allocated_label
                
                	Highest allocated label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lowest_allocated_label
                
                	Lowest allocated label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.BindingsSummaryAll, self).__init__()

                    self.yang_name = "bindings-summary-all"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf)}
                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Nodes.Node.BindingsSummaryAll.BindAf)}

                    self.address_family = YLeaf(YType.enumeration, "address-family")

                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                    self.vrf = MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")

                    self.bind_af = YList(self)
                    self._segment_path = lambda: "bindings-summary-all"

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                class BindAf(Entity):
                    """
                    bind af
                    
                    .. attribute:: address_family
                    
                    	Binding Summary Address Family
                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: binding_local
                    
                    	Number of local bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_remote
                    
                    	Number of remote bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: binding_total
                    
                    	Total bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_lib_update
                    
                    	Last update to LIB local binding
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lib_minimum_revision_sent_all
                    
                    	Last update sent to all peers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.BindingsSummaryAll.BindAf, self).__init__()

                        self.yang_name = "bind-af"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.address_family = YLeaf(YType.enumeration, "address-family")

                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                        self._segment_path = lambda: "bind-af"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "bindings-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


            class DefaultVrf(Entity):
                """
                DefaultVRF specific operational data
                
                .. attribute:: afs
                
                	Address Family specific operational data
                	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs>`
                
                .. attribute:: backoff_parameters
                
                	The LDP Backoff Parameters
                	**type**\:   :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters>`
                
                .. attribute:: backoffs
                
                	The LDP backoff
                	**type**\:   :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Backoffs>`
                
                .. attribute:: capabilities
                
                	LDP capability database information
                	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Capabilities>`
                
                .. attribute:: graceful_restart
                
                	LDP Graceful Restart info
                	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart>`
                
                .. attribute:: issu
                
                	LDP ISSU related information
                	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu>`
                
                .. attribute:: ldp_id
                
                	Local LDP Id
                	**type**\:   :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.LdpId>`
                
                .. attribute:: neighbor_briefs
                
                	The LDP Neighbors (brief)
                	**type**\:   :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs>`
                
                .. attribute:: neighbor_capabilities
                
                	LDP Neighbors Capabilities
                	**type**\:   :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities>`
                
                .. attribute:: neighbors
                
                	The LDP Neighbors
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors>`
                
                .. attribute:: nsr
                
                	LDP NSR related information
                	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr>`
                
                .. attribute:: parameters
                
                	LDP parameters
                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Parameters>`
                
                .. attribute:: statistics
                
                	The LDP Statistics
                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Statistics>`
                
                .. attribute:: summary
                
                	LDP VRF summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Summary>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"afs" : ("afs", MplsLdp.Nodes.Node.DefaultVrf.Afs), "backoff-parameters" : ("backoff_parameters", MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters), "backoffs" : ("backoffs", MplsLdp.Nodes.Node.DefaultVrf.Backoffs), "capabilities" : ("capabilities", MplsLdp.Nodes.Node.DefaultVrf.Capabilities), "graceful-restart" : ("graceful_restart", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart), "issu" : ("issu", MplsLdp.Nodes.Node.DefaultVrf.Issu), "ldp-id" : ("ldp_id", MplsLdp.Nodes.Node.DefaultVrf.LdpId), "neighbor-briefs" : ("neighbor_briefs", MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs), "neighbor-capabilities" : ("neighbor_capabilities", MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities), "neighbors" : ("neighbors", MplsLdp.Nodes.Node.DefaultVrf.Neighbors), "nsr" : ("nsr", MplsLdp.Nodes.Node.DefaultVrf.Nsr), "parameters" : ("parameters", MplsLdp.Nodes.Node.DefaultVrf.Parameters), "statistics" : ("statistics", MplsLdp.Nodes.Node.DefaultVrf.Statistics), "summary" : ("summary", MplsLdp.Nodes.Node.DefaultVrf.Summary)}
                    self._child_list_classes = {}

                    self.afs = MplsLdp.Nodes.Node.DefaultVrf.Afs()
                    self.afs.parent = self
                    self._children_name_map["afs"] = "afs"
                    self._children_yang_names.add("afs")

                    self.backoff_parameters = MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters()
                    self.backoff_parameters.parent = self
                    self._children_name_map["backoff_parameters"] = "backoff-parameters"
                    self._children_yang_names.add("backoff-parameters")

                    self.backoffs = MplsLdp.Nodes.Node.DefaultVrf.Backoffs()
                    self.backoffs.parent = self
                    self._children_name_map["backoffs"] = "backoffs"
                    self._children_yang_names.add("backoffs")

                    self.capabilities = MplsLdp.Nodes.Node.DefaultVrf.Capabilities()
                    self.capabilities.parent = self
                    self._children_name_map["capabilities"] = "capabilities"
                    self._children_yang_names.add("capabilities")

                    self.graceful_restart = MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart()
                    self.graceful_restart.parent = self
                    self._children_name_map["graceful_restart"] = "graceful-restart"
                    self._children_yang_names.add("graceful-restart")

                    self.issu = MplsLdp.Nodes.Node.DefaultVrf.Issu()
                    self.issu.parent = self
                    self._children_name_map["issu"] = "issu"
                    self._children_yang_names.add("issu")

                    self.ldp_id = MplsLdp.Nodes.Node.DefaultVrf.LdpId()
                    self.ldp_id.parent = self
                    self._children_name_map["ldp_id"] = "ldp-id"
                    self._children_yang_names.add("ldp-id")

                    self.neighbor_briefs = MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs()
                    self.neighbor_briefs.parent = self
                    self._children_name_map["neighbor_briefs"] = "neighbor-briefs"
                    self._children_yang_names.add("neighbor-briefs")

                    self.neighbor_capabilities = MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities()
                    self.neighbor_capabilities.parent = self
                    self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"
                    self._children_yang_names.add("neighbor-capabilities")

                    self.neighbors = MplsLdp.Nodes.Node.DefaultVrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.nsr = MplsLdp.Nodes.Node.DefaultVrf.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"
                    self._children_yang_names.add("nsr")

                    self.parameters = MplsLdp.Nodes.Node.DefaultVrf.Parameters()
                    self.parameters.parent = self
                    self._children_name_map["parameters"] = "parameters"
                    self._children_yang_names.add("parameters")

                    self.statistics = MplsLdp.Nodes.Node.DefaultVrf.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._children_yang_names.add("statistics")

                    self.summary = MplsLdp.Nodes.Node.DefaultVrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")
                    self._segment_path = lambda: "default-vrf"


                class Afs(Entity):
                    """
                    Address Family specific operational data
                    
                    .. attribute:: af
                    
                    	Operational data for given Address Family
                    	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs, self).__init__()

                        self.yang_name = "afs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"af" : ("af", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af)}

                        self.af = YList(self)
                        self._segment_path = lambda: "afs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs, [], name, value)


                    class Af(Entity):
                        """
                        Operational data for given Address Family
                        
                        .. attribute:: af_name  <key>
                        
                        	Address Family name
                        	**type**\:   :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                        
                        .. attribute:: bindings
                        
                        	The LDP Bindings
                        	**type**\:   :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings>`
                        
                        .. attribute:: bindings_advertise_spec
                        
                        	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec>`
                        
                        .. attribute:: bindings_summary
                        
                        	Counters for the LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary>`
                        
                        .. attribute:: bindings_summary_all
                        
                        	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
                        	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll>`
                        
                        .. attribute:: discovery
                        
                        	The LDP Discovery
                        	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery>`
                        
                        .. attribute:: forwarding_summary
                        
                        	Summary information regarding LDP forwarding setup
                        	**type**\:   :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary>`
                        
                        .. attribute:: forwardings
                        
                        	The LDP Forwarding rewrites
                        	**type**\:   :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings>`
                        
                        .. attribute:: igp
                        
                        	LDP IGP related information
                        	**type**\:   :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp>`
                        
                        .. attribute:: interface_summary
                        
                        	IPv4 interface summary information
                        	**type**\:   :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary>`
                        
                        .. attribute:: interfaces
                        
                        	LDP Interface related information
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af, self).__init__()

                            self.yang_name = "af"
                            self.yang_parent_name = "afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"bindings" : ("bindings", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings), "bindings-advertise-spec" : ("bindings_advertise_spec", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec), "bindings-summary" : ("bindings_summary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll), "discovery" : ("discovery", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery), "forwarding-summary" : ("forwarding_summary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary), "forwardings" : ("forwardings", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings), "igp" : ("igp", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp), "interface-summary" : ("interface_summary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary), "interfaces" : ("interfaces", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces)}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.bindings = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings()
                            self.bindings.parent = self
                            self._children_name_map["bindings"] = "bindings"
                            self._children_yang_names.add("bindings")

                            self.bindings_advertise_spec = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec()
                            self.bindings_advertise_spec.parent = self
                            self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"
                            self._children_yang_names.add("bindings-advertise-spec")

                            self.bindings_summary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary()
                            self.bindings_summary.parent = self
                            self._children_name_map["bindings_summary"] = "bindings-summary"
                            self._children_yang_names.add("bindings-summary")

                            self.bindings_summary_all = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll()
                            self.bindings_summary_all.parent = self
                            self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                            self._children_yang_names.add("bindings-summary-all")

                            self.discovery = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery()
                            self.discovery.parent = self
                            self._children_name_map["discovery"] = "discovery"
                            self._children_yang_names.add("discovery")

                            self.forwarding_summary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary()
                            self.forwarding_summary.parent = self
                            self._children_name_map["forwarding_summary"] = "forwarding-summary"
                            self._children_yang_names.add("forwarding-summary")

                            self.forwardings = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings()
                            self.forwardings.parent = self
                            self._children_name_map["forwardings"] = "forwardings"
                            self._children_yang_names.add("forwardings")

                            self.igp = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp()
                            self.igp.parent = self
                            self._children_name_map["igp"] = "igp"
                            self._children_yang_names.add("igp")

                            self.interface_summary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary()
                            self.interface_summary.parent = self
                            self._children_name_map["interface_summary"] = "interface-summary"
                            self._children_yang_names.add("interface-summary")

                            self.interfaces = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                            self._children_yang_names.add("interfaces")
                            self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af, ['af_name'], name, value)


                        class Bindings(Entity):
                            """
                            The LDP Bindings
                            
                            .. attribute:: binding
                            
                            	Binding Information
                            	**type**\: list of    :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings, self).__init__()

                                self.yang_name = "bindings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"binding" : ("binding", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding)}

                                self.binding = YList(self)
                                self._segment_path = lambda: "bindings"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings, [], name, value)


                            class Binding(Entity):
                                """
                                Binding Information
                                
                                .. attribute:: prefix  <key>
                                
                                	The IP Prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: advertise_prefix_acl
                                
                                	Advertise Prerfix ACL
                                	**type**\:  str
                                
                                .. attribute:: advertise_tsr_acl
                                
                                	Advertise TSR ACL
                                	**type**\:  str
                                
                                .. attribute:: config_enforced_local_label_value
                                
                                	Config/User enforced local label value
                                	**type**\:  bool
                                
                                .. attribute:: is_elc
                                
                                	Is the entry entropy label capable
                                	**type**\:  bool
                                
                                .. attribute:: is_no_route
                                
                                	No route
                                	**type**\:  bool
                                
                                .. attribute:: label_oor
                                
                                	Label space depletion OOR
                                	**type**\:  bool
                                
                                .. attribute:: le_local_binding_revision
                                
                                	Local Binding revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: le_local_label_state
                                
                                	Local label state
                                	**type**\:   :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peers_acked
                                
                                	Peers that have ACKed this entry
                                	**type**\: list of    :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                
                                .. attribute:: peers_advertised_to
                                
                                	Peers this entry is advertised to
                                	**type**\: list of    :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                
                                .. attribute:: remote_binding
                                
                                	Remote binding
                                	**type**\: list of    :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding, self).__init__()

                                    self.yang_name = "binding"
                                    self.yang_parent_name = "bindings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr), "vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf)}
                                    self._child_list_classes = {"peers-acked" : ("peers_acked", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked), "peers-advertised-to" : ("peers_advertised_to", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo), "remote-binding" : ("remote_binding", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.advertise_prefix_acl = YLeaf(YType.str, "advertise-prefix-acl")

                                    self.advertise_tsr_acl = YLeaf(YType.str, "advertise-tsr-acl")

                                    self.config_enforced_local_label_value = YLeaf(YType.boolean, "config-enforced-local-label-value")

                                    self.is_elc = YLeaf(YType.boolean, "is-elc")

                                    self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                    self.le_local_binding_revision = YLeaf(YType.uint32, "le-local-binding-revision")

                                    self.le_local_label_state = YLeaf(YType.enumeration, "le-local-label-state")

                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                    self.prefix_xr = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"
                                    self._children_yang_names.add("prefix-xr")

                                    self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.peers_acked = YList(self)
                                    self.peers_advertised_to = YList(self)
                                    self.remote_binding = YList(self)
                                    self._segment_path = lambda: "binding" + "[prefix='" + self.prefix.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding, ['prefix', 'advertise_prefix_acl', 'advertise_tsr_acl', 'config_enforced_local_label_value', 'is_elc', 'is_no_route', 'label_oor', 'le_local_binding_revision', 'le_local_label_state', 'local_label', 'prefix_length'], name, value)


                                class PeersAcked(Entity):
                                    """
                                    Peers that have ACKed this entry
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                        self.yang_name = "peers-acked"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                        self._segment_path = lambda: "peers-acked"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAcked, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class PeersAdvertisedTo(Entity):
                                    """
                                    Peers this entry is advertised to
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ldp_id
                                    
                                    	LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR identifier
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                        self.yang_name = "peers-advertised-to"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                        self._segment_path = lambda: "peers-advertised-to"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "prefix-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class RemoteBinding(Entity):
                                    """
                                    Remote binding
                                    
                                    .. attribute:: assigning_peer_ldp_ident
                                    
                                    	Assigning peer
                                    	**type**\:   :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_stale
                                    
                                    	Is the entry stale
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                        self.yang_name = "remote-binding"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"assigning-peer-ldp-ident" : ("assigning_peer_ldp_ident", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent)}
                                        self._child_list_classes = {}

                                        self.is_elc = YLeaf(YType.boolean, "is-elc")

                                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                                        self.remote_label = YLeaf(YType.uint32, "remote-label")

                                        self.assigning_peer_ldp_ident = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                        self.assigning_peer_ldp_ident.parent = self
                                        self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                        self._children_yang_names.add("assigning-peer-ldp-ident")
                                        self._segment_path = lambda: "remote-binding"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding, ['is_elc', 'is_stale', 'remote_label'], name, value)


                                    class AssigningPeerLdpIdent(Entity):
                                        """
                                        Assigning peer
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                            self.yang_name = "assigning-peer-ldp-ident"
                                            self.yang_parent_name = "remote-binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "assigning-peer-ldp-ident"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "binding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Bindings.Binding.Vrf, ['id', 'name'], name, value)


                        class BindingsAdvertiseSpec(Entity):
                            """
                            Advertisement Spec (ACL) for LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: advt_acl
                            
                            	Advertisement ACLs
                            	**type**\: list of    :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                            
                            .. attribute:: allocation_acl
                            
                            	Local label Allocation filter
                            	**type**\:   :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                self.yang_name = "bindings-advertise-spec"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"allocation-acl" : ("allocation_acl", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)}
                                self._child_list_classes = {"advt-acl" : ("advt_acl", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl)}

                                self.allocation_acl = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                self.allocation_acl.parent = self
                                self._children_name_map["allocation_acl"] = "allocation-acl"
                                self._children_yang_names.add("allocation-acl")

                                self.advt_acl = YList(self)
                                self._segment_path = lambda: "bindings-advertise-spec"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                            class AdvtAcl(Entity):
                                """
                                Advertisement ACLs
                                
                                .. attribute:: peer_acl
                                
                                	Peer ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                    self.yang_name = "advt-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.peer_acl = YLeaf(YType.str, "peer-acl")

                                    self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                    self._segment_path = lambda: "advt-acl"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, ['peer_acl', 'prefix_acl'], name, value)


                            class AllocationAcl(Entity):
                                """
                                Local label Allocation filter
                                
                                .. attribute:: has_acl
                                
                                	Has ACL filter?
                                	**type**\:  bool
                                
                                .. attribute:: is_host_route_only
                                
                                	Host\-routes only?
                                	**type**\:  bool
                                
                                .. attribute:: prefix_acl
                                
                                	Prefix ACL
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                    self.yang_name = "allocation-acl"
                                    self.yang_parent_name = "bindings-advertise-spec"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.has_acl = YLeaf(YType.boolean, "has-acl")

                                    self.is_host_route_only = YLeaf(YType.boolean, "is-host-route-only")

                                    self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                    self._segment_path = lambda: "allocation-acl"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, ['has_acl', 'is_host_route_only', 'prefix_acl'], name, value)


                        class BindingsSummary(Entity):
                            """
                            Counters for the LDP Label Infomation Base
                            (LIB)
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.BindAf>`
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary, self).__init__()

                                self.yang_name = "bindings-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf)}
                                self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.BindAf)}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local = YLeaf(YType.uint32, "binding-local")

                                    self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                    self.binding_total = YLeaf(YType.uint32, "binding-total")

                                    self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                    self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                    self._segment_path = lambda: "bind-af"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummary.Vrf, ['id', 'name'], name, value)


                        class BindingsSummaryAll(Entity):
                            """
                            Aggregate VRF counters for the LDP Label
                            Infomation Base (LIB)
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: bind_af
                            
                            	bind af
                            	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf>`
                            
                            .. attribute:: binding_local_explicit_null
                            
                            	Number of local explicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_implicit_null
                            
                            	Number of local implicit null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_no_route
                            
                            	Local bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_non_null
                            
                            	Number of local non\-null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_null
                            
                            	Number of local null bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_local_oor
                            
                            	Number of local bindings        needing label \- OOR
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: binding_no_route
                            
                            	Bindings with no route
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: highest_allocated_label
                            
                            	Highest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lowest_allocated_label
                            
                            	Lowest allocated label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll, self).__init__()

                                self.yang_name = "bindings-summary-all"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf)}
                                self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf)}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.bind_af = YList(self)
                                self._segment_path = lambda: "bindings-summary-all"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                            class BindAf(Entity):
                                """
                                bind af
                                
                                .. attribute:: address_family
                                
                                	Binding Summary Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: binding_local
                                
                                	Number of local bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_remote
                                
                                	Number of remote bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_total
                                
                                	Total bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_lib_update
                                
                                	Last update to LIB local binding
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lib_minimum_revision_sent_all
                                
                                	Last update sent to all peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf, self).__init__()

                                    self.yang_name = "bind-af"
                                    self.yang_parent_name = "bindings-summary-all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local = YLeaf(YType.uint32, "binding-local")

                                    self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                    self.binding_total = YLeaf(YType.uint32, "binding-total")

                                    self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                    self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                    self._segment_path = lambda: "bind-af"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "bindings-summary-all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


                        class Discovery(Entity):
                            """
                            The LDP Discovery
                            
                            .. attribute:: brief
                            
                            	Brief information on LDP discovery
                            	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief>`
                            
                            .. attribute:: link_hellos
                            
                            	The LDP Discovery link
                            	**type**\:   :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos>`
                            
                            .. attribute:: stats
                            
                            	The LDP Discovery Statistics
                            	**type**\:   :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats>`
                            
                            .. attribute:: summary
                            
                            	Summarized information on LDP discovery
                            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary>`
                            
                            .. attribute:: targeted_hellos
                            
                            	The LDP Discovery Targeted
                            	**type**\:   :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery, self).__init__()

                                self.yang_name = "discovery"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"brief" : ("brief", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief), "link-hellos" : ("link_hellos", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos), "stats" : ("stats", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats), "summary" : ("summary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary), "targeted-hellos" : ("targeted_hellos", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos)}
                                self._child_list_classes = {}

                                self.brief = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief()
                                self.brief.parent = self
                                self._children_name_map["brief"] = "brief"
                                self._children_yang_names.add("brief")

                                self.link_hellos = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos()
                                self.link_hellos.parent = self
                                self._children_name_map["link_hellos"] = "link-hellos"
                                self._children_yang_names.add("link-hellos")

                                self.stats = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats()
                                self.stats.parent = self
                                self._children_name_map["stats"] = "stats"
                                self._children_yang_names.add("stats")

                                self.summary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"
                                self._children_yang_names.add("summary")

                                self.targeted_hellos = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos()
                                self.targeted_hellos.parent = self
                                self._children_name_map["targeted_hellos"] = "targeted-hellos"
                                self._children_yang_names.add("targeted-hellos")
                                self._segment_path = lambda: "discovery"


                            class Brief(Entity):
                                """
                                Brief information on LDP discovery
                                
                                .. attribute:: link_hello_briefs
                                
                                	The LDP Discovery link brief information
                                	**type**\:   :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                
                                .. attribute:: targeted_hello_briefs
                                
                                	The LDP Discovery Targeted brief information
                                	**type**\:   :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief, self).__init__()

                                    self.yang_name = "brief"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"link-hello-briefs" : ("link_hello_briefs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs), "targeted-hello-briefs" : ("targeted_hello_briefs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs)}
                                    self._child_list_classes = {}

                                    self.link_hello_briefs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                    self.link_hello_briefs.parent = self
                                    self._children_name_map["link_hello_briefs"] = "link-hello-briefs"
                                    self._children_yang_names.add("link-hello-briefs")

                                    self.targeted_hello_briefs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                    self.targeted_hello_briefs.parent = self
                                    self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                    self._children_yang_names.add("targeted-hello-briefs")
                                    self._segment_path = lambda: "brief"


                                class LinkHelloBriefs(Entity):
                                    """
                                    The LDP Discovery link brief information
                                    
                                    .. attribute:: link_hello_brief
                                    
                                    	Brief information on LDP link discovery
                                    	**type**\: list of    :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                        self.yang_name = "link-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"link-hello-brief" : ("link_hello_brief", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief)}

                                        self.link_hello_brief = YList(self)
                                        self._segment_path = lambda: "link-hello-briefs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                    class LinkHelloBrief(Entity):
                                        """
                                        Brief information on LDP link discovery
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: address_family
                                        
                                        	Discovery Brief Address Family
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: address_family_set
                                        
                                        	Discovery Brief Address Family Set
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                            self.yang_name = "link-hello-brief"
                                            self.yang_parent_name = "link-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)}
                                            self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.address_family = YLeaf(YType.enumeration, "address-family")

                                            self.address_family_set = YLeaf(YType.enumeration, "address-family-set")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', 'address_family', 'address_family_set', 'interface', 'interface_name_xr'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_up = YLeaf(YType.boolean, "session-up")
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, ['id', 'name'], name, value)


                                class TargetedHelloBriefs(Entity):
                                    """
                                    The LDP Discovery Targeted brief information
                                    
                                    .. attribute:: targeted_hello_brief
                                    
                                    	Brief information on LDP targeted discovery
                                    	**type**\: list of    :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                        self.yang_name = "targeted-hello-briefs"
                                        self.yang_parent_name = "brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"targeted-hello-brief" : ("targeted_hello_brief", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief)}

                                        self.targeted_hello_brief = YList(self)
                                        self._segment_path = lambda: "targeted-hello-briefs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                    class TargetedHelloBrief(Entity):
                                        """
                                        Brief information on LDP targeted discovery
                                        
                                        .. attribute:: address_family
                                        
                                        	Targeted Discovery Address Family
                                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                            self.yang_name = "targeted-hello-brief"
                                            self.yang_parent_name = "targeted-hello-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"dhcb-target-address" : ("dhcb_target_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress), "vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)}
                                            self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation)}

                                            self.address_family = YLeaf(YType.enumeration, "address-family")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.target_address = YLeaf(YType.str, "target-address")

                                            self.dhcb_target_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                            self._children_yang_names.add("dhcb-target-address")

                                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "targeted-hello-brief"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['address_family', 'local_address', 'target_address'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_up = YLeaf(YType.boolean, "session-up")
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "targeted-hello-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, ['id', 'name'], name, value)


                            class LinkHellos(Entity):
                                """
                                The LDP Discovery link
                                
                                .. attribute:: link_hello
                                
                                	Information on LDP link discovery
                                	**type**\: list of    :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                    self.yang_name = "link-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"link-hello" : ("link_hello", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello)}

                                    self.link_hello = YList(self)
                                    self._segment_path = lambda: "link-hellos"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                class LinkHello(Entity):
                                    """
                                    Information on LDP link discovery
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: discovery_link_af
                                    
                                    	LDP hello AF info
                                    	**type**\: list of    :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                    
                                    .. attribute:: hello_information
                                    
                                    	LDP hello info
                                    	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                        self.yang_name = "link-hello"
                                        self.yang_parent_name = "link-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)}
                                        self._child_list_classes = {"discovery-link-af" : ("discovery_link_af", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf), "hello-information" : ("hello_information", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.next_hello = YLeaf(YType.uint32, "next-hello")

                                        self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                        self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.discovery_link_af = YList(self)
                                        self.hello_information = YList(self)
                                        self._segment_path = lambda: "link-hello" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', 'interface', 'interface_name_xr', 'next_hello', 'quick_start_disabled'], name, value)


                                    class DiscoveryLinkAf(Entity):
                                        """
                                        LDP hello AF info
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_src_address
                                        
                                        	Local source address
                                        	**type**\:   :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                        
                                        .. attribute:: local_transport_address
                                        
                                        	Local transport address
                                        	**type**\:   :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                            self.yang_name = "discovery-link-af"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-src-address" : ("local_src_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress), "local-transport-address" : ("local_transport_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress)}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.local_src_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                            self.local_src_address.parent = self
                                            self._children_name_map["local_src_address"] = "local-src-address"
                                            self._children_yang_names.add("local-src-address")

                                            self.local_transport_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                            self.local_transport_address.parent = self
                                            self._children_name_map["local_transport_address"] = "local-transport-address"
                                            self._children_yang_names.add("local-transport-address")
                                            self._segment_path = lambda: "discovery-link-af"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, ['interval'], name, value)


                                        class LocalSrcAddress(Entity):
                                            """
                                            Local source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                self.yang_name = "local-src-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-src-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class LocalTransportAddress(Entity):
                                            """
                                            Local transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                self.yang_name = "local-transport-address"
                                                self.yang_parent_name = "discovery-link-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-transport-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class HelloInformation(Entity):
                                        """
                                        LDP hello info
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: hold_time
                                        
                                        	Session hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: is_no_route
                                        
                                        	Is route valid
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_targeted
                                        
                                        	Is session a targeted session
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                        
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_ldp_identifier
                                        
                                        	Neighbor LDP Identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_src_address
                                        
                                        	Neighbor source address
                                        	**type**\:   :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                        
                                        .. attribute:: neighbor_transport_address
                                        
                                        	Neighbor transport address
                                        	**type**\:   :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\:  str
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\:  bool
                                        
                                        .. attribute:: target
                                        
                                        	Target address
                                        	**type**\:   :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                            self.yang_name = "hello-information"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-src-address" : ("neighbor_src_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress), "neighbor-transport-address" : ("neighbor_transport_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress), "target" : ("target", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)}
                                            self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo)}

                                            self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                            self.established_age = YLeaf(YType.uint64, "established-age")

                                            self.established_time = YLeaf(YType.uint64, "established-time")

                                            self.hold_time = YLeaf(YType.uint32, "hold-time")

                                            self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                            self.is_targeted = YLeaf(YType.boolean, "is-targeted")

                                            self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                            self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                            self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                            self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                            self.session_up = YLeaf(YType.boolean, "session-up")

                                            self.neighbor_src_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                            self.neighbor_src_address.parent = self
                                            self._children_name_map["neighbor_src_address"] = "neighbor-src-address"
                                            self._children_yang_names.add("neighbor-src-address")

                                            self.neighbor_transport_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                            self.neighbor_transport_address.parent = self
                                            self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"
                                            self._children_yang_names.add("neighbor-transport-address")

                                            self.target = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                            self.target.parent = self
                                            self._children_name_map["target"] = "target"
                                            self._children_yang_names.add("target")

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "hello-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, ['disc_expiry', 'established_age', 'established_time', 'hold_time', 'is_no_route', 'is_targeted', 'local_hold_time', 'neighbor_hold_time', 'neighbor_ldp_identifier', 'session_bringup_failure_reason', 'session_up'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\:  str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                self._segment_path = lambda: "last-session-down-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                                        class NeighborSrcAddress(Entity):
                                            """
                                            Neighbor source address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                self.yang_name = "neighbor-src-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "neighbor-src-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class NeighborTransportAddress(Entity):
                                            """
                                            Neighbor transport address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                self.yang_name = "neighbor-transport-address"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "neighbor-transport-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class Target(Entity):
                                            """
                                            Target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                self.yang_name = "target"
                                                self.yang_parent_name = "hello-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "link-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, ['id', 'name'], name, value)


                            class Stats(Entity):
                                """
                                The LDP Discovery Statistics
                                
                                .. attribute:: stat
                                
                                	Information on LDP discovery statistics
                                	**type**\: list of    :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats.Stat>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats, self).__init__()

                                    self.yang_name = "stats"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"stat" : ("stat", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats.Stat)}

                                    self.stat = YList(self)
                                    self._segment_path = lambda: "stats"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats, [], name, value)


                                class Stat(Entity):
                                    """
                                    Information on LDP discovery statistics
                                    
                                    .. attribute:: adjacency_group_up_time
                                    
                                    	Adjacency group up time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tcp_arb_chg_count
                                    
                                    	Count of changes in TCP arbitration
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_open_count
                                    
                                    	Count of attempted TCP opens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_role
                                    
                                    	TCP Role
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                        self.yang_name = "stat"
                                        self.yang_parent_name = "stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.adjacency_group_up_time = YLeaf(YType.uint32, "adjacency-group-up-time")

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.tcp_arb_chg_count = YLeaf(YType.uint32, "tcp-arb-chg-count")

                                        self.tcp_open_count = YLeaf(YType.uint32, "tcp-open-count")

                                        self.tcp_role = YLeaf(YType.uint32, "tcp-role")
                                        self._segment_path = lambda: "stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Stats.Stat, ['adjacency_group_up_time', 'label_space_id', 'lsr_id', 'tcp_arb_chg_count', 'tcp_open_count', 'tcp_role'], name, value)


                            class Summary(Entity):
                                """
                                Summarized information on LDP discovery
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP identifier
                                	**type**\:  str
                                
                                .. attribute:: num_of_active_ldp_interfaces
                                
                                	Number of active LDP enabled interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_addr_recv
                                
                                	Number of hello discoveries received with bad source address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_hello_pdu
                                
                                	Number of hello discoveries received with bad hello PDU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_bad_xport_addr
                                
                                	Number of hello discoveries received with bad export address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_same_router_id
                                
                                	Number of hello discoveries received with the same router id as this router
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_disc_with_wrong_router_id
                                
                                	Number of hello discoveries received with the router id that is not destined for this router
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_ldp_interfaces
                                
                                	Total Number of LDP configured interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_recv
                                
                                	Number of link hello discoveries in recv state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_lnk_disc_xmit
                                
                                	Number of link hello discoveries in xmit state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_recv
                                
                                	Number of targeted hello discoveries in recv state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_tgt_disc_xmit
                                
                                	Number of targeted hello discoveries in xmit state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary, self).__init__()

                                    self.yang_name = "summary"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf)}
                                    self._child_list_classes = {}

                                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                    self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                                    self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                                    self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                                    self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                                    self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                                    self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                                    self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                                    self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                                    self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                                    self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                                    self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                                    self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.Summary.Vrf, ['id', 'name'], name, value)


                            class TargetedHellos(Entity):
                                """
                                The LDP Discovery Targeted
                                
                                .. attribute:: targeted_hello
                                
                                	Information on LDP targeted discovery
                                	**type**\: list of    :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                    self.yang_name = "targeted-hellos"
                                    self.yang_parent_name = "discovery"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"targeted-hello" : ("targeted_hello", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello)}

                                    self.targeted_hello = YList(self)
                                    self._segment_path = lambda: "targeted-hellos"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                class TargetedHello(Entity):
                                    """
                                    Information on LDP targeted discovery
                                    
                                    .. attribute:: adjacency_ldp_identifier
                                    
                                    	Adjacency LDP Identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcb_local_address
                                    
                                    	DHCB local address
                                    	**type**\:   :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                    
                                    .. attribute:: dhcb_target_address
                                    
                                    	DHCB target address
                                    	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                    
                                    .. attribute:: disc_expiry
                                    
                                    	Discovery expiry time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: established_age
                                    
                                    	Hello adjacency estabished age in nanosec
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: established_time
                                    
                                    	Hello adjacency estabished time in nanosec
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: hold_time
                                    
                                    	Targeted hello hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval in sec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_session_down_info
                                    
                                    	Last session down information
                                    	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: local_hold_time
                                    
                                    	Local hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_hold_time
                                    
                                    	Neighbor hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello
                                    
                                    	Next hello due time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: quick_start_disabled
                                    
                                    	Quick\-start disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: session_bringup_failure_reason
                                    
                                    	session bringup failure reason
                                    	**type**\:  str
                                    
                                    .. attribute:: session_up
                                    
                                    	Is session up for this adj
                                    	**type**\:  bool
                                    
                                    .. attribute:: state
                                    
                                    	Targeted hello state
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	The target IP Address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                        self.yang_name = "targeted-hello"
                                        self.yang_parent_name = "targeted-hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"dhcb-local-address" : ("dhcb_local_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress), "dhcb-target-address" : ("dhcb_target_address", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)}
                                        self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo)}

                                        self.adjacency_ldp_identifier = YLeaf(YType.str, "adjacency-ldp-identifier")

                                        self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                        self.established_age = YLeaf(YType.uint64, "established-age")

                                        self.established_time = YLeaf(YType.uint64, "established-time")

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.local_address = YLeaf(YType.str, "local-address")

                                        self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                        self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                        self.next_hello = YLeaf(YType.uint32, "next-hello")

                                        self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                        self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                        self.session_up = YLeaf(YType.boolean, "session-up")

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.target_address = YLeaf(YType.str, "target-address")

                                        self.dhcb_local_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                        self.dhcb_local_address.parent = self
                                        self._children_name_map["dhcb_local_address"] = "dhcb-local-address"
                                        self._children_yang_names.add("dhcb-local-address")

                                        self.dhcb_target_address = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                        self.dhcb_target_address.parent = self
                                        self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                        self._children_yang_names.add("dhcb-target-address")

                                        self.last_session_down_info = YList(self)
                                        self._segment_path = lambda: "targeted-hello"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['adjacency_ldp_identifier', 'disc_expiry', 'established_age', 'established_time', 'hold_time', 'interval', 'local_address', 'local_hold_time', 'neighbor_hold_time', 'next_hello', 'quick_start_disabled', 'session_bringup_failure_reason', 'session_up', 'state', 'target_address'], name, value)


                                    class DhcbLocalAddress(Entity):
                                        """
                                        DHCB local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                            self.yang_name = "dhcb-local-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "dhcb-local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class DhcbTargetAddress(Entity):
                                        """
                                        DHCB target address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                            self.yang_name = "dhcb-target-address"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "dhcb-target-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class LastSessionDownInfo(Entity):
                                        """
                                        Last session down information
                                        
                                        .. attribute:: last_session_down_reason
                                        
                                        	The reason of last socket failure
                                        	**type**\:  str
                                        
                                        .. attribute:: last_session_down_time
                                        
                                        	Timestamp of when the last session went down
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_session_up_time
                                        
                                        	The time duration the last session was up
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                            self.yang_name = "last-session-down-info"
                                            self.yang_parent_name = "targeted-hello"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                            self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                            self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                            self._segment_path = lambda: "last-session-down-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                        class ForwardingSummary(Entity):
                            """
                            Summary information regarding LDP forwarding
                            setup
                            
                            .. attribute:: fsht
                            
                            	Forwarding state hold time registered with LSD
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: intfs
                            
                            	MPLS forwarding enabled interface count
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_lsd_bound
                            
                            	LDP is connected to LSD server
                            	**type**\:  bool
                            
                            .. attribute:: lbls
                            
                            	Local label allocated count
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: rws
                            
                            	Forwarding rewrites summary
                            	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary, self).__init__()

                                self.yang_name = "forwarding-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"rws" : ("rws", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws), "vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf)}
                                self._child_list_classes = {}

                                self.fsht = YLeaf(YType.uint16, "fsht")

                                self.intfs = YLeaf(YType.uint16, "intfs")

                                self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                                self.lbls = YLeaf(YType.uint16, "lbls")

                                self.rws = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws()
                                self.rws.parent = self
                                self._children_name_map["rws"] = "rws"
                                self._children_yang_names.add("rws")

                                self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "forwarding-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                            class Rws(Entity):
                                """
                                Forwarding rewrites summary
                                
                                .. attribute:: nhs
                                
                                	Forwarding rewrites nexthops (paths) summary
                                	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                
                                .. attribute:: pfxs
                                
                                	Forwarding rewrites prefix summary
                                	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                    self.yang_name = "rws"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs)}
                                    self._child_list_classes = {}

                                    self.nhs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                    self.nhs.parent = self
                                    self._children_name_map["nhs"] = "nhs"
                                    self._children_yang_names.add("nhs")

                                    self.pfxs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                    self.pfxs.parent = self
                                    self._children_name_map["pfxs"] = "pfxs"
                                    self._children_yang_names.add("pfxs")
                                    self._segment_path = lambda: "rws"


                                class Nhs(Entity):
                                    """
                                    Forwarding rewrites nexthops (paths) summary
                                    
                                    .. attribute:: backup_paths
                                    
                                    	Count of non\-primary backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_backup_paths
                                    
                                    	Count of labeled backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: labeled_paths
                                    
                                    	Count of all labeled paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: protected_paths
                                    
                                    	Count of FRR protected paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_backup_paths
                                    
                                    	Count of non\-primary remote backup paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_paths
                                    
                                    	Total path count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                        self.yang_name = "nhs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                                        self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                                        self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                                        self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                                        self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                                        self.total_paths = YLeaf(YType.uint32, "total-paths")
                                        self._segment_path = lambda: "nhs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                                class Pfxs(Entity):
                                    """
                                    Forwarding rewrites prefix summary
                                    
                                    .. attribute:: ecmp_pfxs
                                    
                                    	Count of prefixes with ECMP
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: labeled_pfxs_aggr
                                    
                                    	Labeled prefix count for all paths
                                    	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                    
                                    .. attribute:: labeled_pfxs_backup
                                    
                                    	Labeled prefix count related to backup paths only
                                    	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                    
                                    .. attribute:: labeled_pfxs_primary
                                    
                                    	Labeled prefix count related to primary paths only
                                    	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                    
                                    .. attribute:: protected_pfxs
                                    
                                    	Count of FRR protected prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: total_pfxs
                                    
                                    	Total Prefix count
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                        self.yang_name = "pfxs"
                                        self.yang_parent_name = "rws"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)}
                                        self._child_list_classes = {}

                                        self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                                        self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                                        self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                                        self.labeled_pfxs_aggr = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                        self.labeled_pfxs_aggr.parent = self
                                        self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                                        self._children_yang_names.add("labeled-pfxs-aggr")

                                        self.labeled_pfxs_backup = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                        self.labeled_pfxs_backup.parent = self
                                        self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                        self._children_yang_names.add("labeled-pfxs-backup")

                                        self.labeled_pfxs_primary = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                        self.labeled_pfxs_primary.parent = self
                                        self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                                        self._children_yang_names.add("labeled-pfxs-primary")
                                        self._segment_path = lambda: "pfxs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                                    class LabeledPfxsAggr(Entity):
                                        """
                                        Labeled prefix count for all paths
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                            self.yang_name = "labeled-pfxs-aggr"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-aggr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsBackup(Entity):
                                        """
                                        Labeled prefix count related to backup paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                            self.yang_name = "labeled-pfxs-backup"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-backup"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                    class LabeledPfxsPrimary(Entity):
                                        """
                                        Labeled prefix count related to primary paths
                                        only
                                        
                                        .. attribute:: labeled_pfxs
                                        
                                        	Count of labeled prefixes with 1 or more paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_partial
                                        
                                        	Count of labeled prefixes with some (but not ALL) paths labeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: unlabeled_pfxs
                                        
                                        	Count of labeled prefixes with ALL paths unlabeled
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                            self.yang_name = "labeled-pfxs-primary"
                                            self.yang_parent_name = "pfxs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                            self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                            self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                            self._segment_path = lambda: "labeled-pfxs-primary"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "forwarding-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.ForwardingSummary.Vrf, ['id', 'name'], name, value)


                        class Forwardings(Entity):
                            """
                            The LDP Forwarding rewrites
                            
                            .. attribute:: forwarding
                            
                            	Information on a particular LDP forwarding rewrite
                            	**type**\: list of    :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings, self).__init__()

                                self.yang_name = "forwardings"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"forwarding" : ("forwarding", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding)}

                                self.forwarding = YList(self)
                                self._segment_path = lambda: "forwardings"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings, [], name, value)


                            class Forwarding(Entity):
                                """
                                Information on a particular LDP forwarding
                                rewrite
                                
                                .. attribute:: prefix  <key>
                                
                                	The IP Prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: paths
                                
                                	Paths
                                	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                
                                .. attribute:: prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: prefix_xr
                                
                                	IP Prefix
                                	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                
                                .. attribute:: route
                                
                                	Route
                                	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route>`
                                
                                .. attribute:: table_id
                                
                                	Table ID associated with IP prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                    self.yang_name = "forwarding"
                                    self.yang_parent_name = "forwardings"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr), "route" : ("route", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route), "vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf)}
                                    self._child_list_classes = {"paths" : ("paths", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                    self.table_id = YLeaf(YType.uint32, "table-id")

                                    self.prefix_xr = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                    self.prefix_xr.parent = self
                                    self._children_name_map["prefix_xr"] = "prefix-xr"
                                    self._children_yang_names.add("prefix-xr")

                                    self.route = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route()
                                    self.route.parent = self
                                    self._children_name_map["route"] = "route"
                                    self._children_yang_names.add("route")

                                    self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.paths = YList(self)
                                    self._segment_path = lambda: "forwarding" + "[prefix='" + self.prefix.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding, ['prefix', 'prefix_length', 'table_id'], name, value)


                                class Paths(Entity):
                                    """
                                    Paths
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                        self.yang_name = "paths"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls), "routing" : ("routing", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)}
                                        self._child_list_classes = {}

                                        self.mpls = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._children_yang_names.add("mpls")

                                        self.routing = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"
                                        self._children_yang_names.add("routing")
                                        self._segment_path = lambda: "paths"


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: mpls_outgoing_info
                                        
                                        	MPLS nexthop info
                                        	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo), "remote-lfa" : ("remote_lfa", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa)}
                                            self._child_list_classes = {}

                                            self.mpls_outgoing_info = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                            self.mpls_outgoing_info.parent = self
                                            self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                            self._children_yang_names.add("mpls-outgoing-info")

                                            self.remote_lfa = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")
                                            self._segment_path = lambda: "mpls"


                                        class MplsOutgoingInfo(Entity):
                                            """
                                            MPLS nexthop info
                                            
                                            .. attribute:: is_from_graceful_restartable_neighbor
                                            
                                            	Is from a GR neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_stale
                                            
                                            	Is the entry stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_peer_ldp_ident
                                            
                                            	Nexthop LDP peer
                                            	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                            
                                            .. attribute:: out_label
                                            
                                            	Outgoing label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_label_owner
                                            
                                            	Outgoing label owner
                                            	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                            
                                            .. attribute:: out_label_rsn
                                            
                                            	Outgoing label reason
                                            	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                            
                                            .. attribute:: out_label_type
                                            
                                            	Outgoing Label Type
                                            	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                self.yang_name = "mpls-outgoing-info"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent)}
                                                self._child_list_classes = {}

                                                self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                self.out_label = YLeaf(YType.uint32, "out-label")

                                                self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                self.nexthop_peer_ldp_ident = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                self.nexthop_peer_ldp_ident.parent = self
                                                self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                self._segment_path = lambda: "mpls-outgoing-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                            class NexthopPeerLdpIdent(Entity):
                                                """
                                                Nexthop LDP peer
                                                
                                                .. attribute:: label_space_id
                                                
                                                	Label space identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ldp_id
                                                
                                                	LDP identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: lsr_id
                                                
                                                	LSR identifier
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                    self.yang_name = "nexthop-peer-ldp-ident"
                                                    self.yang_parent_name = "mpls-outgoing-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                    self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                    self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                    self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	Remote LFA MPLS nexthop(s\_ info
                                            	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "mpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo)}
                                                self._child_list_classes = {}

                                                self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                self.mpls_outgoing_info = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._children_yang_names.add("mpls-outgoing-info")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, ['has_remote_lfa_bkup'], name, value)


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                Remote LFA MPLS nexthop(s\_ info
                                                
                                                .. attribute:: stack
                                                
                                                	Inner label stack info
                                                	**type**\: list of    :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"stack" : ("stack", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack)}

                                                    self.stack = YList(self)
                                                    self._segment_path = lambda: "mpls-outgoing-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                class Stack(Entity):
                                                    """
                                                    Inner label stack info
                                                    
                                                    .. attribute:: is_from_graceful_restartable_neighbor
                                                    
                                                    	Is from a GR neighbor
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_stale
                                                    
                                                    	Is the entry stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nexthop_peer_ldp_ident
                                                    
                                                    	Nexthop LDP peer
                                                    	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                    
                                                    .. attribute:: out_label
                                                    
                                                    	Outgoing label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: out_label_owner
                                                    
                                                    	Outgoing label owner
                                                    	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                    
                                                    .. attribute:: out_label_rsn
                                                    
                                                    	Outgoing label reason
                                                    	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                    
                                                    .. attribute:: out_label_type
                                                    
                                                    	Outgoing Label Type
                                                    	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                        self.yang_name = "stack"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent)}
                                                        self._child_list_classes = {}

                                                        self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                        self.out_label = YLeaf(YType.uint32, "out-label")

                                                        self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                        self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                        self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                        self.nexthop_peer_ldp_ident = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                        self.nexthop_peer_ldp_ident.parent = self
                                                        self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                        self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                        self._segment_path = lambda: "stack"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                    class NexthopPeerLdpIdent(Entity):
                                                        """
                                                        Nexthop LDP peer
                                                        
                                                        .. attribute:: label_space_id
                                                        
                                                        	Label space identifier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ldp_id
                                                        
                                                        	LDP identifier
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: lsr_id
                                                        
                                                        	LSR identifier
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                            self.yang_name = "nexthop-peer-ldp-ident"
                                                            self.yang_parent_name = "stack"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                            self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: bkup_path_id
                                        
                                        	Backup path Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: flags
                                        
                                        	Route path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface Name
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	Path's load metric for load balancing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next Hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                        
                                        .. attribute:: next_hop_table_id
                                        
                                        	Table ID for nexthop address
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	Nexthop Identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_is_overriden
                                        
                                        	Nexthop is overriden by LDP
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_flags
                                        
                                        	Routing path flags decoded
                                        	**type**\:   :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                        
                                        .. attribute:: path_id
                                        
                                        	path Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA\-FRR backup info
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop" : ("next_hop", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop), "remote-lfa" : ("remote_lfa", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa)}
                                            self._child_list_classes = {}

                                            self.bkup_path_id = YLeaf(YType.uint8, "bkup-path-id")

                                            self.flags = YLeaf(YType.uint32, "flags")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                            self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                            self.nh_is_overriden = YLeaf(YType.boolean, "nh-is-overriden")

                                            self.path_flags = YLeaf(YType.enumeration, "path-flags")

                                            self.path_id = YLeaf(YType.uint8, "path-id")

                                            self.next_hop = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.remote_lfa = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")
                                            self._segment_path = lambda: "routing"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, ['bkup_path_id', 'flags', 'interface', 'interface_name', 'load_metric', 'next_hop_table_id', 'nexthop_id', 'nh_is_overriden', 'path_flags', 'path_id'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next Hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA\-FRR backup info
                                            
                                            .. attribute:: has_q_node
                                            
                                            	Whether remote LFA path has a Q node associated
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_remote_lfa_bkup
                                            
                                            	Whether path has remote LFA backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: needs_tldp
                                            
                                            	Whether TLDP is needed with remote PQ node
                                            	**type**\:  bool
                                            
                                            .. attribute:: remote_p_node_id
                                            
                                            	Remote/P node address
                                            	**type**\:   :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                            
                                            .. attribute:: remote_q_node_id
                                            
                                            	Remote/Q node address
                                            	**type**\:   :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "routing"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"remote-p-node-id" : ("remote_p_node_id", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId), "remote-q-node-id" : ("remote_q_node_id", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId)}
                                                self._child_list_classes = {}

                                                self.has_q_node = YLeaf(YType.boolean, "has-q-node")

                                                self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                self.needs_tldp = YLeaf(YType.boolean, "needs-tldp")

                                                self.remote_p_node_id = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                self.remote_p_node_id.parent = self
                                                self._children_name_map["remote_p_node_id"] = "remote-p-node-id"
                                                self._children_yang_names.add("remote-p-node-id")

                                                self.remote_q_node_id = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                self.remote_q_node_id.parent = self
                                                self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                self._children_yang_names.add("remote-q-node-id")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, ['has_q_node', 'has_remote_lfa_bkup', 'needs_tldp'], name, value)


                                            class RemotePNodeId(Entity):
                                                """
                                                Remote/P node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                    self.yang_name = "remote-p-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "remote-p-node-id"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class RemoteQNodeId(Entity):
                                                """
                                                Remote/Q node address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                    self.yang_name = "remote-q-node-id"
                                                    self.yang_parent_name = "remote-lfa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "remote-q-node-id"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class PrefixXr(Entity):
                                    """
                                    IP Prefix
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                        self.yang_name = "prefix-xr"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "prefix-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class Route(Entity):
                                    """
                                    Route
                                    
                                    .. attribute:: mpls
                                    
                                    	MPLS information
                                    	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                    
                                    .. attribute:: routing
                                    
                                    	IP routing information
                                    	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                        self.yang_name = "route"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls), "routing" : ("routing", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing)}
                                        self._child_list_classes = {}

                                        self.mpls = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                        self.mpls.parent = self
                                        self._children_name_map["mpls"] = "mpls"
                                        self._children_yang_names.add("mpls")

                                        self.routing = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                        self.routing.parent = self
                                        self._children_name_map["routing"] = "routing"
                                        self._children_yang_names.add("routing")
                                        self._segment_path = lambda: "route"


                                    class Mpls(Entity):
                                        """
                                        MPLS information
                                        
                                        .. attribute:: forwarding_update_age
                                        
                                        	Last Forwarding update nanosec age
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: forwarding_update_count
                                        
                                        	Number of forwarding updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_update_timestamp
                                        
                                        	Last Forwarding update nanosec timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                            self.yang_name = "mpls"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.forwarding_update_age = YLeaf(YType.uint64, "forwarding-update-age")

                                            self.forwarding_update_count = YLeaf(YType.uint32, "forwarding-update-count")

                                            self.forwarding_update_timestamp = YLeaf(YType.uint64, "forwarding-update-timestamp")

                                            self.local_label = YLeaf(YType.uint32, "local-label")
                                            self._segment_path = lambda: "mpls"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, ['forwarding_update_age', 'forwarding_update_count', 'forwarding_update_timestamp', 'local_label'], name, value)


                                    class Routing(Entity):
                                        """
                                        IP routing information
                                        
                                        .. attribute:: flags
                                        
                                        	Route RIB flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_local_vrf_leaked
                                        
                                        	Is route leaked across local VRFs?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Route metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Route priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: routing_update_age
                                        
                                        	Last Routing update nanosec age
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: routing_update_count
                                        
                                        	Number of routing updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: routing_update_timestamp
                                        
                                        	Last Routing update nanosec timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: source
                                        
                                        	Route source protol Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sr_local_label
                                        
                                        	SR Local\-label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: type
                                        
                                        	Route type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: version
                                        
                                        	Route RIB ersion
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                            self.yang_name = "routing"
                                            self.yang_parent_name = "route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.flags = YLeaf(YType.uint32, "flags")

                                            self.is_local_vrf_leaked = YLeaf(YType.boolean, "is-local-vrf-leaked")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.priority = YLeaf(YType.uint8, "priority")

                                            self.routing_update_age = YLeaf(YType.uint64, "routing-update-age")

                                            self.routing_update_count = YLeaf(YType.uint32, "routing-update-count")

                                            self.routing_update_timestamp = YLeaf(YType.uint64, "routing-update-timestamp")

                                            self.source = YLeaf(YType.uint16, "source")

                                            self.sr_local_label = YLeaf(YType.uint32, "sr-local-label")

                                            self.type = YLeaf(YType.uint16, "type")

                                            self.version = YLeaf(YType.uint32, "version")
                                            self._segment_path = lambda: "routing"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Route.Routing, ['flags', 'is_local_vrf_leaked', 'metric', 'priority', 'routing_update_age', 'routing_update_count', 'routing_update_timestamp', 'source', 'sr_local_label', 'type', 'version'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Forwardings.Forwarding.Vrf, ['id', 'name'], name, value)


                        class Igp(Entity):
                            """
                            LDP IGP related information
                            
                            .. attribute:: sync_delay_restart
                            
                            	LDP\-IGP Synchronization Delay related information
                            	**type**\:   :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart>`
                            
                            .. attribute:: syncs
                            
                            	LDP IGP Sync related information
                            	**type**\:   :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp, self).__init__()

                                self.yang_name = "igp"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sync-delay-restart" : ("sync_delay_restart", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart), "syncs" : ("syncs", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs)}
                                self._child_list_classes = {}

                                self.sync_delay_restart = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart()
                                self.sync_delay_restart.parent = self
                                self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                self._children_yang_names.add("sync-delay-restart")

                                self.syncs = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs()
                                self.syncs.parent = self
                                self._children_name_map["syncs"] = "syncs"
                                self._children_yang_names.add("syncs")
                                self._segment_path = lambda: "igp"


                            class SyncDelayRestart(Entity):
                                """
                                LDP\-IGP Synchronization Delay related
                                information
                                
                                .. attribute:: configured
                                
                                	Is restart delay configured
                                	**type**\:  bool
                                
                                .. attribute:: delay_secs
                                
                                	Delay time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remaining_secs
                                
                                	Delay timer remaining time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: timer_running
                                
                                	Is restart delay timer running
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                    self.yang_name = "sync-delay-restart"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.configured = YLeaf(YType.boolean, "configured")

                                    self.delay_secs = YLeaf(YType.uint32, "delay-secs")

                                    self.remaining_secs = YLeaf(YType.uint32, "remaining-secs")

                                    self.timer_running = YLeaf(YType.boolean, "timer-running")
                                    self._segment_path = lambda: "sync-delay-restart"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.SyncDelayRestart, ['configured', 'delay_secs', 'remaining_secs', 'timer_running'], name, value)


                            class Syncs(Entity):
                                """
                                LDP IGP Sync related information
                                
                                .. attribute:: sync
                                
                                	LDP\-IGP Synchronization related information for an interface
                                	**type**\: list of    :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs, self).__init__()

                                    self.yang_name = "syncs"
                                    self.yang_parent_name = "igp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sync" : ("sync", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync)}

                                    self.sync = YList(self)
                                    self._segment_path = lambda: "syncs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs, [], name, value)


                                class Sync(Entity):
                                    """
                                    LDP\-IGP Synchronization related information
                                    for an interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: delay_timer_remaining
                                    
                                    	Remaining timer (seconds) till expiry of sync delay timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_only_peer
                                    
                                    	Interface GR\-only reachable peers
                                    	**type**\: list of    :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                    
                                    .. attribute:: igp_sync_delay
                                    
                                    	IGP sync delay in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: igp_sync_down_reason
                                    
                                    	Reason IGP Sync Not Achieved
                                    	**type**\:   :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                    
                                    .. attribute:: igp_sync_state
                                    
                                    	IGP Sync state
                                    	**type**\:   :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_delay_timer_running
                                    
                                    	Is sync delay timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: peers
                                    
                                    	Interface Peers
                                    	**type**\: list of    :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                        self.yang_name = "sync"
                                        self.yang_parent_name = "syncs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf)}
                                        self._child_list_classes = {"gr-only-peer" : ("gr_only_peer", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer), "peers" : ("peers", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.delay_timer_remaining = YLeaf(YType.uint32, "delay-timer-remaining")

                                        self.igp_sync_delay = YLeaf(YType.uint32, "igp-sync-delay")

                                        self.igp_sync_down_reason = YLeaf(YType.enumeration, "igp-sync-down-reason")

                                        self.igp_sync_state = YLeaf(YType.enumeration, "igp-sync-state")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.is_delay_timer_running = YLeaf(YType.boolean, "is-delay-timer-running")

                                        self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.gr_only_peer = YList(self)
                                        self.peers = YList(self)
                                        self._segment_path = lambda: "sync" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', 'delay_timer_remaining', 'igp_sync_delay', 'igp_sync_down_reason', 'igp_sync_state', 'interface_name_xr', 'is_delay_timer_running'], name, value)


                                    class GrOnlyPeer(Entity):
                                        """
                                        Interface GR\-only reachable peers
                                        
                                        .. attribute:: is_chkpt_created
                                        
                                        	Is created due to checkpointing
                                        	**type**\:  bool
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                            self.yang_name = "gr-only-peer"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.is_chkpt_created = YLeaf(YType.boolean, "is-chkpt-created")

                                            self.peer_id = YLeaf(YType.str, "peer-id")
                                            self._segment_path = lambda: "gr-only-peer"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, ['is_chkpt_created', 'peer_id'], name, value)


                                    class Peers(Entity):
                                        """
                                        Interface Peers
                                        
                                        .. attribute:: is_gr_enabled
                                        
                                        	Is GR enabled session
                                        	**type**\:  bool
                                        
                                        .. attribute:: peer_id
                                        
                                        	Peer Identifier
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                            self.yang_name = "peers"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                                            self.peer_id = YLeaf(YType.str, "peer-id")
                                            self._segment_path = lambda: "peers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Peers, ['is_gr_enabled', 'peer_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "sync"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Igp.Syncs.Sync.Vrf, ['id', 'name'], name, value)


                        class InterfaceSummary(Entity):
                            """
                            IPv4 interface summary information
                            
                            .. attribute:: auto_config
                            
                            	Auto\-configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_disabled
                            
                            	Autoconfigure disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_config_forward_reference_interfaces
                            
                            	Auto\-configured forward references
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_references
                            
                            	Number of forward referenced interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_count
                            
                            	Number of known IP Interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: known_ip_interface_ldp_enabled
                            
                            	Number of known IP Interfaces with LDP Enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_attached_interface
                            
                            	Number of attached interfaces configured in LDP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldp_configured_te_interface
                            
                            	Number of TE tunnel interfaces configured in LDP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary, self).__init__()

                                self.yang_name = "interface-summary"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.auto_config = YLeaf(YType.uint32, "auto-config")

                                self.auto_config_disabled = YLeaf(YType.uint32, "auto-config-disabled")

                                self.auto_config_forward_reference_interfaces = YLeaf(YType.uint32, "auto-config-forward-reference-interfaces")

                                self.forward_references = YLeaf(YType.uint32, "forward-references")

                                self.known_ip_interface_count = YLeaf(YType.uint32, "known-ip-interface-count")

                                self.known_ip_interface_ldp_enabled = YLeaf(YType.uint32, "known-ip-interface-ldp-enabled")

                                self.ldp_configured_attached_interface = YLeaf(YType.uint32, "ldp-configured-attached-interface")

                                self.ldp_configured_te_interface = YLeaf(YType.uint32, "ldp-configured-te-interface")
                                self._segment_path = lambda: "interface-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.InterfaceSummary, ['auto_config', 'auto_config_disabled', 'auto_config_forward_reference_interfaces', 'forward_references', 'known_ip_interface_count', 'known_ip_interface_ldp_enabled', 'ldp_configured_attached_interface', 'ldp_configured_te_interface'], name, value)


                        class Interfaces(Entity):
                            """
                            LDP Interface related information
                            
                            .. attribute:: interface
                            
                            	IPv4 interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface" : ("interface", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface)}

                                self.interface = YList(self)
                                self._segment_path = lambda: "interfaces"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces, [], name, value)


                            class Interface(Entity):
                                """
                                IPv4 interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	The Interface Name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: auto_config
                                
                                	Auto config
                                	**type**\: list of    :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                
                                .. attribute:: interface
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\:  str
                                
                                .. attribute:: is_im_stale
                                
                                	Is IM information stale
                                	**type**\:  bool
                                
                                .. attribute:: ldp_autoconfig_disable
                                
                                	LDP autoconfig disable
                                	**type**\:  bool
                                
                                .. attribute:: ldp_config_mode
                                
                                	LDP config mode
                                	**type**\:  bool
                                
                                .. attribute:: ldp_enabled
                                
                                	LDP enabled
                                	**type**\:  bool
                                
                                .. attribute:: te_mesh_grp
                                
                                	TE tunnel mesh\-group
                                	**type**\: list of    :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf)}
                                    self._child_list_classes = {"auto-config" : ("auto_config", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig), "te-mesh-grp" : ("te_mesh_grp", MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface = YLeaf(YType.str, "interface")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.is_im_stale = YLeaf(YType.boolean, "is-im-stale")

                                    self.ldp_autoconfig_disable = YLeaf(YType.boolean, "ldp-autoconfig-disable")

                                    self.ldp_config_mode = YLeaf(YType.boolean, "ldp-config-mode")

                                    self.ldp_enabled = YLeaf(YType.boolean, "ldp-enabled")

                                    self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.auto_config = YList(self)
                                    self.te_mesh_grp = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface, ['interface_name', 'interface', 'interface_name_xr', 'is_im_stale', 'ldp_autoconfig_disable', 'ldp_config_mode', 'ldp_enabled'], name, value)


                                class AutoConfig(Entity):
                                    """
                                    Auto config
                                    
                                    .. attribute:: tuple
                                    
                                    	Tuple
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                        self.yang_name = "auto-config"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.tuple = YLeaf(YType.str, "tuple")
                                        self._segment_path = lambda: "auto-config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.AutoConfig, ['tuple'], name, value)


                                class TeMeshGrp(Entity):
                                    """
                                    TE tunnel mesh\-group
                                    
                                    .. attribute:: ldp_mesh_group_enabled
                                    
                                    	LDP has enabled this TE mesh\-group
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_te_mesh_group_all_cfgd
                                    
                                    	LDP has enabled all TE mesh\-groups
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_mesh_group_id
                                    
                                    	TE tunnel Mesh Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                        self.yang_name = "te-mesh-grp"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ldp_mesh_group_enabled = YLeaf(YType.boolean, "ldp-mesh-group-enabled")

                                        self.ldp_te_mesh_group_all_cfgd = YLeaf(YType.boolean, "ldp-te-mesh-group-all-cfgd")

                                        self.te_mesh_group_id = YLeaf(YType.uint32, "te-mesh-group-id")
                                        self._segment_path = lambda: "te-mesh-grp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.TeMeshGrp, ['ldp_mesh_group_enabled', 'ldp_te_mesh_group_all_cfgd', 'te_mesh_group_id'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Afs.Af.Interfaces.Interface.Vrf, ['id', 'name'], name, value)


                class BackoffParameters(Entity):
                    """
                    The LDP Backoff Parameters
                    
                    .. attribute:: initial_seconds
                    
                    	Initial backoff value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: maximum_seconds
                    
                    	Maximum backoff value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters, self).__init__()

                        self.yang_name = "backoff-parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.initial_seconds = YLeaf(YType.uint32, "initial-seconds")

                        self.maximum_seconds = YLeaf(YType.uint32, "maximum-seconds")
                        self._segment_path = lambda: "backoff-parameters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.BackoffParameters, ['initial_seconds', 'maximum_seconds'], name, value)


                class Backoffs(Entity):
                    """
                    The LDP backoff
                    
                    .. attribute:: backoff
                    
                    	LDP Backoff Information
                    	**type**\: list of    :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Backoffs.Backoff>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Backoffs, self).__init__()

                        self.yang_name = "backoffs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"backoff" : ("backoff", MplsLdp.Nodes.Node.DefaultVrf.Backoffs.Backoff)}

                        self.backoff = YList(self)
                        self._segment_path = lambda: "backoffs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Backoffs, [], name, value)


                    class Backoff(Entity):
                        """
                        LDP Backoff Information
                        
                        .. attribute:: backoff_seconds
                        
                        	Backoff seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: waiting_seconds
                        
                        	Backoff waiting seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Backoffs.Backoff, self).__init__()

                            self.yang_name = "backoff"
                            self.yang_parent_name = "backoffs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.backoff_seconds = YLeaf(YType.uint32, "backoff-seconds")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.waiting_seconds = YLeaf(YType.uint32, "waiting-seconds")
                            self._segment_path = lambda: "backoff"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Backoffs.Backoff, ['backoff_seconds', 'label_space_id', 'lsr_id', 'waiting_seconds'], name, value)


                class Capabilities(Entity):
                    """
                    LDP capability database information
                    
                    .. attribute:: capability
                    
                    	Information on LDP capability
                    	**type**\: list of    :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Capabilities, self).__init__()

                        self.yang_name = "capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"capability" : ("capability", MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability)}

                        self.capability = YList(self)
                        self._segment_path = lambda: "capabilities"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Capabilities, [], name, value)


                    class Capability(Entity):
                        """
                        Information on LDP capability
                        
                        .. attribute:: capability_type  <key>
                        
                        	The capability type (IANA assigned)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: capability
                        
                        	Capability information
                        	**type**\:   :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability>`
                        
                        .. attribute:: capability_owner
                        
                        	Capability owner
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability, self).__init__()

                            self.yang_name = "capability"
                            self.yang_parent_name = "capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"capability" : ("capability", MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability)}
                            self._child_list_classes = {}

                            self.capability_type = YLeaf(YType.int32, "capability-type")

                            self.capability_owner = YLeaf(YType.str, "capability-owner")

                            self.capability = MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability()
                            self.capability.parent = self
                            self._children_name_map["capability"] = "capability"
                            self._children_yang_names.add("capability")
                            self._segment_path = lambda: "capability" + "[capability-type='" + self.capability_type.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability, ['capability_type', 'capability_owner'], name, value)


                        class Capability(Entity):
                            """
                            Capability information
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "capability"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Capabilities.Capability.Capability, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                class GracefulRestart(Entity):
                    """
                    LDP Graceful Restart info
                    
                    .. attribute:: forwarding_state_hold_timer_remaining_seconds
                    
                    	Forwarding state hold timer remaining time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: graceful_restartable_neighbor
                    
                    	Vector of graceful restart neighbor information
                    	**type**\: list of    :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor>`
                    
                    .. attribute:: is_forwarding_state_hold_timer_running
                    
                    	Is graceful restart forwarding state hold timer running
                    	**type**\:  bool
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart, self).__init__()

                        self.yang_name = "graceful-restart"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf)}
                        self._child_list_classes = {"graceful-restartable-neighbor" : ("graceful_restartable_neighbor", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor)}

                        self.forwarding_state_hold_timer_remaining_seconds = YLeaf(YType.uint32, "forwarding-state-hold-timer-remaining-seconds")

                        self.is_forwarding_state_hold_timer_running = YLeaf(YType.boolean, "is-forwarding-state-hold-timer-running")

                        self.vrf = MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._children_yang_names.add("vrf")

                        self.graceful_restartable_neighbor = YList(self)
                        self._segment_path = lambda: "graceful-restart"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart, ['forwarding_state_hold_timer_remaining_seconds', 'is_forwarding_state_hold_timer_running'], name, value)


                    class GracefulRestartableNeighbor(Entity):
                        """
                        Vector of graceful restart neighbor information
                        
                        .. attribute:: connect_count
                        
                        	ConnectCount
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_address
                        
                        	Addresses bound to GR down Nbr
                        	**type**\: list of    :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                        
                        .. attribute:: down_nbr_down_reason
                        
                        	Session down reason code
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flags
                        
                        	Flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down_nbr_flap_count
                        
                        	Count of back2back flaps
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: down_nbr_interface
                        
                        	Interfaces bound to GR down Nbr
                        	**type**\: list of    :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                        
                        .. attribute:: gr_peer
                        
                        	GR peer LDP Id
                        	**type**\:   :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                        
                        .. attribute:: is_liveness_timer_running
                        
                        	Is liveness timer running
                        	**type**\:  bool
                        
                        .. attribute:: is_neighbor_up
                        
                        	Is neighbor up
                        	**type**\:  bool
                        
                        .. attribute:: is_recovery_timer_running
                        
                        	Is recovery timer running
                        	**type**\:  bool
                        
                        .. attribute:: liveness_timer_remaining_seconds
                        
                        	Remaining time from liveness timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: recovery_timer_remaining_seconds
                        
                        	Recovery timer remining time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                            self.yang_name = "graceful-restartable-neighbor"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"gr-peer" : ("gr_peer", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)}
                            self._child_list_classes = {"down-nbr-address" : ("down_nbr_address", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress), "down-nbr-interface" : ("down_nbr_interface", MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)}

                            self.connect_count = YLeaf(YType.uint32, "connect-count")

                            self.down_nbr_down_reason = YLeaf(YType.uint32, "down-nbr-down-reason")

                            self.down_nbr_flags = YLeaf(YType.uint32, "down-nbr-flags")

                            self.down_nbr_flap_count = YLeaf(YType.uint8, "down-nbr-flap-count")

                            self.is_liveness_timer_running = YLeaf(YType.boolean, "is-liveness-timer-running")

                            self.is_neighbor_up = YLeaf(YType.boolean, "is-neighbor-up")

                            self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

                            self.liveness_timer_remaining_seconds = YLeaf(YType.uint32, "liveness-timer-remaining-seconds")

                            self.recovery_timer_remaining_seconds = YLeaf(YType.uint32, "recovery-timer-remaining-seconds")

                            self.gr_peer = MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                            self.gr_peer.parent = self
                            self._children_name_map["gr_peer"] = "gr-peer"
                            self._children_yang_names.add("gr-peer")

                            self.down_nbr_address = YList(self)
                            self.down_nbr_interface = YList(self)
                            self._segment_path = lambda: "graceful-restartable-neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor, ['connect_count', 'down_nbr_down_reason', 'down_nbr_flags', 'down_nbr_flap_count', 'is_liveness_timer_running', 'is_neighbor_up', 'is_recovery_timer_running', 'liveness_timer_remaining_seconds', 'recovery_timer_remaining_seconds'], name, value)


                        class DownNbrAddress(Entity):
                            """
                            Addresses bound to GR down Nbr
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                self.yang_name = "down-nbr-address"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.dummy = YLeaf(YType.uint8, "dummy")

                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                self._segment_path = lambda: "down-nbr-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class DownNbrInterface(Entity):
                            """
                            Interfaces bound to GR down Nbr
                            
                            .. attribute:: address_family
                            
                            	Interface adj Address Family
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: interface_handle
                            
                            	Interfaces handle
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                self.yang_name = "down-nbr-interface"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")
                                self._segment_path = lambda: "down-nbr-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, ['address_family', 'interface_handle'], name, value)


                        class GrPeer(Entity):
                            """
                            GR peer LDP Id
                            
                            .. attribute:: label_space_id
                            
                            	Label space identifier
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_id
                            
                            	LDP identifier
                            	**type**\:  str
                            
                            .. attribute:: lsr_id
                            
                            	LSR identifier
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                self.yang_name = "gr-peer"
                                self.yang_parent_name = "graceful-restartable-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                self._segment_path = lambda: "gr-peer"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "graceful-restart"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.id = YLeaf(YType.uint32, "id")

                            self.name = YLeaf(YType.str, "name")
                            self._segment_path = lambda: "vrf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.GracefulRestart.Vrf, ['id', 'name'], name, value)


                class Issu(Entity):
                    """
                    LDP ISSU related information
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Issu, self).__init__()

                        self.yang_name = "issu"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary)}
                        self._child_list_classes = {}

                        self.ha_statistics = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._children_yang_names.add("ha-statistics")

                        self.ha_summary = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"
                        self._children_yang_names.add("ha-summary")
                        self._segment_path = lambda: "issu"


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_global = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"
                            self._children_yang_names.add("ha-global")

                            self.ha_neighbors = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "ha-statistics"


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync)}
                                self._child_list_classes = {}

                                self.init_sync = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._children_yang_names.add("init-sync")
                                self._segment_path = lambda: "ha-global"


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\:  bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\:  bool
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                    self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                    self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                    self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                    self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                    self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                    self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                    self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                    self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                    self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                    self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                    self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                    self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                    self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                    self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                    self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                    self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                    self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                    self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                    self.num_peers = YLeaf(YType.uint32, "num-peers")

                                    self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                    self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                    self._segment_path = lambda: "init-sync"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "issu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf)}
                            self._child_list_classes = {}

                            self.sessions = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._children_yang_names.add("sessions")

                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "ha-summary"


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                self.total = YLeaf(YType.uint32, "total")
                                self._segment_path = lambda: "sessions"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Issu.HaSummary.Vrf, ['id', 'name'], name, value)


                class LdpId(Entity):
                    """
                    Local LDP Id
                    
                    .. attribute:: label_space_id
                    
                    	Label space identifier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ldp_id
                    
                    	LDP identifier
                    	**type**\:  str
                    
                    .. attribute:: lsr_id
                    
                    	LSR identifier
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.LdpId, self).__init__()

                        self.yang_name = "ldp-id"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                        self._segment_path = lambda: "ldp-id"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.LdpId, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                class NeighborBriefs(Entity):
                    """
                    The LDP Neighbors (brief)
                    
                    .. attribute:: neighbor_brief
                    
                    	Brief information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs, self).__init__()

                        self.yang_name = "neighbor-briefs"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-brief" : ("neighbor_brief", MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief)}

                        self.neighbor_brief = YList(self)
                        self._segment_path = lambda: "neighbor-briefs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs, [], name, value)


                    class NeighborBrief(Entity):
                        """
                        Brief information on a particular LDP neighbor
                        
                        .. attribute:: is_graceful_restartable
                        
                        	Is graceful restartable
                        	**type**\:  bool
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nbr_br_af_info
                        
                        	Neighbor Brief AF Info
                        	**type**\: list of    :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                        
                        .. attribute:: nsr_state
                        
                        	NSR readiness state
                        	**type**\:   :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                        
                        .. attribute:: up_time_seconds
                        
                        	Up time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief, self).__init__()

                            self.yang_name = "neighbor-brief"
                            self.yang_parent_name = "neighbor-briefs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf)}
                            self._child_list_classes = {"nbr-br-af-info" : ("nbr_br_af_info", MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo)}

                            self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                            self.up_time_seconds = YLeaf(YType.uint32, "up-time-seconds")

                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")

                            self.nbr_br_af_info = YList(self)
                            self._segment_path = lambda: "neighbor-brief"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief, ['is_graceful_restartable', 'label_space_id', 'lsr_id', 'nsr_state', 'up_time_seconds'], name, value)


                        class NbrBrAfInfo(Entity):
                            """
                            Neighbor Brief AF Info
                            
                            .. attribute:: address_family
                            
                            	Neighbor Brief Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: num_of_nbr_addresses
                            
                            	Number of neighbor addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_discovery
                            
                            	Number of neighbor discovery sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_of_nbr_lbl
                            
                            	Number of neighbor labels
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                self.yang_name = "nbr-br-af-info"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.num_of_nbr_addresses = YLeaf(YType.uint32, "num-of-nbr-addresses")

                                self.num_of_nbr_discovery = YLeaf(YType.uint32, "num-of-nbr-discovery")

                                self.num_of_nbr_lbl = YLeaf(YType.uint32, "num-of-nbr-lbl")
                                self._segment_path = lambda: "nbr-br-af-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, ['address_family', 'num_of_nbr_addresses', 'num_of_nbr_discovery', 'num_of_nbr_lbl'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "neighbor-brief"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborBriefs.NeighborBrief.Vrf, ['id', 'name'], name, value)


                class NeighborCapabilities(Entity):
                    """
                    LDP Neighbors Capabilities
                    
                    .. attribute:: neighbor_capability
                    
                    	Information on capabilities of a particular LDP neighbor
                    	**type**\: list of    :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities, self).__init__()

                        self.yang_name = "neighbor-capabilities"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor-capability" : ("neighbor_capability", MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability)}

                        self.neighbor_capability = YList(self)
                        self._segment_path = lambda: "neighbor-capabilities"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities, [], name, value)


                    class NeighborCapability(Entity):
                        """
                        Information on capabilities of a particular LDP
                        neighbor
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: received
                        
                        	List of received capabilities
                        	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Received>`
                        
                        .. attribute:: sent
                        
                        	List of sent capabilities
                        	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability, self).__init__()

                            self.yang_name = "neighbor-capability"
                            self.yang_parent_name = "neighbor-capabilities"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"received" : ("received", MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Received), "sent" : ("sent", MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent)}

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.received = YList(self)
                            self.sent = YList(self)
                            self._segment_path = lambda: "neighbor-capability"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability, ['label_space_id', 'lsr_id'], name, value)


                        class Received(Entity):
                            """
                            List of received capabilities
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                self.yang_name = "received"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "received"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                        class Sent(Entity):
                            """
                            List of sent capabilities
                            
                            .. attribute:: capability_data
                            
                            	Capability data
                            	**type**\:  str
                            
                            .. attribute:: capability_data_length
                            
                            	Capability data length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: description
                            
                            	Capability description
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: type
                            
                            	Capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                self.yang_name = "sent"
                                self.yang_parent_name = "neighbor-capability"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.capability_data = YLeaf(YType.str, "capability-data")

                                self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                self.description = YLeaf(YType.str, "description")

                                self.type = YLeaf(YType.uint16, "type")
                                self._segment_path = lambda: "sent"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.NeighborCapabilities.NeighborCapability.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                class Neighbors(Entity):
                    """
                    The LDP Neighbors
                    
                    .. attribute:: neighbor
                    
                    	Information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"neighbor" : ("neighbor", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor)}

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        Information on a particular LDP neighbor
                        
                        .. attribute:: detailed_information
                        
                        	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                        	**type**\:   :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation>`
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_nbr_bound_ipv4_address_info
                        
                        	Neighbor IPv4 Address Info
                        	**type**\: list of    :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                        
                        .. attribute:: ldp_nbr_bound_ipv6_address_info
                        
                        	Neighbor IPv6 Address Info
                        	**type**\: list of    :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                        
                        .. attribute:: ldp_nbr_ipv4_adj_info
                        
                        	Neighbor's IPv4 Adjacency Information
                        	**type**\: list of    :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                        
                        .. attribute:: ldp_nbr_ipv6_adj_info
                        
                        	Neighbor's IPv6 Adjacency Information
                        	**type**\: list of    :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: protocol_information
                        
                        	Protocol Information
                        	**type**\:   :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation>`
                        
                        .. attribute:: tcp_information
                        
                        	TCP Information
                        	**type**\:   :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"detailed-information" : ("detailed_information", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation), "protocol-information" : ("protocol_information", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation), "tcp-information" : ("tcp_information", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation)}
                            self._child_list_classes = {"ldp-nbr-bound-ipv4-address-info" : ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo), "ldp-nbr-bound-ipv6-address-info" : ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo), "ldp-nbr-ipv4-adj-info" : ("ldp_nbr_ipv4_adj_info", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo), "ldp-nbr-ipv6-adj-info" : ("ldp_nbr_ipv6_adj_info", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo)}

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.detailed_information = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation()
                            self.detailed_information.parent = self
                            self._children_name_map["detailed_information"] = "detailed-information"
                            self._children_yang_names.add("detailed-information")

                            self.protocol_information = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation()
                            self.protocol_information.parent = self
                            self._children_name_map["protocol_information"] = "protocol-information"
                            self._children_yang_names.add("protocol-information")

                            self.tcp_information = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation()
                            self.tcp_information.parent = self
                            self._children_name_map["tcp_information"] = "tcp-information"
                            self._children_yang_names.add("tcp-information")

                            self.ldp_nbr_bound_ipv4_address_info = YList(self)
                            self.ldp_nbr_bound_ipv6_address_info = YList(self)
                            self.ldp_nbr_ipv4_adj_info = YList(self)
                            self.ldp_nbr_ipv6_adj_info = YList(self)
                            self._segment_path = lambda: "neighbor"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor, ['label_space_id', 'lsr_id'], name, value)


                        class DetailedInformation(Entity):
                            """
                            Detailed information with regards to holdtime,
                            KA, inbound filtering, and Session protection
                            
                            .. attribute:: advertise_bgp_prefixes
                            
                            	Is BGP labelled prefixes advertised to the neighbor
                            	**type**\:  bool
                            
                            .. attribute:: bgp_advertisement_state
                            
                            	BGP labelled prefixes advertisement state
                            	**type**\:   :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                            
                            .. attribute:: capabilities
                            
                            	Capabilities sent to and received from neighbor
                            	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                            
                            .. attribute:: client
                            
                            	Targeted Session clients
                            	**type**\: list of    :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client>`
                            
                            .. attribute:: has_ipv4_inbound
                            
                            	IPv4 Inbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv4_outbound
                            
                            	IPv4 Outbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv6_inbound
                            
                            	IPv6 Inbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_ipv6_outbound
                            
                            	IPv6 Outbound label filtering present
                            	**type**\:  bool
                            
                            .. attribute:: has_sp
                            
                            	Session Protection enabled
                            	**type**\:  bool
                            
                            .. attribute:: inbound_ipv4acl
                            
                            	IPv4 Inbound accept ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: inbound_ipv6acl
                            
                            	IPv6 Inbound accept ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: ipv4_duplicate_address
                            
                            	Duplicate IPv4 address bound to this peer
                            	**type**\: list of    :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                            
                            .. attribute:: ipv6_duplicate_address
                            
                            	Duplicate IPv6 address bound to this peer
                            	**type**\: list of    :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                            
                            .. attribute:: keep_alive_interval
                            
                            	Session keepalive interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nsr_last_sync_error
                            
                            	Last NSR sync error
                            	**type**\:   :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                            
                            .. attribute:: nsr_last_sync_nack_reason
                            
                            	Last NSR sync NACK reaston
                            	**type**\:   :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                            
                            .. attribute:: nsr_sync_state
                            
                            	NSR Sync State
                            	**type**\:   :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                            
                            .. attribute:: outbound_ipv4acl
                            
                            	IPv4 Outbound advertise ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: outbound_ipv6acl
                            
                            	IPv6 Outbound advertise ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: peer_holdtime
                            
                            	Session holdtime value in seconds from the peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: peer_state
                            
                            	Peer state
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: sp_duration
                            
                            	Session protection holdup time duration in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: sp_has_acl
                            
                            	Session protection ACL is present
                            	**type**\:  bool
                            
                            .. attribute:: sp_has_duration
                            
                            	Session Protection has non\-default duration
                            	**type**\:  bool
                            
                            .. attribute:: sp_state
                            
                            	Session Protection state
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: spacl
                            
                            	Session Protection ACL
                            	**type**\:  str
                            
                            	**length:** 0..80
                            
                            .. attribute:: spht_remaining
                            
                            	Session Protection holdup time remaining value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: spht_running
                            
                            	Session Protection holdup timer is running
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                self.yang_name = "detailed-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"capabilities" : ("capabilities", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities)}
                                self._child_list_classes = {"client" : ("client", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client), "ipv4-duplicate-address" : ("ipv4_duplicate_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress), "ipv6-duplicate-address" : ("ipv6_duplicate_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress)}

                                self.advertise_bgp_prefixes = YLeaf(YType.boolean, "advertise-bgp-prefixes")

                                self.bgp_advertisement_state = YLeaf(YType.enumeration, "bgp-advertisement-state")

                                self.has_ipv4_inbound = YLeaf(YType.boolean, "has-ipv4-inbound")

                                self.has_ipv4_outbound = YLeaf(YType.boolean, "has-ipv4-outbound")

                                self.has_ipv6_inbound = YLeaf(YType.boolean, "has-ipv6-inbound")

                                self.has_ipv6_outbound = YLeaf(YType.boolean, "has-ipv6-outbound")

                                self.has_sp = YLeaf(YType.boolean, "has-sp")

                                self.inbound_ipv4acl = YLeaf(YType.str, "inbound-ipv4acl")

                                self.inbound_ipv6acl = YLeaf(YType.str, "inbound-ipv6acl")

                                self.keep_alive_interval = YLeaf(YType.uint32, "keep-alive-interval")

                                self.nsr_last_sync_error = YLeaf(YType.enumeration, "nsr-last-sync-error")

                                self.nsr_last_sync_nack_reason = YLeaf(YType.enumeration, "nsr-last-sync-nack-reason")

                                self.nsr_sync_state = YLeaf(YType.enumeration, "nsr-sync-state")

                                self.outbound_ipv4acl = YLeaf(YType.str, "outbound-ipv4acl")

                                self.outbound_ipv6acl = YLeaf(YType.str, "outbound-ipv6acl")

                                self.peer_holdtime = YLeaf(YType.uint32, "peer-holdtime")

                                self.peer_state = YLeaf(YType.str, "peer-state")

                                self.sp_duration = YLeaf(YType.uint32, "sp-duration")

                                self.sp_has_acl = YLeaf(YType.boolean, "sp-has-acl")

                                self.sp_has_duration = YLeaf(YType.boolean, "sp-has-duration")

                                self.sp_state = YLeaf(YType.str, "sp-state")

                                self.spacl = YLeaf(YType.str, "spacl")

                                self.spht_remaining = YLeaf(YType.uint32, "spht-remaining")

                                self.spht_running = YLeaf(YType.boolean, "spht-running")

                                self.capabilities = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                self.capabilities.parent = self
                                self._children_name_map["capabilities"] = "capabilities"
                                self._children_yang_names.add("capabilities")

                                self.client = YList(self)
                                self.ipv4_duplicate_address = YList(self)
                                self.ipv6_duplicate_address = YList(self)
                                self._segment_path = lambda: "detailed-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation, ['advertise_bgp_prefixes', 'bgp_advertisement_state', 'has_ipv4_inbound', 'has_ipv4_outbound', 'has_ipv6_inbound', 'has_ipv6_outbound', 'has_sp', 'inbound_ipv4acl', 'inbound_ipv6acl', 'keep_alive_interval', 'nsr_last_sync_error', 'nsr_last_sync_nack_reason', 'nsr_sync_state', 'outbound_ipv4acl', 'outbound_ipv6acl', 'peer_holdtime', 'peer_state', 'sp_duration', 'sp_has_acl', 'sp_has_duration', 'sp_state', 'spacl', 'spht_remaining', 'spht_running'], name, value)


                            class Capabilities(Entity):
                                """
                                Capabilities sent to and received from neighbor
                                
                                .. attribute:: received
                                
                                	List of received capabilities
                                	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                
                                .. attribute:: sent
                                
                                	List of sent capabilities
                                	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                    self.yang_name = "capabilities"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"received" : ("received", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received), "sent" : ("sent", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)}

                                    self.received = YList(self)
                                    self.sent = YList(self)
                                    self._segment_path = lambda: "capabilities"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                class Received(Entity):
                                    """
                                    List of received capabilities
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\:  str
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\:  str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                        self.yang_name = "received"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.capability_data = YLeaf(YType.str, "capability-data")

                                        self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                        self.description = YLeaf(YType.str, "description")

                                        self.type = YLeaf(YType.uint16, "type")
                                        self._segment_path = lambda: "received"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                class Sent(Entity):
                                    """
                                    List of sent capabilities
                                    
                                    .. attribute:: capability_data
                                    
                                    	Capability data
                                    	**type**\:  str
                                    
                                    .. attribute:: capability_data_length
                                    
                                    	Capability data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: description
                                    
                                    	Capability description
                                    	**type**\:  str
                                    
                                    	**length:** 0..80
                                    
                                    .. attribute:: type
                                    
                                    	Capability type (IANA assigned)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                        self.yang_name = "sent"
                                        self.yang_parent_name = "capabilities"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.capability_data = YLeaf(YType.str, "capability-data")

                                        self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                        self.description = YLeaf(YType.str, "description")

                                        self.type = YLeaf(YType.uint16, "type")
                                        self._segment_path = lambda: "sent"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                            class Client(Entity):
                                """
                                Targeted Session clients
                                
                                .. attribute:: name
                                
                                	Client's name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                    self.yang_name = "client"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "client"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Client, ['name'], name, value)


                            class Ipv4DuplicateAddress(Entity):
                                """
                                Duplicate IPv4 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv4-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ipv4-duplicate-address"


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv4-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class Ipv6DuplicateAddress(Entity):
                                """
                                Duplicate IPv6 address bound to this peer
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                    self.yang_name = "ipv6-duplicate-address"
                                    self.yang_parent_name = "detailed-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ipv6-duplicate-address"


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ipv6-duplicate-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrBoundIpv4AddressInfo(Entity):
                            """
                            Neighbor IPv4 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address)}
                                self._child_list_classes = {}

                                self.address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")
                                self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrBoundIpv6AddressInfo(Entity):
                            """
                            Neighbor IPv6 Address Info
                            
                            .. attribute:: address
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address)}
                                self._child_list_classes = {}

                                self.address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")
                                self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"


                            class Address(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrIpv4AdjInfo(Entity):
                            """
                            Neighbor's IPv4 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv4-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup)}
                                self._child_list_classes = {}

                                self.adjacency_group = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._children_yang_names.add("adjacency-group")
                                self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData)}
                                    self._child_list_classes = {}

                                    self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                    self.link_hello_data = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"
                                    self._children_yang_names.add("link-hello-data")

                                    self.target_hello_data = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._children_yang_names.add("target-hello-data")
                                    self._segment_path = lambda: "adjacency-group"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "link-hello-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                        self._child_list_classes = {}

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.local_address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"
                                        self._children_yang_names.add("local-address")

                                        self.target_address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._children_yang_names.add("target-address")
                                        self._segment_path = lambda: "target-hello-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "target-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class LdpNbrIpv6AdjInfo(Entity):
                            """
                            Neighbor's IPv6 Adjacency Information
                            
                            .. attribute:: adjacency_group
                            
                            	Adjacency group
                            	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                self.yang_name = "ldp-nbr-ipv6-adj-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup)}
                                self._child_list_classes = {}

                                self.adjacency_group = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                self.adjacency_group.parent = self
                                self._children_name_map["adjacency_group"] = "adjacency-group"
                                self._children_yang_names.add("adjacency-group")
                                self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"


                            class AdjacencyGroup(Entity):
                                """
                                Adjacency group
                                
                                .. attribute:: hello_type
                                
                                	HelloType
                                	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                
                                .. attribute:: link_hello_data
                                
                                	Link hello
                                	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                
                                .. attribute:: target_hello_data
                                
                                	Target Hello
                                	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                    self.yang_name = "adjacency-group"
                                    self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData)}
                                    self._child_list_classes = {}

                                    self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                    self.link_hello_data = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                    self.link_hello_data.parent = self
                                    self._children_name_map["link_hello_data"] = "link-hello-data"
                                    self._children_yang_names.add("link-hello-data")

                                    self.target_hello_data = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                    self.target_hello_data.parent = self
                                    self._children_name_map["target_hello_data"] = "target-hello-data"
                                    self._children_yang_names.add("target-hello-data")
                                    self._segment_path = lambda: "adjacency-group"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                class LinkHelloData(Entity):
                                    """
                                    Link hello
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                        self.yang_name = "link-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "link-hello-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                class TargetHelloData(Entity):
                                    """
                                    Target Hello
                                    
                                    .. attribute:: local_address
                                    
                                    	Local Address
                                    	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                    
                                    .. attribute:: target_address
                                    
                                    	Target Address
                                    	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                        self.yang_name = "target-hello-data"
                                        self.yang_parent_name = "adjacency-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                        self._child_list_classes = {}

                                        self.state = YLeaf(YType.enumeration, "state")

                                        self.local_address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                        self.local_address.parent = self
                                        self._children_name_map["local_address"] = "local-address"
                                        self._children_yang_names.add("local-address")

                                        self.target_address = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                        self.target_address.parent = self
                                        self._children_name_map["target_address"] = "target-address"
                                        self._children_yang_names.add("target-address")
                                        self._segment_path = lambda: "target-hello-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                    class LocalAddress(Entity):
                                        """
                                        Local Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                            self.yang_name = "local-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class TargetAddress(Entity):
                                        """
                                        Target Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                            self.yang_name = "target-address"
                                            self.yang_parent_name = "target-hello-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "target-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class ProtocolInformation(Entity):
                            """
                            Protocol Information
                            
                            .. attribute:: downstream_on_demand
                            
                            	Is Label advertisment mode in Downstream On Demand mode or Not
                            	**type**\:  bool
                            
                            .. attribute:: ta_graceful_restart_adjacency
                            
                            	Graceful restart information
                            	**type**\:   :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                            
                            .. attribute:: ta_holdtime
                            
                            	Session holdtime in sec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_rcvd
                            
                            	Number of pies received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_pies_sent
                            
                            	Number of pies sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ta_state
                            
                            	State
                            	**type**\:  str
                            
                            .. attribute:: ta_up_time_seconds
                            
                            	Up time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                self.yang_name = "protocol-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ta-graceful-restart-adjacency" : ("ta_graceful_restart_adjacency", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency)}
                                self._child_list_classes = {}

                                self.downstream_on_demand = YLeaf(YType.boolean, "downstream-on-demand")

                                self.ta_holdtime = YLeaf(YType.uint32, "ta-holdtime")

                                self.ta_pies_rcvd = YLeaf(YType.uint32, "ta-pies-rcvd")

                                self.ta_pies_sent = YLeaf(YType.uint32, "ta-pies-sent")

                                self.ta_state = YLeaf(YType.str, "ta-state")

                                self.ta_up_time_seconds = YLeaf(YType.uint32, "ta-up-time-seconds")

                                self.ta_graceful_restart_adjacency = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                self.ta_graceful_restart_adjacency.parent = self
                                self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                self._children_yang_names.add("ta-graceful-restart-adjacency")
                                self._segment_path = lambda: "protocol-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation, ['downstream_on_demand', 'ta_holdtime', 'ta_pies_rcvd', 'ta_pies_sent', 'ta_state', 'ta_up_time_seconds'], name, value)


                            class TaGracefulRestartAdjacency(Entity):
                                """
                                Graceful restart information
                                
                                .. attribute:: is_graceful_restartable
                                
                                	Is graceful restartable
                                	**type**\:  bool
                                
                                .. attribute:: reconnect_timeout
                                
                                	Reconnect timeout
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recovery_time
                                
                                	Recovery time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                    self.yang_name = "ta-graceful-restart-adjacency"
                                    self.yang_parent_name = "protocol-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                    self.reconnect_timeout = YLeaf(YType.uint32, "reconnect-timeout")

                                    self.recovery_time = YLeaf(YType.uint32, "recovery-time")
                                    self._segment_path = lambda: "ta-graceful-restart-adjacency"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, ['is_graceful_restartable', 'reconnect_timeout', 'recovery_time'], name, value)


                        class TcpInformation(Entity):
                            """
                            TCP Information
                            
                            .. attribute:: foreign_host
                            
                            	Foreign host address
                            	**type**\:   :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                            
                            .. attribute:: foreign_port
                            
                            	Foreign port number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_md5_on
                            
                            	Is MD5 Digest on
                            	**type**\:  bool
                            
                            .. attribute:: local_host
                            
                            	Local host address
                            	**type**\:   :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                            
                            .. attribute:: local_port
                            
                            	Local port number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                self.yang_name = "tcp-information"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"foreign-host" : ("foreign_host", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost), "local-host" : ("local_host", MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost)}
                                self._child_list_classes = {}

                                self.foreign_port = YLeaf(YType.uint16, "foreign-port")

                                self.is_md5_on = YLeaf(YType.boolean, "is-md5-on")

                                self.local_port = YLeaf(YType.uint16, "local-port")

                                self.foreign_host = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                self.foreign_host.parent = self
                                self._children_name_map["foreign_host"] = "foreign-host"
                                self._children_yang_names.add("foreign-host")

                                self.local_host = MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                self.local_host.parent = self
                                self._children_name_map["local_host"] = "local-host"
                                self._children_yang_names.add("local-host")
                                self._segment_path = lambda: "tcp-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation, ['foreign_port', 'is_md5_on', 'local_port'], name, value)


                            class ForeignHost(Entity):
                                """
                                Foreign host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                    self.yang_name = "foreign-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "foreign-host"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.ForeignHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LocalHost(Entity):
                                """
                                Local host address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                    self.yang_name = "local-host"
                                    self.yang_parent_name = "tcp-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "local-host"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Neighbors.Neighbor.TcpInformation.LocalHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class Nsr(Entity):
                    """
                    LDP NSR related information
                    
                    .. attribute:: ha_statistics
                    
                    	LDP NSR Statistics related information
                    	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics>`
                    
                    .. attribute:: ha_summary
                    
                    	LDP HA Summary
                    	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary>`
                    
                    .. attribute:: nsr_pending
                    
                    	LDP NSR Pending related information
                    	**type**\:   :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr, self).__init__()

                        self.yang_name = "nsr"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary), "nsr-pending" : ("nsr_pending", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending)}
                        self._child_list_classes = {}

                        self.ha_statistics = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics()
                        self.ha_statistics.parent = self
                        self._children_name_map["ha_statistics"] = "ha-statistics"
                        self._children_yang_names.add("ha-statistics")

                        self.ha_summary = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary()
                        self.ha_summary.parent = self
                        self._children_name_map["ha_summary"] = "ha-summary"
                        self._children_yang_names.add("ha-summary")

                        self.nsr_pending = MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending()
                        self.nsr_pending.parent = self
                        self._children_name_map["nsr_pending"] = "nsr-pending"
                        self._children_yang_names.add("nsr-pending")
                        self._segment_path = lambda: "nsr"


                    class HaStatistics(Entity):
                        """
                        LDP NSR Statistics related information
                        
                        .. attribute:: ha_global
                        
                        	LDP NSR Global Statistics information
                        	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal>`
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics, self).__init__()

                            self.yang_name = "ha-statistics"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_global = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal()
                            self.ha_global.parent = self
                            self._children_name_map["ha_global"] = "ha-global"
                            self._children_yang_names.add("ha-global")

                            self.ha_neighbors = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "ha-statistics"


                        class HaGlobal(Entity):
                            """
                            LDP NSR Global Statistics information
                            
                            .. attribute:: init_sync
                            
                            	Init Sync
                            	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                self.yang_name = "ha-global"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync)}
                                self._child_list_classes = {}

                                self.init_sync = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                self.init_sync.parent = self
                                self._children_name_map["init_sync"] = "init-sync"
                                self._children_yang_names.add("init-sync")
                                self._segment_path = lambda: "ha-global"


                            class InitSync(Entity):
                                """
                                Init Sync
                                
                                .. attribute:: init_sync_end
                                
                                	Init Sync End Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_sync_start
                                
                                	Init Sync Start Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_default_mtu
                                
                                	default IPC MTU bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_exceeded_mtu_msg_cnt
                                
                                	ipc exceeded mtu msg cnt
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_max_rx_batch_bytes
                                
                                	biggest IPC RX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_max_tx_batch_bytes
                                
                                	biggest IPC TX bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_rx_bytes
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_rx_cnt
                                
                                	num IPC msgs rxed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_msg_tx_bytes
                                
                                	total IPC bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ipc_msg_tx_cnt
                                
                                	num IPC msgs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_restart_cnt
                                
                                	number of times ipc has been restarted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipc_tx_fail_cnt
                                
                                	number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_cfged
                                
                                	TRUE if NSR configured
                                	**type**\:  bool
                                
                                .. attribute:: nsr_synced
                                
                                	TRUE if NSR synced
                                	**type**\:  bool
                                
                                .. attribute:: num_cap_rcvd
                                
                                	Number of Rcvd Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_cap_sent
                                
                                	Number of Sent Capabilities objects
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl
                                
                                	Number of label bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lbl_adv
                                
                                	Num of lbl adv
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_lcl_addr_wd
                                
                                	Num of lcl address withdraw
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_peers
                                
                                	Number of Peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_pfx
                                
                                	Number of binding prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_ipc_tx_fail_cnt
                                
                                	total number of ipc send failures
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                    self.yang_name = "init-sync"
                                    self.yang_parent_name = "ha-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                    self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                    self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                    self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                    self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                    self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                    self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                    self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                    self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                    self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                    self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                    self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                    self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                    self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                    self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                    self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                    self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                    self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                    self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                    self.num_peers = YLeaf(YType.uint32, "num-peers")

                                    self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                    self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                    self._segment_path = lambda: "init-sync"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "ha-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class HaSummary(Entity):
                        """
                        LDP HA Summary
                        
                        .. attribute:: sessions
                        
                        	Session summary
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary, self).__init__()

                            self.yang_name = "ha-summary"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf)}
                            self._child_list_classes = {}

                            self.sessions = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._children_yang_names.add("sessions")

                            self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "ha-summary"


                        class Sessions(Entity):
                            """
                            Session summary
                            
                            .. attribute:: nsr_eligible
                            
                            	NSR eligible sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_app_wait
                            
                            	Number of sessions in NSR app\-wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_none
                            
                            	Number of sessions in NSR none state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_operational
                            
                            	Number of sessions in NSR operational state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_prepare
                            
                            	Number of sessions in NSR prepare state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_ready
                            
                            	Number of sessions in NSR ready state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase1
                            
                            	Number of sessions in NSR TCP phase 1 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_tcp_phase2
                            
                            	Number of sessions in NSR TCP phase 2 state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state_wait
                            
                            	Number of sessions in NSR wait state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total sessions
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                self.total = YLeaf(YType.uint32, "total")
                                self._segment_path = lambda: "sessions"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "ha-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.HaSummary.Vrf, ['id', 'name'], name, value)


                    class NsrPending(Entity):
                        """
                        LDP NSR Pending related information
                        
                        .. attribute:: ha_neighbors
                        
                        	The LDP HA Neighbors
                        	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending, self).__init__()

                            self.yang_name = "nsr-pending"
                            self.yang_parent_name = "nsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-neighbors" : ("ha_neighbors", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors)}
                            self._child_list_classes = {}

                            self.ha_neighbors = MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors()
                            self.ha_neighbors.parent = self
                            self._children_name_map["ha_neighbors"] = "ha-neighbors"
                            self._children_yang_names.add("ha-neighbors")
                            self._segment_path = lambda: "nsr-pending"


                        class HaNeighbors(Entity):
                            """
                            The LDP HA Neighbors
                            
                            .. attribute:: ha_neighbor
                            
                            	Information on a particular LDP HA neighbor
                            	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                self.yang_name = "ha-neighbors"
                                self.yang_parent_name = "nsr-pending"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor)}

                                self.ha_neighbor = YList(self)
                                self._segment_path = lambda: "ha-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                            class HaNeighbor(Entity):
                                """
                                Information on a particular LDP HA neighbor
                                
                                .. attribute:: init_sync_info
                                
                                	NSR Init Sync Info
                                	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                
                                .. attribute:: label_space_id
                                
                                	Label space ID of neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lbl_spc_id
                                
                                	lbl spc id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsr_id
                                
                                	LSR ID of neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsr_id_xr
                                
                                	lsr id xr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sync_state
                                
                                	nsr sync state
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: num_msg
                                
                                	Number of sync messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: steady_state_sync_info
                                
                                	NSR Steady State Sync Info
                                	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                    self.yang_name = "ha-neighbor"
                                    self.yang_parent_name = "ha-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                    self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")

                                    self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                    self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                    self.num_msg = YLeaf(YType.uint32, "num-msg")

                                    self.init_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                    self.init_sync_info.parent = self
                                    self._children_name_map["init_sync_info"] = "init-sync-info"
                                    self._children_yang_names.add("init-sync-info")

                                    self.steady_state_sync_info = MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                    self.steady_state_sync_info.parent = self
                                    self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                    self._children_yang_names.add("steady-state-sync-info")
                                    self._segment_path = lambda: "ha-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                class InitSyncInfo(Entity):
                                    """
                                    NSR Init Sync Info
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_addr
                                    
                                    	Number of peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_app_bytes
                                    
                                    	Number of external App data bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_duplicate_addr
                                    
                                    	Number of duplicate peer addresses
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of peer bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_rx_bytes
                                    
                                    	Number of unprocessed Rx buffer bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                        self.yang_name = "init-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.num_addr = YLeaf(YType.uint32, "num-addr")

                                        self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                        self._segment_path = lambda: "init-sync-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                class SteadyStateSyncInfo(Entity):
                                    """
                                    NSR Steady State Sync Info
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Num of Rcvd Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Num of Sent Capabilities
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_join
                                    
                                    	Number of standby adj join
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_stdby_adj_leave
                                    
                                    	Number of standby adj leave
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_rq
                                    
                                    	Number of remote label request events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_lbl_wd
                                    
                                    	Number of remote label withdraw events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                        self.yang_name = "steady-state-sync-info"
                                        self.yang_parent_name = "ha-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                        self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                        self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                        self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                        self._segment_path = lambda: "steady-state-sync-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                class Parameters(Entity):
                    """
                    LDP parameters
                    
                    .. attribute:: address_family_parameter
                    
                    	Per AF parameters
                    	**type**\: list of    :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter>`
                    
                    .. attribute:: af_binding_withdraw_delay
                    
                    	Delay (sec) in Binding Withdrawal for an Address Family
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: discovery_quick_start_disabled_on_interfaces
                    
                    	Discovery quick\-start disabled on some LDP\-enabled interfaces
                    	**type**\:  bool
                    
                    .. attribute:: global_discovery_quick_start_disabled
                    
                    	Discovery quick\-start globally disabled
                    	**type**\:  bool
                    
                    .. attribute:: global_md5_password_enabled
                    
                    	Global MD5 password enabled
                    	**type**\:  bool
                    
                    .. attribute:: graceful_restart_information
                    
                    	Graceful restart information
                    	**type**\:   :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation>`
                    
                    .. attribute:: hello_hold_time
                    
                    	Hello hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_interval
                    
                    	Hello interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: housekeeping_timer_interval
                    
                    	Housekeeping periodic timer interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: igp_sync_delay_time_for_interface
                    
                    	Interface IGP sync delay time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: igp_sync_delay_time_on_restart
                    
                    	IGP sync delay time on process restart in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: keepalive_interval
                    
                    	Keepalive interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_out_of_mem_state
                    
                    	LDP Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ldp_recovery_timeout
                    
                    	LDP recovery timeout with LSD
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: le_no_route_timeout
                    
                    	LIB entry no route timeout
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_attached
                    
                    	Maximum number of LDP enabled attached interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_intf_te
                    
                    	Maximum number of LDP enabled TE interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_peer
                    
                    	Maximum number of LDP peers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_enabled
                    
                    	TRUE if NSR is enabled
                    	**type**\:  bool
                    
                    .. attribute:: nsr_synced
                    
                    	TRUE if LDP is standby and is NSR Sync\-ed with active
                    	**type**\:  bool
                    
                    .. attribute:: protocol_version
                    
                    	Protocol version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: role_is_active
                    
                    	Is process role active or standby
                    	**type**\:  bool
                    
                    .. attribute:: router_id
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: session_hold_time
                    
                    	Session hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_hold_time
                    
                    	Targeted hello hold time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: targeted_hello_interval
                    
                    	Targeted hello interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Parameters, self).__init__()

                        self.yang_name = "parameters"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"graceful-restart-information" : ("graceful_restart_information", MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation)}
                        self._child_list_classes = {"address-family-parameter" : ("address_family_parameter", MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter)}

                        self.af_binding_withdraw_delay = YLeaf(YType.uint32, "af-binding-withdraw-delay")

                        self.discovery_quick_start_disabled_on_interfaces = YLeaf(YType.boolean, "discovery-quick-start-disabled-on-interfaces")

                        self.global_discovery_quick_start_disabled = YLeaf(YType.boolean, "global-discovery-quick-start-disabled")

                        self.global_md5_password_enabled = YLeaf(YType.boolean, "global-md5-password-enabled")

                        self.hello_hold_time = YLeaf(YType.uint32, "hello-hold-time")

                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                        self.housekeeping_timer_interval = YLeaf(YType.uint32, "housekeeping-timer-interval")

                        self.igp_sync_delay_time_for_interface = YLeaf(YType.uint32, "igp-sync-delay-time-for-interface")

                        self.igp_sync_delay_time_on_restart = YLeaf(YType.uint32, "igp-sync-delay-time-on-restart")

                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                        self.ldp_out_of_mem_state = YLeaf(YType.uint32, "ldp-out-of-mem-state")

                        self.ldp_recovery_timeout = YLeaf(YType.uint32, "ldp-recovery-timeout")

                        self.le_no_route_timeout = YLeaf(YType.uint32, "le-no-route-timeout")

                        self.max_intf_attached = YLeaf(YType.uint32, "max-intf-attached")

                        self.max_intf_te = YLeaf(YType.uint32, "max-intf-te")

                        self.max_peer = YLeaf(YType.uint32, "max-peer")

                        self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                        self.protocol_version = YLeaf(YType.uint32, "protocol-version")

                        self.role_is_active = YLeaf(YType.boolean, "role-is-active")

                        self.router_id = YLeaf(YType.str, "router-id")

                        self.session_hold_time = YLeaf(YType.uint32, "session-hold-time")

                        self.targeted_hello_hold_time = YLeaf(YType.uint32, "targeted-hello-hold-time")

                        self.targeted_hello_interval = YLeaf(YType.uint32, "targeted-hello-interval")

                        self.graceful_restart_information = MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation()
                        self.graceful_restart_information.parent = self
                        self._children_name_map["graceful_restart_information"] = "graceful-restart-information"
                        self._children_yang_names.add("graceful-restart-information")

                        self.address_family_parameter = YList(self)
                        self._segment_path = lambda: "parameters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Parameters, ['af_binding_withdraw_delay', 'discovery_quick_start_disabled_on_interfaces', 'global_discovery_quick_start_disabled', 'global_md5_password_enabled', 'hello_hold_time', 'hello_interval', 'housekeeping_timer_interval', 'igp_sync_delay_time_for_interface', 'igp_sync_delay_time_on_restart', 'keepalive_interval', 'ldp_out_of_mem_state', 'ldp_recovery_timeout', 'le_no_route_timeout', 'max_intf_attached', 'max_intf_te', 'max_peer', 'nsr_enabled', 'nsr_synced', 'protocol_version', 'role_is_active', 'router_id', 'session_hold_time', 'targeted_hello_hold_time', 'targeted_hello_interval'], name, value)


                    class AddressFamilyParameter(Entity):
                        """
                        Per AF parameters
                        
                        .. attribute:: address_family
                        
                        	Address Family
                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: discovery_transport_address
                        
                        	Discovery transport address
                        	**type**\:   :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                        
                        .. attribute:: is_accepting_targeted_hellos
                        
                        	Accepting targeted Hellos
                        	**type**\:  bool
                        
                        .. attribute:: label_imp_null_override_acl
                        
                        	ACL to override local label to use implicit\-null
                        	**type**\:  str
                        
                        .. attribute:: null_label
                        
                        	Null label
                        	**type**\:  str
                        
                        .. attribute:: targeted_hello_acl
                        
                        	Targeted Hello ACL
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter, self).__init__()

                            self.yang_name = "address-family-parameter"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"discovery-transport-address" : ("discovery_transport_address", MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress)}
                            self._child_list_classes = {}

                            self.address_family = YLeaf(YType.enumeration, "address-family")

                            self.is_accepting_targeted_hellos = YLeaf(YType.boolean, "is-accepting-targeted-hellos")

                            self.label_imp_null_override_acl = YLeaf(YType.str, "label-imp-null-override-acl")

                            self.null_label = YLeaf(YType.str, "null-label")

                            self.targeted_hello_acl = YLeaf(YType.str, "targeted-hello-acl")

                            self.discovery_transport_address = MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                            self.discovery_transport_address.parent = self
                            self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                            self._children_yang_names.add("discovery-transport-address")
                            self._segment_path = lambda: "address-family-parameter"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter, ['address_family', 'is_accepting_targeted_hellos', 'label_imp_null_override_acl', 'null_label', 'targeted_hello_acl'], name, value)


                        class DiscoveryTransportAddress(Entity):
                            """
                            Discovery transport address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                            
                            .. attribute:: dummy
                            
                            	No Address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                self.yang_name = "discovery-transport-address"
                                self.yang_parent_name = "address-family-parameter"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.dummy = YLeaf(YType.uint8, "dummy")

                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                self._segment_path = lambda: "discovery-transport-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                    class GracefulRestartInformation(Entity):
                        """
                        Graceful restart information
                        
                        .. attribute:: graceful_restart_forwarding_state_hold_time
                        
                        	Graceful restart forward state hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_restart_reconnect_timeout
                        
                        	Reconnect timeout value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_graceful_restart_configured
                        
                        	Is graceful restart configured
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation, self).__init__()

                            self.yang_name = "graceful-restart-information"
                            self.yang_parent_name = "parameters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.graceful_restart_forwarding_state_hold_time = YLeaf(YType.uint32, "graceful-restart-forwarding-state-hold-time")

                            self.graceful_restart_reconnect_timeout = YLeaf(YType.uint32, "graceful-restart-reconnect-timeout")

                            self.is_graceful_restart_configured = YLeaf(YType.boolean, "is-graceful-restart-configured")
                            self._segment_path = lambda: "graceful-restart-information"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Parameters.GracefulRestartInformation, ['graceful_restart_forwarding_state_hold_time', 'graceful_restart_reconnect_timeout', 'is_graceful_restart_configured'], name, value)


                class Statistics(Entity):
                    """
                    The LDP Statistics
                    
                    .. attribute:: statistic
                    
                    	Statistical Information on a particular LDP neighbor
                    	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"statistic" : ("statistic", MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic)}

                        self.statistic = YList(self)
                        self._segment_path = lambda: "statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Statistics, [], name, value)


                    class Statistic(Entity):
                        """
                        Statistical Information on a particular LDP
                        neighbor
                        
                        .. attribute:: iccp_enabled
                        
                        	Is session ICCP enabled?
                        	**type**\:  bool
                        
                        .. attribute:: label_space_id
                        
                        	Label space ID of neighbor
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: lsr_id
                        
                        	LSR ID of neighbor
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: message_in
                        
                        	Message in count
                        	**type**\:   :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn>`
                        
                        .. attribute:: message_out
                        
                        	Message out count
                        	**type**\:   :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic, self).__init__()

                            self.yang_name = "statistic"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"message-in" : ("message_in", MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn), "message-out" : ("message_out", MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut)}
                            self._child_list_classes = {}

                            self.iccp_enabled = YLeaf(YType.boolean, "iccp-enabled")

                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                            self.message_in = MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn()
                            self.message_in.parent = self
                            self._children_name_map["message_in"] = "message-in"
                            self._children_yang_names.add("message-in")

                            self.message_out = MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut()
                            self.message_out.parent = self
                            self._children_name_map["message_out"] = "message-out"
                            self._children_yang_names.add("message-out")
                            self._segment_path = lambda: "statistic"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic, ['iccp_enabled', 'label_space_id', 'lsr_id'], name, value)


                        class MessageIn(Entity):
                            """
                            Message in count
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn, self).__init__()

                                self.yang_name = "message-in"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_count = YLeaf(YType.uint32, "address-count")

                                self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                self.init_count = YLeaf(YType.uint32, "init-count")

                                self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                self.notification_count = YLeaf(YType.uint32, "notification-count")

                                self.total_count = YLeaf(YType.uint32, "total-count")
                                self._segment_path = lambda: "message-in"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageIn, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                        class MessageOut(Entity):
                            """
                            Message out count
                            
                            .. attribute:: address_count
                            
                            	Address message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: address_withdraw_count
                            
                            	Address withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_app_data_count
                            
                            	ICCP RG App Data count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_conn_count
                            
                            	ICCP RG Connect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_disconn_count
                            
                            	ICCP RG Disconnect count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_rg_notif_count
                            
                            	ICCP RG Notif count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: init_count
                            
                            	Init message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_count
                            
                            	Keepalive count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_abort_request_count
                            
                            	Label abort request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_map_count
                            
                            	Label map count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_release_count
                            
                            	Label release count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_request_count
                            
                            	Label request count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_withdraw_count
                            
                            	Label withdraw count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notification_count
                            
                            	Notification count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_count
                            
                            	Total message count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut, self).__init__()

                                self.yang_name = "message-out"
                                self.yang_parent_name = "statistic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_count = YLeaf(YType.uint32, "address-count")

                                self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                self.init_count = YLeaf(YType.uint32, "init-count")

                                self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                self.notification_count = YLeaf(YType.uint32, "notification-count")

                                self.total_count = YLeaf(YType.uint32, "total-count")
                                self._segment_path = lambda: "message-out"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Statistics.Statistic.MessageOut, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                class Summary(Entity):
                    """
                    LDP VRF summary
                    
                    .. attribute:: common
                    
                    	Common Summary information
                    	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Summary.Common>`
                    
                    .. attribute:: vrf
                    
                    	VRF information
                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DefaultVrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"common" : ("common", MplsLdp.Nodes.Node.DefaultVrf.Summary.Common), "vrf" : ("vrf", MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf)}
                        self._child_list_classes = {}

                        self.common = MplsLdp.Nodes.Node.DefaultVrf.Summary.Common()
                        self.common.parent = self
                        self._children_name_map["common"] = "common"
                        self._children_yang_names.add("common")

                        self.vrf = MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf()
                        self.vrf.parent = self
                        self._children_name_map["vrf"] = "vrf"
                        self._children_yang_names.add("vrf")
                        self._segment_path = lambda: "summary"


                    class Common(Entity):
                        """
                        Common Summary information
                        
                        .. attribute:: address_families
                        
                        	Address Families enabled
                        	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                        
                        .. attribute:: number_of_bindings_ipv4
                        
                        	Total number of ipv4 bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_bindings_ipv6
                        
                        	Total number of ipv6 bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_downstream_on_demand_neighbors
                        
                        	Number of Downstream\-On\-Demand neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_graceful_restart_neighbors
                        
                        	Number of Graceful Restart neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_hello_adj
                        
                        	Number of LDP discovery IPv4 hello adjacencies
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_local_addresses
                        
                        	Number of IPv4 local addresses
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4_routes
                        
                        	Number of resolved IPv4 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4af
                        
                        	Number of IPv4 address\-families enabled
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv4ldp_interfaces
                        
                        	Number of LDP IPv4 configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_hello_adj
                        
                        	Number of LDP discovery IPv6 hello adjacencies
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_local_addresses
                        
                        	Number of IPv6 local addresses
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6_routes
                        
                        	Number of resolved IPv6 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6af
                        
                        	Number of IPv6 address\-families enabled
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ipv6ldp_interfaces
                        
                        	Number of LDP IPv6 configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_ldp_interfaces
                        
                        	Number of LDP configured interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv4
                        
                        	Total number of ipv4 local label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_local_bindings_ipv6
                        
                        	Total number of ipv6 local label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_nsr_synced_neighbors
                        
                        	Number of NSR\-synced/operational neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv4
                        
                        	Total number of ipv4 remote label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_remote_bindings_ipv6
                        
                        	Total number of ipv6 remote label bindings
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Summary.Common, self).__init__()

                            self.yang_name = "common"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.address_families = YLeaf(YType.enumeration, "address-families")

                            self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                            self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                            self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                            self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                            self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                            self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                            self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                            self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                            self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                            self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                            self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                            self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                            self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                            self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                            self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                            self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                            self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                            self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                            self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                            self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                            self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                            self._segment_path = lambda: "common"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


                    class Vrf(Entity):
                        """
                        VRF information
                        
                        .. attribute:: id
                        
                        	VRF Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.id = YLeaf(YType.uint32, "id")

                            self.name = YLeaf(YType.str, "name")
                            self._segment_path = lambda: "vrf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.DefaultVrf.Summary.Vrf, ['id', 'name'], name, value)


            class DiscoverySummaryAll(Entity):
                """
                Summary information regarding LDP discovery
                
                .. attribute:: local_ldp_id
                
                	Local LDP identifier
                	**type**\:  str
                
                .. attribute:: num_of_active_ldp_interfaces
                
                	Number of active LDP enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_addr_recv
                
                	Number of hello discoveries received with bad source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_hello_pdu
                
                	Number of hello discoveries received with bad hello PDU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_bad_xport_addr
                
                	Number of hello discoveries received with bad export address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_same_router_id
                
                	Number of hello discoveries received with the same router id as this router
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_disc_with_wrong_router_id
                
                	Number of hello discoveries received with the router id that is not destined for this router
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_ldp_interfaces
                
                	Total Number of LDP configured interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_recv
                
                	Number of link hello discoveries in recv state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_lnk_disc_xmit
                
                	Number of link hello discoveries in xmit state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_recv
                
                	Number of targeted hello discoveries in recv state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_of_tgt_disc_xmit
                
                	Number of targeted hello discoveries in xmit state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.DiscoverySummaryAll, self).__init__()

                    self.yang_name = "discovery-summary-all"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                    self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                    self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                    self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                    self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                    self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                    self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                    self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                    self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                    self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                    self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                    self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                    self.vrf = MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "discovery-summary-all"

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.DiscoverySummaryAll, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "discovery-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.DiscoverySummaryAll.Vrf, ['id', 'name'], name, value)


            class ForwardingSummaryAll(Entity):
                """
                Summary information regarding LDP forwarding
                setup
                
                .. attribute:: fsht
                
                	Forwarding state hold time registered with LSD
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: intfs
                
                	MPLS forwarding enabled interface count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: is_lsd_bound
                
                	LDP is connected to LSD server
                	**type**\:  bool
                
                .. attribute:: lbls
                
                	Local label allocated count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: rws
                
                	Forwarding rewrites summary
                	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws>`
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.ForwardingSummaryAll, self).__init__()

                    self.yang_name = "forwarding-summary-all"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"rws" : ("rws", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws), "vrf" : ("vrf", MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.fsht = YLeaf(YType.uint16, "fsht")

                    self.intfs = YLeaf(YType.uint16, "intfs")

                    self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                    self.lbls = YLeaf(YType.uint16, "lbls")

                    self.rws = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws()
                    self.rws.parent = self
                    self._children_name_map["rws"] = "rws"
                    self._children_yang_names.add("rws")

                    self.vrf = MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "forwarding-summary-all"

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                class Rws(Entity):
                    """
                    Forwarding rewrites summary
                    
                    .. attribute:: nhs
                    
                    	Forwarding rewrites nexthops (paths) summary
                    	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs>`
                    
                    .. attribute:: pfxs
                    
                    	Forwarding rewrites prefix summary
                    	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws, self).__init__()

                        self.yang_name = "rws"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs)}
                        self._child_list_classes = {}

                        self.nhs = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs()
                        self.nhs.parent = self
                        self._children_name_map["nhs"] = "nhs"
                        self._children_yang_names.add("nhs")

                        self.pfxs = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs()
                        self.pfxs.parent = self
                        self._children_name_map["pfxs"] = "pfxs"
                        self._children_yang_names.add("pfxs")
                        self._segment_path = lambda: "rws"


                    class Nhs(Entity):
                        """
                        Forwarding rewrites nexthops (paths) summary
                        
                        .. attribute:: backup_paths
                        
                        	Count of non\-primary backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_backup_paths
                        
                        	Count of labeled backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: labeled_paths
                        
                        	Count of all labeled paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protected_paths
                        
                        	Count of FRR protected paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_backup_paths
                        
                        	Count of non\-primary remote backup paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_paths
                        
                        	Total path count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs, self).__init__()

                            self.yang_name = "nhs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                            self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                            self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                            self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                            self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                            self.total_paths = YLeaf(YType.uint32, "total-paths")
                            self._segment_path = lambda: "nhs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                    class Pfxs(Entity):
                        """
                        Forwarding rewrites prefix summary
                        
                        .. attribute:: ecmp_pfxs
                        
                        	Count of prefixes with ECMP
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: labeled_pfxs_aggr
                        
                        	Labeled prefix count for all paths
                        	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr>`
                        
                        .. attribute:: labeled_pfxs_backup
                        
                        	Labeled prefix count related to backup paths only
                        	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup>`
                        
                        .. attribute:: labeled_pfxs_primary
                        
                        	Labeled prefix count related to primary paths only
                        	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary>`
                        
                        .. attribute:: protected_pfxs
                        
                        	Count of FRR protected prefixes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: total_pfxs
                        
                        	Total Prefix count
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs, self).__init__()

                            self.yang_name = "pfxs"
                            self.yang_parent_name = "rws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary)}
                            self._child_list_classes = {}

                            self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                            self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                            self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                            self.labeled_pfxs_aggr = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr()
                            self.labeled_pfxs_aggr.parent = self
                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                            self._children_yang_names.add("labeled-pfxs-aggr")

                            self.labeled_pfxs_backup = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup()
                            self.labeled_pfxs_backup.parent = self
                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                            self._children_yang_names.add("labeled-pfxs-backup")

                            self.labeled_pfxs_primary = MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary()
                            self.labeled_pfxs_primary.parent = self
                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                            self._children_yang_names.add("labeled-pfxs-primary")
                            self._segment_path = lambda: "pfxs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                        class LabeledPfxsAggr(Entity):
                            """
                            Labeled prefix count for all paths
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                self.yang_name = "labeled-pfxs-aggr"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-aggr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                        class LabeledPfxsBackup(Entity):
                            """
                            Labeled prefix count related to backup paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                self.yang_name = "labeled-pfxs-backup"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-backup"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                        class LabeledPfxsPrimary(Entity):
                            """
                            Labeled prefix count related to primary paths
                            only
                            
                            .. attribute:: labeled_pfxs
                            
                            	Count of labeled prefixes with 1 or more paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: labeled_pfxs_partial
                            
                            	Count of labeled prefixes with some (but not ALL) paths labeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: unlabeled_pfxs
                            
                            	Count of labeled prefixes with ALL paths unlabeled
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                self.yang_name = "labeled-pfxs-primary"
                                self.yang_parent_name = "pfxs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                self._segment_path = lambda: "labeled-pfxs-primary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "forwarding-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.ForwardingSummaryAll.Vrf, ['id', 'name'], name, value)


            class NsrSummaryAll(Entity):
                """
                Summary information regarding LDP NSR State
                
                .. attribute:: sessions
                
                	Session summary
                	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.NsrSummaryAll.Sessions>`
                
                .. attribute:: vrf
                
                	VRF information
                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.NsrSummaryAll.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.NsrSummaryAll, self).__init__()

                    self.yang_name = "nsr-summary-all"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Nodes.Node.NsrSummaryAll.Sessions), "vrf" : ("vrf", MplsLdp.Nodes.Node.NsrSummaryAll.Vrf)}
                    self._child_list_classes = {}

                    self.sessions = MplsLdp.Nodes.Node.NsrSummaryAll.Sessions()
                    self.sessions.parent = self
                    self._children_name_map["sessions"] = "sessions"
                    self._children_yang_names.add("sessions")

                    self.vrf = MplsLdp.Nodes.Node.NsrSummaryAll.Vrf()
                    self.vrf.parent = self
                    self._children_name_map["vrf"] = "vrf"
                    self._children_yang_names.add("vrf")
                    self._segment_path = lambda: "nsr-summary-all"


                class Sessions(Entity):
                    """
                    Session summary
                    
                    .. attribute:: nsr_eligible
                    
                    	NSR eligible sessions
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_app_wait
                    
                    	Number of sessions in NSR app\-wait state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_none
                    
                    	Number of sessions in NSR none state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_operational
                    
                    	Number of sessions in NSR operational state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_prepare
                    
                    	Number of sessions in NSR prepare state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_ready
                    
                    	Number of sessions in NSR ready state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase1
                    
                    	Number of sessions in NSR TCP phase 1 state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_tcp_phase2
                    
                    	Number of sessions in NSR TCP phase 2 state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_state_wait
                    
                    	Number of sessions in NSR wait state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total
                    
                    	Total sessions
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.NsrSummaryAll.Sessions, self).__init__()

                        self.yang_name = "sessions"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                        self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                        self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                        self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                        self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                        self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                        self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                        self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                        self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                        self.total = YLeaf(YType.uint32, "total")
                        self._segment_path = lambda: "sessions"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.NsrSummaryAll.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                class Vrf(Entity):
                    """
                    VRF information
                    
                    .. attribute:: id
                    
                    	VRF Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.NsrSummaryAll.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "nsr-summary-all"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.id = YLeaf(YType.uint32, "id")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "vrf"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.NsrSummaryAll.Vrf, ['id', 'name'], name, value)


            class Summary(Entity):
                """
                LDP summary
                
                .. attribute:: common
                
                	Common Summary information
                	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Summary.Common>`
                
                .. attribute:: is_bound_with_atom
                
                	Bound status with L2VPN ATOM
                	**type**\:  bool
                
                .. attribute:: is_bound_with_interface_manager
                
                	Bound status with Interface Manager
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ip_arm
                
                	Bound status with IP Arm
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ipv4_rib
                
                	Bound status with IPv4 RIB
                	**type**\:  bool
                
                .. attribute:: is_bound_with_ipv6_rib
                
                	Bound status with IPv6 RIB
                	**type**\:  bool
                
                .. attribute:: is_bound_with_lsd
                
                	Bound status with LSD
                	**type**\:  bool
                
                .. attribute:: is_bound_with_nsr_mate
                
                	Bound status with NSR Mate
                	**type**\:  bool
                
                .. attribute:: is_bound_with_rsi
                
                	Bound status with rsi
                	**type**\:  bool
                
                .. attribute:: is_bound_with_sysdb
                
                	Bound status with sysdb
                	**type**\:  bool
                
                .. attribute:: is_mldp_registered
                
                	mLDP registration status
                	**type**\:  bool
                
                .. attribute:: is_nsr_configured
                
                	NSR configured
                	**type**\:  bool
                
                .. attribute:: is_registered_with_interface_manager
                
                	Registration status with Interface Manager
                	**type**\:  bool
                
                .. attribute:: is_registered_with_ipv4_rib
                
                	Registration status with IPv4 RIB
                	**type**\:  bool
                
                .. attribute:: is_registered_with_ipv6_rib
                
                	Registration status with IPv6 RIB
                	**type**\:  bool
                
                .. attribute:: is_registered_with_lsd
                
                	Registration status with LSD
                	**type**\:  bool
                
                .. attribute:: is_registered_with_sysdb
                
                	Registration status with Sysdb
                	**type**\:  bool
                
                .. attribute:: number_of_autocfg_interfaces
                
                	Number of auto\-configured interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_fwd_ref_interfaces
                
                	Number of Forward Referenc interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of known interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_ipv4rib_tables
                
                	Total number of ipv4 RIB tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_ipv6rib_tables
                
                	Total number of ipv6 RIB tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv4rib_tables
                
                	Number of ipv4 RIB tables registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_registered_ipv6rib_tables
                
                	Number of ipv6 RIB tables registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf
                
                	Number of configured VRFs (including default)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrf_oper
                
                	Number of configured operational VRFs (including default)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"common" : ("common", MplsLdp.Nodes.Node.Summary.Common)}
                    self._child_list_classes = {}

                    self.is_bound_with_atom = YLeaf(YType.boolean, "is-bound-with-atom")

                    self.is_bound_with_interface_manager = YLeaf(YType.boolean, "is-bound-with-interface-manager")

                    self.is_bound_with_ip_arm = YLeaf(YType.boolean, "is-bound-with-ip-arm")

                    self.is_bound_with_ipv4_rib = YLeaf(YType.boolean, "is-bound-with-ipv4-rib")

                    self.is_bound_with_ipv6_rib = YLeaf(YType.boolean, "is-bound-with-ipv6-rib")

                    self.is_bound_with_lsd = YLeaf(YType.boolean, "is-bound-with-lsd")

                    self.is_bound_with_nsr_mate = YLeaf(YType.boolean, "is-bound-with-nsr-mate")

                    self.is_bound_with_rsi = YLeaf(YType.boolean, "is-bound-with-rsi")

                    self.is_bound_with_sysdb = YLeaf(YType.boolean, "is-bound-with-sysdb")

                    self.is_mldp_registered = YLeaf(YType.boolean, "is-mldp-registered")

                    self.is_nsr_configured = YLeaf(YType.boolean, "is-nsr-configured")

                    self.is_registered_with_interface_manager = YLeaf(YType.boolean, "is-registered-with-interface-manager")

                    self.is_registered_with_ipv4_rib = YLeaf(YType.boolean, "is-registered-with-ipv4-rib")

                    self.is_registered_with_ipv6_rib = YLeaf(YType.boolean, "is-registered-with-ipv6-rib")

                    self.is_registered_with_lsd = YLeaf(YType.boolean, "is-registered-with-lsd")

                    self.is_registered_with_sysdb = YLeaf(YType.boolean, "is-registered-with-sysdb")

                    self.number_of_autocfg_interfaces = YLeaf(YType.uint32, "number-of-autocfg-interfaces")

                    self.number_of_fwd_ref_interfaces = YLeaf(YType.uint32, "number-of-fwd-ref-interfaces")

                    self.number_of_interfaces = YLeaf(YType.uint32, "number-of-interfaces")

                    self.number_of_ipv4rib_tables = YLeaf(YType.uint32, "number-of-ipv4rib-tables")

                    self.number_of_ipv6rib_tables = YLeaf(YType.uint32, "number-of-ipv6rib-tables")

                    self.number_of_registered_ipv4rib_tables = YLeaf(YType.uint32, "number-of-registered-ipv4rib-tables")

                    self.number_of_registered_ipv6rib_tables = YLeaf(YType.uint32, "number-of-registered-ipv6rib-tables")

                    self.number_of_vrf = YLeaf(YType.uint32, "number-of-vrf")

                    self.number_of_vrf_oper = YLeaf(YType.uint32, "number-of-vrf-oper")

                    self.common = MplsLdp.Nodes.Node.Summary.Common()
                    self.common.parent = self
                    self._children_name_map["common"] = "common"
                    self._children_yang_names.add("common")
                    self._segment_path = lambda: "summary"

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.Summary, ['is_bound_with_atom', 'is_bound_with_interface_manager', 'is_bound_with_ip_arm', 'is_bound_with_ipv4_rib', 'is_bound_with_ipv6_rib', 'is_bound_with_lsd', 'is_bound_with_nsr_mate', 'is_bound_with_rsi', 'is_bound_with_sysdb', 'is_mldp_registered', 'is_nsr_configured', 'is_registered_with_interface_manager', 'is_registered_with_ipv4_rib', 'is_registered_with_ipv6_rib', 'is_registered_with_lsd', 'is_registered_with_sysdb', 'number_of_autocfg_interfaces', 'number_of_fwd_ref_interfaces', 'number_of_interfaces', 'number_of_ipv4rib_tables', 'number_of_ipv6rib_tables', 'number_of_registered_ipv4rib_tables', 'number_of_registered_ipv6rib_tables', 'number_of_vrf', 'number_of_vrf_oper'], name, value)


                class Common(Entity):
                    """
                    Common Summary information
                    
                    .. attribute:: address_families
                    
                    	Address Families enabled
                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                    
                    .. attribute:: number_of_bindings_ipv4
                    
                    	Total number of ipv4 bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_bindings_ipv6
                    
                    	Total number of ipv6 bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_downstream_on_demand_neighbors
                    
                    	Number of Downstream\-On\-Demand neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_graceful_restart_neighbors
                    
                    	Number of Graceful Restart neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_hello_adj
                    
                    	Number of LDP discovery IPv4 hello adjacencies
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_local_addresses
                    
                    	Number of IPv4 local addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4_routes
                    
                    	Number of resolved IPv4 routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4af
                    
                    	Number of IPv4 address\-families enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv4ldp_interfaces
                    
                    	Number of LDP IPv4 configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_hello_adj
                    
                    	Number of LDP discovery IPv6 hello adjacencies
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_local_addresses
                    
                    	Number of IPv6 local addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6_routes
                    
                    	Number of resolved IPv6 routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6af
                    
                    	Number of IPv6 address\-families enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ipv6ldp_interfaces
                    
                    	Number of LDP IPv6 configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_ldp_interfaces
                    
                    	Number of LDP configured interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv4
                    
                    	Total number of ipv4 local label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_local_bindings_ipv6
                    
                    	Total number of ipv6 local label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_nsr_synced_neighbors
                    
                    	Number of NSR\-synced/operational neighbors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv4
                    
                    	Total number of ipv4 remote label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_remote_bindings_ipv6
                    
                    	Total number of ipv6 remote label bindings
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.Summary.Common, self).__init__()

                        self.yang_name = "common"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.address_families = YLeaf(YType.enumeration, "address-families")

                        self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                        self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                        self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                        self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                        self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                        self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                        self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                        self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                        self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                        self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                        self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                        self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                        self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                        self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                        self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                        self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                        self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                        self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                        self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                        self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                        self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                        self._segment_path = lambda: "common"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


            class Vrfs(Entity):
                """
                VRF specific operational data
                
                .. attribute:: vrf
                
                	Operational data for given VRF
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf>`
                
                

                """

                _prefix = 'mpls-ldp-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(MplsLdp.Nodes.Node.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf)}

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for given VRF
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: afs
                    
                    	Address Family specific operational data
                    	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs>`
                    
                    .. attribute:: backoff_parameters
                    
                    	The LDP Backoff Parameters
                    	**type**\:   :py:class:`BackoffParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters>`
                    
                    .. attribute:: backoffs
                    
                    	The LDP backoff
                    	**type**\:   :py:class:`Backoffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs>`
                    
                    .. attribute:: capabilities
                    
                    	LDP capability database information
                    	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities>`
                    
                    .. attribute:: graceful_restart
                    
                    	LDP Graceful Restart info
                    	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart>`
                    
                    .. attribute:: issu
                    
                    	LDP ISSU related information
                    	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu>`
                    
                    .. attribute:: ldp_id
                    
                    	Local LDP Id
                    	**type**\:   :py:class:`LdpId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId>`
                    
                    .. attribute:: neighbor_briefs
                    
                    	The LDP Neighbors (brief)
                    	**type**\:   :py:class:`NeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs>`
                    
                    .. attribute:: neighbor_capabilities
                    
                    	LDP Neighbors Capabilities
                    	**type**\:   :py:class:`NeighborCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities>`
                    
                    .. attribute:: neighbors
                    
                    	The LDP Neighbors
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors>`
                    
                    .. attribute:: nsr
                    
                    	LDP NSR related information
                    	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr>`
                    
                    .. attribute:: parameters
                    
                    	LDP parameters
                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters>`
                    
                    .. attribute:: statistics
                    
                    	The LDP Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics>`
                    
                    .. attribute:: summary
                    
                    	LDP VRF summary
                    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Summary>`
                    
                    

                    """

                    _prefix = 'mpls-ldp-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(MplsLdp.Nodes.Node.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"afs" : ("afs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs), "backoff-parameters" : ("backoff_parameters", MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters), "backoffs" : ("backoffs", MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs), "capabilities" : ("capabilities", MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities), "graceful-restart" : ("graceful_restart", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart), "issu" : ("issu", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu), "ldp-id" : ("ldp_id", MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId), "neighbor-briefs" : ("neighbor_briefs", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs), "neighbor-capabilities" : ("neighbor_capabilities", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities), "neighbors" : ("neighbors", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors), "nsr" : ("nsr", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr), "parameters" : ("parameters", MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters), "statistics" : ("statistics", MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics), "summary" : ("summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Summary)}
                        self._child_list_classes = {}

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.afs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"
                        self._children_yang_names.add("afs")

                        self.backoff_parameters = MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters()
                        self.backoff_parameters.parent = self
                        self._children_name_map["backoff_parameters"] = "backoff-parameters"
                        self._children_yang_names.add("backoff-parameters")

                        self.backoffs = MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs()
                        self.backoffs.parent = self
                        self._children_name_map["backoffs"] = "backoffs"
                        self._children_yang_names.add("backoffs")

                        self.capabilities = MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities()
                        self.capabilities.parent = self
                        self._children_name_map["capabilities"] = "capabilities"
                        self._children_yang_names.add("capabilities")

                        self.graceful_restart = MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart()
                        self.graceful_restart.parent = self
                        self._children_name_map["graceful_restart"] = "graceful-restart"
                        self._children_yang_names.add("graceful-restart")

                        self.issu = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"
                        self._children_yang_names.add("issu")

                        self.ldp_id = MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId()
                        self.ldp_id.parent = self
                        self._children_name_map["ldp_id"] = "ldp-id"
                        self._children_yang_names.add("ldp-id")

                        self.neighbor_briefs = MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs()
                        self.neighbor_briefs.parent = self
                        self._children_name_map["neighbor_briefs"] = "neighbor-briefs"
                        self._children_yang_names.add("neighbor-briefs")

                        self.neighbor_capabilities = MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities()
                        self.neighbor_capabilities.parent = self
                        self._children_name_map["neighbor_capabilities"] = "neighbor-capabilities"
                        self._children_yang_names.add("neighbor-capabilities")

                        self.neighbors = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                        self._children_yang_names.add("neighbors")

                        self.nsr = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                        self._children_yang_names.add("nsr")

                        self.parameters = MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters()
                        self.parameters.parent = self
                        self._children_name_map["parameters"] = "parameters"
                        self._children_yang_names.add("parameters")

                        self.statistics = MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                        self.summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                        self._children_yang_names.add("summary")
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf, ['vrf_name'], name, value)


                    class Afs(Entity):
                        """
                        Address Family specific operational data
                        
                        .. attribute:: af
                        
                        	Operational data for given Address Family
                        	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"af" : ("af", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af)}

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            Operational data for given Address Family
                            
                            .. attribute:: af_name  <key>
                            
                            	Address Family name
                            	**type**\:   :py:class:`MplsLdpOperAfName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdpOperAfName>`
                            
                            .. attribute:: bindings
                            
                            	The LDP Bindings
                            	**type**\:   :py:class:`Bindings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings>`
                            
                            .. attribute:: bindings_advertise_spec
                            
                            	Advertisement Spec (ACL) for LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsAdvertiseSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec>`
                            
                            .. attribute:: bindings_summary
                            
                            	Counters for the LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary>`
                            
                            .. attribute:: bindings_summary_all
                            
                            	Aggregate VRF counters for the LDP Label Infomation Base (LIB)
                            	**type**\:   :py:class:`BindingsSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll>`
                            
                            .. attribute:: discovery
                            
                            	The LDP Discovery
                            	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery>`
                            
                            .. attribute:: forwarding_summary
                            
                            	Summary information regarding LDP forwarding setup
                            	**type**\:   :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary>`
                            
                            .. attribute:: forwardings
                            
                            	The LDP Forwarding rewrites
                            	**type**\:   :py:class:`Forwardings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings>`
                            
                            .. attribute:: igp
                            
                            	LDP IGP related information
                            	**type**\:   :py:class:`Igp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp>`
                            
                            .. attribute:: interface_summary
                            
                            	IPv4 interface summary information
                            	**type**\:   :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary>`
                            
                            .. attribute:: interfaces
                            
                            	LDP Interface related information
                            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"bindings" : ("bindings", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings), "bindings-advertise-spec" : ("bindings_advertise_spec", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec), "bindings-summary" : ("bindings_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary), "bindings-summary-all" : ("bindings_summary_all", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll), "discovery" : ("discovery", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery), "forwarding-summary" : ("forwarding_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary), "forwardings" : ("forwardings", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings), "igp" : ("igp", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp), "interface-summary" : ("interface_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary), "interfaces" : ("interfaces", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces)}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.bindings = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings()
                                self.bindings.parent = self
                                self._children_name_map["bindings"] = "bindings"
                                self._children_yang_names.add("bindings")

                                self.bindings_advertise_spec = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec()
                                self.bindings_advertise_spec.parent = self
                                self._children_name_map["bindings_advertise_spec"] = "bindings-advertise-spec"
                                self._children_yang_names.add("bindings-advertise-spec")

                                self.bindings_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary()
                                self.bindings_summary.parent = self
                                self._children_name_map["bindings_summary"] = "bindings-summary"
                                self._children_yang_names.add("bindings-summary")

                                self.bindings_summary_all = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll()
                                self.bindings_summary_all.parent = self
                                self._children_name_map["bindings_summary_all"] = "bindings-summary-all"
                                self._children_yang_names.add("bindings-summary-all")

                                self.discovery = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery()
                                self.discovery.parent = self
                                self._children_name_map["discovery"] = "discovery"
                                self._children_yang_names.add("discovery")

                                self.forwarding_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary()
                                self.forwarding_summary.parent = self
                                self._children_name_map["forwarding_summary"] = "forwarding-summary"
                                self._children_yang_names.add("forwarding-summary")

                                self.forwardings = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings()
                                self.forwardings.parent = self
                                self._children_name_map["forwardings"] = "forwardings"
                                self._children_yang_names.add("forwardings")

                                self.igp = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp()
                                self.igp.parent = self
                                self._children_name_map["igp"] = "igp"
                                self._children_yang_names.add("igp")

                                self.interface_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary()
                                self.interface_summary.parent = self
                                self._children_name_map["interface_summary"] = "interface-summary"
                                self._children_yang_names.add("interface-summary")

                                self.interfaces = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"
                                self._children_yang_names.add("interfaces")
                                self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                            class Bindings(Entity):
                                """
                                The LDP Bindings
                                
                                .. attribute:: binding
                                
                                	Binding Information
                                	**type**\: list of    :py:class:`Binding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings, self).__init__()

                                    self.yang_name = "bindings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"binding" : ("binding", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding)}

                                    self.binding = YList(self)
                                    self._segment_path = lambda: "bindings"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings, [], name, value)


                                class Binding(Entity):
                                    """
                                    Binding Information
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	The IP Prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: advertise_prefix_acl
                                    
                                    	Advertise Prerfix ACL
                                    	**type**\:  str
                                    
                                    .. attribute:: advertise_tsr_acl
                                    
                                    	Advertise TSR ACL
                                    	**type**\:  str
                                    
                                    .. attribute:: config_enforced_local_label_value
                                    
                                    	Config/User enforced local label value
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_elc
                                    
                                    	Is the entry entropy label capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_no_route
                                    
                                    	No route
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_oor
                                    
                                    	Label space depletion OOR
                                    	**type**\:  bool
                                    
                                    .. attribute:: le_local_binding_revision
                                    
                                    	Local Binding revision
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: le_local_label_state
                                    
                                    	Local label state
                                    	**type**\:   :py:class:`LocalLabelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LocalLabelState>`
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peers_acked
                                    
                                    	Peers that have ACKed this entry
                                    	**type**\: list of    :py:class:`PeersAcked <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked>`
                                    
                                    .. attribute:: peers_advertised_to
                                    
                                    	Peers this entry is advertised to
                                    	**type**\: list of    :py:class:`PeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr>`
                                    
                                    .. attribute:: remote_binding
                                    
                                    	Remote binding
                                    	**type**\: list of    :py:class:`RemoteBinding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding, self).__init__()

                                        self.yang_name = "binding"
                                        self.yang_parent_name = "bindings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr), "vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf)}
                                        self._child_list_classes = {"peers-acked" : ("peers_acked", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked), "peers-advertised-to" : ("peers_advertised_to", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo), "remote-binding" : ("remote_binding", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.advertise_prefix_acl = YLeaf(YType.str, "advertise-prefix-acl")

                                        self.advertise_tsr_acl = YLeaf(YType.str, "advertise-tsr-acl")

                                        self.config_enforced_local_label_value = YLeaf(YType.boolean, "config-enforced-local-label-value")

                                        self.is_elc = YLeaf(YType.boolean, "is-elc")

                                        self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.le_local_binding_revision = YLeaf(YType.uint32, "le-local-binding-revision")

                                        self.le_local_label_state = YLeaf(YType.enumeration, "le-local-label-state")

                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.prefix_xr = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"
                                        self._children_yang_names.add("prefix-xr")

                                        self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.peers_acked = YList(self)
                                        self.peers_advertised_to = YList(self)
                                        self.remote_binding = YList(self)
                                        self._segment_path = lambda: "binding" + "[prefix='" + self.prefix.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding, ['prefix', 'advertise_prefix_acl', 'advertise_tsr_acl', 'config_enforced_local_label_value', 'is_elc', 'is_no_route', 'label_oor', 'le_local_binding_revision', 'le_local_label_state', 'local_label', 'prefix_length'], name, value)


                                    class PeersAcked(Entity):
                                        """
                                        Peers that have ACKed this entry
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, self).__init__()

                                            self.yang_name = "peers-acked"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "peers-acked"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAcked, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class PeersAdvertisedTo(Entity):
                                        """
                                        Peers this entry is advertised to
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ldp_id
                                        
                                        	LDP identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR identifier
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, self).__init__()

                                            self.yang_name = "peers-advertised-to"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                                            self._segment_path = lambda: "peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PeersAdvertisedTo, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "prefix-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class RemoteBinding(Entity):
                                        """
                                        Remote binding
                                        
                                        .. attribute:: assigning_peer_ldp_ident
                                        
                                        	Assigning peer
                                        	**type**\:   :py:class:`AssigningPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent>`
                                        
                                        .. attribute:: is_elc
                                        
                                        	Is the entry entropy label capable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_stale
                                        
                                        	Is the entry stale
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, self).__init__()

                                            self.yang_name = "remote-binding"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"assigning-peer-ldp-ident" : ("assigning_peer_ldp_ident", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent)}
                                            self._child_list_classes = {}

                                            self.is_elc = YLeaf(YType.boolean, "is-elc")

                                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                                            self.remote_label = YLeaf(YType.uint32, "remote-label")

                                            self.assigning_peer_ldp_ident = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent()
                                            self.assigning_peer_ldp_ident.parent = self
                                            self._children_name_map["assigning_peer_ldp_ident"] = "assigning-peer-ldp-ident"
                                            self._children_yang_names.add("assigning-peer-ldp-ident")
                                            self._segment_path = lambda: "remote-binding"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding, ['is_elc', 'is_stale', 'remote_label'], name, value)


                                        class AssigningPeerLdpIdent(Entity):
                                            """
                                            Assigning peer
                                            
                                            .. attribute:: label_space_id
                                            
                                            	Label space identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ldp_id
                                            
                                            	LDP identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: lsr_id
                                            
                                            	LSR identifier
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, self).__init__()

                                                self.yang_name = "assigning-peer-ldp-ident"
                                                self.yang_parent_name = "remote-binding"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                self._segment_path = lambda: "assigning-peer-ldp-ident"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.RemoteBinding.AssigningPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "binding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Bindings.Binding.Vrf, ['id', 'name'], name, value)


                            class BindingsAdvertiseSpec(Entity):
                                """
                                Advertisement Spec (ACL) for LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: advt_acl
                                
                                	Advertisement ACLs
                                	**type**\: list of    :py:class:`AdvtAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl>`
                                
                                .. attribute:: allocation_acl
                                
                                	Local label Allocation filter
                                	**type**\:   :py:class:`AllocationAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, self).__init__()

                                    self.yang_name = "bindings-advertise-spec"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"allocation-acl" : ("allocation_acl", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl)}
                                    self._child_list_classes = {"advt-acl" : ("advt_acl", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl)}

                                    self.allocation_acl = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl()
                                    self.allocation_acl.parent = self
                                    self._children_name_map["allocation_acl"] = "allocation-acl"
                                    self._children_yang_names.add("allocation-acl")

                                    self.advt_acl = YList(self)
                                    self._segment_path = lambda: "bindings-advertise-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec, [], name, value)


                                class AdvtAcl(Entity):
                                    """
                                    Advertisement ACLs
                                    
                                    .. attribute:: peer_acl
                                    
                                    	Peer ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, self).__init__()

                                        self.yang_name = "advt-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.peer_acl = YLeaf(YType.str, "peer-acl")

                                        self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                        self._segment_path = lambda: "advt-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AdvtAcl, ['peer_acl', 'prefix_acl'], name, value)


                                class AllocationAcl(Entity):
                                    """
                                    Local label Allocation filter
                                    
                                    .. attribute:: has_acl
                                    
                                    	Has ACL filter?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_host_route_only
                                    
                                    	Host\-routes only?
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_acl
                                    
                                    	Prefix ACL
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, self).__init__()

                                        self.yang_name = "allocation-acl"
                                        self.yang_parent_name = "bindings-advertise-spec"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.has_acl = YLeaf(YType.boolean, "has-acl")

                                        self.is_host_route_only = YLeaf(YType.boolean, "is-host-route-only")

                                        self.prefix_acl = YLeaf(YType.str, "prefix-acl")
                                        self._segment_path = lambda: "allocation-acl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsAdvertiseSpec.AllocationAcl, ['has_acl', 'is_host_route_only', 'prefix_acl'], name, value)


                            class BindingsSummary(Entity):
                                """
                                Counters for the LDP Label Infomation Base
                                (LIB)
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf>`
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary, self).__init__()

                                    self.yang_name = "bindings-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf)}
                                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf)}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                    self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.address_family = YLeaf(YType.enumeration, "address-family")

                                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                        self._segment_path = lambda: "bind-af"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummary.Vrf, ['id', 'name'], name, value)


                            class BindingsSummaryAll(Entity):
                                """
                                Aggregate VRF counters for the LDP Label
                                Infomation Base (LIB)
                                
                                .. attribute:: address_family
                                
                                	Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: bind_af
                                
                                	bind af
                                	**type**\: list of    :py:class:`BindAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf>`
                                
                                .. attribute:: binding_local_explicit_null
                                
                                	Number of local explicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_implicit_null
                                
                                	Number of local implicit null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_no_route
                                
                                	Local bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_non_null
                                
                                	Number of local non\-null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_null
                                
                                	Number of local null bindings
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_local_oor
                                
                                	Number of local bindings        needing label \- OOR
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_no_route
                                
                                	Bindings with no route
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: highest_allocated_label
                                
                                	Highest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lowest_allocated_label
                                
                                	Lowest allocated label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll, self).__init__()

                                    self.yang_name = "bindings-summary-all"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf)}
                                    self._child_list_classes = {"bind-af" : ("bind_af", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf)}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.binding_local_explicit_null = YLeaf(YType.uint32, "binding-local-explicit-null")

                                    self.binding_local_implicit_null = YLeaf(YType.uint32, "binding-local-implicit-null")

                                    self.binding_local_no_route = YLeaf(YType.uint32, "binding-local-no-route")

                                    self.binding_local_non_null = YLeaf(YType.uint32, "binding-local-non-null")

                                    self.binding_local_null = YLeaf(YType.uint32, "binding-local-null")

                                    self.binding_local_oor = YLeaf(YType.uint32, "binding-local-oor")

                                    self.binding_no_route = YLeaf(YType.uint32, "binding-no-route")

                                    self.highest_allocated_label = YLeaf(YType.uint32, "highest-allocated-label")

                                    self.lowest_allocated_label = YLeaf(YType.uint32, "lowest-allocated-label")

                                    self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")

                                    self.bind_af = YList(self)
                                    self._segment_path = lambda: "bindings-summary-all"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll, ['address_family', 'binding_local_explicit_null', 'binding_local_implicit_null', 'binding_local_no_route', 'binding_local_non_null', 'binding_local_null', 'binding_local_oor', 'binding_no_route', 'highest_allocated_label', 'lowest_allocated_label'], name, value)


                                class BindAf(Entity):
                                    """
                                    bind af
                                    
                                    .. attribute:: address_family
                                    
                                    	Binding Summary Address Family
                                    	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                    
                                    .. attribute:: binding_local
                                    
                                    	Number of local bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_remote
                                    
                                    	Number of remote bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: binding_total
                                    
                                    	Total bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_lib_update
                                    
                                    	Last update to LIB local binding
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lib_minimum_revision_sent_all
                                    
                                    	Last update sent to all peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf, self).__init__()

                                        self.yang_name = "bind-af"
                                        self.yang_parent_name = "bindings-summary-all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.address_family = YLeaf(YType.enumeration, "address-family")

                                        self.binding_local = YLeaf(YType.uint32, "binding-local")

                                        self.binding_remote = YLeaf(YType.uint32, "binding-remote")

                                        self.binding_total = YLeaf(YType.uint32, "binding-total")

                                        self.last_lib_update = YLeaf(YType.uint32, "last-lib-update")

                                        self.lib_minimum_revision_sent_all = YLeaf(YType.uint32, "lib-minimum-revision-sent-all")
                                        self._segment_path = lambda: "bind-af"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.BindAf, ['address_family', 'binding_local', 'binding_remote', 'binding_total', 'last_lib_update', 'lib_minimum_revision_sent_all'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "bindings-summary-all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.BindingsSummaryAll.Vrf, ['id', 'name'], name, value)


                            class Discovery(Entity):
                                """
                                The LDP Discovery
                                
                                .. attribute:: brief
                                
                                	Brief information on LDP discovery
                                	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief>`
                                
                                .. attribute:: link_hellos
                                
                                	The LDP Discovery link
                                	**type**\:   :py:class:`LinkHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos>`
                                
                                .. attribute:: stats
                                
                                	The LDP Discovery Statistics
                                	**type**\:   :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats>`
                                
                                .. attribute:: summary
                                
                                	Summarized information on LDP discovery
                                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary>`
                                
                                .. attribute:: targeted_hellos
                                
                                	The LDP Discovery Targeted
                                	**type**\:   :py:class:`TargetedHellos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery, self).__init__()

                                    self.yang_name = "discovery"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"brief" : ("brief", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief), "link-hellos" : ("link_hellos", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos), "stats" : ("stats", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats), "summary" : ("summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary), "targeted-hellos" : ("targeted_hellos", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos)}
                                    self._child_list_classes = {}

                                    self.brief = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief()
                                    self.brief.parent = self
                                    self._children_name_map["brief"] = "brief"
                                    self._children_yang_names.add("brief")

                                    self.link_hellos = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos()
                                    self.link_hellos.parent = self
                                    self._children_name_map["link_hellos"] = "link-hellos"
                                    self._children_yang_names.add("link-hellos")

                                    self.stats = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats()
                                    self.stats.parent = self
                                    self._children_name_map["stats"] = "stats"
                                    self._children_yang_names.add("stats")

                                    self.summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary()
                                    self.summary.parent = self
                                    self._children_name_map["summary"] = "summary"
                                    self._children_yang_names.add("summary")

                                    self.targeted_hellos = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos()
                                    self.targeted_hellos.parent = self
                                    self._children_name_map["targeted_hellos"] = "targeted-hellos"
                                    self._children_yang_names.add("targeted-hellos")
                                    self._segment_path = lambda: "discovery"


                                class Brief(Entity):
                                    """
                                    Brief information on LDP discovery
                                    
                                    .. attribute:: link_hello_briefs
                                    
                                    	The LDP Discovery link brief information
                                    	**type**\:   :py:class:`LinkHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs>`
                                    
                                    .. attribute:: targeted_hello_briefs
                                    
                                    	The LDP Discovery Targeted brief information
                                    	**type**\:   :py:class:`TargetedHelloBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief, self).__init__()

                                        self.yang_name = "brief"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-briefs" : ("link_hello_briefs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs), "targeted-hello-briefs" : ("targeted_hello_briefs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs)}
                                        self._child_list_classes = {}

                                        self.link_hello_briefs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs()
                                        self.link_hello_briefs.parent = self
                                        self._children_name_map["link_hello_briefs"] = "link-hello-briefs"
                                        self._children_yang_names.add("link-hello-briefs")

                                        self.targeted_hello_briefs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs()
                                        self.targeted_hello_briefs.parent = self
                                        self._children_name_map["targeted_hello_briefs"] = "targeted-hello-briefs"
                                        self._children_yang_names.add("targeted-hello-briefs")
                                        self._segment_path = lambda: "brief"


                                    class LinkHelloBriefs(Entity):
                                        """
                                        The LDP Discovery link brief information
                                        
                                        .. attribute:: link_hello_brief
                                        
                                        	Brief information on LDP link discovery
                                        	**type**\: list of    :py:class:`LinkHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, self).__init__()

                                            self.yang_name = "link-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"link-hello-brief" : ("link_hello_brief", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief)}

                                            self.link_hello_brief = YList(self)
                                            self._segment_path = lambda: "link-hello-briefs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs, [], name, value)


                                        class LinkHelloBrief(Entity):
                                            """
                                            Brief information on LDP link discovery
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	The Interface Name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: address_family
                                            
                                            	Discovery Brief Address Family
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: address_family_set
                                            
                                            	Discovery Brief Address Family Set
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation>`
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: interface_name_xr
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, self).__init__()

                                                self.yang_name = "link-hello-brief"
                                                self.yang_parent_name = "link-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf)}
                                                self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation)}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                                self.address_family_set = YLeaf(YType.enumeration, "address-family-set")

                                                self.interface = YLeaf(YType.str, "interface")

                                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"
                                                self._children_yang_names.add("vrf")

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "link-hello-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief, ['interface_name', 'address_family', 'address_family_set', 'interface', 'interface_name_xr'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                    self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                    self.session_up = YLeaf(YType.boolean, "session-up")
                                                    self._segment_path = lambda: "hello-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                            class Vrf(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "link-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.id = YLeaf(YType.uint32, "id")

                                                    self.name = YLeaf(YType.str, "name")
                                                    self._segment_path = lambda: "vrf"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.LinkHelloBriefs.LinkHelloBrief.Vrf, ['id', 'name'], name, value)


                                    class TargetedHelloBriefs(Entity):
                                        """
                                        The LDP Discovery Targeted brief information
                                        
                                        .. attribute:: targeted_hello_brief
                                        
                                        	Brief information on LDP targeted discovery
                                        	**type**\: list of    :py:class:`TargetedHelloBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, self).__init__()

                                            self.yang_name = "targeted-hello-briefs"
                                            self.yang_parent_name = "brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"targeted-hello-brief" : ("targeted_hello_brief", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief)}

                                            self.targeted_hello_brief = YList(self)
                                            self._segment_path = lambda: "targeted-hello-briefs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs, [], name, value)


                                        class TargetedHelloBrief(Entity):
                                            """
                                            Brief information on LDP targeted discovery
                                            
                                            .. attribute:: address_family
                                            
                                            	Targeted Discovery Address Family
                                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                            
                                            .. attribute:: dhcb_target_address
                                            
                                            	DHCB target address
                                            	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress>`
                                            
                                            .. attribute:: hello_information
                                            
                                            	LDP hello info
                                            	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation>`
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: target_address
                                            
                                            	The target IP Address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: vrf
                                            
                                            	VRF information
                                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, self).__init__()

                                                self.yang_name = "targeted-hello-brief"
                                                self.yang_parent_name = "targeted-hello-briefs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"dhcb-target-address" : ("dhcb_target_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress), "vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf)}
                                                self._child_list_classes = {"hello-information" : ("hello_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation)}

                                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                                self.local_address = YLeaf(YType.str, "local-address")

                                                self.target_address = YLeaf(YType.str, "target-address")

                                                self.dhcb_target_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress()
                                                self.dhcb_target_address.parent = self
                                                self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                                self._children_yang_names.add("dhcb-target-address")

                                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf()
                                                self.vrf.parent = self
                                                self._children_name_map["vrf"] = "vrf"
                                                self._children_yang_names.add("vrf")

                                                self.hello_information = YList(self)
                                                self._segment_path = lambda: "targeted-hello-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief, ['address_family', 'local_address', 'target_address'], name, value)


                                            class DhcbTargetAddress(Entity):
                                                """
                                                DHCB target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, self).__init__()

                                                    self.yang_name = "dhcb-target-address"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "dhcb-target-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class HelloInformation(Entity):
                                                """
                                                LDP hello info
                                                
                                                .. attribute:: hold_time
                                                
                                                	Session hold time in sec
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_ldp_identifier
                                                
                                                	Neighbor LDP Identifier
                                                	**type**\:  str
                                                
                                                .. attribute:: session_up
                                                
                                                	Is session up for this adj
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, self).__init__()

                                                    self.yang_name = "hello-information"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                    self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                    self.session_up = YLeaf(YType.boolean, "session-up")
                                                    self._segment_path = lambda: "hello-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.HelloInformation, ['hold_time', 'neighbor_ldp_identifier', 'session_up'], name, value)


                                            class Vrf(Entity):
                                                """
                                                VRF information
                                                
                                                .. attribute:: id
                                                
                                                	VRF Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: name
                                                
                                                	VRF Name
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, self).__init__()

                                                    self.yang_name = "vrf"
                                                    self.yang_parent_name = "targeted-hello-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.id = YLeaf(YType.uint32, "id")

                                                    self.name = YLeaf(YType.str, "name")
                                                    self._segment_path = lambda: "vrf"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Brief.TargetedHelloBriefs.TargetedHelloBrief.Vrf, ['id', 'name'], name, value)


                                class LinkHellos(Entity):
                                    """
                                    The LDP Discovery link
                                    
                                    .. attribute:: link_hello
                                    
                                    	Information on LDP link discovery
                                    	**type**\: list of    :py:class:`LinkHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, self).__init__()

                                        self.yang_name = "link-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"link-hello" : ("link_hello", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello)}

                                        self.link_hello = YList(self)
                                        self._segment_path = lambda: "link-hellos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos, [], name, value)


                                    class LinkHello(Entity):
                                        """
                                        Information on LDP link discovery
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: discovery_link_af
                                        
                                        	LDP hello AF info
                                        	**type**\: list of    :py:class:`DiscoveryLinkAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf>`
                                        
                                        .. attribute:: hello_information
                                        
                                        	LDP hello info
                                        	**type**\: list of    :py:class:`HelloInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation>`
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, self).__init__()

                                            self.yang_name = "link-hello"
                                            self.yang_parent_name = "link-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf)}
                                            self._child_list_classes = {"discovery-link-af" : ("discovery_link_af", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf), "hello-information" : ("hello_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.next_hello = YLeaf(YType.uint32, "next-hello")

                                            self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                            self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.discovery_link_af = YList(self)
                                            self.hello_information = YList(self)
                                            self._segment_path = lambda: "link-hello" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello, ['interface_name', 'interface', 'interface_name_xr', 'next_hello', 'quick_start_disabled'], name, value)


                                        class DiscoveryLinkAf(Entity):
                                            """
                                            LDP hello AF info
                                            
                                            .. attribute:: interval
                                            
                                            	Hello interval in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_src_address
                                            
                                            	Local source address
                                            	**type**\:   :py:class:`LocalSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress>`
                                            
                                            .. attribute:: local_transport_address
                                            
                                            	Local transport address
                                            	**type**\:   :py:class:`LocalTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, self).__init__()

                                                self.yang_name = "discovery-link-af"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"local-src-address" : ("local_src_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress), "local-transport-address" : ("local_transport_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress)}
                                                self._child_list_classes = {}

                                                self.interval = YLeaf(YType.uint32, "interval")

                                                self.local_src_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress()
                                                self.local_src_address.parent = self
                                                self._children_name_map["local_src_address"] = "local-src-address"
                                                self._children_yang_names.add("local-src-address")

                                                self.local_transport_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress()
                                                self.local_transport_address.parent = self
                                                self._children_name_map["local_transport_address"] = "local-transport-address"
                                                self._children_yang_names.add("local-transport-address")
                                                self._segment_path = lambda: "discovery-link-af"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf, ['interval'], name, value)


                                            class LocalSrcAddress(Entity):
                                                """
                                                Local source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, self).__init__()

                                                    self.yang_name = "local-src-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "local-src-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class LocalTransportAddress(Entity):
                                                """
                                                Local transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, self).__init__()

                                                    self.yang_name = "local-transport-address"
                                                    self.yang_parent_name = "discovery-link-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "local-transport-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.DiscoveryLinkAf.LocalTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class HelloInformation(Entity):
                                            """
                                            LDP hello info
                                            
                                            .. attribute:: disc_expiry
                                            
                                            	Discovery expiry time in sec
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: established_age
                                            
                                            	Hello adjacency estabished age in nanosec
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: established_time
                                            
                                            	Hello adjacency estabished time in nanosec
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: hold_time
                                            
                                            	Session hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: is_no_route
                                            
                                            	Is route valid
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_targeted
                                            
                                            	Is session a targeted session
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_session_down_info
                                            
                                            	Last session down information
                                            	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo>`
                                            
                                            .. attribute:: local_hold_time
                                            
                                            	Local hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_hold_time
                                            
                                            	Neighbor hold time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_ldp_identifier
                                            
                                            	Neighbor LDP Identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_src_address
                                            
                                            	Neighbor source address
                                            	**type**\:   :py:class:`NeighborSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress>`
                                            
                                            .. attribute:: neighbor_transport_address
                                            
                                            	Neighbor transport address
                                            	**type**\:   :py:class:`NeighborTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress>`
                                            
                                            .. attribute:: session_bringup_failure_reason
                                            
                                            	session bringup failure reason
                                            	**type**\:  str
                                            
                                            .. attribute:: session_up
                                            
                                            	Is session up for this adj
                                            	**type**\:  bool
                                            
                                            .. attribute:: target
                                            
                                            	Target address
                                            	**type**\:   :py:class:`Target <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, self).__init__()

                                                self.yang_name = "hello-information"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-src-address" : ("neighbor_src_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress), "neighbor-transport-address" : ("neighbor_transport_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress), "target" : ("target", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target)}
                                                self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo)}

                                                self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                                self.established_age = YLeaf(YType.uint64, "established-age")

                                                self.established_time = YLeaf(YType.uint64, "established-time")

                                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                                self.is_no_route = YLeaf(YType.boolean, "is-no-route")

                                                self.is_targeted = YLeaf(YType.boolean, "is-targeted")

                                                self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                                self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                                self.neighbor_ldp_identifier = YLeaf(YType.str, "neighbor-ldp-identifier")

                                                self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                                self.session_up = YLeaf(YType.boolean, "session-up")

                                                self.neighbor_src_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress()
                                                self.neighbor_src_address.parent = self
                                                self._children_name_map["neighbor_src_address"] = "neighbor-src-address"
                                                self._children_yang_names.add("neighbor-src-address")

                                                self.neighbor_transport_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress()
                                                self.neighbor_transport_address.parent = self
                                                self._children_name_map["neighbor_transport_address"] = "neighbor-transport-address"
                                                self._children_yang_names.add("neighbor-transport-address")

                                                self.target = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target()
                                                self.target.parent = self
                                                self._children_name_map["target"] = "target"
                                                self._children_yang_names.add("target")

                                                self.last_session_down_info = YList(self)
                                                self._segment_path = lambda: "hello-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation, ['disc_expiry', 'established_age', 'established_time', 'hold_time', 'is_no_route', 'is_targeted', 'local_hold_time', 'neighbor_hold_time', 'neighbor_ldp_identifier', 'session_bringup_failure_reason', 'session_up'], name, value)


                                            class LastSessionDownInfo(Entity):
                                                """
                                                Last session down information
                                                
                                                .. attribute:: last_session_down_reason
                                                
                                                	The reason of last socket failure
                                                	**type**\:  str
                                                
                                                .. attribute:: last_session_down_time
                                                
                                                	Timestamp of when the last session went down
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: last_session_up_time
                                                
                                                	The time duration the last session was up
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, self).__init__()

                                                    self.yang_name = "last-session-down-info"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                    self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                    self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                    self._segment_path = lambda: "last-session-down-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                                            class NeighborSrcAddress(Entity):
                                                """
                                                Neighbor source address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, self).__init__()

                                                    self.yang_name = "neighbor-src-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "neighbor-src-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborSrcAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class NeighborTransportAddress(Entity):
                                                """
                                                Neighbor transport address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, self).__init__()

                                                    self.yang_name = "neighbor-transport-address"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "neighbor-transport-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.NeighborTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class Target(Entity):
                                                """
                                                Target address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, self).__init__()

                                                    self.yang_name = "target"
                                                    self.yang_parent_name = "hello-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "target"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.HelloInformation.Target, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "link-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.LinkHellos.LinkHello.Vrf, ['id', 'name'], name, value)


                                class Stats(Entity):
                                    """
                                    The LDP Discovery Statistics
                                    
                                    .. attribute:: stat
                                    
                                    	Information on LDP discovery statistics
                                    	**type**\: list of    :py:class:`Stat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats, self).__init__()

                                        self.yang_name = "stats"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"stat" : ("stat", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat)}

                                        self.stat = YList(self)
                                        self._segment_path = lambda: "stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats, [], name, value)


                                    class Stat(Entity):
                                        """
                                        Information on LDP discovery statistics
                                        
                                        .. attribute:: adjacency_group_up_time
                                        
                                        	Adjacency group up time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: label_space_id
                                        
                                        	Label space ID of neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsr_id
                                        
                                        	LSR ID of neighbor
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: tcp_arb_chg_count
                                        
                                        	Count of changes in TCP arbitration
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_open_count
                                        
                                        	Count of attempted TCP opens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tcp_role
                                        
                                        	TCP Role
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, self).__init__()

                                            self.yang_name = "stat"
                                            self.yang_parent_name = "stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.adjacency_group_up_time = YLeaf(YType.uint32, "adjacency-group-up-time")

                                            self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                            self.lsr_id = YLeaf(YType.str, "lsr-id")

                                            self.tcp_arb_chg_count = YLeaf(YType.uint32, "tcp-arb-chg-count")

                                            self.tcp_open_count = YLeaf(YType.uint32, "tcp-open-count")

                                            self.tcp_role = YLeaf(YType.uint32, "tcp-role")
                                            self._segment_path = lambda: "stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Stats.Stat, ['adjacency_group_up_time', 'label_space_id', 'lsr_id', 'tcp_arb_chg_count', 'tcp_open_count', 'tcp_role'], name, value)


                                class Summary(Entity):
                                    """
                                    Summarized information on LDP discovery
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: num_of_active_ldp_interfaces
                                    
                                    	Number of active LDP enabled interfaces
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_addr_recv
                                    
                                    	Number of hello discoveries received with bad source address
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_hello_pdu
                                    
                                    	Number of hello discoveries received with bad hello PDU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_bad_xport_addr
                                    
                                    	Number of hello discoveries received with bad export address
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_same_router_id
                                    
                                    	Number of hello discoveries received with the same router id as this router
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_disc_with_wrong_router_id
                                    
                                    	Number of hello discoveries received with the router id that is not destined for this router
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_ldp_interfaces
                                    
                                    	Total Number of LDP configured interfaces
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_recv
                                    
                                    	Number of link hello discoveries in recv state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_lnk_disc_xmit
                                    
                                    	Number of link hello discoveries in xmit state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_recv
                                    
                                    	Number of targeted hello discoveries in recv state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_tgt_disc_xmit
                                    
                                    	Number of targeted hello discoveries in xmit state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary, self).__init__()

                                        self.yang_name = "summary"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf)}
                                        self._child_list_classes = {}

                                        self.local_ldp_id = YLeaf(YType.str, "local-ldp-id")

                                        self.num_of_active_ldp_interfaces = YLeaf(YType.uint32, "num-of-active-ldp-interfaces")

                                        self.num_of_disc_with_bad_addr_recv = YLeaf(YType.uint32, "num-of-disc-with-bad-addr-recv")

                                        self.num_of_disc_with_bad_hello_pdu = YLeaf(YType.uint32, "num-of-disc-with-bad-hello-pdu")

                                        self.num_of_disc_with_bad_xport_addr = YLeaf(YType.uint32, "num-of-disc-with-bad-xport-addr")

                                        self.num_of_disc_with_same_router_id = YLeaf(YType.uint32, "num-of-disc-with-same-router-id")

                                        self.num_of_disc_with_wrong_router_id = YLeaf(YType.uint32, "num-of-disc-with-wrong-router-id")

                                        self.num_of_ldp_interfaces = YLeaf(YType.uint32, "num-of-ldp-interfaces")

                                        self.num_of_lnk_disc_recv = YLeaf(YType.uint32, "num-of-lnk-disc-recv")

                                        self.num_of_lnk_disc_xmit = YLeaf(YType.uint32, "num-of-lnk-disc-xmit")

                                        self.num_of_tgt_disc_recv = YLeaf(YType.uint32, "num-of-tgt-disc-recv")

                                        self.num_of_tgt_disc_xmit = YLeaf(YType.uint32, "num-of-tgt-disc-xmit")

                                        self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary, ['local_ldp_id', 'num_of_active_ldp_interfaces', 'num_of_disc_with_bad_addr_recv', 'num_of_disc_with_bad_hello_pdu', 'num_of_disc_with_bad_xport_addr', 'num_of_disc_with_same_router_id', 'num_of_disc_with_wrong_router_id', 'num_of_ldp_interfaces', 'num_of_lnk_disc_recv', 'num_of_lnk_disc_xmit', 'num_of_tgt_disc_recv', 'num_of_tgt_disc_xmit'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.Summary.Vrf, ['id', 'name'], name, value)


                                class TargetedHellos(Entity):
                                    """
                                    The LDP Discovery Targeted
                                    
                                    .. attribute:: targeted_hello
                                    
                                    	Information on LDP targeted discovery
                                    	**type**\: list of    :py:class:`TargetedHello <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, self).__init__()

                                        self.yang_name = "targeted-hellos"
                                        self.yang_parent_name = "discovery"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"targeted-hello" : ("targeted_hello", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello)}

                                        self.targeted_hello = YList(self)
                                        self._segment_path = lambda: "targeted-hellos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos, [], name, value)


                                    class TargetedHello(Entity):
                                        """
                                        Information on LDP targeted discovery
                                        
                                        .. attribute:: adjacency_ldp_identifier
                                        
                                        	Adjacency LDP Identifier
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcb_local_address
                                        
                                        	DHCB local address
                                        	**type**\:   :py:class:`DhcbLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress>`
                                        
                                        .. attribute:: dhcb_target_address
                                        
                                        	DHCB target address
                                        	**type**\:   :py:class:`DhcbTargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress>`
                                        
                                        .. attribute:: disc_expiry
                                        
                                        	Discovery expiry time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: established_age
                                        
                                        	Hello adjacency estabished age in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: established_time
                                        
                                        	Hello adjacency estabished time in nanosec
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: hold_time
                                        
                                        	Targeted hello hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval in sec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_session_down_info
                                        
                                        	Last session down information
                                        	**type**\: list of    :py:class:`LastSessionDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo>`
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: local_hold_time
                                        
                                        	Local hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_hold_time
                                        
                                        	Neighbor hold time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hello
                                        
                                        	Next hello due time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: quick_start_disabled
                                        
                                        	Quick\-start disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: session_bringup_failure_reason
                                        
                                        	session bringup failure reason
                                        	**type**\:  str
                                        
                                        .. attribute:: session_up
                                        
                                        	Is session up for this adj
                                        	**type**\:  bool
                                        
                                        .. attribute:: state
                                        
                                        	Targeted hello state
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	The target IP Address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, self).__init__()

                                            self.yang_name = "targeted-hello"
                                            self.yang_parent_name = "targeted-hellos"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"dhcb-local-address" : ("dhcb_local_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress), "dhcb-target-address" : ("dhcb_target_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress)}
                                            self._child_list_classes = {"last-session-down-info" : ("last_session_down_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo)}

                                            self.adjacency_ldp_identifier = YLeaf(YType.str, "adjacency-ldp-identifier")

                                            self.disc_expiry = YLeaf(YType.uint32, "disc-expiry")

                                            self.established_age = YLeaf(YType.uint64, "established-age")

                                            self.established_time = YLeaf(YType.uint64, "established-time")

                                            self.hold_time = YLeaf(YType.uint32, "hold-time")

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.local_address = YLeaf(YType.str, "local-address")

                                            self.local_hold_time = YLeaf(YType.uint32, "local-hold-time")

                                            self.neighbor_hold_time = YLeaf(YType.uint32, "neighbor-hold-time")

                                            self.next_hello = YLeaf(YType.uint32, "next-hello")

                                            self.quick_start_disabled = YLeaf(YType.boolean, "quick-start-disabled")

                                            self.session_bringup_failure_reason = YLeaf(YType.str, "session-bringup-failure-reason")

                                            self.session_up = YLeaf(YType.boolean, "session-up")

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.target_address = YLeaf(YType.str, "target-address")

                                            self.dhcb_local_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress()
                                            self.dhcb_local_address.parent = self
                                            self._children_name_map["dhcb_local_address"] = "dhcb-local-address"
                                            self._children_yang_names.add("dhcb-local-address")

                                            self.dhcb_target_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress()
                                            self.dhcb_target_address.parent = self
                                            self._children_name_map["dhcb_target_address"] = "dhcb-target-address"
                                            self._children_yang_names.add("dhcb-target-address")

                                            self.last_session_down_info = YList(self)
                                            self._segment_path = lambda: "targeted-hello"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello, ['adjacency_ldp_identifier', 'disc_expiry', 'established_age', 'established_time', 'hold_time', 'interval', 'local_address', 'local_hold_time', 'neighbor_hold_time', 'next_hello', 'quick_start_disabled', 'session_bringup_failure_reason', 'session_up', 'state', 'target_address'], name, value)


                                        class DhcbLocalAddress(Entity):
                                            """
                                            DHCB local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, self).__init__()

                                                self.yang_name = "dhcb-local-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbLocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class DhcbTargetAddress(Entity):
                                            """
                                            DHCB target address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, self).__init__()

                                                self.yang_name = "dhcb-target-address"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "dhcb-target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.DhcbTargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class LastSessionDownInfo(Entity):
                                            """
                                            Last session down information
                                            
                                            .. attribute:: last_session_down_reason
                                            
                                            	The reason of last socket failure
                                            	**type**\:  str
                                            
                                            .. attribute:: last_session_down_time
                                            
                                            	Timestamp of when the last session went down
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_session_up_time
                                            
                                            	The time duration the last session was up
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, self).__init__()

                                                self.yang_name = "last-session-down-info"
                                                self.yang_parent_name = "targeted-hello"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.last_session_down_reason = YLeaf(YType.str, "last-session-down-reason")

                                                self.last_session_down_time = YLeaf(YType.uint64, "last-session-down-time")

                                                self.last_session_up_time = YLeaf(YType.uint32, "last-session-up-time")
                                                self._segment_path = lambda: "last-session-down-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Discovery.TargetedHellos.TargetedHello.LastSessionDownInfo, ['last_session_down_reason', 'last_session_down_time', 'last_session_up_time'], name, value)


                            class ForwardingSummary(Entity):
                                """
                                Summary information regarding LDP forwarding
                                setup
                                
                                .. attribute:: fsht
                                
                                	Forwarding state hold time registered with LSD
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: intfs
                                
                                	MPLS forwarding enabled interface count
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_lsd_bound
                                
                                	LDP is connected to LSD server
                                	**type**\:  bool
                                
                                .. attribute:: lbls
                                
                                	Local label allocated count
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rws
                                
                                	Forwarding rewrites summary
                                	**type**\:   :py:class:`Rws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary, self).__init__()

                                    self.yang_name = "forwarding-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rws" : ("rws", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws), "vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf)}
                                    self._child_list_classes = {}

                                    self.fsht = YLeaf(YType.uint16, "fsht")

                                    self.intfs = YLeaf(YType.uint16, "intfs")

                                    self.is_lsd_bound = YLeaf(YType.boolean, "is-lsd-bound")

                                    self.lbls = YLeaf(YType.uint16, "lbls")

                                    self.rws = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws()
                                    self.rws.parent = self
                                    self._children_name_map["rws"] = "rws"
                                    self._children_yang_names.add("rws")

                                    self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "forwarding-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary, ['fsht', 'intfs', 'is_lsd_bound', 'lbls'], name, value)


                                class Rws(Entity):
                                    """
                                    Forwarding rewrites summary
                                    
                                    .. attribute:: nhs
                                    
                                    	Forwarding rewrites nexthops (paths) summary
                                    	**type**\:   :py:class:`Nhs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs>`
                                    
                                    .. attribute:: pfxs
                                    
                                    	Forwarding rewrites prefix summary
                                    	**type**\:   :py:class:`Pfxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws, self).__init__()

                                        self.yang_name = "rws"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"nhs" : ("nhs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs), "pfxs" : ("pfxs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs)}
                                        self._child_list_classes = {}

                                        self.nhs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs()
                                        self.nhs.parent = self
                                        self._children_name_map["nhs"] = "nhs"
                                        self._children_yang_names.add("nhs")

                                        self.pfxs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs()
                                        self.pfxs.parent = self
                                        self._children_name_map["pfxs"] = "pfxs"
                                        self._children_yang_names.add("pfxs")
                                        self._segment_path = lambda: "rws"


                                    class Nhs(Entity):
                                        """
                                        Forwarding rewrites nexthops (paths) summary
                                        
                                        .. attribute:: backup_paths
                                        
                                        	Count of non\-primary backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_backup_paths
                                        
                                        	Count of labeled backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_paths
                                        
                                        	Count of all labeled paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: protected_paths
                                        
                                        	Count of FRR protected paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_backup_paths
                                        
                                        	Count of non\-primary remote backup paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_paths
                                        
                                        	Total path count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, self).__init__()

                                            self.yang_name = "nhs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.backup_paths = YLeaf(YType.uint32, "backup-paths")

                                            self.labeled_backup_paths = YLeaf(YType.uint32, "labeled-backup-paths")

                                            self.labeled_paths = YLeaf(YType.uint32, "labeled-paths")

                                            self.protected_paths = YLeaf(YType.uint32, "protected-paths")

                                            self.remote_backup_paths = YLeaf(YType.uint32, "remote-backup-paths")

                                            self.total_paths = YLeaf(YType.uint32, "total-paths")
                                            self._segment_path = lambda: "nhs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Nhs, ['backup_paths', 'labeled_backup_paths', 'labeled_paths', 'protected_paths', 'remote_backup_paths', 'total_paths'], name, value)


                                    class Pfxs(Entity):
                                        """
                                        Forwarding rewrites prefix summary
                                        
                                        .. attribute:: ecmp_pfxs
                                        
                                        	Count of prefixes with ECMP
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: labeled_pfxs_aggr
                                        
                                        	Labeled prefix count for all paths
                                        	**type**\:   :py:class:`LabeledPfxsAggr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr>`
                                        
                                        .. attribute:: labeled_pfxs_backup
                                        
                                        	Labeled prefix count related to backup paths only
                                        	**type**\:   :py:class:`LabeledPfxsBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup>`
                                        
                                        .. attribute:: labeled_pfxs_primary
                                        
                                        	Labeled prefix count related to primary paths only
                                        	**type**\:   :py:class:`LabeledPfxsPrimary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary>`
                                        
                                        .. attribute:: protected_pfxs
                                        
                                        	Count of FRR protected prefixes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: total_pfxs
                                        
                                        	Total Prefix count
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, self).__init__()

                                            self.yang_name = "pfxs"
                                            self.yang_parent_name = "rws"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"labeled-pfxs-aggr" : ("labeled_pfxs_aggr", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr), "labeled-pfxs-backup" : ("labeled_pfxs_backup", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup), "labeled-pfxs-primary" : ("labeled_pfxs_primary", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary)}
                                            self._child_list_classes = {}

                                            self.ecmp_pfxs = YLeaf(YType.uint16, "ecmp-pfxs")

                                            self.protected_pfxs = YLeaf(YType.uint16, "protected-pfxs")

                                            self.total_pfxs = YLeaf(YType.uint16, "total-pfxs")

                                            self.labeled_pfxs_aggr = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr()
                                            self.labeled_pfxs_aggr.parent = self
                                            self._children_name_map["labeled_pfxs_aggr"] = "labeled-pfxs-aggr"
                                            self._children_yang_names.add("labeled-pfxs-aggr")

                                            self.labeled_pfxs_backup = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup()
                                            self.labeled_pfxs_backup.parent = self
                                            self._children_name_map["labeled_pfxs_backup"] = "labeled-pfxs-backup"
                                            self._children_yang_names.add("labeled-pfxs-backup")

                                            self.labeled_pfxs_primary = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary()
                                            self.labeled_pfxs_primary.parent = self
                                            self._children_name_map["labeled_pfxs_primary"] = "labeled-pfxs-primary"
                                            self._children_yang_names.add("labeled-pfxs-primary")
                                            self._segment_path = lambda: "pfxs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs, ['ecmp_pfxs', 'protected_pfxs', 'total_pfxs'], name, value)


                                        class LabeledPfxsAggr(Entity):
                                            """
                                            Labeled prefix count for all paths
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, self).__init__()

                                                self.yang_name = "labeled-pfxs-aggr"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-aggr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsAggr, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsBackup(Entity):
                                            """
                                            Labeled prefix count related to backup paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, self).__init__()

                                                self.yang_name = "labeled-pfxs-backup"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-backup"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsBackup, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                        class LabeledPfxsPrimary(Entity):
                                            """
                                            Labeled prefix count related to primary paths
                                            only
                                            
                                            .. attribute:: labeled_pfxs
                                            
                                            	Count of labeled prefixes with 1 or more paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: labeled_pfxs_partial
                                            
                                            	Count of labeled prefixes with some (but not ALL) paths labeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unlabeled_pfxs
                                            
                                            	Count of labeled prefixes with ALL paths unlabeled
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, self).__init__()

                                                self.yang_name = "labeled-pfxs-primary"
                                                self.yang_parent_name = "pfxs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.labeled_pfxs = YLeaf(YType.uint16, "labeled-pfxs")

                                                self.labeled_pfxs_partial = YLeaf(YType.uint16, "labeled-pfxs-partial")

                                                self.unlabeled_pfxs = YLeaf(YType.uint16, "unlabeled-pfxs")
                                                self._segment_path = lambda: "labeled-pfxs-primary"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Rws.Pfxs.LabeledPfxsPrimary, ['labeled_pfxs', 'labeled_pfxs_partial', 'unlabeled_pfxs'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: id
                                    
                                    	VRF Id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "forwarding-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.id = YLeaf(YType.uint32, "id")

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.ForwardingSummary.Vrf, ['id', 'name'], name, value)


                            class Forwardings(Entity):
                                """
                                The LDP Forwarding rewrites
                                
                                .. attribute:: forwarding
                                
                                	Information on a particular LDP forwarding rewrite
                                	**type**\: list of    :py:class:`Forwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings, self).__init__()

                                    self.yang_name = "forwardings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"forwarding" : ("forwarding", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding)}

                                    self.forwarding = YList(self)
                                    self._segment_path = lambda: "forwardings"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings, [], name, value)


                                class Forwarding(Entity):
                                    """
                                    Information on a particular LDP forwarding
                                    rewrite
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	The IP Prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: paths
                                    
                                    	Paths
                                    	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: prefix_xr
                                    
                                    	IP Prefix
                                    	**type**\:   :py:class:`PrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr>`
                                    
                                    .. attribute:: route
                                    
                                    	Route
                                    	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route>`
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID associated with IP prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, self).__init__()

                                        self.yang_name = "forwarding"
                                        self.yang_parent_name = "forwardings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"prefix-xr" : ("prefix_xr", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr), "route" : ("route", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route), "vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf)}
                                        self._child_list_classes = {"paths" : ("paths", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        self.table_id = YLeaf(YType.uint32, "table-id")

                                        self.prefix_xr = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr()
                                        self.prefix_xr.parent = self
                                        self._children_name_map["prefix_xr"] = "prefix-xr"
                                        self._children_yang_names.add("prefix-xr")

                                        self.route = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route()
                                        self.route.parent = self
                                        self._children_name_map["route"] = "route"
                                        self._children_yang_names.add("route")

                                        self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.paths = YList(self)
                                        self._segment_path = lambda: "forwarding" + "[prefix='" + self.prefix.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding, ['prefix', 'prefix_length', 'table_id'], name, value)


                                    class Paths(Entity):
                                        """
                                        Paths
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls>`
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls), "routing" : ("routing", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing)}
                                            self._child_list_classes = {}

                                            self.mpls = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._children_yang_names.add("mpls")

                                            self.routing = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"
                                            self._children_yang_names.add("routing")
                                            self._segment_path = lambda: "paths"


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: mpls_outgoing_info
                                            
                                            	MPLS nexthop info
                                            	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo>`
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo), "remote-lfa" : ("remote_lfa", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa)}
                                                self._child_list_classes = {}

                                                self.mpls_outgoing_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo()
                                                self.mpls_outgoing_info.parent = self
                                                self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                self._children_yang_names.add("mpls-outgoing-info")

                                                self.remote_lfa = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")
                                                self._segment_path = lambda: "mpls"


                                            class MplsOutgoingInfo(Entity):
                                                """
                                                MPLS nexthop info
                                                
                                                .. attribute:: is_from_graceful_restartable_neighbor
                                                
                                                	Is from a GR neighbor
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_stale
                                                
                                                	Is the entry stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_peer_ldp_ident
                                                
                                                	Nexthop LDP peer
                                                	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent>`
                                                
                                                .. attribute:: out_label
                                                
                                                	Outgoing label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: out_label_owner
                                                
                                                	Outgoing label owner
                                                	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                
                                                .. attribute:: out_label_rsn
                                                
                                                	Outgoing label reason
                                                	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                
                                                .. attribute:: out_label_type
                                                
                                                	Outgoing Label Type
                                                	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, self).__init__()

                                                    self.yang_name = "mpls-outgoing-info"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent)}
                                                    self._child_list_classes = {}

                                                    self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                    self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                    self.out_label = YLeaf(YType.uint32, "out-label")

                                                    self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                    self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                    self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                    self.nexthop_peer_ldp_ident = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent()
                                                    self.nexthop_peer_ldp_ident.parent = self
                                                    self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                    self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                    self._segment_path = lambda: "mpls-outgoing-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                class NexthopPeerLdpIdent(Entity):
                                                    """
                                                    Nexthop LDP peer
                                                    
                                                    .. attribute:: label_space_id
                                                    
                                                    	Label space identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ldp_id
                                                    
                                                    	LDP identifier
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: lsr_id
                                                    
                                                    	LSR identifier
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, self).__init__()

                                                        self.yang_name = "nexthop-peer-ldp-ident"
                                                        self.yang_parent_name = "mpls-outgoing-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                        self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                        self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                        self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.MplsOutgoingInfo.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_outgoing_info
                                                
                                                	Remote LFA MPLS nexthop(s\_ info
                                                	**type**\:   :py:class:`MplsOutgoingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "mpls"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"mpls-outgoing-info" : ("mpls_outgoing_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo)}
                                                    self._child_list_classes = {}

                                                    self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                    self.mpls_outgoing_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo()
                                                    self.mpls_outgoing_info.parent = self
                                                    self._children_name_map["mpls_outgoing_info"] = "mpls-outgoing-info"
                                                    self._children_yang_names.add("mpls-outgoing-info")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa, ['has_remote_lfa_bkup'], name, value)


                                                class MplsOutgoingInfo(Entity):
                                                    """
                                                    Remote LFA MPLS nexthop(s\_ info
                                                    
                                                    .. attribute:: stack
                                                    
                                                    	Inner label stack info
                                                    	**type**\: list of    :py:class:`Stack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, self).__init__()

                                                        self.yang_name = "mpls-outgoing-info"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"stack" : ("stack", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack)}

                                                        self.stack = YList(self)
                                                        self._segment_path = lambda: "mpls-outgoing-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo, [], name, value)


                                                    class Stack(Entity):
                                                        """
                                                        Inner label stack info
                                                        
                                                        .. attribute:: is_from_graceful_restartable_neighbor
                                                        
                                                        	Is from a GR neighbor
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_stale
                                                        
                                                        	Is the entry stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: nexthop_peer_ldp_ident
                                                        
                                                        	Nexthop LDP peer
                                                        	**type**\:   :py:class:`NexthopPeerLdpIdent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent>`
                                                        
                                                        .. attribute:: out_label
                                                        
                                                        	Outgoing label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: out_label_owner
                                                        
                                                        	Outgoing label owner
                                                        	**type**\:   :py:class:`LdpRoutePathLblOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathLblOwner>`
                                                        
                                                        .. attribute:: out_label_rsn
                                                        
                                                        	Outgoing label reason
                                                        	**type**\:   :py:class:`LdpFwdUnlblRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpFwdUnlblRsn>`
                                                        
                                                        .. attribute:: out_label_type
                                                        
                                                        	Outgoing Label Type
                                                        	**type**\:   :py:class:`LabelValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LabelValue>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'mpls-ldp-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, self).__init__()

                                                            self.yang_name = "stack"
                                                            self.yang_parent_name = "mpls-outgoing-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"nexthop-peer-ldp-ident" : ("nexthop_peer_ldp_ident", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent)}
                                                            self._child_list_classes = {}

                                                            self.is_from_graceful_restartable_neighbor = YLeaf(YType.boolean, "is-from-graceful-restartable-neighbor")

                                                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                                                            self.out_label = YLeaf(YType.uint32, "out-label")

                                                            self.out_label_owner = YLeaf(YType.enumeration, "out-label-owner")

                                                            self.out_label_rsn = YLeaf(YType.enumeration, "out-label-rsn")

                                                            self.out_label_type = YLeaf(YType.enumeration, "out-label-type")

                                                            self.nexthop_peer_ldp_ident = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent()
                                                            self.nexthop_peer_ldp_ident.parent = self
                                                            self._children_name_map["nexthop_peer_ldp_ident"] = "nexthop-peer-ldp-ident"
                                                            self._children_yang_names.add("nexthop-peer-ldp-ident")
                                                            self._segment_path = lambda: "stack"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack, ['is_from_graceful_restartable_neighbor', 'is_stale', 'out_label', 'out_label_owner', 'out_label_rsn', 'out_label_type'], name, value)


                                                        class NexthopPeerLdpIdent(Entity):
                                                            """
                                                            Nexthop LDP peer
                                                            
                                                            .. attribute:: label_space_id
                                                            
                                                            	Label space identifier
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ldp_id
                                                            
                                                            	LDP identifier
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: lsr_id
                                                            
                                                            	LSR identifier
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'mpls-ldp-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, self).__init__()

                                                                self.yang_name = "nexthop-peer-ldp-ident"
                                                                self.yang_parent_name = "stack"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                                                self.lsr_id = YLeaf(YType.str, "lsr-id")
                                                                self._segment_path = lambda: "nexthop-peer-ldp-ident"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Mpls.RemoteLfa.MplsOutgoingInfo.Stack.NexthopPeerLdpIdent, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: bkup_path_id
                                            
                                            	Backup path Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface Name
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	Path's load metric for load balancing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next Hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop>`
                                            
                                            .. attribute:: next_hop_table_id
                                            
                                            	Table ID for nexthop address
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_id
                                            
                                            	Nexthop Identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_is_overriden
                                            
                                            	Nexthop is overriden by LDP
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_flags
                                            
                                            	Routing path flags decoded
                                            	**type**\:   :py:class:`LdpRoutePathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpRoutePathFlags>`
                                            
                                            .. attribute:: path_id
                                            
                                            	path Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA\-FRR backup info
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa>`
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop" : ("next_hop", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop), "remote-lfa" : ("remote_lfa", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa)}
                                                self._child_list_classes = {}

                                                self.bkup_path_id = YLeaf(YType.uint8, "bkup-path-id")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.interface = YLeaf(YType.str, "interface")

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                                self.nh_is_overriden = YLeaf(YType.boolean, "nh-is-overriden")

                                                self.path_flags = YLeaf(YType.enumeration, "path-flags")

                                                self.path_id = YLeaf(YType.uint8, "path-id")

                                                self.next_hop = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.remote_lfa = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")
                                                self._segment_path = lambda: "routing"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing, ['bkup_path_id', 'flags', 'interface', 'interface_name', 'load_metric', 'next_hop_table_id', 'nexthop_id', 'nh_is_overriden', 'path_flags', 'path_id'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next Hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                
                                                .. attribute:: dummy
                                                
                                                	No Address
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ipv4
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.NextHop, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA\-FRR backup info
                                                
                                                .. attribute:: has_q_node
                                                
                                                	Whether remote LFA path has a Q node associated
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_remote_lfa_bkup
                                                
                                                	Whether path has remote LFA backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: needs_tldp
                                                
                                                	Whether TLDP is needed with remote PQ node
                                                	**type**\:  bool
                                                
                                                .. attribute:: remote_p_node_id
                                                
                                                	Remote/P node address
                                                	**type**\:   :py:class:`RemotePNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId>`
                                                
                                                .. attribute:: remote_q_node_id
                                                
                                                	Remote/Q node address
                                                	**type**\:   :py:class:`RemoteQNodeId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId>`
                                                
                                                

                                                """

                                                _prefix = 'mpls-ldp-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "routing"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"remote-p-node-id" : ("remote_p_node_id", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId), "remote-q-node-id" : ("remote_q_node_id", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId)}
                                                    self._child_list_classes = {}

                                                    self.has_q_node = YLeaf(YType.boolean, "has-q-node")

                                                    self.has_remote_lfa_bkup = YLeaf(YType.boolean, "has-remote-lfa-bkup")

                                                    self.needs_tldp = YLeaf(YType.boolean, "needs-tldp")

                                                    self.remote_p_node_id = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId()
                                                    self.remote_p_node_id.parent = self
                                                    self._children_name_map["remote_p_node_id"] = "remote-p-node-id"
                                                    self._children_yang_names.add("remote-p-node-id")

                                                    self.remote_q_node_id = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId()
                                                    self.remote_q_node_id.parent = self
                                                    self._children_name_map["remote_q_node_id"] = "remote-q-node-id"
                                                    self._children_yang_names.add("remote-q-node-id")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa, ['has_q_node', 'has_remote_lfa_bkup', 'needs_tldp'], name, value)


                                                class RemotePNodeId(Entity):
                                                    """
                                                    Remote/P node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, self).__init__()

                                                        self.yang_name = "remote-p-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                                        self._segment_path = lambda: "remote-p-node-id"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemotePNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                                class RemoteQNodeId(Entity):
                                                    """
                                                    Remote/Q node address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                                    
                                                    .. attribute:: dummy
                                                    
                                                    	No Address
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'mpls-ldp-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, self).__init__()

                                                        self.yang_name = "remote-q-node-id"
                                                        self.yang_parent_name = "remote-lfa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                                        self._segment_path = lambda: "remote-q-node-id"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Paths.Routing.RemoteLfa.RemoteQNodeId, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class PrefixXr(Entity):
                                        """
                                        IP Prefix
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, self).__init__()

                                            self.yang_name = "prefix-xr"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "prefix-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.PrefixXr, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                    class Route(Entity):
                                        """
                                        Route
                                        
                                        .. attribute:: mpls
                                        
                                        	MPLS information
                                        	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls>`
                                        
                                        .. attribute:: routing
                                        
                                        	IP routing information
                                        	**type**\:   :py:class:`Routing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route, self).__init__()

                                            self.yang_name = "route"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"mpls" : ("mpls", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls), "routing" : ("routing", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing)}
                                            self._child_list_classes = {}

                                            self.mpls = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls()
                                            self.mpls.parent = self
                                            self._children_name_map["mpls"] = "mpls"
                                            self._children_yang_names.add("mpls")

                                            self.routing = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing()
                                            self.routing.parent = self
                                            self._children_name_map["routing"] = "routing"
                                            self._children_yang_names.add("routing")
                                            self._segment_path = lambda: "route"


                                        class Mpls(Entity):
                                            """
                                            MPLS information
                                            
                                            .. attribute:: forwarding_update_age
                                            
                                            	Last Forwarding update nanosec age
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: forwarding_update_count
                                            
                                            	Number of forwarding updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_update_timestamp
                                            
                                            	Last Forwarding update nanosec timestamp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, self).__init__()

                                                self.yang_name = "mpls"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.forwarding_update_age = YLeaf(YType.uint64, "forwarding-update-age")

                                                self.forwarding_update_count = YLeaf(YType.uint32, "forwarding-update-count")

                                                self.forwarding_update_timestamp = YLeaf(YType.uint64, "forwarding-update-timestamp")

                                                self.local_label = YLeaf(YType.uint32, "local-label")
                                                self._segment_path = lambda: "mpls"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Mpls, ['forwarding_update_age', 'forwarding_update_count', 'forwarding_update_timestamp', 'local_label'], name, value)


                                        class Routing(Entity):
                                            """
                                            IP routing information
                                            
                                            .. attribute:: flags
                                            
                                            	Route RIB flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_local_vrf_leaked
                                            
                                            	Is route leaked across local VRFs?
                                            	**type**\:  bool
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: routing_update_age
                                            
                                            	Last Routing update nanosec age
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: routing_update_count
                                            
                                            	Number of routing updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: routing_update_timestamp
                                            
                                            	Last Routing update nanosec timestamp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: source
                                            
                                            	Route source protol Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sr_local_label
                                            
                                            	SR Local\-label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: version
                                            
                                            	Route RIB ersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, self).__init__()

                                                self.yang_name = "routing"
                                                self.yang_parent_name = "route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.is_local_vrf_leaked = YLeaf(YType.boolean, "is-local-vrf-leaked")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.routing_update_age = YLeaf(YType.uint64, "routing-update-age")

                                                self.routing_update_count = YLeaf(YType.uint32, "routing-update-count")

                                                self.routing_update_timestamp = YLeaf(YType.uint64, "routing-update-timestamp")

                                                self.source = YLeaf(YType.uint16, "source")

                                                self.sr_local_label = YLeaf(YType.uint32, "sr-local-label")

                                                self.type = YLeaf(YType.uint16, "type")

                                                self.version = YLeaf(YType.uint32, "version")
                                                self._segment_path = lambda: "routing"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Route.Routing, ['flags', 'is_local_vrf_leaked', 'metric', 'priority', 'routing_update_age', 'routing_update_count', 'routing_update_timestamp', 'source', 'sr_local_label', 'type', 'version'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "forwarding"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Forwardings.Forwarding.Vrf, ['id', 'name'], name, value)


                            class Igp(Entity):
                                """
                                LDP IGP related information
                                
                                .. attribute:: sync_delay_restart
                                
                                	LDP\-IGP Synchronization Delay related information
                                	**type**\:   :py:class:`SyncDelayRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart>`
                                
                                .. attribute:: syncs
                                
                                	LDP IGP Sync related information
                                	**type**\:   :py:class:`Syncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp, self).__init__()

                                    self.yang_name = "igp"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sync-delay-restart" : ("sync_delay_restart", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart), "syncs" : ("syncs", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs)}
                                    self._child_list_classes = {}

                                    self.sync_delay_restart = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart()
                                    self.sync_delay_restart.parent = self
                                    self._children_name_map["sync_delay_restart"] = "sync-delay-restart"
                                    self._children_yang_names.add("sync-delay-restart")

                                    self.syncs = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs()
                                    self.syncs.parent = self
                                    self._children_name_map["syncs"] = "syncs"
                                    self._children_yang_names.add("syncs")
                                    self._segment_path = lambda: "igp"


                                class SyncDelayRestart(Entity):
                                    """
                                    LDP\-IGP Synchronization Delay related
                                    information
                                    
                                    .. attribute:: configured
                                    
                                    	Is restart delay configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: delay_secs
                                    
                                    	Delay time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remaining_secs
                                    
                                    	Delay timer remaining time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timer_running
                                    
                                    	Is restart delay timer running
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, self).__init__()

                                        self.yang_name = "sync-delay-restart"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.configured = YLeaf(YType.boolean, "configured")

                                        self.delay_secs = YLeaf(YType.uint32, "delay-secs")

                                        self.remaining_secs = YLeaf(YType.uint32, "remaining-secs")

                                        self.timer_running = YLeaf(YType.boolean, "timer-running")
                                        self._segment_path = lambda: "sync-delay-restart"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.SyncDelayRestart, ['configured', 'delay_secs', 'remaining_secs', 'timer_running'], name, value)


                                class Syncs(Entity):
                                    """
                                    LDP IGP Sync related information
                                    
                                    .. attribute:: sync
                                    
                                    	LDP\-IGP Synchronization related information for an interface
                                    	**type**\: list of    :py:class:`Sync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs, self).__init__()

                                        self.yang_name = "syncs"
                                        self.yang_parent_name = "igp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"sync" : ("sync", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync)}

                                        self.sync = YList(self)
                                        self._segment_path = lambda: "syncs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs, [], name, value)


                                    class Sync(Entity):
                                        """
                                        LDP\-IGP Synchronization related information
                                        for an interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	The Interface Name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: delay_timer_remaining
                                        
                                        	Remaining timer (seconds) till expiry of sync delay timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_only_peer
                                        
                                        	Interface GR\-only reachable peers
                                        	**type**\: list of    :py:class:`GrOnlyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer>`
                                        
                                        .. attribute:: igp_sync_delay
                                        
                                        	IGP sync delay in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: igp_sync_down_reason
                                        
                                        	Reason IGP Sync Not Achieved
                                        	**type**\:   :py:class:`LdpIgpSyncDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncDownReason>`
                                        
                                        .. attribute:: igp_sync_state
                                        
                                        	IGP Sync state
                                        	**type**\:   :py:class:`LdpIgpSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpIgpSyncState>`
                                        
                                        .. attribute:: interface_name_xr
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_delay_timer_running
                                        
                                        	Is sync delay timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: peers
                                        
                                        	Interface Peers
                                        	**type**\: list of    :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, self).__init__()

                                            self.yang_name = "sync"
                                            self.yang_parent_name = "syncs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf)}
                                            self._child_list_classes = {"gr-only-peer" : ("gr_only_peer", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer), "peers" : ("peers", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.delay_timer_remaining = YLeaf(YType.uint32, "delay-timer-remaining")

                                            self.igp_sync_delay = YLeaf(YType.uint32, "igp-sync-delay")

                                            self.igp_sync_down_reason = YLeaf(YType.enumeration, "igp-sync-down-reason")

                                            self.igp_sync_state = YLeaf(YType.enumeration, "igp-sync-state")

                                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                            self.is_delay_timer_running = YLeaf(YType.boolean, "is-delay-timer-running")

                                            self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")

                                            self.gr_only_peer = YList(self)
                                            self.peers = YList(self)
                                            self._segment_path = lambda: "sync" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync, ['interface_name', 'delay_timer_remaining', 'igp_sync_delay', 'igp_sync_down_reason', 'igp_sync_state', 'interface_name_xr', 'is_delay_timer_running'], name, value)


                                        class GrOnlyPeer(Entity):
                                            """
                                            Interface GR\-only reachable peers
                                            
                                            .. attribute:: is_chkpt_created
                                            
                                            	Is created due to checkpointing
                                            	**type**\:  bool
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, self).__init__()

                                                self.yang_name = "gr-only-peer"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.is_chkpt_created = YLeaf(YType.boolean, "is-chkpt-created")

                                                self.peer_id = YLeaf(YType.str, "peer-id")
                                                self._segment_path = lambda: "gr-only-peer"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.GrOnlyPeer, ['is_chkpt_created', 'peer_id'], name, value)


                                        class Peers(Entity):
                                            """
                                            Interface Peers
                                            
                                            .. attribute:: is_gr_enabled
                                            
                                            	Is GR enabled session
                                            	**type**\:  bool
                                            
                                            .. attribute:: peer_id
                                            
                                            	Peer Identifier
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, self).__init__()

                                                self.yang_name = "peers"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                                                self.peer_id = YLeaf(YType.str, "peer-id")
                                                self._segment_path = lambda: "peers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Peers, ['is_gr_enabled', 'peer_id'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: id
                                            
                                            	VRF Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	VRF Name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "sync"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.id = YLeaf(YType.uint32, "id")

                                                self.name = YLeaf(YType.str, "name")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Igp.Syncs.Sync.Vrf, ['id', 'name'], name, value)


                            class InterfaceSummary(Entity):
                                """
                                IPv4 interface summary information
                                
                                .. attribute:: auto_config
                                
                                	Auto\-configured interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_disabled
                                
                                	Autoconfigure disabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_config_forward_reference_interfaces
                                
                                	Auto\-configured forward references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_references
                                
                                	Number of forward referenced interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_count
                                
                                	Number of known IP Interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: known_ip_interface_ldp_enabled
                                
                                	Number of known IP Interfaces with LDP Enabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_attached_interface
                                
                                	Number of attached interfaces configured in LDP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldp_configured_te_interface
                                
                                	Number of TE tunnel interfaces configured in LDP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary, self).__init__()

                                    self.yang_name = "interface-summary"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.auto_config = YLeaf(YType.uint32, "auto-config")

                                    self.auto_config_disabled = YLeaf(YType.uint32, "auto-config-disabled")

                                    self.auto_config_forward_reference_interfaces = YLeaf(YType.uint32, "auto-config-forward-reference-interfaces")

                                    self.forward_references = YLeaf(YType.uint32, "forward-references")

                                    self.known_ip_interface_count = YLeaf(YType.uint32, "known-ip-interface-count")

                                    self.known_ip_interface_ldp_enabled = YLeaf(YType.uint32, "known-ip-interface-ldp-enabled")

                                    self.ldp_configured_attached_interface = YLeaf(YType.uint32, "ldp-configured-attached-interface")

                                    self.ldp_configured_te_interface = YLeaf(YType.uint32, "ldp-configured-te-interface")
                                    self._segment_path = lambda: "interface-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.InterfaceSummary, ['auto_config', 'auto_config_disabled', 'auto_config_forward_reference_interfaces', 'forward_references', 'known_ip_interface_count', 'known_ip_interface_ldp_enabled', 'ldp_configured_attached_interface', 'ldp_configured_te_interface'], name, value)


                            class Interfaces(Entity):
                                """
                                LDP Interface related information
                                
                                .. attribute:: interface
                                
                                	IPv4 interface information
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces, self).__init__()

                                    self.yang_name = "interfaces"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface" : ("interface", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface)}

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces, [], name, value)


                                class Interface(Entity):
                                    """
                                    IPv4 interface information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	The Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: auto_config
                                    
                                    	Auto config
                                    	**type**\: list of    :py:class:`AutoConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig>`
                                    
                                    .. attribute:: interface
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_im_stale
                                    
                                    	Is IM information stale
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_autoconfig_disable
                                    
                                    	LDP autoconfig disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_config_mode
                                    
                                    	LDP config mode
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_enabled
                                    
                                    	LDP enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_mesh_grp
                                    
                                    	TE tunnel mesh\-group
                                    	**type**\: list of    :py:class:`TeMeshGrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf)}
                                        self._child_list_classes = {"auto-config" : ("auto_config", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig), "te-mesh-grp" : ("te_mesh_grp", MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface = YLeaf(YType.str, "interface")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.is_im_stale = YLeaf(YType.boolean, "is-im-stale")

                                        self.ldp_autoconfig_disable = YLeaf(YType.boolean, "ldp-autoconfig-disable")

                                        self.ldp_config_mode = YLeaf(YType.boolean, "ldp-config-mode")

                                        self.ldp_enabled = YLeaf(YType.boolean, "ldp-enabled")

                                        self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")

                                        self.auto_config = YList(self)
                                        self.te_mesh_grp = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface, ['interface_name', 'interface', 'interface_name_xr', 'is_im_stale', 'ldp_autoconfig_disable', 'ldp_config_mode', 'ldp_enabled'], name, value)


                                    class AutoConfig(Entity):
                                        """
                                        Auto config
                                        
                                        .. attribute:: tuple
                                        
                                        	Tuple
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, self).__init__()

                                            self.yang_name = "auto-config"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.tuple = YLeaf(YType.str, "tuple")
                                            self._segment_path = lambda: "auto-config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.AutoConfig, ['tuple'], name, value)


                                    class TeMeshGrp(Entity):
                                        """
                                        TE tunnel mesh\-group
                                        
                                        .. attribute:: ldp_mesh_group_enabled
                                        
                                        	LDP has enabled this TE mesh\-group
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_te_mesh_group_all_cfgd
                                        
                                        	LDP has enabled all TE mesh\-groups
                                        	**type**\:  bool
                                        
                                        .. attribute:: te_mesh_group_id
                                        
                                        	TE tunnel Mesh Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, self).__init__()

                                            self.yang_name = "te-mesh-grp"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ldp_mesh_group_enabled = YLeaf(YType.boolean, "ldp-mesh-group-enabled")

                                            self.ldp_te_mesh_group_all_cfgd = YLeaf(YType.boolean, "ldp-te-mesh-group-all-cfgd")

                                            self.te_mesh_group_id = YLeaf(YType.uint32, "te-mesh-group-id")
                                            self._segment_path = lambda: "te-mesh-grp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.TeMeshGrp, ['ldp_mesh_group_enabled', 'ldp_te_mesh_group_all_cfgd', 'te_mesh_group_id'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: id
                                        
                                        	VRF Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.id = YLeaf(YType.uint32, "id")

                                            self.name = YLeaf(YType.str, "name")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Afs.Af.Interfaces.Interface.Vrf, ['id', 'name'], name, value)


                    class BackoffParameters(Entity):
                        """
                        The LDP Backoff Parameters
                        
                        .. attribute:: initial_seconds
                        
                        	Initial backoff value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: maximum_seconds
                        
                        	Maximum backoff value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters, self).__init__()

                            self.yang_name = "backoff-parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.initial_seconds = YLeaf(YType.uint32, "initial-seconds")

                            self.maximum_seconds = YLeaf(YType.uint32, "maximum-seconds")
                            self._segment_path = lambda: "backoff-parameters"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.BackoffParameters, ['initial_seconds', 'maximum_seconds'], name, value)


                    class Backoffs(Entity):
                        """
                        The LDP backoff
                        
                        .. attribute:: backoff
                        
                        	LDP Backoff Information
                        	**type**\: list of    :py:class:`Backoff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs.Backoff>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs, self).__init__()

                            self.yang_name = "backoffs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"backoff" : ("backoff", MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs.Backoff)}

                            self.backoff = YList(self)
                            self._segment_path = lambda: "backoffs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs, [], name, value)


                        class Backoff(Entity):
                            """
                            LDP Backoff Information
                            
                            .. attribute:: backoff_seconds
                            
                            	Backoff seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: waiting_seconds
                            
                            	Backoff waiting seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs.Backoff, self).__init__()

                                self.yang_name = "backoff"
                                self.yang_parent_name = "backoffs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.backoff_seconds = YLeaf(YType.uint32, "backoff-seconds")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.waiting_seconds = YLeaf(YType.uint32, "waiting-seconds")
                                self._segment_path = lambda: "backoff"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Backoffs.Backoff, ['backoff_seconds', 'label_space_id', 'lsr_id', 'waiting_seconds'], name, value)


                    class Capabilities(Entity):
                        """
                        LDP capability database information
                        
                        .. attribute:: capability
                        
                        	Information on LDP capability
                        	**type**\: list of    :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities, self).__init__()

                            self.yang_name = "capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"capability" : ("capability", MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability)}

                            self.capability = YList(self)
                            self._segment_path = lambda: "capabilities"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities, [], name, value)


                        class Capability(Entity):
                            """
                            Information on LDP capability
                            
                            .. attribute:: capability_type  <key>
                            
                            	The capability type (IANA assigned)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: capability
                            
                            	Capability information
                            	**type**\:   :py:class:`Capability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability>`
                            
                            .. attribute:: capability_owner
                            
                            	Capability owner
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability, self).__init__()

                                self.yang_name = "capability"
                                self.yang_parent_name = "capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"capability" : ("capability", MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability)}
                                self._child_list_classes = {}

                                self.capability_type = YLeaf(YType.int32, "capability-type")

                                self.capability_owner = YLeaf(YType.str, "capability-owner")

                                self.capability = MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability()
                                self.capability.parent = self
                                self._children_name_map["capability"] = "capability"
                                self._children_yang_names.add("capability")
                                self._segment_path = lambda: "capability" + "[capability-type='" + self.capability_type.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability, ['capability_type', 'capability_owner'], name, value)


                            class Capability(Entity):
                                """
                                Capability information
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability, self).__init__()

                                    self.yang_name = "capability"
                                    self.yang_parent_name = "capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "capability"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Capabilities.Capability.Capability, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                    class GracefulRestart(Entity):
                        """
                        LDP Graceful Restart info
                        
                        .. attribute:: forwarding_state_hold_timer_remaining_seconds
                        
                        	Forwarding state hold timer remaining time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: graceful_restartable_neighbor
                        
                        	Vector of graceful restart neighbor information
                        	**type**\: list of    :py:class:`GracefulRestartableNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor>`
                        
                        .. attribute:: is_forwarding_state_hold_timer_running
                        
                        	Is graceful restart forwarding state hold timer running
                        	**type**\:  bool
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart, self).__init__()

                            self.yang_name = "graceful-restart"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf)}
                            self._child_list_classes = {"graceful-restartable-neighbor" : ("graceful_restartable_neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor)}

                            self.forwarding_state_hold_timer_remaining_seconds = YLeaf(YType.uint32, "forwarding-state-hold-timer-remaining-seconds")

                            self.is_forwarding_state_hold_timer_running = YLeaf(YType.boolean, "is-forwarding-state-hold-timer-running")

                            self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")

                            self.graceful_restartable_neighbor = YList(self)
                            self._segment_path = lambda: "graceful-restart"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart, ['forwarding_state_hold_timer_remaining_seconds', 'is_forwarding_state_hold_timer_running'], name, value)


                        class GracefulRestartableNeighbor(Entity):
                            """
                            Vector of graceful restart neighbor information
                            
                            .. attribute:: connect_count
                            
                            	ConnectCount
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_address
                            
                            	Addresses bound to GR down Nbr
                            	**type**\: list of    :py:class:`DownNbrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress>`
                            
                            .. attribute:: down_nbr_down_reason
                            
                            	Session down reason code
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flags
                            
                            	Flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: down_nbr_flap_count
                            
                            	Count of back2back flaps
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: down_nbr_interface
                            
                            	Interfaces bound to GR down Nbr
                            	**type**\: list of    :py:class:`DownNbrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface>`
                            
                            .. attribute:: gr_peer
                            
                            	GR peer LDP Id
                            	**type**\:   :py:class:`GrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer>`
                            
                            .. attribute:: is_liveness_timer_running
                            
                            	Is liveness timer running
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_up
                            
                            	Is neighbor up
                            	**type**\:  bool
                            
                            .. attribute:: is_recovery_timer_running
                            
                            	Is recovery timer running
                            	**type**\:  bool
                            
                            .. attribute:: liveness_timer_remaining_seconds
                            
                            	Remaining time from liveness timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: recovery_timer_remaining_seconds
                            
                            	Recovery timer remining time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, self).__init__()

                                self.yang_name = "graceful-restartable-neighbor"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"gr-peer" : ("gr_peer", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer)}
                                self._child_list_classes = {"down-nbr-address" : ("down_nbr_address", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress), "down-nbr-interface" : ("down_nbr_interface", MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface)}

                                self.connect_count = YLeaf(YType.uint32, "connect-count")

                                self.down_nbr_down_reason = YLeaf(YType.uint32, "down-nbr-down-reason")

                                self.down_nbr_flags = YLeaf(YType.uint32, "down-nbr-flags")

                                self.down_nbr_flap_count = YLeaf(YType.uint8, "down-nbr-flap-count")

                                self.is_liveness_timer_running = YLeaf(YType.boolean, "is-liveness-timer-running")

                                self.is_neighbor_up = YLeaf(YType.boolean, "is-neighbor-up")

                                self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

                                self.liveness_timer_remaining_seconds = YLeaf(YType.uint32, "liveness-timer-remaining-seconds")

                                self.recovery_timer_remaining_seconds = YLeaf(YType.uint32, "recovery-timer-remaining-seconds")

                                self.gr_peer = MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer()
                                self.gr_peer.parent = self
                                self._children_name_map["gr_peer"] = "gr-peer"
                                self._children_yang_names.add("gr-peer")

                                self.down_nbr_address = YList(self)
                                self.down_nbr_interface = YList(self)
                                self._segment_path = lambda: "graceful-restartable-neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor, ['connect_count', 'down_nbr_down_reason', 'down_nbr_flags', 'down_nbr_flap_count', 'is_liveness_timer_running', 'is_neighbor_up', 'is_recovery_timer_running', 'liveness_timer_remaining_seconds', 'recovery_timer_remaining_seconds'], name, value)


                            class DownNbrAddress(Entity):
                                """
                                Addresses bound to GR down Nbr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, self).__init__()

                                    self.yang_name = "down-nbr-address"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "down-nbr-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class DownNbrInterface(Entity):
                                """
                                Interfaces bound to GR down Nbr
                                
                                .. attribute:: address_family
                                
                                	Interface adj Address Family
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: interface_handle
                                
                                	Interfaces handle
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, self).__init__()

                                    self.yang_name = "down-nbr-interface"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")
                                    self._segment_path = lambda: "down-nbr-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.DownNbrInterface, ['address_family', 'interface_handle'], name, value)


                            class GrPeer(Entity):
                                """
                                GR peer LDP Id
                                
                                .. attribute:: label_space_id
                                
                                	Label space identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ldp_id
                                
                                	LDP identifier
                                	**type**\:  str
                                
                                .. attribute:: lsr_id
                                
                                	LSR identifier
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, self).__init__()

                                    self.yang_name = "gr-peer"
                                    self.yang_parent_name = "graceful-restartable-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                                    self.ldp_id = YLeaf(YType.str, "ldp-id")

                                    self.lsr_id = YLeaf(YType.str, "lsr-id")
                                    self._segment_path = lambda: "gr-peer"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.GracefulRestartableNeighbor.GrPeer, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "graceful-restart"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.GracefulRestart.Vrf, ['id', 'name'], name, value)


                    class Issu(Entity):
                        """
                        LDP ISSU related information
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu, self).__init__()

                            self.yang_name = "issu"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary)}
                            self._child_list_classes = {}

                            self.ha_statistics = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._children_yang_names.add("ha-statistics")

                            self.ha_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"
                            self._children_yang_names.add("ha-summary")
                            self._segment_path = lambda: "issu"


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_global = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"
                                self._children_yang_names.add("ha-global")

                                self.ha_neighbors = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "ha-statistics"


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync)}
                                    self._child_list_classes = {}

                                    self.init_sync = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._children_yang_names.add("init-sync")
                                    self._segment_path = lambda: "ha-global"


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                        self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                        self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                        self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                        self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                        self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                        self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                        self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                        self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                        self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                        self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                        self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                        self.num_peers = YLeaf(YType.uint32, "num-peers")

                                        self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                        self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                        self._segment_path = lambda: "init-sync"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "issu"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf)}
                                self._child_list_classes = {}

                                self.sessions = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._children_yang_names.add("sessions")

                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "ha-summary"


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                    self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                    self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                    self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                    self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                    self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                    self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                    self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                    self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                    self.total = YLeaf(YType.uint32, "total")
                                    self._segment_path = lambda: "sessions"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Issu.HaSummary.Vrf, ['id', 'name'], name, value)


                    class LdpId(Entity):
                        """
                        Local LDP Id
                        
                        .. attribute:: label_space_id
                        
                        	Label space identifier
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ldp_id
                        
                        	LDP identifier
                        	**type**\:  str
                        
                        .. attribute:: lsr_id
                        
                        	LSR identifier
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId, self).__init__()

                            self.yang_name = "ldp-id"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.label_space_id = YLeaf(YType.uint16, "label-space-id")

                            self.ldp_id = YLeaf(YType.str, "ldp-id")

                            self.lsr_id = YLeaf(YType.str, "lsr-id")
                            self._segment_path = lambda: "ldp-id"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.LdpId, ['label_space_id', 'ldp_id', 'lsr_id'], name, value)


                    class NeighborBriefs(Entity):
                        """
                        The LDP Neighbors (brief)
                        
                        .. attribute:: neighbor_brief
                        
                        	Brief information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`NeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs, self).__init__()

                            self.yang_name = "neighbor-briefs"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-brief" : ("neighbor_brief", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief)}

                            self.neighbor_brief = YList(self)
                            self._segment_path = lambda: "neighbor-briefs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs, [], name, value)


                        class NeighborBrief(Entity):
                            """
                            Brief information on a particular LDP neighbor
                            
                            .. attribute:: is_graceful_restartable
                            
                            	Is graceful restartable
                            	**type**\:  bool
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nbr_br_af_info
                            
                            	Neighbor Brief AF Info
                            	**type**\: list of    :py:class:`NbrBrAfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo>`
                            
                            .. attribute:: nsr_state
                            
                            	NSR readiness state
                            	**type**\:   :py:class:`ShowNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.ShowNsrState>`
                            
                            .. attribute:: up_time_seconds
                            
                            	Up time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief, self).__init__()

                                self.yang_name = "neighbor-brief"
                                self.yang_parent_name = "neighbor-briefs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf)}
                                self._child_list_classes = {"nbr-br-af-info" : ("nbr_br_af_info", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo)}

                                self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.up_time_seconds = YLeaf(YType.uint32, "up-time-seconds")

                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")

                                self.nbr_br_af_info = YList(self)
                                self._segment_path = lambda: "neighbor-brief"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief, ['is_graceful_restartable', 'label_space_id', 'lsr_id', 'nsr_state', 'up_time_seconds'], name, value)


                            class NbrBrAfInfo(Entity):
                                """
                                Neighbor Brief AF Info
                                
                                .. attribute:: address_family
                                
                                	Neighbor Brief Address Family
                                	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                                
                                .. attribute:: num_of_nbr_addresses
                                
                                	Number of neighbor addresses
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_discovery
                                
                                	Number of neighbor discovery sources
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_of_nbr_lbl
                                
                                	Number of neighbor labels
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, self).__init__()

                                    self.yang_name = "nbr-br-af-info"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_family = YLeaf(YType.enumeration, "address-family")

                                    self.num_of_nbr_addresses = YLeaf(YType.uint32, "num-of-nbr-addresses")

                                    self.num_of_nbr_discovery = YLeaf(YType.uint32, "num-of-nbr-discovery")

                                    self.num_of_nbr_lbl = YLeaf(YType.uint32, "num-of-nbr-lbl")
                                    self._segment_path = lambda: "nbr-br-af-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.NbrBrAfInfo, ['address_family', 'num_of_nbr_addresses', 'num_of_nbr_discovery', 'num_of_nbr_lbl'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "neighbor-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborBriefs.NeighborBrief.Vrf, ['id', 'name'], name, value)


                    class NeighborCapabilities(Entity):
                        """
                        LDP Neighbors Capabilities
                        
                        .. attribute:: neighbor_capability
                        
                        	Information on capabilities of a particular LDP neighbor
                        	**type**\: list of    :py:class:`NeighborCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities, self).__init__()

                            self.yang_name = "neighbor-capabilities"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-capability" : ("neighbor_capability", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability)}

                            self.neighbor_capability = YList(self)
                            self._segment_path = lambda: "neighbor-capabilities"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities, [], name, value)


                        class NeighborCapability(Entity):
                            """
                            Information on capabilities of a particular LDP
                            neighbor
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: received
                            
                            	List of received capabilities
                            	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received>`
                            
                            .. attribute:: sent
                            
                            	List of sent capabilities
                            	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, self).__init__()

                                self.yang_name = "neighbor-capability"
                                self.yang_parent_name = "neighbor-capabilities"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"received" : ("received", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received), "sent" : ("sent", MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent)}

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.received = YList(self)
                                self.sent = YList(self)
                                self._segment_path = lambda: "neighbor-capability"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability, ['label_space_id', 'lsr_id'], name, value)


                            class Received(Entity):
                                """
                                List of received capabilities
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, self).__init__()

                                    self.yang_name = "received"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "received"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                            class Sent(Entity):
                                """
                                List of sent capabilities
                                
                                .. attribute:: capability_data
                                
                                	Capability data
                                	**type**\:  str
                                
                                .. attribute:: capability_data_length
                                
                                	Capability data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: description
                                
                                	Capability description
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: type
                                
                                	Capability type (IANA assigned)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, self).__init__()

                                    self.yang_name = "sent"
                                    self.yang_parent_name = "neighbor-capability"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.capability_data = YLeaf(YType.str, "capability-data")

                                    self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                    self.description = YLeaf(YType.str, "description")

                                    self.type = YLeaf(YType.uint16, "type")
                                    self._segment_path = lambda: "sent"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.NeighborCapabilities.NeighborCapability.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                    class Neighbors(Entity):
                        """
                        The LDP Neighbors
                        
                        .. attribute:: neighbor
                        
                        	Information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor" : ("neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor)}

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            Information on a particular LDP neighbor
                            
                            .. attribute:: detailed_information
                            
                            	Detailed information with regards to holdtime, KA, inbound filtering, and Session protection
                            	**type**\:   :py:class:`DetailedInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation>`
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ldp_nbr_bound_ipv4_address_info
                            
                            	Neighbor IPv4 Address Info
                            	**type**\: list of    :py:class:`LdpNbrBoundIpv4AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo>`
                            
                            .. attribute:: ldp_nbr_bound_ipv6_address_info
                            
                            	Neighbor IPv6 Address Info
                            	**type**\: list of    :py:class:`LdpNbrBoundIpv6AddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo>`
                            
                            .. attribute:: ldp_nbr_ipv4_adj_info
                            
                            	Neighbor's IPv4 Adjacency Information
                            	**type**\: list of    :py:class:`LdpNbrIpv4AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo>`
                            
                            .. attribute:: ldp_nbr_ipv6_adj_info
                            
                            	Neighbor's IPv6 Adjacency Information
                            	**type**\: list of    :py:class:`LdpNbrIpv6AdjInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo>`
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: protocol_information
                            
                            	Protocol Information
                            	**type**\:   :py:class:`ProtocolInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation>`
                            
                            .. attribute:: tcp_information
                            
                            	TCP Information
                            	**type**\:   :py:class:`TcpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"detailed-information" : ("detailed_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation), "protocol-information" : ("protocol_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation), "tcp-information" : ("tcp_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation)}
                                self._child_list_classes = {"ldp-nbr-bound-ipv4-address-info" : ("ldp_nbr_bound_ipv4_address_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo), "ldp-nbr-bound-ipv6-address-info" : ("ldp_nbr_bound_ipv6_address_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo), "ldp-nbr-ipv4-adj-info" : ("ldp_nbr_ipv4_adj_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo), "ldp-nbr-ipv6-adj-info" : ("ldp_nbr_ipv6_adj_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo)}

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.detailed_information = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation()
                                self.detailed_information.parent = self
                                self._children_name_map["detailed_information"] = "detailed-information"
                                self._children_yang_names.add("detailed-information")

                                self.protocol_information = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation()
                                self.protocol_information.parent = self
                                self._children_name_map["protocol_information"] = "protocol-information"
                                self._children_yang_names.add("protocol-information")

                                self.tcp_information = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation()
                                self.tcp_information.parent = self
                                self._children_name_map["tcp_information"] = "tcp-information"
                                self._children_yang_names.add("tcp-information")

                                self.ldp_nbr_bound_ipv4_address_info = YList(self)
                                self.ldp_nbr_bound_ipv6_address_info = YList(self)
                                self.ldp_nbr_ipv4_adj_info = YList(self)
                                self.ldp_nbr_ipv6_adj_info = YList(self)
                                self._segment_path = lambda: "neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor, ['label_space_id', 'lsr_id'], name, value)


                            class DetailedInformation(Entity):
                                """
                                Detailed information with regards to holdtime,
                                KA, inbound filtering, and Session protection
                                
                                .. attribute:: advertise_bgp_prefixes
                                
                                	Is BGP labelled prefixes advertised to the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: bgp_advertisement_state
                                
                                	BGP labelled prefixes advertisement state
                                	**type**\:   :py:class:`MgmtLdpNbrBgpAdvtState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNbrBgpAdvtState>`
                                
                                .. attribute:: capabilities
                                
                                	Capabilities sent to and received from neighbor
                                	**type**\:   :py:class:`Capabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities>`
                                
                                .. attribute:: client
                                
                                	Targeted Session clients
                                	**type**\: list of    :py:class:`Client <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client>`
                                
                                .. attribute:: has_ipv4_inbound
                                
                                	IPv4 Inbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv4_outbound
                                
                                	IPv4 Outbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv6_inbound
                                
                                	IPv6 Inbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_ipv6_outbound
                                
                                	IPv6 Outbound label filtering present
                                	**type**\:  bool
                                
                                .. attribute:: has_sp
                                
                                	Session Protection enabled
                                	**type**\:  bool
                                
                                .. attribute:: inbound_ipv4acl
                                
                                	IPv4 Inbound accept ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: inbound_ipv6acl
                                
                                	IPv6 Inbound accept ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: ipv4_duplicate_address
                                
                                	Duplicate IPv4 address bound to this peer
                                	**type**\: list of    :py:class:`Ipv4DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress>`
                                
                                .. attribute:: ipv6_duplicate_address
                                
                                	Duplicate IPv6 address bound to this peer
                                	**type**\: list of    :py:class:`Ipv6DuplicateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress>`
                                
                                .. attribute:: keep_alive_interval
                                
                                	Session keepalive interval in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsr_last_sync_error
                                
                                	Last NSR sync error
                                	**type**\:   :py:class:`MgmtLdpNsrPeerSyncErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncErr>`
                                
                                .. attribute:: nsr_last_sync_nack_reason
                                
                                	Last NSR sync NACK reaston
                                	**type**\:   :py:class:`MgmtLdpNsrPeerLdpSyncNackRsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerLdpSyncNackRsn>`
                                
                                .. attribute:: nsr_sync_state
                                
                                	NSR Sync State
                                	**type**\:   :py:class:`MgmtLdpNsrPeerSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MgmtLdpNsrPeerSyncState>`
                                
                                .. attribute:: outbound_ipv4acl
                                
                                	IPv4 Outbound advertise ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: outbound_ipv6acl
                                
                                	IPv6 Outbound advertise ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: peer_holdtime
                                
                                	Session holdtime value in seconds from the peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: peer_state
                                
                                	Peer state
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: sp_duration
                                
                                	Session protection holdup time duration in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: sp_has_acl
                                
                                	Session protection ACL is present
                                	**type**\:  bool
                                
                                .. attribute:: sp_has_duration
                                
                                	Session Protection has non\-default duration
                                	**type**\:  bool
                                
                                .. attribute:: sp_state
                                
                                	Session Protection state
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: spacl
                                
                                	Session Protection ACL
                                	**type**\:  str
                                
                                	**length:** 0..80
                                
                                .. attribute:: spht_remaining
                                
                                	Session Protection holdup time remaining value in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: spht_running
                                
                                	Session Protection holdup timer is running
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, self).__init__()

                                    self.yang_name = "detailed-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"capabilities" : ("capabilities", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities)}
                                    self._child_list_classes = {"client" : ("client", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client), "ipv4-duplicate-address" : ("ipv4_duplicate_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress), "ipv6-duplicate-address" : ("ipv6_duplicate_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress)}

                                    self.advertise_bgp_prefixes = YLeaf(YType.boolean, "advertise-bgp-prefixes")

                                    self.bgp_advertisement_state = YLeaf(YType.enumeration, "bgp-advertisement-state")

                                    self.has_ipv4_inbound = YLeaf(YType.boolean, "has-ipv4-inbound")

                                    self.has_ipv4_outbound = YLeaf(YType.boolean, "has-ipv4-outbound")

                                    self.has_ipv6_inbound = YLeaf(YType.boolean, "has-ipv6-inbound")

                                    self.has_ipv6_outbound = YLeaf(YType.boolean, "has-ipv6-outbound")

                                    self.has_sp = YLeaf(YType.boolean, "has-sp")

                                    self.inbound_ipv4acl = YLeaf(YType.str, "inbound-ipv4acl")

                                    self.inbound_ipv6acl = YLeaf(YType.str, "inbound-ipv6acl")

                                    self.keep_alive_interval = YLeaf(YType.uint32, "keep-alive-interval")

                                    self.nsr_last_sync_error = YLeaf(YType.enumeration, "nsr-last-sync-error")

                                    self.nsr_last_sync_nack_reason = YLeaf(YType.enumeration, "nsr-last-sync-nack-reason")

                                    self.nsr_sync_state = YLeaf(YType.enumeration, "nsr-sync-state")

                                    self.outbound_ipv4acl = YLeaf(YType.str, "outbound-ipv4acl")

                                    self.outbound_ipv6acl = YLeaf(YType.str, "outbound-ipv6acl")

                                    self.peer_holdtime = YLeaf(YType.uint32, "peer-holdtime")

                                    self.peer_state = YLeaf(YType.str, "peer-state")

                                    self.sp_duration = YLeaf(YType.uint32, "sp-duration")

                                    self.sp_has_acl = YLeaf(YType.boolean, "sp-has-acl")

                                    self.sp_has_duration = YLeaf(YType.boolean, "sp-has-duration")

                                    self.sp_state = YLeaf(YType.str, "sp-state")

                                    self.spacl = YLeaf(YType.str, "spacl")

                                    self.spht_remaining = YLeaf(YType.uint32, "spht-remaining")

                                    self.spht_running = YLeaf(YType.boolean, "spht-running")

                                    self.capabilities = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities()
                                    self.capabilities.parent = self
                                    self._children_name_map["capabilities"] = "capabilities"
                                    self._children_yang_names.add("capabilities")

                                    self.client = YList(self)
                                    self.ipv4_duplicate_address = YList(self)
                                    self.ipv6_duplicate_address = YList(self)
                                    self._segment_path = lambda: "detailed-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation, ['advertise_bgp_prefixes', 'bgp_advertisement_state', 'has_ipv4_inbound', 'has_ipv4_outbound', 'has_ipv6_inbound', 'has_ipv6_outbound', 'has_sp', 'inbound_ipv4acl', 'inbound_ipv6acl', 'keep_alive_interval', 'nsr_last_sync_error', 'nsr_last_sync_nack_reason', 'nsr_sync_state', 'outbound_ipv4acl', 'outbound_ipv6acl', 'peer_holdtime', 'peer_state', 'sp_duration', 'sp_has_acl', 'sp_has_duration', 'sp_state', 'spacl', 'spht_remaining', 'spht_running'], name, value)


                                class Capabilities(Entity):
                                    """
                                    Capabilities sent to and received from neighbor
                                    
                                    .. attribute:: received
                                    
                                    	List of received capabilities
                                    	**type**\: list of    :py:class:`Received <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received>`
                                    
                                    .. attribute:: sent
                                    
                                    	List of sent capabilities
                                    	**type**\: list of    :py:class:`Sent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, self).__init__()

                                        self.yang_name = "capabilities"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"received" : ("received", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received), "sent" : ("sent", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent)}

                                        self.received = YList(self)
                                        self.sent = YList(self)
                                        self._segment_path = lambda: "capabilities"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities, [], name, value)


                                    class Received(Entity):
                                        """
                                        List of received capabilities
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\:  str
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\:  str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, self).__init__()

                                            self.yang_name = "received"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.capability_data = YLeaf(YType.str, "capability-data")

                                            self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                            self.description = YLeaf(YType.str, "description")

                                            self.type = YLeaf(YType.uint16, "type")
                                            self._segment_path = lambda: "received"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Received, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                    class Sent(Entity):
                                        """
                                        List of sent capabilities
                                        
                                        .. attribute:: capability_data
                                        
                                        	Capability data
                                        	**type**\:  str
                                        
                                        .. attribute:: capability_data_length
                                        
                                        	Capability data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: description
                                        
                                        	Capability description
                                        	**type**\:  str
                                        
                                        	**length:** 0..80
                                        
                                        .. attribute:: type
                                        
                                        	Capability type (IANA assigned)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, self).__init__()

                                            self.yang_name = "sent"
                                            self.yang_parent_name = "capabilities"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.capability_data = YLeaf(YType.str, "capability-data")

                                            self.capability_data_length = YLeaf(YType.uint16, "capability-data-length")

                                            self.description = YLeaf(YType.str, "description")

                                            self.type = YLeaf(YType.uint16, "type")
                                            self._segment_path = lambda: "sent"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Capabilities.Sent, ['capability_data', 'capability_data_length', 'description', 'type'], name, value)


                                class Client(Entity):
                                    """
                                    Targeted Session clients
                                    
                                    .. attribute:: name
                                    
                                    	Client's name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, self).__init__()

                                        self.yang_name = "client"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.name = YLeaf(YType.str, "name")
                                        self._segment_path = lambda: "client"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Client, ['name'], name, value)


                                class Ipv4DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv4 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv4-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"address" : ("address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address)}
                                        self._child_list_classes = {}

                                        self.address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._children_yang_names.add("address")
                                        self._segment_path = lambda: "ipv4-duplicate-address"


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv4-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv4DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class Ipv6DuplicateAddress(Entity):
                                    """
                                    Duplicate IPv6 address bound to this peer
                                    
                                    .. attribute:: address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress, self).__init__()

                                        self.yang_name = "ipv6-duplicate-address"
                                        self.yang_parent_name = "detailed-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"address" : ("address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address)}
                                        self._child_list_classes = {}

                                        self.address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                        self._children_yang_names.add("address")
                                        self._segment_path = lambda: "ipv6-duplicate-address"


                                    class Address(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                        
                                        .. attribute:: dummy
                                        
                                        	No Address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ipv4
                                        
                                        	IPv4 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address type
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, self).__init__()

                                            self.yang_name = "address"
                                            self.yang_parent_name = "ipv6-duplicate-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.dummy = YLeaf(YType.uint8, "dummy")

                                            self.ipv4 = YLeaf(YType.str, "ipv4")

                                            self.ipv6 = YLeaf(YType.str, "ipv6")
                                            self._segment_path = lambda: "address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.DetailedInformation.Ipv6DuplicateAddress.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrBoundIpv4AddressInfo(Entity):
                                """
                                Neighbor IPv4 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv4-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv4-address-info"


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv4-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv4AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrBoundIpv6AddressInfo(Entity):
                                """
                                Neighbor IPv6 Address Info
                                
                                .. attribute:: address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-bound-ipv6-address-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"address" : ("address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address)}
                                    self._child_list_classes = {}

                                    self.address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                    self._children_yang_names.add("address")
                                    self._segment_path = lambda: "ldp-nbr-bound-ipv6-address-info"


                                class Address(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, self).__init__()

                                        self.yang_name = "address"
                                        self.yang_parent_name = "ldp-nbr-bound-ipv6-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrBoundIpv6AddressInfo.Address, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrIpv4AdjInfo(Entity):
                                """
                                Neighbor's IPv4 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv4-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup)}
                                    self._child_list_classes = {}

                                    self.adjacency_group = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._children_yang_names.add("adjacency-group")
                                    self._segment_path = lambda: "ldp-nbr-ipv4-adj-info"


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv4-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData)}
                                        self._child_list_classes = {}

                                        self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                        self.link_hello_data = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"
                                        self._children_yang_names.add("link-hello-data")

                                        self.target_hello_data = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._children_yang_names.add("target-hello-data")
                                        self._segment_path = lambda: "adjacency-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "link-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                            self._child_list_classes = {}

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.local_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                            self._children_yang_names.add("local-address")

                                            self.target_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._children_yang_names.add("target-address")
                                            self._segment_path = lambda: "target-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv4AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class LdpNbrIpv6AdjInfo(Entity):
                                """
                                Neighbor's IPv6 Adjacency Information
                                
                                .. attribute:: adjacency_group
                                
                                	Adjacency group
                                	**type**\:   :py:class:`AdjacencyGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo, self).__init__()

                                    self.yang_name = "ldp-nbr-ipv6-adj-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"adjacency-group" : ("adjacency_group", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup)}
                                    self._child_list_classes = {}

                                    self.adjacency_group = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup()
                                    self.adjacency_group.parent = self
                                    self._children_name_map["adjacency_group"] = "adjacency-group"
                                    self._children_yang_names.add("adjacency-group")
                                    self._segment_path = lambda: "ldp-nbr-ipv6-adj-info"


                                class AdjacencyGroup(Entity):
                                    """
                                    Adjacency group
                                    
                                    .. attribute:: hello_type
                                    
                                    	HelloType
                                    	**type**\:   :py:class:`LdpAdjUnionDiscrim <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAdjUnionDiscrim>`
                                    
                                    .. attribute:: link_hello_data
                                    
                                    	Link hello
                                    	**type**\:   :py:class:`LinkHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData>`
                                    
                                    .. attribute:: target_hello_data
                                    
                                    	Target Hello
                                    	**type**\:   :py:class:`TargetHelloData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, self).__init__()

                                        self.yang_name = "adjacency-group"
                                        self.yang_parent_name = "ldp-nbr-ipv6-adj-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"link-hello-data" : ("link_hello_data", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData), "target-hello-data" : ("target_hello_data", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData)}
                                        self._child_list_classes = {}

                                        self.hello_type = YLeaf(YType.enumeration, "hello-type")

                                        self.link_hello_data = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData()
                                        self.link_hello_data.parent = self
                                        self._children_name_map["link_hello_data"] = "link-hello-data"
                                        self._children_yang_names.add("link-hello-data")

                                        self.target_hello_data = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData()
                                        self.target_hello_data.parent = self
                                        self._children_name_map["target_hello_data"] = "target-hello-data"
                                        self._children_yang_names.add("target-hello-data")
                                        self._segment_path = lambda: "adjacency-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup, ['hello_type'], name, value)


                                    class LinkHelloData(Entity):
                                        """
                                        Link hello
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, self).__init__()

                                            self.yang_name = "link-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface = YLeaf(YType.str, "interface")

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "link-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.LinkHelloData, ['interface', 'interface_name'], name, value)


                                    class TargetHelloData(Entity):
                                        """
                                        Target Hello
                                        
                                        .. attribute:: local_address
                                        
                                        	Local Address
                                        	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress>`
                                        
                                        .. attribute:: state
                                        
                                        	State
                                        	**type**\:   :py:class:`DhcbState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.DhcbState>`
                                        
                                        .. attribute:: target_address
                                        
                                        	Target Address
                                        	**type**\:   :py:class:`TargetAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress>`
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, self).__init__()

                                            self.yang_name = "target-hello-data"
                                            self.yang_parent_name = "adjacency-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"local-address" : ("local_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress), "target-address" : ("target_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress)}
                                            self._child_list_classes = {}

                                            self.state = YLeaf(YType.enumeration, "state")

                                            self.local_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress()
                                            self.local_address.parent = self
                                            self._children_name_map["local_address"] = "local-address"
                                            self._children_yang_names.add("local-address")

                                            self.target_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress()
                                            self.target_address.parent = self
                                            self._children_name_map["target_address"] = "target-address"
                                            self._children_yang_names.add("target-address")
                                            self._segment_path = lambda: "target-hello-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData, ['state'], name, value)


                                        class LocalAddress(Entity):
                                            """
                                            Local Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, self).__init__()

                                                self.yang_name = "local-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.LocalAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                        class TargetAddress(Entity):
                                            """
                                            Target Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                            
                                            .. attribute:: dummy
                                            
                                            	No Address
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ipv4
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'mpls-ldp-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, self).__init__()

                                                self.yang_name = "target-address"
                                                self.yang_parent_name = "target-hello-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.dummy = YLeaf(YType.uint8, "dummy")

                                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                                self.ipv6 = YLeaf(YType.str, "ipv6")
                                                self._segment_path = lambda: "target-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.LdpNbrIpv6AdjInfo.AdjacencyGroup.TargetHelloData.TargetAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                            class ProtocolInformation(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: downstream_on_demand
                                
                                	Is Label advertisment mode in Downstream On Demand mode or Not
                                	**type**\:  bool
                                
                                .. attribute:: ta_graceful_restart_adjacency
                                
                                	Graceful restart information
                                	**type**\:   :py:class:`TaGracefulRestartAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency>`
                                
                                .. attribute:: ta_holdtime
                                
                                	Session holdtime in sec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_rcvd
                                
                                	Number of pies received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_pies_sent
                                
                                	Number of pies sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ta_state
                                
                                	State
                                	**type**\:  str
                                
                                .. attribute:: ta_up_time_seconds
                                
                                	Up time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, self).__init__()

                                    self.yang_name = "protocol-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ta-graceful-restart-adjacency" : ("ta_graceful_restart_adjacency", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency)}
                                    self._child_list_classes = {}

                                    self.downstream_on_demand = YLeaf(YType.boolean, "downstream-on-demand")

                                    self.ta_holdtime = YLeaf(YType.uint32, "ta-holdtime")

                                    self.ta_pies_rcvd = YLeaf(YType.uint32, "ta-pies-rcvd")

                                    self.ta_pies_sent = YLeaf(YType.uint32, "ta-pies-sent")

                                    self.ta_state = YLeaf(YType.str, "ta-state")

                                    self.ta_up_time_seconds = YLeaf(YType.uint32, "ta-up-time-seconds")

                                    self.ta_graceful_restart_adjacency = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency()
                                    self.ta_graceful_restart_adjacency.parent = self
                                    self._children_name_map["ta_graceful_restart_adjacency"] = "ta-graceful-restart-adjacency"
                                    self._children_yang_names.add("ta-graceful-restart-adjacency")
                                    self._segment_path = lambda: "protocol-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation, ['downstream_on_demand', 'ta_holdtime', 'ta_pies_rcvd', 'ta_pies_sent', 'ta_state', 'ta_up_time_seconds'], name, value)


                                class TaGracefulRestartAdjacency(Entity):
                                    """
                                    Graceful restart information
                                    
                                    .. attribute:: is_graceful_restartable
                                    
                                    	Is graceful restartable
                                    	**type**\:  bool
                                    
                                    .. attribute:: reconnect_timeout
                                    
                                    	Reconnect timeout
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recovery_time
                                    
                                    	Recovery time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, self).__init__()

                                        self.yang_name = "ta-graceful-restart-adjacency"
                                        self.yang_parent_name = "protocol-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.is_graceful_restartable = YLeaf(YType.boolean, "is-graceful-restartable")

                                        self.reconnect_timeout = YLeaf(YType.uint32, "reconnect-timeout")

                                        self.recovery_time = YLeaf(YType.uint32, "recovery-time")
                                        self._segment_path = lambda: "ta-graceful-restart-adjacency"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.ProtocolInformation.TaGracefulRestartAdjacency, ['is_graceful_restartable', 'reconnect_timeout', 'recovery_time'], name, value)


                            class TcpInformation(Entity):
                                """
                                TCP Information
                                
                                .. attribute:: foreign_host
                                
                                	Foreign host address
                                	**type**\:   :py:class:`ForeignHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost>`
                                
                                .. attribute:: foreign_port
                                
                                	Foreign port number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_md5_on
                                
                                	Is MD5 Digest on
                                	**type**\:  bool
                                
                                .. attribute:: local_host
                                
                                	Local host address
                                	**type**\:   :py:class:`LocalHost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost>`
                                
                                .. attribute:: local_port
                                
                                	Local port number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, self).__init__()

                                    self.yang_name = "tcp-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"foreign-host" : ("foreign_host", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost), "local-host" : ("local_host", MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost)}
                                    self._child_list_classes = {}

                                    self.foreign_port = YLeaf(YType.uint16, "foreign-port")

                                    self.is_md5_on = YLeaf(YType.boolean, "is-md5-on")

                                    self.local_port = YLeaf(YType.uint16, "local-port")

                                    self.foreign_host = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost()
                                    self.foreign_host.parent = self
                                    self._children_name_map["foreign_host"] = "foreign-host"
                                    self._children_yang_names.add("foreign-host")

                                    self.local_host = MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost()
                                    self.local_host.parent = self
                                    self._children_name_map["local_host"] = "local-host"
                                    self._children_yang_names.add("local-host")
                                    self._segment_path = lambda: "tcp-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation, ['foreign_port', 'is_md5_on', 'local_port'], name, value)


                                class ForeignHost(Entity):
                                    """
                                    Foreign host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, self).__init__()

                                        self.yang_name = "foreign-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "foreign-host"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.ForeignHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                                class LocalHost(Entity):
                                    """
                                    Local host address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                    
                                    .. attribute:: dummy
                                    
                                    	No Address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, self).__init__()

                                        self.yang_name = "local-host"
                                        self.yang_parent_name = "tcp-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.dummy = YLeaf(YType.uint8, "dummy")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "local-host"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Neighbors.Neighbor.TcpInformation.LocalHost, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                    class Nsr(Entity):
                        """
                        LDP NSR related information
                        
                        .. attribute:: ha_statistics
                        
                        	LDP NSR Statistics related information
                        	**type**\:   :py:class:`HaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics>`
                        
                        .. attribute:: ha_summary
                        
                        	LDP HA Summary
                        	**type**\:   :py:class:`HaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary>`
                        
                        .. attribute:: nsr_pending
                        
                        	LDP NSR Pending related information
                        	**type**\:   :py:class:`NsrPending <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr, self).__init__()

                            self.yang_name = "nsr"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ha-statistics" : ("ha_statistics", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics), "ha-summary" : ("ha_summary", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary), "nsr-pending" : ("nsr_pending", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending)}
                            self._child_list_classes = {}

                            self.ha_statistics = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics()
                            self.ha_statistics.parent = self
                            self._children_name_map["ha_statistics"] = "ha-statistics"
                            self._children_yang_names.add("ha-statistics")

                            self.ha_summary = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary()
                            self.ha_summary.parent = self
                            self._children_name_map["ha_summary"] = "ha-summary"
                            self._children_yang_names.add("ha-summary")

                            self.nsr_pending = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending()
                            self.nsr_pending.parent = self
                            self._children_name_map["nsr_pending"] = "nsr-pending"
                            self._children_yang_names.add("nsr-pending")
                            self._segment_path = lambda: "nsr"


                        class HaStatistics(Entity):
                            """
                            LDP NSR Statistics related information
                            
                            .. attribute:: ha_global
                            
                            	LDP NSR Global Statistics information
                            	**type**\:   :py:class:`HaGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal>`
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics, self).__init__()

                                self.yang_name = "ha-statistics"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-global" : ("ha_global", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal), "ha-neighbors" : ("ha_neighbors", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_global = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal()
                                self.ha_global.parent = self
                                self._children_name_map["ha_global"] = "ha-global"
                                self._children_yang_names.add("ha-global")

                                self.ha_neighbors = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "ha-statistics"


                            class HaGlobal(Entity):
                                """
                                LDP NSR Global Statistics information
                                
                                .. attribute:: init_sync
                                
                                	Init Sync
                                	**type**\:   :py:class:`InitSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal, self).__init__()

                                    self.yang_name = "ha-global"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"init-sync" : ("init_sync", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync)}
                                    self._child_list_classes = {}

                                    self.init_sync = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync()
                                    self.init_sync.parent = self
                                    self._children_name_map["init_sync"] = "init-sync"
                                    self._children_yang_names.add("init-sync")
                                    self._segment_path = lambda: "ha-global"


                                class InitSync(Entity):
                                    """
                                    Init Sync
                                    
                                    .. attribute:: init_sync_end
                                    
                                    	Init Sync End Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_sync_start
                                    
                                    	Init Sync Start Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_default_mtu
                                    
                                    	default IPC MTU bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_exceeded_mtu_msg_cnt
                                    
                                    	ipc exceeded mtu msg cnt
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_max_rx_batch_bytes
                                    
                                    	biggest IPC RX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_max_tx_batch_bytes
                                    
                                    	biggest IPC TX bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_rx_bytes
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_rx_cnt
                                    
                                    	num IPC msgs rxed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_msg_tx_bytes
                                    
                                    	total IPC bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: ipc_msg_tx_cnt
                                    
                                    	num IPC msgs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_restart_cnt
                                    
                                    	number of times ipc has been restarted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipc_tx_fail_cnt
                                    
                                    	number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_cfged
                                    
                                    	TRUE if NSR configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_synced
                                    
                                    	TRUE if NSR synced
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_cap_rcvd
                                    
                                    	Number of Rcvd Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_cap_sent
                                    
                                    	Number of Sent Capabilities objects
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl
                                    
                                    	Number of label bindings
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lbl_adv
                                    
                                    	Num of lbl adv
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_lcl_addr_wd
                                    
                                    	Num of lcl address withdraw
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_peers
                                    
                                    	Number of Peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_pfx
                                    
                                    	Number of binding prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_ipc_tx_fail_cnt
                                    
                                    	total number of ipc send failures
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, self).__init__()

                                        self.yang_name = "init-sync"
                                        self.yang_parent_name = "ha-global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                        self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                        self.ipc_default_mtu = YLeaf(YType.uint32, "ipc-default-mtu")

                                        self.ipc_exceeded_mtu_msg_cnt = YLeaf(YType.uint32, "ipc-exceeded-mtu-msg-cnt")

                                        self.ipc_max_rx_batch_bytes = YLeaf(YType.uint32, "ipc-max-rx-batch-bytes")

                                        self.ipc_max_tx_batch_bytes = YLeaf(YType.uint32, "ipc-max-tx-batch-bytes")

                                        self.ipc_msg_rx_bytes = YLeaf(YType.uint32, "ipc-msg-rx-bytes")

                                        self.ipc_msg_rx_cnt = YLeaf(YType.uint32, "ipc-msg-rx-cnt")

                                        self.ipc_msg_tx_bytes = YLeaf(YType.uint32, "ipc-msg-tx-bytes")

                                        self.ipc_msg_tx_cnt = YLeaf(YType.uint32, "ipc-msg-tx-cnt")

                                        self.ipc_restart_cnt = YLeaf(YType.uint32, "ipc-restart-cnt")

                                        self.ipc_tx_fail_cnt = YLeaf(YType.uint32, "ipc-tx-fail-cnt")

                                        self.nsr_cfged = YLeaf(YType.boolean, "nsr-cfged")

                                        self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                                        self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                        self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                        self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                        self.num_lbl_adv = YLeaf(YType.uint32, "num-lbl-adv")

                                        self.num_lcl_addr_wd = YLeaf(YType.uint32, "num-lcl-addr-wd")

                                        self.num_peers = YLeaf(YType.uint32, "num-peers")

                                        self.num_pfx = YLeaf(YType.uint32, "num-pfx")

                                        self.total_ipc_tx_fail_cnt = YLeaf(YType.uint32, "total-ipc-tx-fail-cnt")
                                        self._segment_path = lambda: "init-sync"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaGlobal.InitSync, ['init_sync_end', 'init_sync_start', 'ipc_default_mtu', 'ipc_exceeded_mtu_msg_cnt', 'ipc_max_rx_batch_bytes', 'ipc_max_tx_batch_bytes', 'ipc_msg_rx_bytes', 'ipc_msg_rx_cnt', 'ipc_msg_tx_bytes', 'ipc_msg_tx_cnt', 'ipc_restart_cnt', 'ipc_tx_fail_cnt', 'nsr_cfged', 'nsr_synced', 'num_cap_rcvd', 'num_cap_sent', 'num_lbl', 'num_lbl_adv', 'num_lcl_addr_wd', 'num_peers', 'num_pfx', 'total_ipc_tx_fail_cnt'], name, value)


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "ha-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaStatistics.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                        class HaSummary(Entity):
                            """
                            LDP HA Summary
                            
                            .. attribute:: sessions
                            
                            	Session summary
                            	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary, self).__init__()

                                self.yang_name = "ha-summary"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sessions" : ("sessions", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions), "vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf)}
                                self._child_list_classes = {}

                                self.sessions = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions()
                                self.sessions.parent = self
                                self._children_name_map["sessions"] = "sessions"
                                self._children_yang_names.add("sessions")

                                self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "ha-summary"


                            class Sessions(Entity):
                                """
                                Session summary
                                
                                .. attribute:: nsr_eligible
                                
                                	NSR eligible sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_app_wait
                                
                                	Number of sessions in NSR app\-wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_none
                                
                                	Number of sessions in NSR none state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_operational
                                
                                	Number of sessions in NSR operational state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_prepare
                                
                                	Number of sessions in NSR prepare state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_ready
                                
                                	Number of sessions in NSR ready state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase1
                                
                                	Number of sessions in NSR TCP phase 1 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_tcp_phase2
                                
                                	Number of sessions in NSR TCP phase 2 state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state_wait
                                
                                	Number of sessions in NSR wait state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total
                                
                                	Total sessions
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions, self).__init__()

                                    self.yang_name = "sessions"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_eligible = YLeaf(YType.uint32, "nsr-eligible")

                                    self.nsr_state_app_wait = YLeaf(YType.uint32, "nsr-state-app-wait")

                                    self.nsr_state_none = YLeaf(YType.uint32, "nsr-state-none")

                                    self.nsr_state_operational = YLeaf(YType.uint32, "nsr-state-operational")

                                    self.nsr_state_prepare = YLeaf(YType.uint32, "nsr-state-prepare")

                                    self.nsr_state_ready = YLeaf(YType.uint32, "nsr-state-ready")

                                    self.nsr_state_tcp_phase1 = YLeaf(YType.uint32, "nsr-state-tcp-phase1")

                                    self.nsr_state_tcp_phase2 = YLeaf(YType.uint32, "nsr-state-tcp-phase2")

                                    self.nsr_state_wait = YLeaf(YType.uint32, "nsr-state-wait")

                                    self.total = YLeaf(YType.uint32, "total")
                                    self._segment_path = lambda: "sessions"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Sessions, ['nsr_eligible', 'nsr_state_app_wait', 'nsr_state_none', 'nsr_state_operational', 'nsr_state_prepare', 'nsr_state_ready', 'nsr_state_tcp_phase1', 'nsr_state_tcp_phase2', 'nsr_state_wait', 'total'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: id
                                
                                	VRF Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "ha-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.id = YLeaf(YType.uint32, "id")

                                    self.name = YLeaf(YType.str, "name")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.HaSummary.Vrf, ['id', 'name'], name, value)


                        class NsrPending(Entity):
                            """
                            LDP NSR Pending related information
                            
                            .. attribute:: ha_neighbors
                            
                            	The LDP HA Neighbors
                            	**type**\:   :py:class:`HaNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending, self).__init__()

                                self.yang_name = "nsr-pending"
                                self.yang_parent_name = "nsr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ha-neighbors" : ("ha_neighbors", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors)}
                                self._child_list_classes = {}

                                self.ha_neighbors = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors()
                                self.ha_neighbors.parent = self
                                self._children_name_map["ha_neighbors"] = "ha-neighbors"
                                self._children_yang_names.add("ha-neighbors")
                                self._segment_path = lambda: "nsr-pending"


                            class HaNeighbors(Entity):
                                """
                                The LDP HA Neighbors
                                
                                .. attribute:: ha_neighbor
                                
                                	Information on a particular LDP HA neighbor
                                	**type**\: list of    :py:class:`HaNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor>`
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, self).__init__()

                                    self.yang_name = "ha-neighbors"
                                    self.yang_parent_name = "nsr-pending"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ha-neighbor" : ("ha_neighbor", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor)}

                                    self.ha_neighbor = YList(self)
                                    self._segment_path = lambda: "ha-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors, [], name, value)


                                class HaNeighbor(Entity):
                                    """
                                    Information on a particular LDP HA neighbor
                                    
                                    .. attribute:: init_sync_info
                                    
                                    	NSR Init Sync Info
                                    	**type**\:   :py:class:`InitSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo>`
                                    
                                    .. attribute:: label_space_id
                                    
                                    	Label space ID of neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lbl_spc_id
                                    
                                    	lbl spc id
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsr_id
                                    
                                    	LSR ID of neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsr_id_xr
                                    
                                    	lsr id xr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sync_state
                                    
                                    	nsr sync state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: num_msg
                                    
                                    	Number of sync messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: steady_state_sync_info
                                    
                                    	NSR Steady State Sync Info
                                    	**type**\:   :py:class:`SteadyStateSyncInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo>`
                                    
                                    

                                    """

                                    _prefix = 'mpls-ldp-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, self).__init__()

                                        self.yang_name = "ha-neighbor"
                                        self.yang_parent_name = "ha-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"init-sync-info" : ("init_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo), "steady-state-sync-info" : ("steady_state_sync_info", MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo)}
                                        self._child_list_classes = {}

                                        self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                        self.lbl_spc_id = YLeaf(YType.uint16, "lbl-spc-id")

                                        self.lsr_id = YLeaf(YType.str, "lsr-id")

                                        self.lsr_id_xr = YLeaf(YType.uint32, "lsr-id-xr")

                                        self.nsr_sync_state = YLeaf(YType.int32, "nsr-sync-state")

                                        self.num_msg = YLeaf(YType.uint32, "num-msg")

                                        self.init_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo()
                                        self.init_sync_info.parent = self
                                        self._children_name_map["init_sync_info"] = "init-sync-info"
                                        self._children_yang_names.add("init-sync-info")

                                        self.steady_state_sync_info = MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo()
                                        self.steady_state_sync_info.parent = self
                                        self._children_name_map["steady_state_sync_info"] = "steady-state-sync-info"
                                        self._children_yang_names.add("steady-state-sync-info")
                                        self._segment_path = lambda: "ha-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor, ['label_space_id', 'lbl_spc_id', 'lsr_id', 'lsr_id_xr', 'nsr_sync_state', 'num_msg'], name, value)


                                    class InitSyncInfo(Entity):
                                        """
                                        NSR Init Sync Info
                                        
                                        .. attribute:: init_sync_end
                                        
                                        	Init Sync End Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: init_sync_start
                                        
                                        	Init Sync Start Time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_addr
                                        
                                        	Number of peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_app_bytes
                                        
                                        	Number of external App data bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_duplicate_addr
                                        
                                        	Number of duplicate peer addresses
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_lbl
                                        
                                        	Number of peer bindings
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_rx_bytes
                                        
                                        	Number of unprocessed Rx buffer bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, self).__init__()

                                            self.yang_name = "init-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.init_sync_end = YLeaf(YType.uint32, "init-sync-end")

                                            self.init_sync_start = YLeaf(YType.uint32, "init-sync-start")

                                            self.num_addr = YLeaf(YType.uint32, "num-addr")

                                            self.num_app_bytes = YLeaf(YType.uint32, "num-app-bytes")

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_duplicate_addr = YLeaf(YType.uint32, "num-duplicate-addr")

                                            self.num_lbl = YLeaf(YType.uint32, "num-lbl")

                                            self.num_rx_bytes = YLeaf(YType.uint32, "num-rx-bytes")
                                            self._segment_path = lambda: "init-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.InitSyncInfo, ['init_sync_end', 'init_sync_start', 'num_addr', 'num_app_bytes', 'num_cap_rcvd', 'num_cap_sent', 'num_duplicate_addr', 'num_lbl', 'num_rx_bytes'], name, value)


                                    class SteadyStateSyncInfo(Entity):
                                        """
                                        NSR Steady State Sync Info
                                        
                                        .. attribute:: num_cap_rcvd
                                        
                                        	Num of Rcvd Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_cap_sent
                                        
                                        	Num of Sent Capabilities
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_join
                                        
                                        	Number of standby adj join
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_stdby_adj_leave
                                        
                                        	Number of standby adj leave
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_rq
                                        
                                        	Number of remote label request events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_lbl_wd
                                        
                                        	Number of remote label withdraw events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'mpls-ldp-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, self).__init__()

                                            self.yang_name = "steady-state-sync-info"
                                            self.yang_parent_name = "ha-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.num_cap_rcvd = YLeaf(YType.uint32, "num-cap-rcvd")

                                            self.num_cap_sent = YLeaf(YType.uint32, "num-cap-sent")

                                            self.num_stdby_adj_join = YLeaf(YType.uint32, "num-stdby-adj-join")

                                            self.num_stdby_adj_leave = YLeaf(YType.uint32, "num-stdby-adj-leave")

                                            self.rem_lbl_rq = YLeaf(YType.uint32, "rem-lbl-rq")

                                            self.rem_lbl_wd = YLeaf(YType.uint32, "rem-lbl-wd")
                                            self._segment_path = lambda: "steady-state-sync-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Nsr.NsrPending.HaNeighbors.HaNeighbor.SteadyStateSyncInfo, ['num_cap_rcvd', 'num_cap_sent', 'num_stdby_adj_join', 'num_stdby_adj_leave', 'rem_lbl_rq', 'rem_lbl_wd'], name, value)


                    class Parameters(Entity):
                        """
                        LDP parameters
                        
                        .. attribute:: address_family_parameter
                        
                        	Per AF parameters
                        	**type**\: list of    :py:class:`AddressFamilyParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter>`
                        
                        .. attribute:: af_binding_withdraw_delay
                        
                        	Delay (sec) in Binding Withdrawal for an Address Family
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: discovery_quick_start_disabled_on_interfaces
                        
                        	Discovery quick\-start disabled on some LDP\-enabled interfaces
                        	**type**\:  bool
                        
                        .. attribute:: global_discovery_quick_start_disabled
                        
                        	Discovery quick\-start globally disabled
                        	**type**\:  bool
                        
                        .. attribute:: global_md5_password_enabled
                        
                        	Global MD5 password enabled
                        	**type**\:  bool
                        
                        .. attribute:: graceful_restart_information
                        
                        	Graceful restart information
                        	**type**\:   :py:class:`GracefulRestartInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation>`
                        
                        .. attribute:: hello_hold_time
                        
                        	Hello hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_interval
                        
                        	Hello interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: housekeeping_timer_interval
                        
                        	Housekeeping periodic timer interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: igp_sync_delay_time_for_interface
                        
                        	Interface IGP sync delay time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: igp_sync_delay_time_on_restart
                        
                        	IGP sync delay time on process restart in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: keepalive_interval
                        
                        	Keepalive interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_out_of_mem_state
                        
                        	LDP Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldp_recovery_timeout
                        
                        	LDP recovery timeout with LSD
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: le_no_route_timeout
                        
                        	LIB entry no route timeout
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_attached
                        
                        	Maximum number of LDP enabled attached interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_intf_te
                        
                        	Maximum number of LDP enabled TE interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_peer
                        
                        	Maximum number of LDP peers
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	TRUE if NSR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: nsr_synced
                        
                        	TRUE if LDP is standby and is NSR Sync\-ed with active
                        	**type**\:  bool
                        
                        .. attribute:: protocol_version
                        
                        	Protocol version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role_is_active
                        
                        	Is process role active or standby
                        	**type**\:  bool
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_hold_time
                        
                        	Session hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_hold_time
                        
                        	Targeted hello hold time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: targeted_hello_interval
                        
                        	Targeted hello interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters, self).__init__()

                            self.yang_name = "parameters"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"graceful-restart-information" : ("graceful_restart_information", MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation)}
                            self._child_list_classes = {"address-family-parameter" : ("address_family_parameter", MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter)}

                            self.af_binding_withdraw_delay = YLeaf(YType.uint32, "af-binding-withdraw-delay")

                            self.discovery_quick_start_disabled_on_interfaces = YLeaf(YType.boolean, "discovery-quick-start-disabled-on-interfaces")

                            self.global_discovery_quick_start_disabled = YLeaf(YType.boolean, "global-discovery-quick-start-disabled")

                            self.global_md5_password_enabled = YLeaf(YType.boolean, "global-md5-password-enabled")

                            self.hello_hold_time = YLeaf(YType.uint32, "hello-hold-time")

                            self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                            self.housekeeping_timer_interval = YLeaf(YType.uint32, "housekeeping-timer-interval")

                            self.igp_sync_delay_time_for_interface = YLeaf(YType.uint32, "igp-sync-delay-time-for-interface")

                            self.igp_sync_delay_time_on_restart = YLeaf(YType.uint32, "igp-sync-delay-time-on-restart")

                            self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                            self.ldp_out_of_mem_state = YLeaf(YType.uint32, "ldp-out-of-mem-state")

                            self.ldp_recovery_timeout = YLeaf(YType.uint32, "ldp-recovery-timeout")

                            self.le_no_route_timeout = YLeaf(YType.uint32, "le-no-route-timeout")

                            self.max_intf_attached = YLeaf(YType.uint32, "max-intf-attached")

                            self.max_intf_te = YLeaf(YType.uint32, "max-intf-te")

                            self.max_peer = YLeaf(YType.uint32, "max-peer")

                            self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                            self.nsr_synced = YLeaf(YType.boolean, "nsr-synced")

                            self.protocol_version = YLeaf(YType.uint32, "protocol-version")

                            self.role_is_active = YLeaf(YType.boolean, "role-is-active")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.session_hold_time = YLeaf(YType.uint32, "session-hold-time")

                            self.targeted_hello_hold_time = YLeaf(YType.uint32, "targeted-hello-hold-time")

                            self.targeted_hello_interval = YLeaf(YType.uint32, "targeted-hello-interval")

                            self.graceful_restart_information = MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation()
                            self.graceful_restart_information.parent = self
                            self._children_name_map["graceful_restart_information"] = "graceful-restart-information"
                            self._children_yang_names.add("graceful-restart-information")

                            self.address_family_parameter = YList(self)
                            self._segment_path = lambda: "parameters"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters, ['af_binding_withdraw_delay', 'discovery_quick_start_disabled_on_interfaces', 'global_discovery_quick_start_disabled', 'global_md5_password_enabled', 'hello_hold_time', 'hello_interval', 'housekeeping_timer_interval', 'igp_sync_delay_time_for_interface', 'igp_sync_delay_time_on_restart', 'keepalive_interval', 'ldp_out_of_mem_state', 'ldp_recovery_timeout', 'le_no_route_timeout', 'max_intf_attached', 'max_intf_te', 'max_peer', 'nsr_enabled', 'nsr_synced', 'protocol_version', 'role_is_active', 'router_id', 'session_hold_time', 'targeted_hello_hold_time', 'targeted_hello_interval'], name, value)


                        class AddressFamilyParameter(Entity):
                            """
                            Per AF parameters
                            
                            .. attribute:: address_family
                            
                            	Address Family
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: discovery_transport_address
                            
                            	Discovery transport address
                            	**type**\:   :py:class:`DiscoveryTransportAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress>`
                            
                            .. attribute:: is_accepting_targeted_hellos
                            
                            	Accepting targeted Hellos
                            	**type**\:  bool
                            
                            .. attribute:: label_imp_null_override_acl
                            
                            	ACL to override local label to use implicit\-null
                            	**type**\:  str
                            
                            .. attribute:: null_label
                            
                            	Null label
                            	**type**\:  str
                            
                            .. attribute:: targeted_hello_acl
                            
                            	Targeted Hello ACL
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter, self).__init__()

                                self.yang_name = "address-family-parameter"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"discovery-transport-address" : ("discovery_transport_address", MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress)}
                                self._child_list_classes = {}

                                self.address_family = YLeaf(YType.enumeration, "address-family")

                                self.is_accepting_targeted_hellos = YLeaf(YType.boolean, "is-accepting-targeted-hellos")

                                self.label_imp_null_override_acl = YLeaf(YType.str, "label-imp-null-override-acl")

                                self.null_label = YLeaf(YType.str, "null-label")

                                self.targeted_hello_acl = YLeaf(YType.str, "targeted-hello-acl")

                                self.discovery_transport_address = MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress()
                                self.discovery_transport_address.parent = self
                                self._children_name_map["discovery_transport_address"] = "discovery-transport-address"
                                self._children_yang_names.add("discovery-transport-address")
                                self._segment_path = lambda: "address-family-parameter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter, ['address_family', 'is_accepting_targeted_hellos', 'label_imp_null_override_acl', 'null_label', 'targeted_hello_acl'], name, value)


                            class DiscoveryTransportAddress(Entity):
                                """
                                Discovery transport address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`LdpAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAfId>`
                                
                                .. attribute:: dummy
                                
                                	No Address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, self).__init__()

                                    self.yang_name = "discovery-transport-address"
                                    self.yang_parent_name = "address-family-parameter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.dummy = YLeaf(YType.uint8, "dummy")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")
                                    self._segment_path = lambda: "discovery-transport-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.AddressFamilyParameter.DiscoveryTransportAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                        class GracefulRestartInformation(Entity):
                            """
                            Graceful restart information
                            
                            .. attribute:: graceful_restart_forwarding_state_hold_time
                            
                            	Graceful restart forward state hold time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_reconnect_timeout
                            
                            	Reconnect timeout value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_graceful_restart_configured
                            
                            	Is graceful restart configured
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation, self).__init__()

                                self.yang_name = "graceful-restart-information"
                                self.yang_parent_name = "parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.graceful_restart_forwarding_state_hold_time = YLeaf(YType.uint32, "graceful-restart-forwarding-state-hold-time")

                                self.graceful_restart_reconnect_timeout = YLeaf(YType.uint32, "graceful-restart-reconnect-timeout")

                                self.is_graceful_restart_configured = YLeaf(YType.boolean, "is-graceful-restart-configured")
                                self._segment_path = lambda: "graceful-restart-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Parameters.GracefulRestartInformation, ['graceful_restart_forwarding_state_hold_time', 'graceful_restart_reconnect_timeout', 'is_graceful_restart_configured'], name, value)


                    class Statistics(Entity):
                        """
                        The LDP Statistics
                        
                        .. attribute:: statistic
                        
                        	Statistical Information on a particular LDP neighbor
                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"statistic" : ("statistic", MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic)}

                            self.statistic = YList(self)
                            self._segment_path = lambda: "statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics, [], name, value)


                        class Statistic(Entity):
                            """
                            Statistical Information on a particular LDP
                            neighbor
                            
                            .. attribute:: iccp_enabled
                            
                            	Is session ICCP enabled?
                            	**type**\:  bool
                            
                            .. attribute:: label_space_id
                            
                            	Label space ID of neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: lsr_id
                            
                            	LSR ID of neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: message_in
                            
                            	Message in count
                            	**type**\:   :py:class:`MessageIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn>`
                            
                            .. attribute:: message_out
                            
                            	Message out count
                            	**type**\:   :py:class:`MessageOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut>`
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic, self).__init__()

                                self.yang_name = "statistic"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"message-in" : ("message_in", MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn), "message-out" : ("message_out", MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut)}
                                self._child_list_classes = {}

                                self.iccp_enabled = YLeaf(YType.boolean, "iccp-enabled")

                                self.label_space_id = YLeaf(YType.uint32, "label-space-id")

                                self.lsr_id = YLeaf(YType.str, "lsr-id")

                                self.message_in = MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn()
                                self.message_in.parent = self
                                self._children_name_map["message_in"] = "message-in"
                                self._children_yang_names.add("message-in")

                                self.message_out = MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut()
                                self.message_out.parent = self
                                self._children_name_map["message_out"] = "message-out"
                                self._children_yang_names.add("message-out")
                                self._segment_path = lambda: "statistic"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic, ['iccp_enabled', 'label_space_id', 'lsr_id'], name, value)


                            class MessageIn(Entity):
                                """
                                Message in count
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn, self).__init__()

                                    self.yang_name = "message-in"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_count = YLeaf(YType.uint32, "address-count")

                                    self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                    self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                    self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                    self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                    self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                    self.init_count = YLeaf(YType.uint32, "init-count")

                                    self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                    self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                    self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                    self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                    self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                    self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                    self.notification_count = YLeaf(YType.uint32, "notification-count")

                                    self.total_count = YLeaf(YType.uint32, "total-count")
                                    self._segment_path = lambda: "message-in"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageIn, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                            class MessageOut(Entity):
                                """
                                Message out count
                                
                                .. attribute:: address_count
                                
                                	Address message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_withdraw_count
                                
                                	Address withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_app_data_count
                                
                                	ICCP RG App Data count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_conn_count
                                
                                	ICCP RG Connect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_disconn_count
                                
                                	ICCP RG Disconnect count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: iccp_rg_notif_count
                                
                                	ICCP RG Notif count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: init_count
                                
                                	Init message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_count
                                
                                	Keepalive count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_abort_request_count
                                
                                	Label abort request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_map_count
                                
                                	Label map count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_release_count
                                
                                	Label release count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_request_count
                                
                                	Label request count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_withdraw_count
                                
                                	Label withdraw count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notification_count
                                
                                	Notification count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_count
                                
                                	Total message count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'mpls-ldp-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut, self).__init__()

                                    self.yang_name = "message-out"
                                    self.yang_parent_name = "statistic"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address_count = YLeaf(YType.uint32, "address-count")

                                    self.address_withdraw_count = YLeaf(YType.uint32, "address-withdraw-count")

                                    self.iccp_rg_app_data_count = YLeaf(YType.uint32, "iccp-rg-app-data-count")

                                    self.iccp_rg_conn_count = YLeaf(YType.uint32, "iccp-rg-conn-count")

                                    self.iccp_rg_disconn_count = YLeaf(YType.uint32, "iccp-rg-disconn-count")

                                    self.iccp_rg_notif_count = YLeaf(YType.uint32, "iccp-rg-notif-count")

                                    self.init_count = YLeaf(YType.uint32, "init-count")

                                    self.keep_alive_count = YLeaf(YType.uint32, "keep-alive-count")

                                    self.label_abort_request_count = YLeaf(YType.uint32, "label-abort-request-count")

                                    self.label_map_count = YLeaf(YType.uint32, "label-map-count")

                                    self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                    self.label_request_count = YLeaf(YType.uint32, "label-request-count")

                                    self.label_withdraw_count = YLeaf(YType.uint32, "label-withdraw-count")

                                    self.notification_count = YLeaf(YType.uint32, "notification-count")

                                    self.total_count = YLeaf(YType.uint32, "total-count")
                                    self._segment_path = lambda: "message-out"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Statistics.Statistic.MessageOut, ['address_count', 'address_withdraw_count', 'iccp_rg_app_data_count', 'iccp_rg_conn_count', 'iccp_rg_disconn_count', 'iccp_rg_notif_count', 'init_count', 'keep_alive_count', 'label_abort_request_count', 'label_map_count', 'label_release_count', 'label_request_count', 'label_withdraw_count', 'notification_count', 'total_count'], name, value)


                    class Summary(Entity):
                        """
                        LDP VRF summary
                        
                        .. attribute:: common
                        
                        	Common Summary information
                        	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf>`
                        
                        

                        """

                        _prefix = 'mpls-ldp-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"common" : ("common", MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common), "vrf" : ("vrf", MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf)}
                            self._child_list_classes = {}

                            self.common = MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common()
                            self.common.parent = self
                            self._children_name_map["common"] = "common"
                            self._children_yang_names.add("common")

                            self.vrf = MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "summary"


                        class Common(Entity):
                            """
                            Common Summary information
                            
                            .. attribute:: address_families
                            
                            	Address Families enabled
                            	**type**\:   :py:class:`LdpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_ldp_oper.LdpAf>`
                            
                            .. attribute:: number_of_bindings_ipv4
                            
                            	Total number of ipv4 bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_bindings_ipv6
                            
                            	Total number of ipv6 bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_downstream_on_demand_neighbors
                            
                            	Number of Downstream\-On\-Demand neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_graceful_restart_neighbors
                            
                            	Number of Graceful Restart neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_hello_adj
                            
                            	Number of LDP discovery IPv4 hello adjacencies
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_local_addresses
                            
                            	Number of IPv4 local addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4_routes
                            
                            	Number of resolved IPv4 routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4af
                            
                            	Number of IPv4 address\-families enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv4ldp_interfaces
                            
                            	Number of LDP IPv4 configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_hello_adj
                            
                            	Number of LDP discovery IPv6 hello adjacencies
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_local_addresses
                            
                            	Number of IPv6 local addresses
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6_routes
                            
                            	Number of resolved IPv6 routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6af
                            
                            	Number of IPv6 address\-families enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ipv6ldp_interfaces
                            
                            	Number of LDP IPv6 configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_ldp_interfaces
                            
                            	Number of LDP configured interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv4
                            
                            	Total number of ipv4 local label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_local_bindings_ipv6
                            
                            	Total number of ipv6 local label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_neighbors
                            
                            	Number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_nsr_synced_neighbors
                            
                            	Number of NSR\-synced/operational neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv4
                            
                            	Total number of ipv4 remote label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_remote_bindings_ipv6
                            
                            	Total number of ipv6 remote label bindings
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common, self).__init__()

                                self.yang_name = "common"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address_families = YLeaf(YType.enumeration, "address-families")

                                self.number_of_bindings_ipv4 = YLeaf(YType.uint32, "number-of-bindings-ipv4")

                                self.number_of_bindings_ipv6 = YLeaf(YType.uint32, "number-of-bindings-ipv6")

                                self.number_of_downstream_on_demand_neighbors = YLeaf(YType.uint32, "number-of-downstream-on-demand-neighbors")

                                self.number_of_graceful_restart_neighbors = YLeaf(YType.uint32, "number-of-graceful-restart-neighbors")

                                self.number_of_ipv4_hello_adj = YLeaf(YType.uint32, "number-of-ipv4-hello-adj")

                                self.number_of_ipv4_local_addresses = YLeaf(YType.uint32, "number-of-ipv4-local-addresses")

                                self.number_of_ipv4_routes = YLeaf(YType.uint32, "number-of-ipv4-routes")

                                self.number_of_ipv4af = YLeaf(YType.uint32, "number-of-ipv4af")

                                self.number_of_ipv4ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv4ldp-interfaces")

                                self.number_of_ipv6_hello_adj = YLeaf(YType.uint32, "number-of-ipv6-hello-adj")

                                self.number_of_ipv6_local_addresses = YLeaf(YType.uint32, "number-of-ipv6-local-addresses")

                                self.number_of_ipv6_routes = YLeaf(YType.uint32, "number-of-ipv6-routes")

                                self.number_of_ipv6af = YLeaf(YType.uint32, "number-of-ipv6af")

                                self.number_of_ipv6ldp_interfaces = YLeaf(YType.uint32, "number-of-ipv6ldp-interfaces")

                                self.number_of_ldp_interfaces = YLeaf(YType.uint32, "number-of-ldp-interfaces")

                                self.number_of_local_bindings_ipv4 = YLeaf(YType.uint32, "number-of-local-bindings-ipv4")

                                self.number_of_local_bindings_ipv6 = YLeaf(YType.uint32, "number-of-local-bindings-ipv6")

                                self.number_of_neighbors = YLeaf(YType.uint32, "number-of-neighbors")

                                self.number_of_nsr_synced_neighbors = YLeaf(YType.uint32, "number-of-nsr-synced-neighbors")

                                self.number_of_remote_bindings_ipv4 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv4")

                                self.number_of_remote_bindings_ipv6 = YLeaf(YType.uint32, "number-of-remote-bindings-ipv6")
                                self._segment_path = lambda: "common"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Common, ['address_families', 'number_of_bindings_ipv4', 'number_of_bindings_ipv6', 'number_of_downstream_on_demand_neighbors', 'number_of_graceful_restart_neighbors', 'number_of_ipv4_hello_adj', 'number_of_ipv4_local_addresses', 'number_of_ipv4_routes', 'number_of_ipv4af', 'number_of_ipv4ldp_interfaces', 'number_of_ipv6_hello_adj', 'number_of_ipv6_local_addresses', 'number_of_ipv6_routes', 'number_of_ipv6af', 'number_of_ipv6ldp_interfaces', 'number_of_ldp_interfaces', 'number_of_local_bindings_ipv4', 'number_of_local_bindings_ipv6', 'number_of_neighbors', 'number_of_nsr_synced_neighbors', 'number_of_remote_bindings_ipv4', 'number_of_remote_bindings_ipv6'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: id
                            
                            	VRF Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'mpls-ldp-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.id = YLeaf(YType.uint32, "id")

                                self.name = YLeaf(YType.str, "name")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsLdp.Nodes.Node.Vrfs.Vrf.Summary.Vrf, ['id', 'name'], name, value)

    def clone_ptr(self):
        self._top_entity = MplsLdp()
        return self._top_entity

